@@ -118,7 +118,7 @@ class IntegrationGenericTests(unittest.TestCase):
         self.connect_worker()
 
         create_work_request_output = Client.execute_command(
-            "create-work-request", self.TASK_NAME, stdin="foo: bar"
+            "work-request", "create", "--yaml", self.TASK_NAME, stdin="foo: bar"
         )
 
         # Work Request is registered
@@ -174,15 +174,19 @@ class IntegrationGenericTests(unittest.TestCase):
         Create work request, assert creation and wait for the work request
         to be completed. Assert expected_status and expected_result.
         """
-        create_work_request_output = Client.execute_command(
-            'create-work-request', self.TASK_NAME, stdin=task_data
+        original_start_latency_count = DebusineServer.get_metric(
+            metric_name="debusine_work_request_start_latency",
+            sample_name="debusine_work_request_start_latency_count",
+            task_type="Worker",
+            task_name=self.TASK_NAME,
+            priority="normal",
         )
 
-        # Work Request is registered
-        self.assertEqual(create_work_request_output['result'], 'success')
-        self.assertIn('registered', create_work_request_output['message'])
+        create_work_request_output = Client.execute_command(
+            "work-request", "create", "--yaml", self.TASK_NAME, stdin=task_data
+        )
 
-        work_request_id = create_work_request_output['work_request_id']
+        work_request_id = create_work_request_output["id"]
 
         # The client will check the status of the created request
         show_work_request_output = Client.execute_command(
@@ -193,9 +197,9 @@ class IntegrationGenericTests(unittest.TestCase):
         self.assertEqual(show_work_request_output['task_name'], self.TASK_NAME)
 
         # Task data is as submitted
-        self.assertEqual(
-            show_work_request_output['task_data'], yaml.safe_load(task_data)
-        )
+        actual_task_data = show_work_request_output['task_data'].copy()
+        self.assertIsInstance(actual_task_data.pop("task_configuration"), int)
+        self.assertEqual(actual_task_data, yaml.safe_load(task_data))
 
         # The worker should get the new work request and start executing it
         Client.wait_for_work_request_completed(work_request_id, expected_result)
@@ -208,6 +212,18 @@ class IntegrationGenericTests(unittest.TestCase):
         self.assertEqual(show_work_request_output["status"], expected_status)
         self.assertEqual(show_work_request_output["result"], expected_result)
 
+        # Metrics are recorded
+        new_start_latency_count = DebusineServer.get_metric(
+            metric_name="debusine_work_request_start_latency",
+            sample_name="debusine_work_request_start_latency_count",
+            task_type="Worker",
+            task_name=self.TASK_NAME,
+            priority="normal",
+        )
+        self.assertEqual(
+            new_start_latency_count, (original_start_latency_count or 0.0) + 1
+        )
+
     def test_web_login(self) -> None:
         """
         Ensure the web interface is accessible after login.
