@@ -1,4 +1,4 @@
-# Copyright 2022 The Debusine Developers
+# Copyright © The Debusine Developers
 # See the AUTHORS file at the top-level directory of this distribution
 #
 # This file is part of Debusine. It is subject to the license terms
@@ -7,6 +7,7 @@
 # modified, propagated, or distributed except according to the terms
 # contained in the LICENSE file.
 """Debusine client controller."""
+
 import json
 import logging
 import os
@@ -119,8 +120,8 @@ class Client:
             Path(result_file.name).read_text().split(",")
         )
 
-        assert (
-            int(work_request_completed_id) == work_request_id
-        ), "Unexpected work request finished"
+        assert int(work_request_completed_id) == work_request_id, (
+            "Unexpected work request finished"
+        )
 
         return result == expected_result
