@@ -12,12 +12,9 @@
 import abc
 import enum
 import urllib.parse
-from typing import Any, Literal, TypeAlias, cast
+from typing import Annotated, Any, Literal, Self, TypeAlias, cast
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
+import pydantic
 
 from debusine.assets import KeyPurpose
 from debusine.utils import DjangoChoicesEnum
@@ -52,16 +49,14 @@ class WorkRequestResults(DjangoChoicesEnum):
 class BaseArtifactDataModel(pydantic.BaseModel):
     """Base pydantic model for bare/artifact data and their components."""
 
-    class Config:
-        """Set up stricter pydantic Config."""
+    model_config = pydantic.ConfigDict(validate_assignment=True, extra="forbid")
 
-        validate_assignment = True
-        extra = "forbid"
-
-    def dict(self, **kwargs: Any) -> dict[str, Any]:
+    # Replace with serialize_by_alias=True in model_config once we can
+    # assume pydantic >= 2.11.
+    def model_dump(self, **kwargs: Any) -> dict[str, Any]:
         """Use aliases by default when serializing."""
         kwargs.setdefault("by_alias", True)
-        return super().dict(**kwargs)
+        return super().model_dump(**kwargs)
 
 
 class BareDataCategory(enum.StrEnum):
@@ -84,27 +79,22 @@ class DebusinePromise(BaseArtifactDataModel):
     promise_workflow_id: int
     promise_category: str
 
-    class Config(BaseArtifactDataModel.Config):
-        """Allow extra fields."""
+    # Allow extra fields.
+    model_config = BaseArtifactDataModel.model_config | pydantic.ConfigDict(
+        extra="allow"
+    )
 
-        extra = "allow"
-
-    @pydantic.root_validator(pre=True)
-    @classmethod
-    def check_no_extra_names_starting_promise(
-        cls, values: dict[str, Any]
-    ) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def check_no_extra_names_starting_promise(self) -> Self:
         r"""Forbid extra field names starting with 'promise\\_'."""
-        allowed_promise_fields = cls.__fields__.keys()
-
-        for key in values:
-            if key.startswith("promise_") and key not in allowed_promise_fields:
+        for key in self.model_extra or {}:
+            if key.startswith("promise_"):
                 raise ValueError(
                     f"Field name '{key}' starting with "
                     f"'promise_' is not allowed."
                 )
 
-        return values
+        return self
 
 
 class RuntimeStatistics(BaseArtifactDataModel):
@@ -167,10 +157,16 @@ class DebusineTaskConfiguration(BaseArtifactDataModel):
     # changed accordingly, to preserve compatibility with old clients
 
     task_type: TaskTypes | None = None
-    task_name: str | None = None
-    subject: str | None = None
+    task_name: Annotated[
+        str | None, pydantic.AfterValidator(_validate_no_colons)
+    ] = None
+    subject: Annotated[
+        str | None, pydantic.AfterValidator(_validate_no_colons)
+    ] = None
     context: str | None = None
-    template: str | None = None
+    template: Annotated[
+        str | None, pydantic.AfterValidator(_validate_no_colons)
+    ] = None
 
     use_templates: list[str] = []
     delete_values: list[str] = []
@@ -213,25 +209,14 @@ class DebusineTaskConfiguration(BaseArtifactDataModel):
             names.append(f"{task_type}:{task_name}:{subject}:{context_encoded}")
         return names
 
-    _validate_task_name = pydantic.validator("task_name", allow_reuse=True)(
-        _validate_no_colons
-    )
-    _validate_subject = pydantic.validator("subject", allow_reuse=True)(
-        _validate_no_colons
-    )
-    _validate_template = pydantic.validator("template", allow_reuse=True)(
-        _validate_no_colons
-    )
-
-    @pydantic.root_validator(allow_reuse=True)
-    @classmethod
-    def template_or_task_match(cls, values: dict[str, Any]) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def template_or_task_match(self) -> Self:
         """Ensure we have either template or the other 4 match fields."""
-        if values.get("template"):
+        if self.template:
             present: list[str] = [
                 name
                 for name in ("task_type", "task_name", "subject", "context")
-                if values.get(name)
+                if getattr(self, name)
             ]
             if present:
                 raise ValueError(
@@ -241,14 +226,14 @@ class DebusineTaskConfiguration(BaseArtifactDataModel):
             missing: list[str] = [
                 name
                 for name in ("task_type", "task_name")
-                if not values.get(name)
+                if not getattr(self, name)
             ]
             if missing:
                 raise ValueError(
                     f"{', '.join(missing)} should be set for non-template"
                     " task configuration entries"
                 )
-        return values
+        return self
 
 
 class DebianQAResult(BaseArtifactDataModel):
@@ -339,10 +324,10 @@ class EmptyArtifactData(ArtifactData):
 class DoseDistCheckHyphenize(BaseArtifactDataModel):
     """Fix dose3 field convention that uses Python-incompatible hyphens."""
 
-    class Config:
-        """Replace all _ by - in fields."""
-
-        alias_generator = lambda x: x.replace("_", "-")  # noqa: E731
+    # Replace all _ by - in fields.
+    model_config = BaseArtifactDataModel.model_config | pydantic.ConfigDict(
+        alias_generator=lambda x: x.replace("_", "-")
+    )
 
 
 class DoseDistCheckBasePkg(BaseArtifactDataModel):
@@ -486,7 +471,7 @@ class DebianUpload(ArtifactData):
     def _changes_filenames(changes_fields: dict[str, Any]) -> list[str]:
         return [file["name"] for file in changes_fields["Files"]]
 
-    @pydantic.validator("changes_fields")
+    @pydantic.field_validator("changes_fields", mode="after")
     @classmethod
     def metadata_mandatory_fields(cls, data: dict[str, Any]) -> dict[str, Any]:
         """Validate that changes_fields contains Architecture and Files."""
@@ -496,7 +481,7 @@ class DebianUpload(ArtifactData):
             raise ValueError("changes_fields must contain Files")
         return data
 
-    @pydantic.validator("changes_fields")
+    @pydantic.field_validator("changes_fields")
     @classmethod
     def metadata_contains_debs_if_binary(
         cls, data: dict[str, Any]
@@ -525,7 +510,7 @@ class DebianUpload(ArtifactData):
             )
         return data
 
-    @pydantic.validator("changes_fields")
+    @pydantic.field_validator("changes_fields")
     @classmethod
     def metadata_contains_dsc_if_source(
         cls, data: dict[str, Any]
@@ -608,7 +593,7 @@ class DebianSystemTarball(ArtifactData):
     codename: str
     mirror: pydantic.AnyUrl
     components: list[str]
-    variant: str | None
+    variant: str | None = None
     pkglist: dict[str, str]
     architecture: str
     with_dev: bool
@@ -739,17 +724,14 @@ class SigningResult(BaseArtifactDataModel):
     output_file: str | None = None
     error_message: str | None = None
 
-    @pydantic.root_validator(allow_reuse=True)
-    @classmethod
-    def check_exactly_one_result(cls, values: dict[str, Any]) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def check_exactly_one_result(self) -> Self:
         """Ensure exactly one of output_file and error_message is present."""
-        if (values.get("output_file") is None) == (
-            values.get("error_message") is None
-        ):
+        if (self.output_file is None) == (self.error_message is None):
             raise ValueError(
                 "Exactly one of output_file and error_message must be set"
             )
-        return values
+        return self
 
 
 class DebusineSigningOutput(ArtifactData):
