@@ -330,19 +330,16 @@ class ArtifactPlayground:
             case deb822.Dsc:
                 if binaries is None:
                     binaries = [source]
-                changes_contents += (
-                    textwrap.dedent(
-                        f"""\
-                        Binary: {', '.join(binaries)}
-                        Homepage: http://www.gnu.org/software/{source}/
-                        Standards-Version: 4.3.0
-                        Package-List:
-                        """
-                    )
-                    + "".join(
-                        f" {binary} deb devel optional arch=any\n"
-                        for binary in binaries
-                    )
+                changes_contents += textwrap.dedent(
+                    f"""\
+                    Binary: {', '.join(binaries)}
+                    Homepage: http://www.gnu.org/software/{source}/
+                    Standards-Version: 4.3.0
+                    Package-List:
+                    """
+                ) + "".join(
+                    f" {binary} deb devel optional arch=any\n"
+                    for binary in binaries
                 )
             case deb822.Changes:
                 timestamp = dt.datetime(
