@@ -11,7 +11,6 @@
 
 import hashlib
 import logging
-import os
 import sys
 from collections.abc import Callable, Generator, Iterable
 from contextlib import contextmanager
@@ -32,6 +31,7 @@ from debusine.artifacts import (
     Upload,
 )
 from debusine.client import exceptions
+from debusine.utils.urls import URLPath
 
 SOURCE_PACKAGE_HASHES = ("sha256", "sha1", "md5")
 log = logging.getLogger(__name__)
@@ -287,7 +287,7 @@ def get_debian_package(path: str) -> Generator[Path]:
         with TemporaryDirectory(prefix="debusine-import-") as td:
             work_path = Path(td)
             dget(path, work_path)
-            yield work_path / os.path.basename(parsed.path)
+            yield work_path / URLPath(parsed.path)[-1]
     else:
         raise ValueError(f"Not a supported URL scheme: {path}")
 
