@@ -23,7 +23,7 @@ from collections import defaultdict
 from collections.abc import Generator, Iterable
 from contextlib import contextmanager
 from pathlib import Path
-from typing import Any, ClassVar, Generic, NoReturn, Optional, TextIO, TypeVar
+from typing import Any, ClassVar, NoReturn, Optional, TextIO
 
 import rich.console
 import rich.json
@@ -36,13 +36,7 @@ from debusine.client.client_utils import copy_file
 from debusine.client.config import ConfigHandler
 from debusine.client.debusine import Debusine
 from debusine.client.exceptions import DebusineError
-from debusine.client.models import (
-    FileResponse,
-    StrictBaseModel,
-    model_to_json_serializable_dict,
-)
-
-Model = TypeVar("Model", bound=StrictBaseModel)
+from debusine.client.models import FileResponse, StrictBaseModel
 
 
 def _get_help(obj: Any) -> str | None:
@@ -99,8 +93,11 @@ class Command(abc.ABC):
         cls.deprecated = deprecated
         cls.commands_by_group[group].append(cls)
 
-    def __init__(self, args: argparse.Namespace) -> None:
+    def __init__(
+        self, parser: argparse.ArgumentParser, args: argparse.Namespace
+    ) -> None:
         """Make the parsed arguments available as ``self.args``."""
+        self.argument_parser = parser
         self.args = args
         self.yaml_in_input = False
         if self.args.yaml:
@@ -158,7 +155,9 @@ class Command(abc.ABC):
             command_cls.configure(subparser)
 
     @classmethod
-    def create(cls, args: argparse.Namespace) -> Optional["Command"]:
+    def create(
+        cls, parser: argparse.ArgumentParser, args: argparse.Namespace
+    ) -> Optional["Command"]:
         """
         Run the command activated by the parsed command line.
 
@@ -168,7 +167,7 @@ class Command(abc.ABC):
         if (command_cls := getattr(args, "command_cls", None)) is not None:
             assert isinstance(command_cls, type)
             assert issubclass(command_cls, Command)
-            return command_cls(args)
+            return command_cls(parser, args)
         return None
 
     @classmethod
@@ -298,10 +297,9 @@ class Command(abc.ABC):
                 summary="Fix the YAML data",
             )
 
-        if (data_type := type(data)) != dict:
+        if (data_type := type(data)) is not dict:
             cls._fail(
-                f"Error: data must be a dictionary. "
-                f"It is: {data_type.__name__}"
+                f"Error: data must be a dictionary. It is: {data_type.__name__}"
             )
 
         assert isinstance(data, dict)
@@ -417,9 +415,11 @@ class DebusineCommand(Command, abc.ABC):
                     f"= {expected_value})"
                 )
 
-    def __init__(self, args: argparse.Namespace) -> None:
+    def __init__(
+        self, parser: argparse.ArgumentParser, args: argparse.Namespace
+    ) -> None:
         """Make the parsed arguments available as ``self.args``."""
-        super().__init__(args)
+        super().__init__(parser, args)
         server_name: str | None = os.environ.get("DEBUSINE_SERVER_NAME")
         if self.args.server is not None:
             server_name = self.args.server
@@ -456,9 +456,11 @@ class WorkspaceCommand(DebusineCommand, abc.ABC):
             help="Workspace name",
         )
 
-    def __init__(self, args: argparse.Namespace) -> None:
+    def __init__(
+        self, parser: argparse.ArgumentParser, args: argparse.Namespace
+    ) -> None:
         """Populate self.workspace."""
-        super().__init__(args)
+        super().__init__(parser, args)
         if args.workspace is None:
             configured_default = self.server_configuration.default_workspace
             self.workspace = configured_default or "System"
@@ -468,16 +470,14 @@ class WorkspaceCommand(DebusineCommand, abc.ABC):
             self.workspace_arg_set = True
 
 
-class ModelCommand(Command, abc.ABC, Generic[Model]):
+class ModelCommand[Model: StrictBaseModel](Command, abc.ABC):
     """Base for commands that list and show client models."""
 
     def _list_yaml(self, instances: Iterable[Model]) -> None:
         """Print the list as YAML."""
         if self.yaml_in_input:
             print("---")  # avoid confusion between input and output
-        self._print_yaml(
-            [model_to_json_serializable_dict(i) for i in instances]
-        )
+        self._print_yaml([i.model_dump(mode="json") for i in instances])
 
     @abc.abstractmethod
     def _list_rich(self, instances: Iterable[Model]) -> None:
@@ -494,7 +494,7 @@ class ModelCommand(Command, abc.ABC, Generic[Model]):
         """Show an instance in machine parsable YAML."""
         if self.yaml_in_input:
             print("---")  # avoid confusion between input and output
-        self._print_yaml(model_to_json_serializable_dict(instance))
+        self._print_yaml(instance.model_dump(mode="json"))
 
     @abc.abstractmethod
     def _show_rich(self, instance: Model) -> None:
@@ -552,9 +552,11 @@ class OptionalInputDataCommand(InputDataCommand, abc.ABC):
     #: Parsed YAML data
     input_data: dict[str, Any] | None
 
-    def __init__(self, args: argparse.Namespace) -> None:
+    def __init__(
+        self, parser: argparse.ArgumentParser, args: argparse.Namespace
+    ) -> None:
         """Read YAML data from input."""
-        super().__init__(args)
+        super().__init__(parser, args)
         if self.args.data is None:
             self.input_data = None
         else:
@@ -579,9 +581,11 @@ class RequiredInputDataCommand(InputDataCommand, abc.ABC):
     #: Parsed YAML data
     input_data: dict[str, Any]
 
-    def __init__(self, args: argparse.Namespace) -> None:
+    def __init__(
+        self, parser: argparse.ArgumentParser, args: argparse.Namespace
+    ) -> None:
         """Read YAML data from input."""
-        super().__init__(args)
+        super().__init__(parser, args)
         self.input_data = self.read_input_data(self.args.data)
 
     @classmethod
