@@ -9,12 +9,16 @@
 
 """Tests for the debusine Cli Collection commands."""
 
+import re
 from functools import partial
 from unittest import mock
 
 from debusine.artifacts.models import CollectionCategory
 from debusine.client.commands.base import Command, DebusineCommand
-from debusine.client.commands.collections import CollectionCommand
+from debusine.client.commands.collections import (
+    CollectionCommand,
+    SingleCollectionCommand,
+)
 from debusine.client.commands.tests.base import BaseCliTests
 from debusine.client.models import CollectionData, CollectionDataNew
 
@@ -31,31 +35,31 @@ class CollectionCommandTests(BaseCliTests):
             full_history_retention_period=7,
             metadata_only_retention_period=14,
             data={"test": 2},
+            links={
+                "webui_self": "/c/42",
+                "webui_category": "/c/suite",
+            },
         )
 
     @Command.preserve_registry()
     def _command(self) -> CollectionCommand:
-
         class ConcreteCollectionCommand(CollectionCommand):
             """Version of CollectionCommand that can be instantiated."""
 
             def run(self) -> None:
                 raise NotImplementedError()
 
-        return ConcreteCollectionCommand(
-            self.build_parsed_namespace(workspace="workspace")
-        )
+        return self.command(ConcreteCollectionCommand, workspace="workspace")
 
     def test_markup_category(self) -> None:
         command = self._command()
         self.assertEqual(
-            command.markup_category("debian:suite"),
-            "[link=https://debusine.debian.org/debian/workspace/collection/"
-            "debian%3Asuite/]debian:suite[/]",
+            command.markup_category(self.data),
+            "[link=https://debusine.debian.org/c/suite]debian:suite[/]",
         )
+        self.data.category = CollectionCategory.WORKFLOW_INTERNAL
         self.assertEqual(
-            command.markup_category("debusine:workflow-internal"),
-            "debusine:workflow-internal",
+            command.markup_category(self.data), "debusine:workflow-internal"
         )
 
     def test_list_rich(self) -> None:
@@ -78,14 +82,8 @@ class CollectionCommandTests(BaseCliTests):
         rich_print.assert_called_once()
 
         self.assertEqual(table.add_row.call_count, 1)
-        url = (
-            "https://debusine.debian.org/debian/workspace/"
-            "collection/debian%3Asuite/sid/"
-        )
-        category_url = (
-            "https://debusine.debian.org/debian/workspace/"
-            "collection/debian%3Asuite/"
-        )
+        url = "https://debusine.debian.org/c/42"
+        category_url = "https://debusine.debian.org/c/suite"
         call = table.add_row.call_args_list[0]
         self.assertEqual(call.args[0], "42")
         self.assertEqual(call.args[1], f"[link={url}]sid[/]")
@@ -114,14 +112,8 @@ class CollectionCommandTests(BaseCliTests):
         rich_print.assert_called_once()
 
         self.assertEqual(table.add_row.call_count, 6)
-        url = (
-            "https://debusine.debian.org/debian/workspace/"
-            "collection/debian%3Asuite/sid/"
-        )
-        category_url = (
-            "https://debusine.debian.org/debian/workspace/"
-            "collection/debian%3Asuite/"
-        )
+        url = "https://debusine.debian.org/c/42"
+        category_url = "https://debusine.debian.org/c/suite"
         rows = [
             call_args_list.args
             for call_args_list in table.add_row.call_args_list
@@ -159,14 +151,8 @@ class CollectionCommandTests(BaseCliTests):
         rich_print.assert_called_once()
 
         self.assertEqual(table.add_row.call_count, 7)
-        url = (
-            "https://debusine.debian.org/debian/workspace/"
-            "collection/debian%3Asuite/sid/"
-        )
-        category_url = (
-            "https://debusine.debian.org/debian/workspace/"
-            "collection/debian%3Asuite/"
-        )
+        url = "https://debusine.debian.org/c/42"
+        category_url = "https://debusine.debian.org/c/suite"
         rows = [
             call_args_list.args
             for call_args_list in table.add_row.call_args_list
@@ -182,6 +168,80 @@ class CollectionCommandTests(BaseCliTests):
         self.assertEqual(rows[6], ("Stats:", self.data.stats))
 
 
+class SingleCollectionCommandTests(BaseCliTests):
+    """Tests for the :py:class:`SingleCollectionCommand` class."""
+
+    @Command.preserve_registry()
+    def _command(
+        self, category_or_fullname: str, name: str | None = None
+    ) -> SingleCollectionCommand:
+        class ConcreteCollectionCommand(SingleCollectionCommand):
+            """Version of SingleCollectionCommand that can be instantiated."""
+
+            def run(self) -> None:
+                raise NotImplementedError()
+
+        return self.command(
+            ConcreteCollectionCommand,
+            workspace="workspace",
+            category_or_fullname=category_or_fullname,
+            name=name,
+        )
+
+    def test_missing_name(self) -> None:
+        for arg in ("debian:suite", "debian:archive", "invalid"):
+            with self.subTest(arg=arg):
+                command = self._command(arg)
+                self.assertEqual(command.collection_category, arg)
+                self.assertEqual(command.collection_name, "_")
+
+    def test_full_name(self) -> None:
+        for arg in (
+            "sid@debian:suite",
+            "_@debian:suite",
+            "sid@debian:archive",
+            "_@debian:archive",
+        ):
+            with self.subTest(arg=arg):
+                command = self._command(arg)
+                name, category = arg.split("@")
+                self.assertEqual(command.collection_category, category)
+                self.assertEqual(command.collection_name, name)
+
+    def test_separate_name(self) -> None:
+        for category, name in (
+            ("debian:archive", "_"),
+            ("debian:suite", "_"),
+            ("debian:archive", "sid"),
+            ("debian:suite", "sid"),
+        ):
+            with self.subTest(category=category, name=name):
+                command = self._command(category, name)
+                self.assertEqual(command.collection_category, category)
+                self.assertEqual(command.collection_name, name)
+
+    def test_name_given_twice(self) -> None:
+        for category, name in (
+            ("_@debian:archive", "_"),
+            ("_@debian:suite", "_"),
+            ("sid@debian:archive", "sid"),
+            ("sid@debian:suite", "sid"),
+            ("a@debian:suite", "b"),
+            ("a@debian:suite", "b"),
+        ):
+            with self.subTest(category=category, name=name):
+                stderr, _ = self.capture_output(
+                    partial(self._command, category, name),
+                    assert_system_exit_code=2,
+                )
+                self.assertRegex(
+                    stderr,
+                    "collection name is given"
+                    f" both in `{re.escape(category)}`"
+                    " and in the name argument",
+                )
+
+
 class ListTests(BaseCliTests):
     """Tests for the :py:class:`collections.List` class."""
 
@@ -274,7 +334,7 @@ class CreateTests(BaseCliTests):
         )
         assert isinstance(command, DebusineCommand)
 
-        created = CollectionData(id=42, **self.sent.dict())
+        created = CollectionData(id=42, **self.sent.model_dump())
         with (
             mock.patch.object(
                 command.debusine, "collection_create", return_value=created
@@ -324,7 +384,7 @@ class CreateTests(BaseCliTests):
         self.assertCreates("--data=-")
 
     def test_invalid_period(self) -> None:
-        stderr, stdout = self.capture_output(
+        stderr, _ = self.capture_output(
             partial(
                 self.create_command,
                 [
@@ -358,7 +418,7 @@ class ManageTests(BaseCliTests):
             metadata_only_retention_period=14,
             data={"test": 2},
         )
-        self.edited = self.sample.copy()
+        self.edited = self.sample.model_copy()
 
     def assertManages(self, *args: str) -> None:
         """Call collection_update with the given arguments match self.edited."""
@@ -422,7 +482,7 @@ class ManageTests(BaseCliTests):
         self.assertManages("--data=-")
 
     def test_invalid_period(self) -> None:
-        stderr, stdout = self.capture_output(
+        stderr, _ = self.capture_output(
             partial(
                 self.create_command,
                 [
