@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Tests for the debusine Cli task configuration commands."""
+
 import os
 from functools import partial
 from pathlib import Path
@@ -176,7 +177,7 @@ class CliTaskConfigPullPushTests(BaseCliTests):
     def test_pull_workspace_must_match_checkout(self) -> None:
         self.write_file(
             Path("MANIFEST"),
-            self.manifest(workspace="workspace", name="name").dict(),
+            self.manifest(workspace="workspace", name="name").model_dump(),
         )
         stderr, stdout = self.capture_output(
             partial(
@@ -203,7 +204,7 @@ class CliTaskConfigPullPushTests(BaseCliTests):
     def test_pull_collection_must_match_checkout_ok(self) -> None:
         self.write_file(
             Path("MANIFEST"),
-            self.manifest(workspace="workspace", name="name").dict(),
+            self.manifest(workspace="workspace", name="name").model_dump(),
         )
         stderr, stdout = self.capture_output(
             partial(
@@ -224,7 +225,7 @@ class CliTaskConfigPullPushTests(BaseCliTests):
     def test_pull_collection_must_match_checkout_fail(self) -> None:
         self.write_file(
             Path("MANIFEST"),
-            self.manifest(workspace="workspace", name="name").dict(),
+            self.manifest(workspace="workspace", name="name").model_dump(),
         )
         stderr, stdout = self.capture_output(
             partial(
@@ -283,9 +284,11 @@ class CliTaskConfigPullPushTests(BaseCliTests):
             ],
         )
 
-        self.assertFileContents(path_manifest, server_repo.manifest.dict())
-        self.assertFileContents(path_template, self.template.dict())
-        self.assertFileContents(path_config1, self.config1.dict())
+        self.assertFileContents(
+            path_manifest, server_repo.manifest.model_dump()
+        )
+        self.assertFileContents(path_template, self.template.model_dump())
+        self.assertFileContents(path_config1, self.config1.model_dump())
 
     def test_pull_existing_repo(self) -> None:
         server_repo = self.make_remote_repo()
@@ -293,13 +296,13 @@ class CliTaskConfigPullPushTests(BaseCliTests):
         server_repo.add(self.template)
         self.mock_fetch(repo=server_repo)
         self.write_file(
-            path_manifest := Path("MANIFEST"), server_repo.manifest.dict()
+            path_manifest := Path("MANIFEST"), server_repo.manifest.model_dump()
         )
         self.write_file(
-            path_config1 := Path("config.yaml"), self.config1.dict()
+            path_config1 := Path("config.yaml"), self.config1.model_dump()
         )
         self.write_file(
-            path_template := Path("template.yaml"), self.template.dict()
+            path_template := Path("template.yaml"), self.template.model_dump()
         )
         cli = self.create_cli(
             ["task-config", "pull", "--workdir", self.workdir.as_posix()]
@@ -324,19 +327,21 @@ class CliTaskConfigPullPushTests(BaseCliTests):
             ],
         )
 
-        self.assertFileContents(path_manifest, server_repo.manifest.dict())
-        self.assertFileContents(path_template, self.template.dict())
-        self.assertFileContents(path_config1, self.config1.dict())
+        self.assertFileContents(
+            path_manifest, server_repo.manifest.model_dump()
+        )
+        self.assertFileContents(path_template, self.template.model_dump())
+        self.assertFileContents(path_config1, self.config1.model_dump())
 
     def test_pull_repo_manifest_mismatch(self) -> None:
         server_repo = self.make_remote_repo()
         server_repo.add(self.config2)
         self.mock_fetch(repo=server_repo)
-        local_manifest = server_repo.manifest.dict()
+        local_manifest = server_repo.manifest.model_dump()
         local_manifest["workspace"] = "other"
         self.write_file(path_manifest := Path("MANIFEST"), local_manifest)
         self.write_file(
-            path_config1 := Path("config.yaml"), self.config1.dict()
+            path_config1 := Path("config.yaml"), self.config1.model_dump()
         )
         cli = self.create_cli(
             [
@@ -431,8 +436,8 @@ class CliTaskConfigPullPushTests(BaseCliTests):
         server_repo = self.make_remote_repo()
         self.mock_fetch(repo=server_repo)
         push_method = self.mock_push()
-        self.write_file(Path("MANIFEST"), self.manifest().dict())
-        self.write_file(Path("config.yaml"), self.config1.dict())
+        self.write_file(Path("MANIFEST"), self.manifest().model_dump())
+        self.write_file(Path("config.yaml"), self.config1.model_dump())
         cli = self.create_cli(
             ["task-config", "push", "--workdir", self.workdir.as_posix()]
         )
@@ -460,8 +465,8 @@ class CliTaskConfigPullPushTests(BaseCliTests):
         server_repo = self.make_remote_repo()
         self.mock_fetch(repo=server_repo)
         push_method = self.mock_push()
-        self.write_file(Path("MANIFEST"), self.manifest().dict())
-        self.write_file(Path("config.yaml"), self.config1.dict())
+        self.write_file(Path("MANIFEST"), self.manifest().model_dump())
+        self.write_file(Path("config.yaml"), self.config1.model_dump())
         cli = self.create_cli(
             [
                 "task-config",
@@ -492,7 +497,7 @@ class CliTaskConfigPullPushTests(BaseCliTests):
         self.assertTrue(push_method.call_args.kwargs["dry_run"])
 
     def test_push_repo_dirty(self) -> None:
-        self.write_file(Path("MANIFEST"), self.manifest().dict())
+        self.write_file(Path("MANIFEST"), self.manifest().model_dump())
         cli = self.create_cli(
             ["task-config", "push", "--workdir", self.workdir.as_posix()]
         )
@@ -512,7 +517,7 @@ class CliTaskConfigPullPushTests(BaseCliTests):
         self.assertEqual(stdout, "")
 
     def test_push_repo_dirty_force(self) -> None:
-        self.write_file(Path("MANIFEST"), self.manifest().dict())
+        self.write_file(Path("MANIFEST"), self.manifest().model_dump())
         fetch_method = self.mock_fetch(repo=self.make_remote_repo())
         push_method = self.mock_push()
         cli = self.create_cli(
@@ -557,7 +562,7 @@ class CliTaskConfigPullPushTests(BaseCliTests):
         server_repo = self.make_remote_repo()
         self.mock_fetch(repo=server_repo)
         push_method = self.mock_push()
-        self.write_file(Path("MANIFEST"), self.manifest().dict())
+        self.write_file(Path("MANIFEST"), self.manifest().model_dump())
         with mock.patch(
             "debusine.client.task_configuration"
             ".LocalTaskConfigurationRepository.git_commit",
@@ -595,7 +600,7 @@ class CliTaskConfigPullPushTests(BaseCliTests):
         fetch_method = self.mock_fetch(repo=server_repo)
         push_method = self.mock_push()
 
-        self.write_file(Path("MANIFEST"), self.manifest().dict())
+        self.write_file(Path("MANIFEST"), self.manifest().model_dump())
         with (
             mock.patch(
                 "debusine.client.task_configuration"
@@ -638,7 +643,7 @@ class CliTaskConfigPullPushTests(BaseCliTests):
         fetch_method = self.mock_fetch(repo=server_repo)
         push_method = self.mock_push()
 
-        self.write_file(Path("MANIFEST"), self.manifest().dict())
+        self.write_file(Path("MANIFEST"), self.manifest().model_dump())
         with (
             mock.patch(
                 "debusine.client.task_configuration"
@@ -692,7 +697,7 @@ class CliTaskConfigPullPushTests(BaseCliTests):
         self.mock_fetch(repo=server_repo)
         push_method = self.mock_push()
 
-        self.write_file(Path("MANIFEST"), self.manifest().dict())
+        self.write_file(Path("MANIFEST"), self.manifest().model_dump())
         with (
             mock.patch(
                 "debusine.client.task_configuration"
