@@ -93,6 +93,10 @@ class FileUploader:
         }
         self._logger = logger
 
+    def _upload_chunk_sleep(self, seconds: float) -> None:  # pragma: no cover
+        """Split out from ``_upload_chunk`` to ease testing."""
+        tm.sleep(seconds)
+
     def _upload_chunk(
         self, url: str, content_range: str, file: "SupportsRead[bytes]"
     ) -> requests.models.Response:
@@ -112,7 +116,7 @@ class FileUploader:
                 if attempt == self._MAX_CHUNK_UPLOAD_RETRIES:
                     raise exc
 
-                tm.sleep(self._CHUNK_UPLOAD_RETRY_WAIT_SECS)
+                self._upload_chunk_sleep(self._CHUNK_UPLOAD_RETRY_WAIT_SECS)
 
     @staticmethod
     def _parse_range_or_raise_exception(
