@@ -30,16 +30,12 @@ from unittest.mock import MagicMock, call
 from urllib.parse import urlencode
 
 import aiohttp
-
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
+import pydantic
 import requests
 import responses
 
 from debusine.artifacts import LocalArtifact, Upload, WorkRequestDebugLogs
+from debusine.artifacts.local_artifact import NewLocalFile, NewRemoteFile
 from debusine.artifacts.models import (
     ArtifactCategory,
     CollectionCategory,
@@ -69,14 +65,12 @@ from debusine.client.models import (
     RelationResponse,
     RelationType,
     RelationsResponse,
-    StrMaxLength255,
     TaskConfigurationCollection,
     TaskConfigurationCollectionUpdateResults,
     WorkRequestExternalDebsignRequest,
     WorkRequestRequest,
     WorkspaceInheritanceChain,
     WorkspaceInheritanceChainElement,
-    model_to_json_serializable_dict,
 )
 from debusine.client.task_configuration import (
     InvalidRepository,
@@ -116,6 +110,7 @@ class SerializeLocalArtifactTests(TestCase):
 
         self.addCleanup(unregister_test_artifact)
 
+        self.test_artifact_class = TestArtifact
         self.category = TestArtifact._category
         self.data = EmptyArtifactData()
 
@@ -130,7 +125,7 @@ class SerializeLocalArtifactTests(TestCase):
             serialize_local_artifact(self.local_artifact, workspace=workspace),
             {
                 "category": self.category,
-                "data": self.data,
+                "data": self.data.model_dump(),
                 "expire_at": None,
                 "files": {},
                 "workspace": workspace,
@@ -140,6 +135,7 @@ class SerializeLocalArtifactTests(TestCase):
 
     def test_guesses_content_type(self) -> None:
         """``serialize_local_artifact`` can guess Content-Type."""
+        files = []
         expected_files: list[tuple[Path, str]] = []
         for suffix, content_type in (
             (".buildinfo", "text/plain; charset=utf-8"),
@@ -148,7 +144,7 @@ class SerializeLocalArtifactTests(TestCase):
             (".md", "text/markdown; charset=utf-8"),
         ):
             file = self.create_temporary_file(suffix=suffix)
-            self.local_artifact.add_local_file(file)
+            files.append(NewLocalFile(file=file))
             expected_files.append((file, content_type))
         for contents, content_type in (
             (b"text\n", "text/plain; charset=us-ascii"),
@@ -159,19 +155,18 @@ class SerializeLocalArtifactTests(TestCase):
             (b"\0\1\2\3\4\5\6\7", "application/octet-stream; charset=binary"),
         ):
             file = self.create_temporary_file(contents=contents)
-            self.local_artifact.add_local_file(file)
+            files.append(NewLocalFile(file=file))
             expected_files.append((file, content_type))
+        artifact = self.test_artifact_class._create(data=self.data, files=files)
 
-        serialized = serialize_local_artifact(
-            self.local_artifact, workspace=None
-        )
+        serialized = serialize_local_artifact(artifact, workspace=None)
 
         self.assertEqual(
             serialized["files"],
             {
                 file.name: FileRequest.create_from(
                     file, content_type=content_type
-                )
+                ).model_dump()
                 for file, content_type in expected_files
             },
         )
@@ -179,18 +174,19 @@ class SerializeLocalArtifactTests(TestCase):
     def test_set_content_type(self) -> None:
         """``serialize_local_artifact`` accepts an explicit Content-Type."""
         file = self.create_temporary_file()
-        self.local_artifact.add_local_file(file, content_type="text/x-foo")
-
-        serialized = serialize_local_artifact(
-            self.local_artifact, workspace=None
+        artifact = self.test_artifact_class._create(
+            data=self.data,
+            files=[NewLocalFile(file=file, content_type="text/x-foo")],
         )
 
+        serialized = serialize_local_artifact(artifact, workspace=None)
+
         self.assertEqual(
             serialized["files"],
             {
                 file.name: FileRequest.create_from(
                     file, content_type="text/x-foo"
-                )
+                ).model_dump()
             },
         )
 
@@ -221,7 +217,9 @@ class SerializeLocalArtifactTests(TestCase):
         # Remove the only file. The "artifact" object will not validate
         artifact.files.popitem()
 
-        with self.assertRaisesRegex(ValueError, "^Model validation failed:"):
+        with self.assertRaisesRegex(
+            ValueError, r"Expecting 1 \.changes file in \[\]"
+        ):
             serialize_local_artifact(artifact, workspace="System")
 
     def test_with_work_request(self) -> None:
@@ -239,21 +237,25 @@ class SerializeLocalArtifactTests(TestCase):
         """``serialize_local_artifact`` handles remote files."""
         changes_file = self.create_temporary_file(suffix=".changes")
         tar_file = self.create_temporary_file(suffix=".tar.xz")
-        self.local_artifact.add_local_file(changes_file)
-        self.local_artifact.add_remote_file(
-            tar_file.name, FileRequest.create_from(tar_file)
+        artifact = self.test_artifact_class._create(
+            data=self.data,
+            files=[
+                NewLocalFile(file=changes_file),
+                NewRemoteFile(
+                    path_in_artifact=tar_file.name,
+                    file_request=FileRequest.create_from(tar_file),
+                ),
+            ],
         )
 
-        serialized = serialize_local_artifact(
-            self.local_artifact, workspace=None
-        )
+        serialized = serialize_local_artifact(artifact, workspace=None)
 
         self.assertEqual(
             serialized["files"],
             {
                 file.name: FileRequest.create_from(
                     file, content_type=content_type
-                )
+                ).model_dump()
                 for file, content_type in (
                     (changes_file, "text/plain; charset=utf-8"),
                     (tar_file, None),
@@ -307,11 +309,18 @@ class DebusineTests(TestCase):
                 "https://debusine.debian.org/a/b",
             ),
         ):
-            with self.subTest(api_url=api_url, path=path):
-                debusine = Debusine(
-                    api_url, self.token, logger=self.logger, scope="scope"
-                )
-                self.assertEqual(debusine.webui_url(path), expected)
+            for test_api_url in (api_url, api_url + "/"):
+                for test_path in (path, path.lstrip("/")):
+                    with self.subTest(api_url=test_api_url, path=test_path):
+                        debusine = Debusine(
+                            test_api_url,
+                            self.token,
+                            logger=self.logger,
+                            scope="scope",
+                        )
+                        self.assertEqual(
+                            debusine.webui_url(test_path), expected
+                        )
 
     @responses.activate
     def test_work_request_iter(self) -> None:
@@ -325,7 +334,7 @@ class DebusineTests(TestCase):
         responses.add(
             responses.GET,
             f'{self.debusine.api_url}/work-request/',
-            json=model_to_json_serializable_dict(listing_response),
+            json=listing_response.model_dump(mode="json"),
         )
 
         self.assertEqual(list(self.debusine.work_request_iter()), work_requests)
@@ -340,7 +349,7 @@ class DebusineTests(TestCase):
         responses.add(
             responses.GET,
             f'{self.debusine.api_url}/work-request/{work_request_id}/',
-            json=model_to_json_serializable_dict(work_request_response),
+            json=work_request_response.model_dump(mode="json"),
         )
 
         self.assertEqual(
@@ -360,7 +369,7 @@ class DebusineTests(TestCase):
         responses.add(
             responses.PATCH,
             f"{self.debusine.api_url}/work-request/{work_request_id}/",
-            json=model_to_json_serializable_dict(work_request_response),
+            json=work_request_response.model_dump(mode="json"),
         )
 
         self.assertEqual(
@@ -382,7 +391,7 @@ class DebusineTests(TestCase):
         responses.add(
             responses.POST,
             f"{self.debusine.api_url}/work-request/{work_request_id}/retry/",
-            json=model_to_json_serializable_dict(work_request_response),
+            json=work_request_response.model_dump(mode="json"),
         )
 
         self.assertEqual(
@@ -400,7 +409,7 @@ class DebusineTests(TestCase):
         responses.add(
             responses.POST,
             f"{self.debusine.api_url}/work-request/{work_request_id}/abort/",
-            json=model_to_json_serializable_dict(work_request_response),
+            json=work_request_response.model_dump(mode="json"),
         )
 
         self.assertEqual(
@@ -433,9 +442,7 @@ class DebusineTests(TestCase):
         responses.add(
             responses.POST,
             f'{self.debusine.api_url}/work-request/',
-            json=model_to_json_serializable_dict(
-                expected_work_request_response
-            ),
+            json=expected_work_request_response.model_dump(mode="json"),
         )
 
         work_request_fields: dict[str, Any] = {
@@ -468,7 +475,7 @@ class DebusineTests(TestCase):
         # "workspace" if it was None
         self.assertEqual(
             json.loads(responses.calls[0].request.body or "null"),
-            work_request_to_post.dict(include=fields_to_post),
+            work_request_to_post.model_dump(include=fields_to_post),
         )
 
     @responses.activate
@@ -536,7 +543,7 @@ class DebusineTests(TestCase):
             responses.GET,
             f'{self.debusine.api_url}/work-request/{work_request_id}/'
             f'external-debsign/',
-            json=model_to_json_serializable_dict(work_request_response),
+            json=work_request_response.model_dump(mode="json"),
         )
 
         self.assertEqual(
@@ -562,7 +569,7 @@ class DebusineTests(TestCase):
             responses.POST,
             f'{self.debusine.api_url}/work-request/{work_request_id}/'
             f'external-debsign/',
-            json=model_to_json_serializable_dict(work_request_response),
+            json=work_request_response.model_dump(mode="json"),
         )
 
         self.assertEqual(
@@ -595,7 +602,7 @@ class DebusineTests(TestCase):
         responses.add(
             responses.POST,
             f"{self.debusine.api_url}/workflow/",
-            json=model_to_json_serializable_dict(expected_workflow_response),
+            json=expected_workflow_response.model_dump(mode="json"),
             status=requests.codes.created,
         )
 
@@ -626,7 +633,7 @@ class DebusineTests(TestCase):
         # "workspace" if it was None.
         self.assertEqual(
             json.loads(responses.calls[0].request.body or "null"),
-            workflow_to_post.dict(include=fields_to_post),
+            workflow_to_post.model_dump(include=fields_to_post),
         )
 
     @responses.activate
@@ -668,7 +675,7 @@ class DebusineTests(TestCase):
         responses.add(
             responses.GET,
             f"{self.api_url}/1.0/artifact/{get_artifact_response.id}/",
-            json=model_to_json_serializable_dict(get_artifact_response),
+            json=get_artifact_response.model_dump(mode="json"),
         )
 
         artifact = self.debusine.artifact_get(artifact_id)
@@ -712,7 +719,7 @@ class DebusineTests(TestCase):
                 f"{self.api_url}/1.0/artifact/{workspace}/"
                 f"{get_artifact_response.id}/"
             ),
-            json=model_to_json_serializable_dict(get_artifact_response),
+            json=get_artifact_response.model_dump(mode="json"),
         )
 
         artifact = self.debusine.artifact_get(artifact_id, workspace=workspace)
@@ -752,7 +759,7 @@ class DebusineTests(TestCase):
         responses.add(
             responses.POST,
             f"{self.api_url}/1.0/artifact/",
-            json=model_to_json_serializable_dict(artifact_response),
+            json=artifact_response.model_dump(mode="json"),
             status=requests.codes.created,
         )
 
@@ -879,7 +886,7 @@ class DebusineTests(TestCase):
                 id=remote_id,
                 workspace=workspace,
                 files_to_upload=[filename],
-            ).json(),
+            ).model_dump_json(),
             status=requests.codes.created,
         )
 
@@ -929,7 +936,9 @@ class DebusineTests(TestCase):
         responses.assert_call_count(url, 1)
 
         assert responses.calls[0].request.body is not None
-        request_body = json.loads(responses.calls[0].request.body)
+        request_body = RelationCreateRequest.model_validate_json(
+            responses.calls[0].request.body
+        )
 
         self.assertEqual(
             request_body,
@@ -961,11 +970,11 @@ class DebusineTests(TestCase):
         relation_response = RelationResponse(
             id=7, artifact=1, target=2, type=RelationType.EXTENDS
         )
-        responses.add(responses.GET, url, json=[dict(relation_response)])
+        responses.add(responses.GET, url, json=[relation_response.model_dump()])
 
         self.assertEqual(
             self.debusine.relation_list(artifact_id=1),
-            RelationsResponse.parse_obj([relation_response]),
+            RelationsResponse([relation_response]),
         )
 
         responses.assert_call_count(url, 1)
@@ -977,11 +986,11 @@ class DebusineTests(TestCase):
         relation_response = RelationResponse(
             id=7, artifact=1, target=2, type=RelationType.EXTENDS
         )
-        responses.add(responses.GET, url, json=[dict(relation_response)])
+        responses.add(responses.GET, url, json=[relation_response.model_dump()])
 
         self.assertEqual(
             self.debusine.relation_list(target_id=2),
-            RelationsResponse.parse_obj([relation_response]),
+            RelationsResponse([relation_response]),
         )
 
         responses.assert_call_count(url, 1)
@@ -1005,13 +1014,9 @@ class DebusineTests(TestCase):
         response_files = {
             f"{directory}file{i}": FileResponse(
                 size=file_size,
-                checksums={
-                    "sha256": pydantic.parse_obj_as(StrMaxLength255, "abc123")
-                },
+                checksums={"sha256": "abc123"},
                 type="file",
-                url=pydantic.parse_obj_as(
-                    pydantic.AnyUrl, f"{artifact_base_url}{directory}file{i}"
-                ),
+                url=f"{artifact_base_url}{directory}file{i}",
             )
             for i in range(files)
         }
@@ -1024,7 +1029,9 @@ class DebusineTests(TestCase):
             files=response_files,
         )
         responses.add(
-            "GET", url_artifact_information, body=artifact_response.json()
+            "GET",
+            url_artifact_information,
+            body=artifact_response.model_dump_json(),
         )
 
         return artifact_response
@@ -1035,7 +1042,7 @@ class DebusineTests(TestCase):
         artifact_response = self.add_get_download_artifact_response()
         responses.add(
             responses.GET,
-            artifact_response.download_tar_gz_url,
+            str(artifact_response.download_tar_gz_url),
             b"Invalid tar",
         )
 
@@ -1073,7 +1080,7 @@ class DebusineTests(TestCase):
         expected_artifact_response = self.add_get_download_artifact_response()
         responses.add(
             responses.GET,
-            expected_artifact_response.download_tar_gz_url,
+            str(expected_artifact_response.download_tar_gz_url),
             compressed.getvalue(),
         )
 
@@ -1106,14 +1113,14 @@ class DebusineTests(TestCase):
     @responses.activate
     def test_download_artifact_tarball(self) -> None:
         """download_artifact() download the artifact as .tar.gz."""
-        compressed, file = self.create_tar()
+        compressed, _ = self.create_tar()
         downloaded_directory = self.create_temporary_directory()
 
         expected_artifact_response = self.add_get_download_artifact_response()
         artifact_id = expected_artifact_response.id
         responses.add(
             responses.GET,
-            expected_artifact_response.download_tar_gz_url,
+            str(expected_artifact_response.download_tar_gz_url),
             compressed.getvalue(),
         )
 
@@ -1141,7 +1148,7 @@ class DebusineTests(TestCase):
 
         responses.add(
             responses.GET,
-            artifact_response.files["file0"].url,
+            str(artifact_response.files["file0"].url),
             contents,
         )
 
@@ -1163,7 +1170,7 @@ class DebusineTests(TestCase):
 
         responses.add(
             responses.GET,
-            artifact_response.download_tar_gz_url,
+            str(artifact_response.download_tar_gz_url),
             compressed.getvalue(),
         )
 
@@ -1188,7 +1195,7 @@ class DebusineTests(TestCase):
 
         responses.add(
             responses.GET,
-            artifact_response.files["directory/sub-directory/file0"].url,
+            str(artifact_response.files["directory/sub-directory/file0"].url),
             contents,
         )
 
@@ -1242,8 +1249,7 @@ class DebusineTests(TestCase):
         """
         artifact_id = 17
         url_system_tar_xz = (
-            f"https://debusine.example.com/"
-            f"artifact/{artifact_id}/system.tar.xz"
+            f"https://debusine.example.com/artifact/{artifact_id}/system.tar.xz"
         )
 
         # Set endpoint to download artifact's information
@@ -1255,21 +1261,18 @@ class DebusineTests(TestCase):
                     "system.tar.xz": FileResponse(
                         size=len(contents),
                         checksums={
-                            "sha256": pydantic.parse_obj_as(
-                                StrMaxLength255,
-                                hashlib.sha256(contents).hexdigest(),
-                            )
+                            "sha256": hashlib.sha256(contents).hexdigest()
                         },
                         type="file",
-                        url=pydantic.parse_obj_as(
-                            pydantic.AnyUrl, url_system_tar_xz
-                        ),
+                        url=url_system_tar_xz,
                     )
                 }
             ),
         )
         responses.add(
-            "GET", url_artifact_information, body=artifact_response.json()
+            "GET",
+            url_artifact_information,
+            body=artifact_response.model_dump_json(),
         )
 
         return artifact_response
@@ -1298,7 +1301,7 @@ class DebusineTests(TestCase):
         )
         responses.add(
             responses.GET,
-            artifact_response.files["system.tar.xz"].url,
+            str(artifact_response.files["system.tar.xz"].url),
             contents,
         )
         destination = downloaded_directory / "system.tar.xz"
@@ -1322,7 +1325,7 @@ class DebusineTests(TestCase):
         )
         responses.add(
             responses.GET,
-            artifact_response.files["system.tar.xz"].url,
+            str(artifact_response.files["system.tar.xz"].url),
             contents,
         )
         destination = downloaded_directory / "system.tar.xz"
@@ -1351,21 +1354,21 @@ class DebusineTests(TestCase):
         asset_request = {
             "category": AssetCategory.SIGNING_KEY,
             "workspace": workspace,
-            "data": asset_data.dict(),
+            "data": asset_data.model_dump(),
             "work_request": work_request,
         }
         asset_response_json = {
             "id": 99,
             "category": AssetCategory.SIGNING_KEY,
             "workspace": workspace,
-            "data": asset_data.dict(),
+            "data": asset_data.model_dump(),
             "work_request": work_request,
         }
         asset_response = AssetResponse(
             id=99,
             category=AssetCategory.SIGNING_KEY,
             workspace=workspace,
-            data=asset_data,
+            data=asset_data.model_dump(),
             work_request=work_request,
         )
 
@@ -1406,15 +1409,15 @@ class DebusineTests(TestCase):
             public_key=base64.b64encode(b"PUBLIC KEY").decode(),
             description="Description",
         )
-        assets_response = AssetsResponse.parse_obj(
+        assets_response = AssetsResponse(
             [
                 AssetResponse(
                     id=99,
                     category=AssetCategory.SIGNING_KEY,
                     workspace="workspace",
-                    data=asset_data,
+                    data=asset_data.model_dump(),
                     work_request=12,
-                ).dict()
+                )
             ]
         )
         assets_response_json = [
@@ -1422,7 +1425,7 @@ class DebusineTests(TestCase):
                 "id": 99,
                 "category": AssetCategory.SIGNING_KEY,
                 "workspace": "workspace",
-                "data": asset_data.dict(),
+                "data": asset_data.model_dump(),
                 "work_request": 12,
             }
         ]
@@ -1488,7 +1491,7 @@ class DebusineTests(TestCase):
                 f"{self.debusine.api_url}/asset/debusine%3Asigning-key/"
                 f"openpgp%3AABC123/sign_with/"
             ),
-            json=permission_check_response.dict(),
+            json=permission_check_response.model_dump(),
         )
         response = self.debusine.asset_permission_check(
             asset_category="debusine:signing-key",
@@ -1557,7 +1560,7 @@ class DebusineTests(TestCase):
         )
 
         response = self.debusine.lookup_multiple(
-            lookup=LookupMultiple.parse_obj({"collection": "collection"}),
+            lookup=LookupMultiple.model_validate({"collection": "collection"}),
             work_request=1,
             expect_type=LookupChildType.ARTIFACT,
             default_category=CollectionCategory.TEST,
@@ -1565,7 +1568,7 @@ class DebusineTests(TestCase):
 
         self.assertEqual(
             response,
-            LookupMultipleResponse.parse_obj(
+            LookupMultipleResponse(
                 [
                     LookupSingleResponse(
                         result_type=LookupResultType.ARTIFACT,
@@ -1600,9 +1603,9 @@ class DebusineTests(TestCase):
     @responses.activate
     def test_streaming_download(self) -> None:
         """Test _streaming_download() sets headers and returns the response."""
-        url = "https://example.net/stream"
+        url = pydantic.AnyUrl("https://example.net/stream")
         body = b"abc123"
-        responses.add(responses.GET, url, body)
+        responses.add(responses.GET, str(url), body)
         r = self.debusine._streaming_download(url)
 
         self.assertEqual(r.content, body)
@@ -1637,7 +1640,7 @@ class DebusineTests(TestCase):
             f"{self.debusine.api_url}/task-configuration/System/default/",
             json={
                 "collection": {"id": 1, "name": "default", "data": {}},
-                "items": [config.dict(), template.dict()],
+                "items": [config.model_dump(), template.model_dump()],
             },
         )
         repository = self.debusine.fetch_task_configuration_collection(
@@ -1665,7 +1668,7 @@ class DebusineTests(TestCase):
         responses.add(
             responses.POST,
             f"{self.debusine.api_url}/task-configuration/System/default/",
-            json=result.dict(),
+            json=result.model_dump(),
         )
         repo = LocalTaskConfigurationRepository(
             self.create_temporary_directory()
@@ -1698,7 +1701,7 @@ class DebusineTests(TestCase):
         responses.add(
             responses.POST,
             f"{self.debusine.api_url}/task-configuration/System/default/",
-            json=result.dict(),
+            json=result.model_dump(),
         )
         repo = LocalTaskConfigurationRepository(
             self.create_temporary_directory()
@@ -1725,7 +1728,7 @@ class DebusineTests(TestCase):
         result = TaskConfigurationCollectionUpdateResults(
             added=2, removed=3, updated=4, unchanged=5
         )
-        responses.add(responses.POST, url, json=result.dict())
+        responses.add(responses.POST, url, json=result.model_dump())
         repo = LocalTaskConfigurationRepository(
             self.create_temporary_directory()
         )
@@ -1761,7 +1764,7 @@ class DebusineTests(TestCase):
             ),
         ]
         result = WorkspaceInheritanceChain(chain=chain)
-        responses.add(responses.GET, url, json=result.dict())
+        responses.add(responses.GET, url, json=result.model_dump())
         res = self.debusine.get_workspace_inheritance("System")
         self.assertEqual(res.chain, chain)
         responses.assert_call_count(url, 1)
@@ -1770,7 +1773,7 @@ class DebusineTests(TestCase):
     def test_set_workspace_inheritance(self) -> None:
         url = f"{self.debusine.api_url}/workspace/System/inheritance/"
         result = WorkspaceInheritanceChain(chain=[])
-        responses.add(responses.POST, url, json=result.dict())
+        responses.add(responses.POST, url, json=result.model_dump())
         res = self.debusine.set_workspace_inheritance(
             "System", chain=WorkspaceInheritanceChain(chain=[])
         )
@@ -1788,7 +1791,7 @@ class DebusineTests(TestCase):
             metadata_only_retention_period=None,
             data={"test": True},
         )
-        responses.add(responses.GET, url, json=result.dict())
+        responses.add(responses.GET, url, json=result.model_dump())
         res = self.debusine.collection_get("System", "debian:suite", "sid")
         self.assertEqual(res, result)
         responses.assert_call_count(url, 1)
@@ -1804,7 +1807,7 @@ class DebusineTests(TestCase):
             metadata_only_retention_period=4,
             data={"test": True},
         )
-        responses.add(responses.GET, url, json=result.dict())
+        responses.add(responses.GET, url, json=result.model_dump())
         res = self.debusine.collection_get(
             "System", result.category, result.name
         )
@@ -1821,11 +1824,11 @@ class DebusineTests(TestCase):
             metadata_only_retention_period=14,
             data={"test": 2},
         )
-        result = CollectionData(id=41, **data.dict())
+        result = CollectionData(id=41, **data.model_dump())
         responses.add(
             responses.POST,
             url,
-            json=result.dict(),
+            json=result.model_dump(),
             status=requests.codes.created,
         )
         res = self.debusine.collection_create("System", data)
@@ -1843,7 +1846,7 @@ class DebusineTests(TestCase):
             metadata_only_retention_period=14,
             data={"test": 2},
         )
-        responses.add(responses.PATCH, url, json=result.dict())
+        responses.add(responses.PATCH, url, json=result.model_dump())
         res = self.debusine.collection_update("System", result)
         self.assertEqual(res, result)
         responses.assert_call_count(url, 1)
@@ -1861,9 +1864,7 @@ class DebusineTests(TestCase):
         )
         listing_response = create_listing_response(data)
         responses.add(
-            responses.GET,
-            url,
-            json=model_to_json_serializable_dict(listing_response),
+            responses.GET, url, json=listing_response.model_dump(mode="json")
         )
         res = list(self.debusine.collection_iter("System"))
         self.assertEqual(res, [data])
