@@ -111,7 +111,7 @@ class DebusineHttpClientTests(TestCase):
                     break
                 obj = objects.popleft()
                 obj.page = pageno
-                body["results"].append(obj.dict())
+                body["results"].append(obj.model_dump())
             if objects:
                 body["next"] = base_url + f"?page={pageno + 1}"
             if pageno > 1:
@@ -157,7 +157,7 @@ class DebusineHttpClientTests(TestCase):
         responses.add(method, self.api_url, body=content)
 
         expected_regexp = (
-            fr"^Server \({self.api_url}\) expected to return "
+            rf"^Server \({self.api_url}\) expected to return "
             f"an empty body. Returned:\nb'{content}'$"
         )
 
@@ -289,7 +289,7 @@ class DebusineHttpClientTests(TestCase):
         with self.assertRaisesRegex(
             exceptions.UnexpectedResponseError,
             "^Server returned unexpected status code: 400 "
-            fr"\({self.api_url}\)$",
+            rf"\({self.api_url}\)$",
         ):
             debusine_client._api_request("GET", self.api_url, SampleResponse)
 
@@ -306,7 +306,7 @@ class DebusineHttpClientTests(TestCase):
         with self.assertRaisesRegex(
             exceptions.UnexpectedResponseError,
             "^Server returned unexpected status code: 400 "
-            fr"\({self.api_url}\)$",
+            rf"\({self.api_url}\)$",
         ):
             debusine_client._api_request("GET", self.api_url, SampleResponse)
 
@@ -382,7 +382,7 @@ class DebusineHttpClientTests(TestCase):
         debusine_client = DebusineHttpClient(self.api_url, self.token)
         with self.assertRaisesRegex(
             exceptions.UnexpectedResponseError,
-            fr"^Server \({self.api_url}\) did not return valid object. Error: ",
+            rf"^Server \({self.api_url}\) did not return valid object. Error: ",
         ):
             debusine_client._api_request("GET", self.api_url, SampleResponse)
 
@@ -632,7 +632,7 @@ class DebusineHttpClientTests(TestCase):
         )
         with self.assertRaisesRegex(
             exceptions.UnexpectedResponseError,
-            fr"^Server \({self.api_url}\) did not return valid object. Error: ",
+            rf"^Server \({self.api_url}\) did not return valid object. Error: ",
         ):
             next(debusine_client.iter_paginated_get("", SampleResponse))
 
@@ -650,6 +650,6 @@ class DebusineHttpClientTests(TestCase):
         )
         with self.assertRaisesRegex(
             exceptions.UnexpectedResponseError,
-            fr"^Server \({self.api_url}\) did not return valid object. Error: ",
+            rf"^Server \({self.api_url}\) did not return valid object. Error: ",
         ):
             next(debusine_client.iter_paginated_get("", SampleResponse))
