@@ -255,7 +255,7 @@ class FileUploaderTests(TestCase):
         """Client upload file, there is a conflict and uploads it again."""
 
         def succeeds_after_one_attempt(
-            request: requests.PreparedRequest,  # noqa: U100
+            request: requests.PreparedRequest,  # noqa: ARG001, U100
         ) -> tuple[int, dict[str, str], None]:
             first_attempt = getattr(succeeds_after_one_attempt, "first", True)
 
@@ -411,9 +411,9 @@ class FileUploaderTests(TestCase):
             uploaded_size=2, status_code_upload=requests.codes.conflict
         )
 
-        error_msg = r"Error uploading .* to {} \({} retries\)".format(
-            self.url,
-            self.file_uploader._MAX_FILE_UPLOAD_RETRIES,
+        error_msg = (
+            rf"Error uploading .* to {self.url} "
+            rf"\({self.file_uploader._MAX_FILE_UPLOAD_RETRIES} retries\)"
         )
         with self.assertRaisesRegex(FileUploadError, error_msg):
             self.file_uploader.upload(self.file_path, self.url)
@@ -456,15 +456,6 @@ class FileUploaderTests(TestCase):
                 file, len(self.file_content), "https://test.com"
             )
 
-    def patch_sleep(self) -> mock.MagicMock:
-        """Patch time.sleep(), return its mock."""
-        patcher = mock.patch("time.sleep", autospec=True)
-        mocked_sleep = patcher.start()
-
-        self.addCleanup(patcher.stop)
-
-        return mocked_sleep
-
     def patch_requests_put(self, side_effect: Any) -> mock.MagicMock:
         """Patch requests.put(), return its mock."""
         patcher = mock.patch("requests.put", autospec=True)
@@ -477,8 +468,6 @@ class FileUploaderTests(TestCase):
 
     def test_upload_chunk_retries(self) -> None:
         """FileUploader._upload_chunk() called twice: once failed."""
-        mocked_sleep = self.patch_sleep()
-
         return_value = "request_result"
         request = mock.create_autospec(
             spec=requests.models.Request, url="https://test.com"
@@ -490,9 +479,12 @@ class FileUploaderTests(TestCase):
             ]
         )
 
-        r = self.file_uploader._upload_chunk(
-            "some-url", "bytes=1-2/2", io.BytesIO(b"some-data")
-        )
+        with mock.patch.object(
+            self.file_uploader, "_upload_chunk_sleep", autospec=True
+        ) as mocked_sleep:
+            r = self.file_uploader._upload_chunk(
+                "some-url", "bytes=1-2/2", io.BytesIO(b"some-data")
+            )
         self.assertEqual(mocked_put.call_count, 2)
         self.assertEqual(r, return_value)
         self.assertEqual(mocked_sleep.call_count, 1)
@@ -502,8 +494,6 @@ class FileUploaderTests(TestCase):
 
     def test_upload_chunk_raise_clientconnectionerror(self) -> None:
         """FileUploader._upload_chunk() called MAX_CHUNK_UPLOAD_RETIRES."""
-        mocked_sleep = self.patch_sleep()
-
         request = mock.create_autospec(
             spec=requests.models.Request, url="https://test.com"
         )
@@ -511,7 +501,12 @@ class FileUploaderTests(TestCase):
             requests.exceptions.RequestException(request=request)
         )
 
-        with self.assertRaises(exceptions.ClientConnectionError):
+        with (
+            self.assertRaises(exceptions.ClientConnectionError),
+            mock.patch.object(
+                self.file_uploader, "_upload_chunk_sleep", autospec=True
+            ) as mocked_sleep,
+        ):
             self.file_uploader._upload_chunk(
                 "some-url", "bytes=1-2/2", io.BytesIO(b"some-data")
             )
@@ -519,7 +514,9 @@ class FileUploaderTests(TestCase):
         self.assertEqual(
             mocked_put.call_count, FileUploader._MAX_CHUNK_UPLOAD_RETRIES
         )
-        self.assertEqual(mocked_sleep.call_count, 2)
+        self.assertEqual(
+            mocked_sleep.call_count, FileUploader._MAX_CHUNK_UPLOAD_RETRIES - 1
+        )
         mocked_sleep.assert_called_with(
             self.file_uploader._CHUNK_UPLOAD_RETRY_WAIT_SECS
         )
