@@ -17,13 +17,9 @@ from pathlib import Path
 from typing import Any, ClassVar
 from unittest import SkipTest, mock
 
+import pydantic
 import yaml
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
 from debusine.artifacts.models import DebusineTaskConfiguration, TaskTypes
 from debusine.client.models import TaskConfigurationCollection
 from debusine.client.task_configuration import (
@@ -180,9 +176,9 @@ class LocalTaskConfigurationRepositoryTestsBase(
         path.parent.mkdir(exist_ok=True, parents=True)
         with path.open("wt") as fd:
             if isinstance(item, pydantic.BaseModel):
-                yaml.safe_dump(item.dict(), fd)
+                yaml.safe_dump(item.model_dump(), fd)
             else:
-                yaml.safe_dump([i.dict() for i in item], fd)
+                yaml.safe_dump([i.model_dump() for i in item], fd)
 
     def list_files(self) -> list[Path]:
         """List files present in self.root."""
@@ -202,9 +198,9 @@ class LocalTaskConfigurationRepositoryTestsBase(
         with path.open() as fd:
             actual = yaml.safe_load(fd)
         if isinstance(expected, pydantic.BaseModel):
-            self.assertEqual(actual, expected.dict())
+            self.assertEqual(actual, expected.model_dump())
         else:
-            self.assertEqual(actual, [i.dict() for i in expected])
+            self.assertEqual(actual, [i.model_dump() for i in expected])
 
 
 class LocalTaskConfigurationRepositoryTests(
@@ -339,7 +335,7 @@ class LocalTaskConfigurationRepositoryTests(
         self.assertEqual(exc.exception.__notes__[0], "source: test.yaml")
 
     def test_iter_items_invalid_data(self) -> None:
-        (self.root / "test.yaml").write_text("test: true")
+        (self.root / "test.yaml").write_text("comment: ''")
         with self.assertRaisesRegex(
             ValueError,
             (
@@ -421,7 +417,7 @@ class LocalTaskConfigurationRepositoryTests(
 
     def test_pull_update(self) -> None:
         old = self.config1
-        new = self.config1.copy(update={"comment": "updated"})
+        new = self.config1.model_copy(update={"comment": "updated"})
 
         server_repo = self.make_remote_repo([new])
 
@@ -450,7 +446,7 @@ class LocalTaskConfigurationRepositoryTests(
 
     def test_pull_update_preserves_mtime(self) -> None:
         old = self.config1
-        new = self.config1.copy(update={"comment": "updated"})
+        new = self.config1.model_copy(update={"comment": "updated"})
 
         server_repo = self.make_remote_repo([new, self.config2])
 
@@ -491,7 +487,7 @@ class LocalTaskConfigurationRepositoryTests(
 
     def test_pull_update_second_in_file(self) -> None:
         old = self.config1
-        new = self.config1.copy(update={"comment": "updated"})
+        new = self.config1.model_copy(update={"comment": "updated"})
 
         server_repo = self.make_remote_repo([new])
 
