@@ -1,4 +1,4 @@
-# Copyright 2024 The Debusine Developers
+# Copyright © The Debusine Developers
 # See the AUTHORS file at the top-level directory of this distribution
 #
 # This file is part of Debusine. It is subject to the license terms
@@ -123,8 +123,8 @@ class JsonDataUniqueConstraint(BaseConstraint):
 
     def remove_sql(
         self,
-        model: type[Model] | None,  # noqa: U100
-        schema_editor: BaseDatabaseSchemaEditor | None,  # noqa: U100
+        model: type[Model] | None,  # noqa: ARG002, U100
+        schema_editor: BaseDatabaseSchemaEditor | None,  # noqa: ARG002, U100
     ) -> str:
         """Remove the index."""
         sql = "DROP INDEX %(name)s"
