@@ -19,32 +19,34 @@ from enum import StrEnum
 from typing import (
     Annotated,
     Any,
-    Generic,
     Literal,
     Optional,
     Self,
     TYPE_CHECKING,
     TypeAlias,
-    TypeVar,
     Union,
     cast,
 )
 
+import pydantic
 from django.conf import settings
 from django.contrib.auth.models import AbstractUser
 from django.contrib.auth.models import UserManager as DjangoUserManager
 from django.core.exceptions import ImproperlyConfigured, ValidationError
 from django.core.validators import MaxLengthValidator, MinLengthValidator
 from django.db import models
-from django.db.models import CheckConstraint, Q, QuerySet, UniqueConstraint
+from django.db.models import (
+    CheckConstraint,
+    F,
+    Q,
+    QuerySet,
+    UniqueConstraint,
+    Value,
+)
+from django.db.models.functions import Coalesce
 from django.urls import reverse
 from django.utils import timezone
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
 from debusine.db.context import ContextConsistencyError, context
 from debusine.db.models import permissions
 from debusine.db.models.permissions import (
@@ -57,6 +59,7 @@ from debusine.db.models.permissions import (
     resolve_role,
 )
 from debusine.db.models.scopes import Scope
+from debusine.db.models.workspaces import Workspace
 from debusine.server import notifications
 from debusine.utils.typing_utils import copy_signature_from
 
@@ -64,7 +67,7 @@ if TYPE_CHECKING:
     from django.http import HttpRequest
     from django_stubs_ext.db.models import TypedModelMeta
 
-    from debusine.web.views.ui.auth import GroupUI, UserUI
+    from debusine.web.views.ui.auth import GroupMembershipUI, GroupUI, UserUI
 
     # https://github.com/typeddjango/django-stubs/issues/2112
     AbstractUserMeta = TypedModelMeta
@@ -72,8 +75,6 @@ else:
     TypedModelMeta = object
     AbstractUserMeta = AbstractUser.Meta
 
-A = TypeVar("A")
-
 
 class TokenManager(models.Manager["Token"]):
     """Manager for Token model."""
@@ -189,6 +190,10 @@ class Token(models.Model):
     class Meta(TypedModelMeta):
         base_manager_name = "objects"
 
+    def __str__(self) -> str:
+        """Return the hash of the Token."""
+        return self.hash
+
     def save(self, *args: Any, **kwargs: Any) -> None:
         """Save the token. If it's a new token it generates a key."""
         if not self.hash:
@@ -208,10 +213,6 @@ class Token(models.Model):
 
         notifications.notify_worker_token_disabled(self)
 
-    def __str__(self) -> str:
-        """Return the hash of the Token."""
-        return self.hash
-
     @classmethod
     def _generate_key(cls) -> str:
         """Create and return a key."""
@@ -231,13 +232,11 @@ def system_user() -> "User":
     return User.objects.get(username=SYSTEM_USER_NAME)
 
 
-class UserQuerySet(QuerySet["User", A], Generic[A]):
+class UserQuerySet[A](QuerySet["User", A]):
     """Custom QuerySet for User."""
 
     @permission_filter(workers=Allow.ALWAYS)
-    def can_display(
-        self, user: PermissionUser  # noqa: U100
-    ) -> "UserQuerySet[A]":
+    def can_display(self, user: PermissionUser) -> "UserQuerySet[A]":
         """Keep only Users that can be displayed."""
         assert user is not None  # Enforced by decorator
         return self
@@ -249,16 +248,14 @@ class UserQuerySet(QuerySet["User", A], Generic[A]):
         return self.filter(pk=user.pk)
 
 
-class UserManager(DjangoUserManager["User"]):
+class UserManager[A](DjangoUserManager["User"]):
     """Manager for User model."""
 
     # We cannot use from_queryset or we hit this problem:
     # https://stackoverflow.com/questions/68367703/adding-custom-queryset-to-usermodel-causes-makemigrations-exception  # noqa: E501
     # Therefore we need to proxy all permission filters here
 
-    def can_display(
-        self, user: PermissionUser  # noqa: U100
-    ) -> "UserQuerySet[A]":
+    def can_display(self, user: PermissionUser) -> "UserQuerySet[A]":
         """Keep only Users that can be displayed."""
         return self.get_queryset().can_display(user)
 
@@ -335,14 +332,6 @@ class Identity(models.Model):
     no Django user is known for it.
     """
 
-    class Meta(TypedModelMeta):
-        constraints = [
-            UniqueConstraint(
-                fields=["issuer", "subject"],
-                name="%(app_label)s_%(class)s_unique_issuer_subject",
-            ),
-        ]
-
     user = models.ForeignKey(
         settings.AUTH_USER_MODEL,
         related_name="identities",
@@ -362,6 +351,14 @@ class Identity(models.Model):
     )
     claims = models.JSONField(default=dict)
 
+    class Meta(TypedModelMeta):
+        constraints = [
+            UniqueConstraint(
+                fields=["issuer", "subject"],
+                name="%(app_label)s_%(class)s_unique_issuer_subject",
+            ),
+        ]
+
     def __str__(self) -> str:
         """Return str for the object."""
         return f"{self.issuer}:{self.subject}"
@@ -384,7 +381,7 @@ def validate_group_name(value: str) -> None:
         )
 
 
-class GroupQuerySet(QuerySet["Group", A], Generic[A]):
+class GroupQuerySet[A](QuerySet["Group", A]):
     """Custom QuerySet for Group."""
 
     @permission_filter()
@@ -445,9 +442,16 @@ class GroupManager(models.Manager["Group"]):
         scope_name, group_name = scope_group.split("/", 1)
         return Group.objects.get(scope__name=scope_name, name=group_name)
 
-    def create_ephemeral(self, scope: Scope, name: str, owner: User) -> "Group":
+    def create_ephemeral(
+        self, workspace: Workspace, name: str, owner: User
+    ) -> "Group":
         """Create an ephemeral group for the given user."""
-        group = self.create(scope=scope, name=name, ephemeral=True)
+        group = self.create(
+            scope=workspace.scope,
+            workspace=workspace,
+            name=name,
+            ephemeral=True,
+        )
         # Sets the user as an admin of the newly created group
         group.add_user(owner, Group.Roles.ADMIN)
         return group
@@ -475,8 +479,7 @@ class GroupRoleBase(permissions.RoleBase):
                     implied_by_group_roles |= gr.implied_by_group_roles
                 case _:
                     raise ImproperlyConfigured(
-                        "Group roles do not support"
-                        f" implications by {type(i)}"
+                        f"Group roles do not support implications by {type(i)}"
                     )
         self.implied_by_scope_roles = frozenset(implied_by_scope_roles)
         self.implied_by_group_roles = frozenset(implied_by_group_roles)
@@ -508,6 +511,9 @@ class Group(models.Model):
 
     name = models.CharField(max_length=255, validators=[validate_group_name])
     scope = models.ForeignKey(Scope, null=False, on_delete=models.PROTECT)
+    workspace = models.ForeignKey(
+        Workspace, null=True, blank=True, on_delete=models.PROTECT
+    )
     users = models.ManyToManyField(
         User,
         blank=True,
@@ -524,14 +530,26 @@ class Group(models.Model):
         base_manager_name = "objects"
         constraints = [
             UniqueConstraint(
-                fields=["name", "scope"],
-                name="%(app_label)s_%(class)s_unique_name_scope",
+                F("name"),
+                F("scope"),
+                # Hack to simulate nulls_distinct in Django 4.2
+                Coalesce("workspace", Value(-1)),
+                name="%(app_label)s_%(class)s_unique_name_scope_workspace",
             ),
+            # From Django 5.0
+            # UniqueConstraint(
+            #     fields=["name", "scope", "workspace"],
+            #     name="%(app_label)s_%(class)s_unique_name_scope_workspace",
+            #     nulls_distinct=False,
+            # ),
         ]
 
     def __str__(self) -> str:
         """Return the scoped group name."""
-        return f"{self.scope.name}/{self.name}"
+        if self.workspace is not None:
+            return f"{self.scope.name}/{self.workspace.name}/{self.name}"
+        else:
+            return f"{self.scope.name}/{self.name}"
 
     @copy_signature_from(models.Model.save)
     def save(self, *args: Any, **kwargs: Any) -> None:
@@ -545,22 +563,53 @@ class Group(models.Model):
         else:
             self.add_audit_log(GroupAuditLogUpdated.create_diff(old, self))
 
+    def get_absolute_url(self) -> str:
+        """Return an absolute URL to this group."""
+        # Prevent circular import
+        from debusine.server.scopes import urlconf_scope
+
+        with urlconf_scope(self.scope.name):
+            if self.workspace is None:
+                return reverse(
+                    "groups:detail",
+                    kwargs={"group": self.name},
+                )
+            else:
+                return reverse(
+                    "workspaces:groups:detail",
+                    kwargs={"wname": self.workspace.name, "group": self.name},
+                )
+
+    @property
+    def name_without_scope(self) -> str:
+        """Get the qualified group name without the scope."""
+        if self.workspace is not None:
+            return f"{self.workspace.name}/{self.name}"
+        else:
+            return self.name
+
     def ui(self, request: "HttpRequest") -> "GroupUI":
         """Return a UI helper for this instance."""
         from debusine.web.views.ui.auth import GroupUI
 
         return GroupUI.get(request, self)
 
-    def get_absolute_url(self) -> str:
-        """Return an absolute URL to this user."""
+    def get_absolute_url_audit_log(self) -> str:
+        """Return an absolute URL to this group's audit log."""
         # Prevent circular import
         from debusine.server.scopes import urlconf_scope
 
         with urlconf_scope(self.scope.name):
-            return reverse(
-                "groups:detail",
-                kwargs={"group": self.name},
-            )
+            if self.workspace is None:
+                return reverse(
+                    "groups:audit-log",
+                    kwargs={"group": self.name},
+                )
+            else:
+                return reverse(
+                    "workspaces:groups:audit-log",
+                    kwargs={"wname": self.workspace.name, "group": self.name},
+                )
 
     @permission_check("{user} cannot display {resource}")
     def can_display(self, user: PermissionUser) -> bool:
@@ -679,10 +728,6 @@ class GroupMembership(models.Model):
         max_length=16, choices=Roles.choices, default=Roles.MEMBER
     )
 
-    def __str__(self) -> str:
-        """Return a string representation."""
-        return f"{self.group}:{self.user}"
-
     class Meta(TypedModelMeta):
         constraints = [
             UniqueConstraint(
@@ -691,6 +736,64 @@ class GroupMembership(models.Model):
             ),
         ]
 
+    def __str__(self) -> str:
+        """Return a string representation."""
+        return f"{self.group}:{self.user}"
+
+    def ui(self, request: "HttpRequest") -> "GroupMembershipUI":
+        """Return a UI helper for this instance."""
+        from debusine.web.views.ui.auth import GroupMembershipUI
+
+        return GroupMembershipUI.get(request, self)
+
+    def get_absolute_url_update(self) -> str:
+        """Return an absolute URL to manage this memberhsip."""
+        # Prevent circular import
+        from debusine.server.scopes import urlconf_scope
+
+        with urlconf_scope(self.group.scope.name):
+            if self.group.workspace is None:
+                return reverse(
+                    "groups:update-member",
+                    kwargs={
+                        "group": self.group.name,
+                        "user": self.user.username,
+                    },
+                )
+            else:
+                return reverse(
+                    "workspaces:groups:update-member",
+                    kwargs={
+                        "wname": self.group.workspace.name,
+                        "group": self.group.name,
+                        "user": self.user.username,
+                    },
+                )
+
+    def get_absolute_url_remove(self) -> str:
+        """Return an absolute URL to remove this memberhsip."""
+        # Prevent circular import
+        from debusine.server.scopes import urlconf_scope
+
+        with urlconf_scope(self.group.scope.name):
+            if self.group.workspace is None:
+                return reverse(
+                    "groups:remove-member",
+                    kwargs={
+                        "group": self.group.name,
+                        "user": self.user.username,
+                    },
+                )
+            else:
+                return reverse(
+                    "workspaces:groups:remove-member",
+                    kwargs={
+                        "wname": self.group.workspace.name,
+                        "group": self.group.name,
+                        "user": self.user.username,
+                    },
+                )
+
 
 class GroupAuditLogEntryTypes(StrEnum):
     """Possible values for GroupAuditLogEntry types."""
@@ -705,11 +808,7 @@ class GroupAuditLogEntryTypes(StrEnum):
 class GroupAuditLogEntryBase(pydantic.BaseModel, abc.ABC):
     """Base class for all audit log payloads."""
 
-    class Config:
-        """Set up stricter pydantic Config."""
-
-        validate_assignment = True
-        extra = "forbid"
+    model_config = pydantic.ConfigDict(validate_assignment=True, extra="forbid")
 
     #: Username of the user performing the action
     actor: str = ""
@@ -727,6 +826,7 @@ class GroupAuditLogCreated(GroupAuditLogEntryBase):
     )
     name: str
     scope: str
+    workspace: str | None = None
     ephemeral: bool
 
     @classmethod
@@ -735,15 +835,17 @@ class GroupAuditLogCreated(GroupAuditLogEntryBase):
         return cls(
             name=group.name,
             scope=str(group.scope),
+            workspace=group.workspace.name if group.workspace else None,
             ephemeral=group.ephemeral,
         )
 
     def description(self) -> str:
         """Format a description for this change."""
         unknown = "<unknown>"
-        group_desc = (
-            f"group {self.name or unknown} in scope {self.scope or unknown}"
-        )
+        group_name = self.name or unknown
+        if self.workspace is not None:
+            group_name = self.workspace + "/" + group_name
+        group_desc = f"group {group_name} in scope {self.scope or unknown}"
         if self.ephemeral:
             return f"{self.actor} created ephemeral {group_desc}"
         else:
@@ -758,6 +860,7 @@ class GroupAuditLogUpdated(GroupAuditLogEntryBase):
     )
     name: tuple[str, str] | None = None
     scope: tuple[str, str] | None = None
+    workspace: tuple[str | None, str | None] | None = None
     ephemeral: tuple[bool, bool] | None = None
 
     @classmethod
@@ -769,19 +872,27 @@ class GroupAuditLogUpdated(GroupAuditLogEntryBase):
         """
         name: tuple[str, str] | None = None
         scope: tuple[str, str] | None = None
+        workspace: tuple[str | None, str | None] | None = None
         ephemeral: tuple[bool, bool] | None = None
         if old.name != new.name:
             name = (old.name, new.name)
         if old.scope != new.scope:
             scope = (str(old.scope), str(new.scope))
+        if old.workspace != new.workspace:
+            workspace = (
+                old.workspace.name if old.workspace else None,
+                new.workspace.name if new.workspace else None,
+            )
         if old.ephemeral != new.ephemeral:
             ephemeral = (old.ephemeral, new.ephemeral)
-        return cls(name=name, scope=scope, ephemeral=ephemeral)
+        return cls(
+            name=name, scope=scope, workspace=workspace, ephemeral=ephemeral
+        )
 
     def description(self) -> str:
         """Format a description for this change."""
         changes: list[str] = []
-        for field in "name", "scope", "ephemeral":
+        for field in "name", "scope", "workspace", "ephemeral":
             change = getattr(self, field)
             if change is None:
                 continue
@@ -848,6 +959,10 @@ GroupAuditLogEntry: TypeAlias = Annotated[
     pydantic.Field(discriminator="type"),
 ]
 
+group_audit_log_entry_adapter: pydantic.TypeAdapter[GroupAuditLogEntry] = (
+    pydantic.TypeAdapter(GroupAuditLogEntry)
+)
+
 
 class GroupAuditLogManager(models.Manager["GroupAuditLog"]):
     """Manager for :py:class:`GroupAuditLog`."""
@@ -859,7 +974,9 @@ class GroupAuditLogManager(models.Manager["GroupAuditLog"]):
         changes: GroupAuditLogEntry,
     ) -> "GroupAuditLog":
         """Create GroupAuditLog entry."""
-        return self.create(group=group, actor=actor, changes=changes.dict())
+        return self.create(
+            group=group, actor=actor, changes=changes.model_dump()
+        )
 
 
 class GroupAuditLog(models.Model):
@@ -880,13 +997,7 @@ class GroupAuditLog(models.Model):
     @property
     def changes_model(self) -> GroupAuditLogEntry:
         """Return the pydantic model for changes."""
-        # mypy complains that GroupAuditLogEntry is a "<typing special form>",
-        # but the code works. I'm adding a mypy override for now, and hopefully
-        # this can get cleaned in pydantic2.
-        # See https://salsa.debian.org/freexian-team/debusine/-/merge_requests/1701#note_597300  # noqa: E501
-        return pydantic.parse_obj_as(
-            GroupAuditLogEntry, self.changes  # type: ignore[arg-type]
-        )
+        return group_audit_log_entry_adapter.validate_python(self.changes)
 
 
 class ClientEnroll(models.Model):
