@@ -8,12 +8,13 @@
 # contained in the LICENSE file.
 
 """Unit tests for the scopes models."""
+
 from typing import ClassVar
 
 from django.contrib.auth.models import AnonymousUser
 from django.core.exceptions import ImproperlyConfigured, ValidationError
 from django.db import IntegrityError, transaction
-from django.test import override_settings
+from django.test import RequestFactory, override_settings
 
 from debusine.db.context import context
 from debusine.db.models import FileInStore, FileStore, Group, Scope, User
@@ -129,6 +130,13 @@ class ScopeTests(TestCase):
         with self.assertNumQueries(expected_queries):
             self.assertFalse(scope.has_role(user, Scope.Roles.OWNER))
 
+    def test_get_ui(self) -> None:
+        from debusine.web.views.ui.scopes import ScopeUI
+
+        request = RequestFactory().get("/")
+        ui = self.scenario.scope.ui(request)
+        self.assertIsInstance(ui, ScopeUI)
+
     def test_create(self) -> None:
         """Test basic behavior."""
         scope = Scope.objects.create(name="test")
