@@ -82,14 +82,14 @@ class WorkerPoolTests(TestCase):
 
     def test_limits_model(self) -> None:
         limits = WorkerPoolLimits(max_active_instances=10)
-        worker_pool = WorkerPool(limits=limits.dict())
+        worker_pool = WorkerPool(limits=limits.model_dump())
         self.assertEqual(worker_pool.limits_model, limits)
 
     def test_specifications_model(self) -> None:
         provider_account = self.playground.create_cloud_provider_account_asset()
         specifications = DummyWorkerPoolSpecification(features=["foo"])
         worker_pool = WorkerPool(
-            specifications=specifications.dict(),
+            specifications=specifications.model_dump(),
             provider_account=provider_account,
         )
         self.assertEqual(worker_pool.specifications_model, specifications)
@@ -109,7 +109,7 @@ class WorkerPoolTests(TestCase):
         specifications = AWSEC2WorkerPoolSpecification(launch_templates=[])
         worker_pool = WorkerPool(
             name="foo",
-            specifications=specifications.dict(),
+            specifications=specifications.model_dump(),
             provider_account=provider_account,
         )
         with self.assertRaisesRegex(
@@ -450,5 +450,5 @@ class ScopeWorkerPoolTests(TestCase):
 
     def test_limits_model(self) -> None:
         limits = ScopeWorkerPoolLimits(target_max_seconds_per_month=99)
-        scope_worker_pool = ScopeWorkerPool(limits=limits.dict())
+        scope_worker_pool = ScopeWorkerPool(limits=limits.model_dump())
         self.assertEqual(scope_worker_pool.limits_model, limits)
