@@ -17,11 +17,6 @@ from unittest import mock
 
 from django.db.models import Model
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic  # type: ignore
-
 from debusine.artifacts.models import (
     ArtifactCategory,
     BareDataCategory,
@@ -307,10 +302,9 @@ class PackageBuildLog(DefaultContext):
                 },
                 source_package=DebianAutopkgtestSource(
                     name="phing",
-                    url=pydantic.parse_obj_as(
-                        pydantic.AnyUrl,
+                    url=(
                         "https://debusine.debian.net/debian/developers/"
-                        "artifact/2489330/download/phing_3.1.0-1.dsc",
+                        "artifact/2489330/download/phing_3.1.0-1.dsc"
                     ),
                     version="3.1.0-1",
                 ),
@@ -353,6 +347,7 @@ class DebianWorkspace(DefaultContext):
     env_sid_autopkgtest_amd64: CollectionItem
     env_sid_lintian_amd64: CollectionItem
 
+    collection_archive: Collection
     collection_qa_results_sid: Collection
     collection_suite_sid: Collection
 
@@ -373,6 +368,10 @@ class DebianWorkspace(DefaultContext):
             variant="lintian",
             workspace=self.workspace,
         )
+        self.collection_archive = self.playground.create_singleton_collection(
+            category=CollectionCategory.ARCHIVE,
+            workspace=self.workspace,
+        )
         self.collection_qa_results_sid = self.playground.create_collection(
             workspace=self.workspace,
             name="sid",
@@ -604,9 +603,7 @@ class UIRegressionTesting(DebianWorkspace):
                 source_package=DebianAutopkgtestSource(
                     name=package.data["name"],
                     version=package.data["version"],
-                    url=pydantic.parse_obj_as(
-                        pydantic.AnyUrl, "https://example.org/test"
-                    ),
+                    url="https://example.org/test",
                 ),
                 architecture=architecture,
                 distribution="debian",
@@ -617,7 +614,7 @@ class UIRegressionTesting(DebianWorkspace):
 
     def add_result_lintian(
         self,
-        package: Artifact,  # noqa: U100
+        package: Artifact,  # noqa: ARG002, U100
         architecture: str,
         *,
         parent: WorkRequest,
@@ -648,7 +645,7 @@ class UIRegressionTesting(DebianWorkspace):
 
     def add_result_piuparts(
         self,
-        package: Artifact,  # noqa: U100
+        package: Artifact,  # noqa: ARG002, U100
         architecture: str,
         *,
         parent: WorkRequest,
@@ -1165,7 +1162,10 @@ class UIPlayground(PackageBuildLog, UIRegressionTesting):
 
         # Make them owners of the playground workspace...
         role_group = self.playground.create_group_role(
-            self.workspace, Workspace.Roles.OWNER, users=[self.user]
+            self.workspace,
+            Workspace.Roles.OWNER,
+            users=[self.user],
+            name="Admins",
         )
         # ...and admin of the owners group
         role_group.set_user_role(self.user, Group.Roles.ADMIN)
@@ -1175,6 +1175,11 @@ class UIPlayground(PackageBuildLog, UIRegressionTesting):
         other_group.add_user(self.user)
         other_group.add_user(other_user)
 
+        # Create an unscoped Admins group
+        ws_group = Group.objects.create(name="Admins", scope=self.scope)
+        ws_group.add_user(self.user)
+        ws_group.set_user_role(self.user, Group.Roles.ADMIN)
+
         # Create a worker pool and some workers
         self.worker_pool = self.playground.create_worker_pool("playground")
 
