@@ -25,7 +25,6 @@ from debusine.artifacts.models import (
     CollectionCategory,
     DebianQAResult,
 )
-from debusine.client.models import model_to_json_serializable_dict
 from debusine.db.models import Artifact, CollectionItem, User, WorkRequest
 from debusine.server.collections.base import (
     CollectionManagerInterface,
@@ -140,7 +139,7 @@ class DebianQAResultsManager(CollectionManagerInterface):
                 category,
                 parent_collection=self.collection,
                 name=name,
-                data=model_to_json_serializable_dict(qa_result),
+                data=qa_result.model_dump(mode="json"),
                 created_at=created_at,
                 created_by_user=user,
                 created_by_workflow=workflow,
@@ -223,7 +222,7 @@ class DebianQAResultsManager(CollectionManagerInterface):
                 artifact,
                 parent_collection=self.collection,
                 name=name,
-                data=model_to_json_serializable_dict(qa_result),
+                data=qa_result.model_dump(mode="json"),
                 created_at=created_at,
                 created_by_user=user,
                 created_by_workflow=workflow,
