@@ -86,17 +86,6 @@ class DebianArchiveManagerTests(TestCase):
         )
         return artifact
 
-    def create_repository_index(self, path: str) -> Artifact:
-        """Create a minimal ``debian:repository-index`` artifact."""
-        artifact, _ = self.playground.create_artifact(
-            category=ArtifactCategory.REPOSITORY_INDEX,
-            workspace=self.scenario.workspace,
-            paths=[path],
-            create_files=True,
-            skip_add_files_in_store=True,
-        )
-        return artifact
-
     def create_suite(self, name: str) -> Collection:
         """Create a minimal ``debian:suite`` collection."""
         return self.playground.create_collection(
@@ -105,7 +94,9 @@ class DebianArchiveManagerTests(TestCase):
 
     def test_add_artifact_repository_index(self) -> None:
         """``add_artifact`` can add a repository index to the suite."""
-        doc_artifact = self.create_repository_index("social-contract.txt")
+        doc_artifact = self.playground.create_repository_index(
+            "social-contract.txt", skip_add_files_in_store=True
+        )
 
         collection_item = self.manager.add_artifact(
             doc_artifact,
@@ -120,7 +111,9 @@ class DebianArchiveManagerTests(TestCase):
 
     def test_add_artifact_repository_index_path_under_dists(self) -> None:
         """``add_artifact`` refuses paths not under ``dists/``."""
-        artifact = self.create_repository_index("foo")
+        artifact = self.playground.create_repository_index(
+            "foo", skip_add_files_in_store=True
+        )
 
         with self.assertRaisesRegex(
             ItemAdditionError,
@@ -134,7 +127,12 @@ class DebianArchiveManagerTests(TestCase):
 
     def test_add_artifact_repository_index_violates_constraint(self) -> None:
         """``add_artifact`` reports repository index constraint violations."""
-        artifacts = [self.create_repository_index("README") for _ in range(2)]
+        artifacts = [
+            self.playground.create_repository_index(
+                "README", skip_add_files_in_store=True
+            )
+            for _ in range(2)
+        ]
         self.manager.add_artifact(
             artifacts[0], user=self.scenario.user, variables={"path": "README"}
         )
@@ -152,13 +150,17 @@ class DebianArchiveManagerTests(TestCase):
 
     def test_add_artifact_repository_index_replace(self) -> None:
         """``add_artifact`` can replace an existing repository index."""
-        readme_artifact = self.create_repository_index("README")
+        readme_artifact = self.playground.create_repository_index(
+            "README", skip_add_files_in_store=True
+        )
         collection_item = self.manager.add_artifact(
             readme_artifact,
             user=self.scenario.user,
             variables={"path": "README"},
         )
-        readme_artifact2 = self.create_repository_index("README")
+        readme_artifact2 = self.playground.create_repository_index(
+            "README", skip_add_files_in_store=True
+        )
         collection_item2 = self.manager.add_artifact(
             readme_artifact2,
             user=self.scenario.user,
@@ -176,7 +178,9 @@ class DebianArchiveManagerTests(TestCase):
 
     def test_do_add_artifact_requires_path(self) -> None:
         """`do_add_artifact` requires a `path` variable."""
-        readme_artifact = self.create_repository_index("README")
+        readme_artifact = self.playground.create_repository_index(
+            "README", skip_add_files_in_store=True
+        )
 
         with self.assertRaisesRegex(
             ItemAdditionError,
@@ -320,7 +324,9 @@ class DebianArchiveManagerTests(TestCase):
 
     def test_do_remove_item_artifact(self) -> None:
         """``do_remove_item`` removes an artifact."""
-        readme_artifact = self.create_repository_index("README")
+        readme_artifact = self.playground.create_repository_index(
+            "README", skip_add_files_in_store=True
+        )
         collection_item = self.manager.add_artifact(
             readme_artifact,
             user=self.scenario.user,
@@ -557,7 +563,9 @@ class DebianArchiveManagerTests(TestCase):
             (suites[1], "main/binary-i386/Packages.xz"),
             (suites[1], "Release"),
         ):
-            index_artifact = self.create_repository_index(PurePath(path).name)
+            index_artifact = self.playground.create_repository_index(
+                PurePath(path).name, skip_add_files_in_store=True
+            )
             items.append(
                 suite.manager.add_artifact(
                     index_artifact,
@@ -566,7 +574,9 @@ class DebianArchiveManagerTests(TestCase):
                 )
             )
 
-        index_artifact = self.create_repository_index("Packages.xz")
+        index_artifact = self.playground.create_repository_index(
+            "Packages.xz", skip_add_files_in_store=True
+        )
         items.append(
             suites[1].manager.add_artifact(
                 index_artifact,
@@ -576,7 +586,9 @@ class DebianArchiveManagerTests(TestCase):
             )
         )
 
-        readme_artifact = self.create_repository_index("README")
+        readme_artifact = self.playground.create_repository_index(
+            "README", skip_add_files_in_store=True
+        )
         items.append(
             self.manager.add_artifact(
                 readme_artifact,
