@@ -19,7 +19,6 @@ from debusine.artifacts.models import (
     CollectionCategory,
     DebianQAResult,
 )
-from debusine.client.models import model_to_json_serializable_dict
 from debusine.db.models import Collection, CollectionItem, WorkRequest
 from debusine.db.playground import scenarios
 from debusine.server.collections import (
@@ -60,8 +59,7 @@ class DebianQAResultsManagerTests(TestCase):
         """Set up tests."""
         super().setUp()
         self.autopkgtest_data_input = AutopkgtestInput(
-            source_artifact=1,
-            binary_artifacts=LookupMultiple.parse_obj([1, 2, 3]),
+            source_artifact=1, binary_artifacts=LookupMultiple((1, 2, 3))
         )
         # Task data that passes validation, useful to create mock autopkgtest
         # work requests
@@ -72,7 +70,7 @@ class DebianQAResultsManagerTests(TestCase):
         )
 
         self.piuparts_data_input = PiupartsDataInput(
-            binary_artifacts=LookupMultiple.parse_obj([1, 2, 3])
+            binary_artifacts=LookupMultiple((1, 2, 3))
         )
         self.piuparts_data = PiupartsData(
             input=self.piuparts_data_input,
@@ -83,8 +81,7 @@ class DebianQAResultsManagerTests(TestCase):
 
         self.lintian_data = LintianData(
             input=LintianInput(
-                source_artifact=1,
-                binary_artifacts=LookupMultiple.parse_obj([1, 2, 3]),
+                source_artifact=1, binary_artifacts=LookupMultiple((1, 2, 3))
             )
         )
 
@@ -642,17 +639,15 @@ class DebianQAResultsManagerTests(TestCase):
                 )[0],
                 parent_collection=self.collection,
                 name=f"autopkgtest_hello_1.0-1_amd64_{i + 1}",
-                data=model_to_json_serializable_dict(
-                    DebianQAResult(
-                        task_name="autopkgtest",
-                        package="hello",
-                        version="1.0-1",
-                        architecture="amd64",
-                        timestamp=int(now.timestamp()) - 10 + i,
-                        work_request_id=work_request.id,
-                        result=WorkRequest.Results.SUCCESS,
-                    )
-                ),
+                data=DebianQAResult(
+                    task_name="autopkgtest",
+                    package="hello",
+                    version="1.0-1",
+                    architecture="amd64",
+                    timestamp=int(now.timestamp()) - 10 + i,
+                    work_request_id=work_request.id,
+                    result=WorkRequest.Results.SUCCESS,
+                ).model_dump(mode="json"),
                 created_by_user=self.scenario.user,
                 created_by_workflow=self.workflow,
             )
