@@ -18,7 +18,6 @@ from debusine.artifacts.models import (
     DebusineTaskConfiguration,
     TaskTypes,
 )
-from debusine.client.models import model_to_json_serializable_dict
 from debusine.db.models import Collection, CollectionItem
 from debusine.db.playground import scenarios
 from debusine.server.collections import DebusineTaskConfigurationManager
@@ -128,9 +127,7 @@ class DebusineTaskConfigurationManagerTests(TaskConfigTestCase):
             replace=True,
         )
 
-        serialized_data = model_to_json_serializable_dict(
-            data, exclude_unset=True
-        )
+        serialized_data = data.model_dump(mode="json", exclude_unset=True)
 
         item_old.refresh_from_db()
         self.assertEqual(item_old.name, "template:test")
@@ -157,7 +154,7 @@ class DebusineTaskConfigurationManagerTests(TaskConfigTestCase):
         self.assertEqual(item.name, "template:test")
         self.assertEqual(item.child_type, CollectionItem.Types.BARE)
         self.assertEqual(
-            item.data, model_to_json_serializable_dict(data, exclude_unset=True)
+            item.data, data.model_dump(mode="json", exclude_unset=True)
         )
 
     def test_remove_item_bare_data(self) -> None:
@@ -239,7 +236,7 @@ class ConfigLookupTests(TaskConfigTestCase):
         with self.assertRaisesRegex(
             TaskConfigError,
             r"(?s)debusine:task-configuration item does not validate"
-            r".+extra fields not permitted",
+            r".+Extra inputs are not permitted",
         ):
             lookup_config_by_name(self.collection, entry.name())
 
@@ -472,7 +469,7 @@ class ApplyConfigurationTests(TaskConfigTestCase):
         apply_configuration(
             task_data, self.collection, TaskTypes.WORKER, "noop", None, None
         )
-        self.assertEqual(task_data, {})
+        self.assertEqual(task_data, {"task_configuration": self.collection.pk})
 
     def test_with_config(self) -> None:
         """Test with overrides to apply."""
@@ -493,7 +490,12 @@ class ApplyConfigurationTests(TaskConfigTestCase):
         )
         self.assertEqual(
             task_data,
-            {"key": "value", "override": "overridden", "default": "added"},
+            {
+                "key": "value",
+                "override": "overridden",
+                "default": "added",
+                "task_configuration": self.collection.pk,
+            },
         )
 
     def test_defaults_with_none(self) -> None:
@@ -509,4 +511,7 @@ class ApplyConfigurationTests(TaskConfigTestCase):
         apply_configuration(
             task_data, self.collection, TaskTypes.WORKER, "noop", None, None
         )
-        self.assertEqual(task_data, {"default": "added"})
+        self.assertEqual(
+            task_data,
+            {"default": "added", "task_configuration": self.collection.pk},
+        )
