@@ -35,6 +35,7 @@ from debusine.db.models import (
 )
 from debusine.server.collections.lookup import (
     LookupResult,
+    artifact_ids,
     lookup_multiple,
     lookup_single,
     reconstruct_lookup,
@@ -643,7 +644,7 @@ class LookupMultipleTests(LookupMixin, TestCase):
         self, data: dict[str, Any] | Sequence[int | str | dict[str, Any]]
     ) -> LookupMultiple:
         """Parse the lookup syntax."""
-        return LookupMultiple.parse_obj(data)
+        return LookupMultiple.model_validate(data)
 
     def assert_lookup_equal(
         self,
@@ -883,7 +884,7 @@ class LookupMultipleTests(LookupMixin, TestCase):
                     with self.assertRaisesRegex(
                         LookupError,
                         f"Result from"
-                        f" {LookupMultiple.parse_obj([lookup]).export()}"
+                        f" {LookupMultiple.model_validate([lookup]).export()}"
                         f" is of type '.*' instead of expected"
                         f" {expect_type.name.lower()!r}",
                     ):
@@ -1303,3 +1304,24 @@ class ReconstructLookupTests(LookupMixin, TestCase):
             ),
             "internal@collections",
         )
+
+
+class ArtifactIdsTests(LookupMixin, TestCase):
+    """Tests for artifact_ids() function."""
+
+    def test_return_artifact_ids(self) -> None:
+        artifact = self.playground.create_minimal_binary_package_artifact()
+        collection = self.playground.create_collection(
+            name="test", category=CollectionCategory.TEST
+        )
+
+        items = [
+            LookupResult(
+                result_type=CollectionItem.Types.ARTIFACT, artifact=artifact
+            ),
+            LookupResult(
+                result_type=CollectionItem.Types.COLLECTION,
+                collection=collection,
+            ),
+        ]
+        self.assertEqual(artifact_ids(items), [artifact.id])
