@@ -24,10 +24,7 @@ from debusine.artifacts.models import (
     RuntimeStatistics,
     TaskTypes,
 )
-from debusine.client.models import (
-    LookupChildType,
-    model_to_json_serializable_dict,
-)
+from debusine.client.models import LookupChildType
 from debusine.db.models import Collection, CollectionItem, WorkRequest
 from debusine.db.playground import scenarios
 from debusine.server.collections.base import ItemAdditionError
@@ -259,9 +256,7 @@ class TaskHistoryManagerTests(TestCase):
             replace=True,
         )
 
-        serialized_data = model_to_json_serializable_dict(
-            data, exclude_unset=True
-        )
+        serialized_data = data.model_dump(mode="json", exclude_unset=True)
         item_old.refresh_from_db()
         self.assertEqual(item_old.name, "Worker:sbuild:base-files:sid/amd64:1")
         self.assertEqual(item_old.child_type, CollectionItem.Types.BARE)
@@ -298,7 +293,7 @@ class TaskHistoryManagerTests(TestCase):
         self.assertEqual(item.name, "Worker:sbuild:base-files:sid/amd64:1")
         self.assertEqual(item.child_type, CollectionItem.Types.BARE)
         self.assertEqual(
-            item.data, model_to_json_serializable_dict(data, exclude_unset=True)
+            item.data, data.model_dump(mode="json", exclude_unset=True)
         )
 
     def test_add_bare_data_keeps_last_success(self) -> None:
@@ -640,7 +635,7 @@ class TaskHistoryManagerTests(TestCase):
         )
         self.assertCountEqual(
             lookup_multiple(
-                LookupMultiple.parse_obj(
+                LookupMultiple.model_validate(
                     {
                         "collection": self.collection_lookup,
                         "child_type": LookupChildType.BARE,
@@ -675,7 +670,7 @@ class TaskHistoryManagerTests(TestCase):
             )
             for work_request in work_requests
         ]
-        subordinate_lookup = LookupMultiple.parse_obj(
+        subordinate_lookup = LookupMultiple.model_validate(
             [f"{upload.id}@artifacts" for upload in uploads]
         )
 
@@ -701,7 +696,7 @@ class TaskHistoryManagerTests(TestCase):
         )
         self.assertCountEqual(
             lookup_multiple(
-                LookupMultiple.parse_obj(
+                LookupMultiple.model_validate(
                     {
                         "collection": self.collection_lookup,
                         "child_type": LookupChildType.BARE,
@@ -754,7 +749,7 @@ class TaskHistoryManagerTests(TestCase):
         )
         self.assertCountEqual(
             lookup_multiple(
-                LookupMultiple.parse_obj(
+                LookupMultiple.model_validate(
                     {
                         "collection": self.collection_lookup,
                         "child_type": LookupChildType.BARE,
@@ -797,7 +792,7 @@ class TaskHistoryManagerTests(TestCase):
             )
             for work_request in work_requests
         ]
-        subordinate_lookup = LookupMultiple.parse_obj(
+        subordinate_lookup = LookupMultiple.model_validate(
             [f"{upload.id}@artifacts" for upload in uploads]
         )
 
@@ -816,7 +811,7 @@ class TaskHistoryManagerTests(TestCase):
         )
         self.assertCountEqual(
             lookup_multiple(
-                LookupMultiple.parse_obj(
+                LookupMultiple.model_validate(
                     {
                         "collection": self.collection_lookup,
                         "child_type": LookupChildType.BARE,
