@@ -9,7 +9,7 @@
 
 """Manager for debusine:workflow-internal collections."""
 
-from datetime import datetime
+import datetime as dt
 from typing import Any
 
 from django.db import IntegrityError
@@ -46,7 +46,7 @@ class WorkflowInternalManager(CollectionManagerInterface):
         data: dict[str, Any] | None = None,  # noqa: U100
         name: str | None = None,
         replace: bool = False,
-        created_at: datetime | None = None,
+        created_at: dt.datetime | None = None,
         replaced_by: CollectionItem | None = None,
     ) -> CollectionItem:
         """Add bare data into the managed collection."""
@@ -96,7 +96,7 @@ class WorkflowInternalManager(CollectionManagerInterface):
         variables: dict[str, Any] | None = None,
         name: str | None = None,
         replace: bool = False,
-        created_at: datetime | None = None,
+        created_at: dt.datetime | None = None,
         replaced_by: CollectionItem | None = None,
     ) -> CollectionItem:
         """
