@@ -13,12 +13,8 @@ import logging
 import traceback
 from typing import Any, NoReturn, TYPE_CHECKING
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
 from django.http import Http404
+from pydantic_core import ErrorDetails
 from rest_framework import status
 from rest_framework.exceptions import APIException
 from rest_framework.views import exception_handler, set_rollback
@@ -29,8 +25,6 @@ from debusine.db.models import Workspace
 if TYPE_CHECKING:
     from debusine.server.views import ProblemResponse
 
-    ErrorDict = pydantic.error_wrappers.ErrorDict
-
 logger = logging.getLogger(__name__)
 
 
@@ -42,7 +36,7 @@ class DebusineAPIException(APIException):
         title: str,
         detail: str | None = None,
         validation_errors: dict[str, Any] | None = None,
-        pydantic_validation_errors: list["ErrorDict"] | None = None,
+        pydantic_validation_errors: list[ErrorDetails] | None = None,
         status_code: int = status.HTTP_400_BAD_REQUEST,
         rollback_transaction: bool = True,
     ) -> None:
