@@ -69,7 +69,10 @@ class LocalFileBackendEntry(
         """Yield the path to a possibly-temporary local copy of the file."""
         yield self.get_local_path()
 
-    def get_url(self, content_type: str | None = None) -> None:  # noqa: U100
+    def get_url(
+        self,
+        content_type: str | None = None,  # noqa: ARG002, U100
+    ) -> None:
         """Return None: no remote URL for a file in LocalFileBackend."""
         return None
 
@@ -195,7 +198,7 @@ class LocalFileBackend(FileBackendInterface[LocalFileBackendConfiguration]):
                         # timezone-naive, but we can reasonably assume that
                         # a debusine store is on a sufficiently Unix-like
                         # file system to be UTC.
-                        tz=dt.timezone.utc,
+                        tz=dt.UTC,
                     )
                 ):
                     continue
