@@ -9,7 +9,7 @@
 
 """Tests for S3FileBackend."""
 
-from datetime import timedelta
+import datetime as dt
 from io import BytesIO
 from typing import ClassVar
 from urllib.parse import parse_qs, urlsplit
@@ -115,8 +115,8 @@ class S3FileBackendTests(TestCase):
             provider_account_data.configuration.s3_endpoint_url = (
                 "https://s3.eu-west-2.amazonaws.com/"
             )
-            self.file_store.provider_account.data = provider_account_data.dict(
-                exclude_unset=True
+            self.file_store.provider_account.data = (
+                provider_account_data.model_dump(exclude_unset=True)
             )
             self.file_store.provider_account.save()
 
@@ -278,8 +278,8 @@ class S3FileBackendTests(TestCase):
             provider_account_data.configuration.s3_endpoint_url = (
                 "https://hel1.your-objectstorage.com/"
             )
-            self.file_store.provider_account.data = provider_account_data.dict(
-                exclude_unset=True
+            self.file_store.provider_account.data = (
+                provider_account_data.model_dump(exclude_unset=True)
             )
             self.file_store.provider_account.save()
 
@@ -296,7 +296,12 @@ class S3FileBackendTests(TestCase):
         stubber.add_response(
             "put_object",
             {},
-            {"Bucket": "test-bucket", "Key": identifier, "Body": stub.ANY},
+            {
+                "Bucket": "test-bucket",
+                "Key": identifier,
+                "Body": stub.ANY,
+                "ChecksumAlgorithm": "SHA256",
+            },
         )
 
         with stubber:
@@ -446,7 +451,7 @@ class S3FileBackendTests(TestCase):
                 "Contents": [
                     {
                         "Key": f"{file.sha256.hex()}-{file.size}",
-                        "LastModified": now - timedelta(days=10 - i),
+                        "LastModified": now - dt.timedelta(days=10 - i),
                     }
                     for i, file in enumerate(files)
                 ]
@@ -457,7 +462,8 @@ class S3FileBackendTests(TestCase):
         with stubber:
             self.assertCountEqual(
                 backend.list_entries(
-                    mtime_filter=lambda mtime: mtime < now - timedelta(days=6)
+                    mtime_filter=lambda mtime: mtime
+                    < now - dt.timedelta(days=6)
                 ),
                 expected_entries[:4],
             )
