@@ -14,8 +14,10 @@ Note: to make commands easier to be invoked from Ansible, we take care to make
 them idempotent.
 """
 
+import argparse
 from collections.abc import Callable
-from typing import Any, NoReturn, cast
+from functools import cached_property
+from typing import Any, NoReturn, Self, cast, override
 
 from django.core.exceptions import ValidationError
 from django.core.management import CommandError, CommandParser
@@ -23,10 +25,15 @@ from django.core.management.base import OutputWrapper
 from django.db import transaction
 
 from debusine.db.context import context
-from debusine.db.models import Group, Scope, User
+from debusine.db.models import Group, Scope, User, Workspace
 from debusine.db.models.scopes import ScopeRole
 from debusine.django.management.debusine_base_command import DebusineBaseCommand
-from debusine.server.management.management_utils import Groups, Users, get_scope
+from debusine.server.management.management_utils import (
+    Groups,
+    Users,
+    get_scope,
+    get_workspace,
+)
 
 
 def print_validation_error(error: ValidationError, file: OutputWrapper) -> None:
@@ -40,11 +47,123 @@ def print_validation_error(error: ValidationError, file: OutputWrapper) -> None:
             file.write(f"* {lead}{msg}")
 
 
+class ParsedGroupArgument:
+    """Parsed elements of a ``scope[/workspace]/name`` specification."""
+
+    def __init__(
+        self, *, scope: str, name: str, workspace: str | None = None
+    ) -> None:
+        """
+        Construct a ParsedGroupArgument.
+
+        :param scope: scope name
+        :param name: group name
+        :param workspace: workspace name, or None if the group is not workspaced
+        """
+        self.scope = scope
+        self.name = name
+        self.workspace = workspace
+
+    @override
+    def __str__(self) -> str:
+        parts = [self.scope]
+        if self.workspace is not None:
+            parts.append(self.workspace)
+        parts.append(self.name)
+        return "/".join(parts)
+
+    @override
+    def __repr__(self) -> str:
+        return f"ParsedGroupArgument({str(self)})"
+
+    def as_queryset_filter(self) -> dict[str, str | None]:
+        """Build a Group queryset filter kwargs."""
+        res: dict[str, str | None] = {
+            "scope__name": self.scope,
+            "name": self.name,
+        }
+        if self.workspace is None:
+            res["workspace"] = None
+        else:
+            res["workspace__name"] = self.workspace
+        return res
+
+    @cached_property
+    def scope_instance(self) -> Scope:
+        """Resolve to a Scope instance."""
+        try:
+            return Scope.objects.get(name=self.scope)
+        except Scope.DoesNotExist:
+            raise CommandError(f"Scope {self.scope!r} not found", returncode=3)
+
+    @cached_property
+    def workspace_instance(self) -> Workspace | None:
+        """Resolve to a Workspace instance."""
+        if self.workspace is None:
+            return None
+        else:
+            try:
+                return Workspace.objects.get(
+                    scope__name=self.scope, name=self.workspace
+                )
+            except Workspace.DoesNotExist:
+                name = self.scope + "/" + self.workspace
+                raise CommandError(
+                    f"Workspace {name!r} not found", returncode=3
+                )
+
+    @cached_property
+    def group_instance(self) -> Group:
+        """Resolve to a Group instance."""
+        try:
+            return Group.objects.get(**self.as_queryset_filter())
+        except Group.DoesNotExist:
+            raise CommandError(
+                f"Group {self.name!r} not found in scope {self.scope!r}"
+                f" and workspace {self.workspace!r}",
+                returncode=3,
+            )
+
+    @classmethod
+    def parse(cls, value: str) -> Self:
+        """Build a ParsedGroupArgument from a string argument."""
+        tokens = value.split("/")
+        match tokens:
+            case [scope, name]:
+                return cls(scope=scope, name=name)
+            case [scope, workspace, name]:
+                return cls(scope=scope, name=name, workspace=workspace)
+            case _:
+                raise CommandError(
+                    f"argument {value!r} should be in the form"
+                    " 'scopename[/workspacename]/groupname'",
+                    returncode=3,
+                )
+
+
 class Command(DebusineBaseCommand):
     """Command to manage groups."""
 
     help = "Manage groups"
 
+    def add_group_argument(
+        self,
+        parser: argparse.ArgumentParser,
+        help: str,  # noqa: A002
+    ) -> None:
+        """Add a group identifier argument to an argument parser."""
+        parser.add_argument(
+            "scope_workspace_group",
+            metavar="scope[/workspace]/name",
+            help=help,
+        )
+
+    def parse_group_argument(
+        self, options: dict[str, Any]
+    ) -> ParsedGroupArgument:
+        """Parse a ``scope[/workspace]/name`` argument."""
+        return ParsedGroupArgument.parse(options["scope_workspace_group"])
+
     def add_arguments(self, parser: CommandParser) -> None:
         """Add CLI arguments."""
         subparsers = parser.add_subparsers(dest="action", required=True)
@@ -56,36 +175,36 @@ class Command(DebusineBaseCommand):
             '--yaml', action="store_true", help="Machine readable YAML output"
         )
         group_list.add_argument(
-            "scope",
-            help="list groups for this scope",
+            "--no-workspace",
+            action="store_true",
+            help="Do not list workspace-specific groups",
+        )
+        group_list.add_argument(
+            "scope_workspace",
+            metavar="scope[/workspace]",
+            help="list groups for this scope or workspace",
         )
 
         create = subparsers.add_parser(
             "create", help=self.handle_create.__doc__
         )
-        create.add_argument(
-            "scope_group",
-            metavar="scope/name",
-            help="scope/name for the new group",
+        self.add_group_argument(
+            create, help="scope/workspace/name identifying the new group"
         )
 
         rename = subparsers.add_parser(
             "rename", help=self.handle_rename.__doc__
         )
-        rename.add_argument(
-            "scope_group",
-            metavar="scope/name",
-            help="scope/name of the group to rename",
+        self.add_group_argument(
+            rename, help="scope/workspace/name identifying the group to rename"
         )
         rename.add_argument("name", help="New name for the group")
 
         delete = subparsers.add_parser(
             "delete", help=self.handle_delete.__doc__
         )
-        delete.add_argument(
-            "scope_group",
-            metavar="scope/name",
-            help="scope/name of the group to delete",
+        self.add_group_argument(
+            delete, help="scope/workspace/name identifying the group to delete"
         )
 
         members = subparsers.add_parser(
@@ -99,11 +218,10 @@ class Command(DebusineBaseCommand):
         members.add_argument(
             '--yaml', action="store_true", help="Machine readable YAML output"
         )
-        members.add_argument(
-            "scope_group",
-            metavar="scope/name",
+        self.add_group_argument(
+            members,
             help=(
-                "scope/name for the group "
+                "scope/workspace/name identifying the group "
                 "(must come before --add/--remove/--set options)"
             ),
         )
@@ -121,32 +239,15 @@ class Command(DebusineBaseCommand):
             help="set members to listed users",
         )
 
-    def get_scope_and_group_name(self, scope_group: str) -> tuple[Scope, str]:
-        """Lookup a scopename/groupname string."""
-        if "/" not in scope_group:
-            raise CommandError(
-                f"scope_group {scope_group!r} should be in the form"
-                " 'scopename/groupname'",
-                returncode=3,
-            )
-        scope_name, group_name = scope_group.split("/", 1)
-        return get_scope(scope_name), group_name
-
-    def get_scope_and_group(self, scope_group: str) -> tuple[Scope, Group]:
-        """Lookup a scopename/groupname string."""
-        scope, group_name = self.get_scope_and_group_name(scope_group)
-        return scope, self.get_group(scope, group_name)
-
-    def get_group(self, scope: Scope, group_name: str) -> Group:
-        """Lookup a group in a scope."""
-        try:
-            group = Group.objects.get(scope=scope, name=group_name)
-        except Group.DoesNotExist:
-            raise CommandError(
-                f"Group {group_name!r} not found in scope {scope.name!r}",
-                returncode=3,
-            )
-        return group
+    def get_scope_and_workspace(
+        self, scope_workspace: str
+    ) -> tuple[Scope, Workspace | None]:
+        """Lookup a ``scopename[/workspace]`` string."""
+        if "/" not in scope_workspace:
+            return get_scope(scope_workspace), None
+        else:
+            workspace = get_workspace(scope_workspace, require_scope=True)
+            return workspace.scope, workspace
 
     def get_users(self, usernames: list[str]) -> list[User]:
         """Resolve a list of usernames into a list of users."""
@@ -179,25 +280,39 @@ class Command(DebusineBaseCommand):
 
         func(*args, **options)
 
-    def handle_list(self, **options: Any) -> NoReturn:
+    def handle_list(
+        self,
+        no_workspace: bool,
+        yaml: bool,
+        scope_workspace: str,
+        **options: Any,
+    ) -> NoReturn:
         """List groups in a scope."""
-        scope = get_scope(options["scope"])
+        scope, workspace = self.get_scope_and_workspace(scope_workspace)
         groups = Group.objects.filter(scope=scope)
-        Groups(options["yaml"]).print(groups, self.stdout)
+        if workspace is not None:
+            groups = groups.filter(workspace=workspace)
+        elif no_workspace:
+            groups = groups.filter(workspace=None)
+        Groups(yaml).print(groups, self.stdout)
         raise SystemExit(0)
 
     @context.disable_permission_checks()
-    def handle_create(self, *, scope_group: str, **options: Any) -> NoReturn:
+    def handle_create(self, **options: Any) -> NoReturn:
         """
         Create a group, specified as scope/name.
 
         This is idempotent, and it makes sure the named group exists.
         """
-        scope, group_name = self.get_scope_and_group_name(scope_group)
+        group_args = self.parse_group_argument(options)
         with transaction.atomic():
-            if Group.objects.filter(scope=scope, name=group_name).exists():
+            if Group.objects.filter(**group_args.as_queryset_filter()).exists():
                 raise SystemExit(0)
-            group = Group(scope=scope, name=group_name)
+            group = Group(
+                scope=group_args.scope_instance,
+                workspace=group_args.workspace_instance,
+                name=group_args.name,
+            )
             try:
                 group.full_clean()
             except ValidationError as exc:
@@ -208,15 +323,13 @@ class Command(DebusineBaseCommand):
         raise SystemExit(0)
 
     @context.disable_permission_checks()
-    def handle_rename(
-        self, *, scope_group: str, name: str, **options: Any
-    ) -> NoReturn:
+    def handle_rename(self, *, name: str, **options: Any) -> NoReturn:
         """Rename a group."""
-        scope, group = self.get_scope_and_group(scope_group)
-
-        if name == group.name:
+        group_args = self.parse_group_argument(options)
+        if name == group_args.name:
             raise SystemExit(0)
 
+        group = group_args.group_instance
         group.name = name
         try:
             group.full_clean()
@@ -229,23 +342,25 @@ class Command(DebusineBaseCommand):
 
         raise SystemExit(0)
 
-    def handle_delete(self, *, scope_group: str, **options: Any) -> NoReturn:
+    def handle_delete(self, **options: Any) -> NoReturn:
         """Delete a group."""
-        scope, group_name = self.get_scope_and_group_name(scope_group)
-
+        group_args = self.parse_group_argument(options)
         with transaction.atomic():
-            if not Group.objects.filter(scope=scope, name=group_name).exists():
+            if not Group.objects.filter(
+                **group_args.as_queryset_filter()
+            ).exists():
                 raise SystemExit(0)
-            group = self.get_group(scope, group_name)
+            group = group_args.group_instance
             ScopeRole.objects.filter(group=group).delete()
             group.delete()
 
         raise SystemExit(0)
 
     @context.disable_permission_checks()
-    def handle_members(self, *, scope_group: str, **options: Any) -> NoReturn:
+    def handle_members(self, **options: Any) -> NoReturn:
         """Display or change group membership."""
-        scope, group = self.get_scope_and_group(scope_group)
+        group_args = self.parse_group_argument(options)
+        group = group_args.group_instance
 
         # Change membership
         change_requested: bool = False
