@@ -1,4 +1,4 @@
-# Copyright 2024 The Debusine Developers
+# Copyright © The Debusine Developers
 # See the AUTHORS file at the top-level directory of this distribution
 #
 # This file is part of Debusine. It is subject to the license terms
@@ -26,7 +26,7 @@ class Command(DebusineBaseCommand):
 
     def handle(self, *args: Any, **options: Any) -> NoReturn:
         """Show server configuration."""
-        cols, lines = shutil.get_terminal_size()
+        cols, _ = shutil.get_terminal_size()
         wrapper = textwrap.TextWrapper(width=cols)
 
         def wprint(text: str) -> None:
