@@ -45,4 +45,4 @@ class CreateTokenCommandTests(TestCase):
             call_command("create_token", username)
 
         self.assertEqual(exc.exception.returncode, 3)
-        self.assertEqual(Token.objects.all().count(), 0)
+        self.assertEqual(Token.objects.count(), 0)
