@@ -10,10 +10,10 @@
 """Tests for the management command delete_expired."""
 
 import contextlib
+import datetime as dt
 import io
 import threading
 from collections.abc import Iterable, Iterator
-from datetime import timedelta
 from typing import Any
 from unittest import mock
 
@@ -66,10 +66,10 @@ class DeleteExpiredCommandTests(TestCase):
         """Set up common data for tests."""
         super().setUpTestData()
         artifact_1, _ = cls.playground.create_artifact(expiration_delay=1)
-        artifact_1.created_at = timezone.now() - timedelta(days=2)
+        artifact_1.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_1.save()
         artifact_2, _ = cls.playground.create_artifact(expiration_delay=1)
-        artifact_2.created_at = timezone.now() - timedelta(days=2)
+        artifact_2.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_2.save()
 
         ArtifactRelation.objects.create(
@@ -121,36 +121,34 @@ class DeleteExpiredCommandTests(TestCase):
         artifact_id_3, _ = self.playground.create_artifact(
             paths=["README"], create_files=True, expiration_delay=1
         )
-        artifact_id_3.created_at = timezone.now() - timedelta(days=2)
+        artifact_id_3.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_id_3.save()
 
         work_request_1 = self.playground.create_workflow()
-        work_request_1.expiration_delay = timedelta(days=1)
-        work_request_1.created_at = timezone.now() - timedelta(days=365)
+        work_request_1.expiration_delay = dt.timedelta(days=1)
+        work_request_1.created_at = timezone.now() - dt.timedelta(days=365)
         work_request_1.save()
         collection_1 = work_request_1.internal_collection
         assert collection_1 is not None
 
-        create_time = timezone.now() - timedelta(days=30)
+        create_time = timezone.now() - dt.timedelta(days=30)
         with mock.patch("django.utils.timezone.now", return_value=create_time):
             self.playground.create_workspace(
-                name="ws", expiration_delay=timedelta(days=7)
+                name="ws", expiration_delay=dt.timedelta(days=7)
             )
 
         self.playground.create_worker_activation_token(
-            expire_at=timezone.now() - timedelta(days=1)
+            expire_at=timezone.now() - dt.timedelta(days=1)
         )
 
         num_artifacts = Artifact.objects.count()
         num_artifact_relations = ArtifactRelation.objects.count()
-        num_files_in_store = FileInStore.objects.all().count()
-        num_work_requests = WorkRequest.objects.all().count()
-        num_collections = Collection.objects.all().count()
+        num_files_in_store = FileInStore.objects.count()
+        num_work_requests = WorkRequest.objects.count()
+        num_collections = Collection.objects.count()
         num_tokens = Token.objects.count()
 
-        stdout, stderr, retval = call_command(
-            "delete_expired", "--dry-run", verbosity=2
-        )
+        stdout, _, _ = call_command("delete_expired", "--dry-run", verbosity=2)
 
         self.assertEqual(
             stdout,
@@ -172,18 +170,18 @@ class DeleteExpiredCommandTests(TestCase):
         )
 
         # Files didn't get deleted
-        self.assertEqual(FileInStore.objects.all().count(), num_files_in_store)
+        self.assertEqual(FileInStore.objects.count(), num_files_in_store)
 
         # Work requests and their internal collections didn't get deleted
-        self.assertEqual(WorkRequest.objects.all().count(), num_work_requests)
-        self.assertEqual(Collection.objects.all().count(), num_collections)
+        self.assertEqual(WorkRequest.objects.count(), num_work_requests)
+        self.assertEqual(Collection.objects.count(), num_collections)
 
         # Tokens didn't get deleted
         self.assertEqual(Token.objects.count(), num_tokens)
 
     def test_delete_expired_dry_run(self) -> None:
         """Test --dry-run without verbose does not write to stdout."""
-        stdout, stderr, retval = call_command("delete_expired", "--dry-run")
+        stdout, _, _ = call_command("delete_expired", "--dry-run")
 
         # dry-run without verbose: no messages are written to stdout.
         self.assertEqual(stdout, "")
@@ -193,8 +191,8 @@ class DeleteExpiredCommandTests(TestCase):
         artifact_id_1 = Artifact.objects.all()[0]
         artifact_id_2 = Artifact.objects.all()[1]
         work_request_1 = self.playground.create_workflow()
-        work_request_1.created_at = timezone.now() - timedelta(days=365)
-        work_request_1.expiration_delay = timedelta(days=1)
+        work_request_1.created_at = timezone.now() - dt.timedelta(days=365)
+        work_request_1.expiration_delay = dt.timedelta(days=1)
         work_request_1.save()
         collection_1 = work_request_1.internal_collection
         assert collection_1 is not None
@@ -208,19 +206,19 @@ class DeleteExpiredCommandTests(TestCase):
             user=self.playground.get_default_user(),
             name="artifact2",
         )
-        create_time = timezone.now() - timedelta(days=30)
+        create_time = timezone.now() - dt.timedelta(days=30)
         with mock.patch("django.utils.timezone.now", return_value=create_time):
             self.playground.create_workspace(
-                name="ws", expiration_delay=timedelta(days=7)
+                name="ws", expiration_delay=dt.timedelta(days=7)
             )
         self.assertEqual(WorkRequest.objects.count(), 1)
         num_collections = Collection.objects.count()
         group = self.playground.create_group(name="test", ephemeral=True)
         token = self.playground.create_worker_activation_token(
-            expire_at=timezone.now() - timedelta(days=1)
+            expire_at=timezone.now() - dt.timedelta(days=1)
         )
 
-        stdout, stderr, retval = call_command("delete_expired", verbosity=2)
+        stdout, _, _ = call_command("delete_expired", verbosity=2)
 
         self.assertEqual(
             stdout,
@@ -240,7 +238,7 @@ class DeleteExpiredCommandTests(TestCase):
     def test_delete_expired_verbose_nothing_deleted(self) -> None:
         """Test delete_expired verbose: print no artifact expired."""
         Artifact.objects.update(created_at=tomorrow())
-        stdout, stderr, retval = call_command("delete_expired", verbosity=2)
+        stdout, _, _ = call_command("delete_expired", verbosity=2)
 
         self.assertEqual(
             stdout,
@@ -285,7 +283,7 @@ class DeleteExpiredArtifactsTests(TestCase):
     def test_mark_to_keep_only_artifact_is_expired(self) -> None:
         """One artifact, expired yesterday. No artifacts are kept."""
         artifact_1, _ = self.playground.create_artifact(expiration_delay=1)
-        artifact_1.created_at = timezone.now() - timedelta(days=2)
+        artifact_1.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_1.save()
 
         collection_parent_1 = Collection.objects.create(
@@ -308,7 +306,7 @@ class DeleteExpiredArtifactsTests(TestCase):
     def test_mark_to_keep_only_artifact_is_retained(self) -> None:
         """One artifact, expired yesterday. retains_artifacts is set."""
         artifact_1, _ = self.playground.create_artifact(expiration_delay=1)
-        artifact_1.created_at = timezone.now() - timedelta(days=2)
+        artifact_1.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_1.save()
 
         collection_parent_1 = Collection.objects.create(
@@ -345,14 +343,14 @@ class DeleteExpiredArtifactsTests(TestCase):
             workflow.save()
             assert workflow.internal_collection is not None
             collections[status] = workflow.internal_collection
-            collections[status].retains_artifacts = (
-                Collection.RetainsArtifacts.WORKFLOW
-            )
+            collections[
+                status
+            ].retains_artifacts = Collection.RetainsArtifacts.WORKFLOW
             collections[status].save()
             artifacts[status], _ = self.playground.create_artifact(
                 expiration_delay=1
             )
-            artifacts[status].created_at = timezone.now() - timedelta(days=2)
+            artifacts[status].created_at = timezone.now() - dt.timedelta(days=2)
             artifacts[status].save()
             collections[status].manager.add_artifact(
                 artifacts[status],
@@ -375,7 +373,7 @@ class DeleteExpiredArtifactsTests(TestCase):
         artifact_expired, _ = self.playground.create_artifact(
             expiration_delay=1
         )
-        artifact_expired.created_at = timezone.now() - timedelta(days=2)
+        artifact_expired.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_expired.save()
         artifact_not_expired, _ = self.playground.create_artifact(
             expiration_delay=1
@@ -396,12 +394,12 @@ class DeleteExpiredArtifactsTests(TestCase):
         artifact_expired_1, _ = self.playground.create_artifact(
             expiration_delay=1
         )
-        artifact_expired_1.created_at = timezone.now() - timedelta(days=2)
+        artifact_expired_1.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_expired_1.save()
         artifact_expired_2, _ = self.playground.create_artifact(
             expiration_delay=1
         )
-        artifact_expired_2.created_at = timezone.now() - timedelta(days=2)
+        artifact_expired_2.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_expired_2.save()
 
         self.playground.create_artifact_relation(
@@ -413,13 +411,13 @@ class DeleteExpiredArtifactsTests(TestCase):
     def test_mark_to_keep_no_artifact_all_expired_three(self) -> None:
         """All artifacts are expired."""
         artifact_1, _ = self.playground.create_artifact(expiration_delay=1)
-        artifact_1.created_at = timezone.now() - timedelta(days=2)
+        artifact_1.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_1.save()
         artifact_2, _ = self.playground.create_artifact(expiration_delay=1)
-        artifact_2.created_at = timezone.now() - timedelta(days=2)
+        artifact_2.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_2.save()
         artifact_3, _ = self.playground.create_artifact(expiration_delay=1)
-        artifact_3.created_at = timezone.now() - timedelta(days=2)
+        artifact_3.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_3.save()
 
         self.playground.create_artifact_relation(artifact_2, artifact_1)
@@ -430,11 +428,11 @@ class DeleteExpiredArtifactsTests(TestCase):
     def test_mark_to_keep_two_artifacts_non_expired_and_targeted(self) -> None:
         """Three artifacts, keep two (non-expired and target of non-expired)."""
         artifact_1, _ = self.playground.create_artifact(expiration_delay=1)
-        artifact_1.created_at = timezone.now() - timedelta(days=2)
+        artifact_1.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_1.save()
         artifact_2, _ = self.playground.create_artifact(expiration_delay=0)
         artifact_3, _ = self.playground.create_artifact(expiration_delay=1)
-        artifact_3.created_at = timezone.now() - timedelta(days=2)
+        artifact_3.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_3.save()
 
         self.playground.create_artifact_relation(artifact_2, artifact_1)
@@ -449,10 +447,10 @@ class DeleteExpiredArtifactsTests(TestCase):
     def test_mark_to_keep_isolated(self) -> None:
         """Two expired and one non-expired isolated."""
         artifact_1, _ = self.playground.create_artifact(expiration_delay=1)
-        artifact_1.created_at = timezone.now() - timedelta(days=2)
+        artifact_1.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_1.save()
         artifact_2, _ = self.playground.create_artifact(expiration_delay=1)
-        artifact_2.created_at = timezone.now() - timedelta(days=2)
+        artifact_2.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_2.save()
         artifact_3, _ = self.playground.create_artifact(expiration_delay=0)
 
@@ -480,17 +478,17 @@ class DeleteExpiredArtifactsTests(TestCase):
     def test_sweep_delete_artifacts(self) -> None:
         """Sweep() delete the artifacts and print progress."""
         artifact_1, _ = self.playground.create_artifact(expiration_delay=1)
-        artifact_1.created_at = timezone.now() - timedelta(days=2)
+        artifact_1.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_1.save()
         artifact_2, _ = self.playground.create_artifact(expiration_delay=1)
-        artifact_2.created_at = timezone.now() - timedelta(days=2)
+        artifact_2.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_2.save()
 
         self.playground.create_artifact_relation(artifact_2, artifact_1)
         self.playground.create_artifact_relation(artifact_1, artifact_2)
 
         artifact_3, _ = self.playground.create_artifact(expiration_delay=1)
-        artifact_3.created_at = timezone.now() - timedelta(days=2)
+        artifact_3.created_at = timezone.now() - dt.timedelta(days=2)
         artifact_3.save()
         artifact_4, _ = self.playground.create_artifact(expiration_delay=0)
 
@@ -502,7 +500,7 @@ class DeleteExpiredArtifactsTests(TestCase):
         self.operation.dry_run = False
         self.delete_expired._sweep(artifacts_to_keep)
 
-        self.assertEqual(Artifact.objects.all().count(), 2)
+        self.assertEqual(Artifact.objects.count(), 2)
         self.assertEqual(
             self.out.getvalue(),
             _format_deleted_artifacts({artifact_1, artifact_2}),
@@ -520,7 +518,7 @@ class DeleteExpiredArtifactsTests(TestCase):
             },
             expiration_delay=1,
         )
-        artifact.created_at = timezone.now() - timedelta(days=2)
+        artifact.created_at = timezone.now() - dt.timedelta(days=2)
         artifact.save()
 
         collection = Collection.objects.create(
@@ -543,7 +541,7 @@ class DeleteExpiredArtifactsTests(TestCase):
         self.operation.dry_run = False
         self.delete_expired._sweep(artifacts_to_keep)
 
-        self.assertEqual(Artifact.objects.all().count(), 0)
+        self.assertEqual(Artifact.objects.count(), 0)
         self.assertEqual(
             self.out.getvalue(),
             _format_deleted_artifacts({artifact}),
@@ -568,10 +566,10 @@ class DeleteExpiredArtifactsTests(TestCase):
 
         # Both files were added in the artifact; one was added in the store,
         # and the other is uploading
-        self.assertEqual(FileInArtifact.objects.all().count(), 2)
-        self.assertEqual(FileInStore.objects.all().count(), 1)
-        self.assertEqual(FileUpload.objects.all().count(), 1)
-        self.assertEqual(File.objects.all().count(), 2)
+        self.assertEqual(FileInArtifact.objects.count(), 2)
+        self.assertEqual(FileInStore.objects.count(), 1)
+        self.assertEqual(FileUpload.objects.count(), 1)
+        self.assertEqual(File.objects.count(), 2)
 
         # Retrieve the store_backend for the uploaded file
         uploaded_fileobj = File.objects.get(
@@ -591,14 +589,14 @@ class DeleteExpiredArtifactsTests(TestCase):
         self.delete_expired._delete_artifact(artifact)
 
         self.assertFalse(Artifact.objects.filter(id=artifact.id).exists())
-        self.assertEqual(FileInArtifact.objects.all().count(), 0)
-        self.assertEqual(FileUpload.objects.all().count(), 0)
+        self.assertEqual(FileInArtifact.objects.count(), 0)
+        self.assertEqual(FileUpload.objects.count(), 0)
 
         # FileInStore and File are not deleted: they are deleted after
         # the artifact is deleted in a different transaction (done in
         # DeleteExpiredArtifacts.run() )
-        self.assertEqual(FileInStore.objects.all().count(), 1)
-        self.assertEqual(File.objects.all().count(), 2)
+        self.assertEqual(FileInStore.objects.count(), 1)
+        self.assertEqual(File.objects.count(), 2)
 
         self.assertTrue(filepath.exists())
 
@@ -664,7 +662,7 @@ class DeleteExpiredArtifactsTests(TestCase):
     def test_delete_artifact_dry_run(self) -> None:
         """_delete_artifact() does nothing: running in dry-run."""
         artifact, _ = self.playground.create_artifact(expiration_delay=1)
-        artifact.created_at = timezone.now() - timedelta(days=2)
+        artifact.created_at = timezone.now() - dt.timedelta(days=2)
         artifact.save()
 
         # By default DeleteExpiredArtifacts runs in dry-run
@@ -734,10 +732,10 @@ class DeleteExpiredArtifactsTransactionTests(TransactionTestCase):
         self.artifact_1, _ = self.playground.create_artifact(
             expiration_delay=1, paths=["README"], create_files=True
         )
-        self.artifact_1.created_at = timezone.now() - timedelta(days=2)
+        self.artifact_1.created_at = timezone.now() - dt.timedelta(days=2)
         self.artifact_1.save()
         self.artifact_2, _ = self.playground.create_artifact(expiration_delay=1)
-        self.artifact_2.created_at = timezone.now() - timedelta(days=2)
+        self.artifact_2.created_at = timezone.now() - dt.timedelta(days=2)
         self.artifact_2.save()
 
         self.artifact_relation = self.playground.create_artifact_relation(
@@ -759,9 +757,9 @@ class DeleteExpiredArtifactsTransactionTests(TransactionTestCase):
         err: io.StringIO,
     ) -> None:
         """Assert result of deletion of artifacts when lock table failed."""
-        self.assertEqual(Artifact.objects.all().count(), expected_artifacts)
+        self.assertEqual(Artifact.objects.count(), expected_artifacts)
         self.assertEqual(
-            ArtifactRelation.objects.all().count(), expected_artifact_relations
+            ArtifactRelation.objects.count(), expected_artifact_relations
         )
 
         self.assertEqual(
@@ -786,8 +784,8 @@ class DeleteExpiredArtifactsTransactionTests(TransactionTestCase):
             delete_expired._lock_timeout_secs = 0.1
 
             with self.subTest(instance._meta.object_name):
-                expected_artifacts = Artifact.objects.all().count()
-                expected_relations = ArtifactRelation.objects.all().count()
+                expected_artifacts = Artifact.objects.count()
+                expected_relations = ArtifactRelation.objects.count()
 
                 manager = instance._meta.default_manager
                 assert manager is not None
@@ -878,7 +876,7 @@ class DeleteExpiredArtifactsTransactionTests(TransactionTestCase):
         artifact, _ = self.playground.create_artifact(
             paths=["README"], create_files=True, expiration_delay=1
         )
-        artifact.created_at = timezone.now() - timedelta(days=2)
+        artifact.created_at = timezone.now() - dt.timedelta(days=2)
         artifact.save()
 
         message_artifacts_deleted = _format_deleted_artifacts(
@@ -1041,7 +1039,11 @@ class DeleteExpiredWorkRequestsTests(TestCase):
     def test_multiple_expired(self) -> None:
         """Multiple expired work requests."""
         wr1 = self.playground.create_worker_task(expired=True)
-        wr2 = self.playground.create_worker_task(expired=True)
+        wr2 = self.playground.create_workflow()
+        wr2.created_at = timezone.now() - dt.timedelta(days=365)
+        wr2.expiration_delay = dt.timedelta(days=1)
+        wr2.save()
+        c2 = wr2.internal_collection
         wr3 = self.playground.create_worker_task(parent=wr2, expired=True)
         with (
             self.mock_perform_deletions() as perform_deletions,
@@ -1052,10 +1054,10 @@ class DeleteExpiredWorkRequestsTests(TestCase):
         self.assertEqual(
             self.delete_expired.to_delete.work_requests, {wr1, wr2, wr3}
         )
-        self.assertEqual(self.delete_expired.to_delete.collections, set())
+        self.assertEqual(self.delete_expired.to_delete.collections, {c2})
         perform_deletions.assert_called()
         verbose.assert_called_once_with(
-            "Deleting 3 expired work requests and 0 expired collections\n"
+            "Deleting 3 expired work requests and 1 expired collections\n"
         )
         self.assert_dry_run_does_not_delete()
 
@@ -1207,10 +1209,10 @@ class DeleteExpiredWorkspacesTests(TestCase):
 
     def test_one_expired(self) -> None:
         """One expired workspace."""
-        create_time = timezone.now() - timedelta(days=30)
+        create_time = timezone.now() - dt.timedelta(days=30)
         with mock.patch("django.utils.timezone.now", return_value=create_time):
             ws = self.playground.create_workspace(
-                name="ws", expiration_delay=timedelta(days=7)
+                name="ws", expiration_delay=dt.timedelta(days=7)
             )
 
         with (
@@ -1228,16 +1230,16 @@ class DeleteExpiredWorkspacesTests(TestCase):
 
     def test_multiple_expired(self) -> None:
         """Multiple expired workspaces."""
-        create_time = timezone.now() - timedelta(days=30)
+        create_time = timezone.now() - dt.timedelta(days=30)
         with mock.patch("django.utils.timezone.now", return_value=create_time):
             ws1 = self.playground.create_workspace(
-                name="ws1", expiration_delay=timedelta(days=7)
+                name="ws1", expiration_delay=dt.timedelta(days=7)
             )
             ws2 = self.playground.create_workspace(
-                name="ws2", expiration_delay=timedelta(days=7)
+                name="ws2", expiration_delay=dt.timedelta(days=7)
             )
             ws3 = self.playground.create_workspace(
-                name="ws3", expiration_delay=timedelta(days=7)
+                name="ws3", expiration_delay=dt.timedelta(days=7)
             )
         with (
             self.mock_perform_deletions() as perform_deletions,
@@ -1313,7 +1315,7 @@ class DeleteExpiredTokensTest(TestCase):
     def test_one_expired(self) -> None:
         """One unused token."""
         token = self.playground.create_worker_activation_token(
-            expire_at=timezone.now() - timedelta(seconds=1)
+            expire_at=timezone.now() - dt.timedelta(seconds=1)
         )
 
         with (
@@ -1333,7 +1335,7 @@ class DeleteExpiredTokensTest(TestCase):
         self.playground.create_user_token()
         self.playground.create_worker_token()
         self.playground.create_worker_activation_token(
-            expire_at=timezone.now() + timedelta(days=1)
+            expire_at=timezone.now() + dt.timedelta(days=1)
         )
 
         with (
