@@ -27,9 +27,7 @@ class DeleteTokensCommandTests(TabularOutputTests, TestCase):
         token = Token.objects.create()
 
         with self.assertPrintsTable() as output:
-            stdout, stderr, _ = call_command(
-                'delete_tokens', '--yes', '--token', token.key
-            )
+            call_command("delete_tokens", "--yes", "--token", token.key)
         self.assertEqual(output.col(0), [token.hash])
 
     def test_delete_tokens_no_tokens(self) -> None:
@@ -47,7 +45,7 @@ class DeleteTokensCommandTests(TabularOutputTests, TestCase):
 
     def test_delete_tokens_no_tokens_force(self) -> None:
         """delete_tokens returns exit code 0 and prints error message."""
-        stdout, stderr, _ = call_command(
+        stdout, _, _ = call_command(
             'delete_tokens',
             '--force',
             '--token',
