@@ -9,7 +9,7 @@
 
 """Tests for the management command list_work_requests."""
 
-import datetime
+import datetime as dt
 from typing import ClassVar
 
 from django.utils import timezone
@@ -34,7 +34,7 @@ class ListWorkRequestsCommandTests(TabularOutputTests, TestCase):
     def test_list_work_requests_not_assigned(self) -> None:
         """Test a non-assigned work request output."""
         with self.assertPrintsTable() as output:
-            stdout, stderr, _ = call_command("list_work_requests")
+            call_command("list_work_requests")
         self.assertEqual(output.col(0), [str(self.work_request.id)])
         self.assertEqual(
             output.col(2), [self.work_request.created_at.isoformat()]
@@ -48,14 +48,14 @@ class ListWorkRequestsCommandTests(TabularOutputTests, TestCase):
         )
         self.work_request.worker = worker
         self.work_request.created_at = timezone.now()
-        one_sec = datetime.timedelta(seconds=1)
+        one_sec = dt.timedelta(seconds=1)
         self.work_request.started_at = self.work_request.created_at + one_sec
         self.work_request.completed_at = self.work_request.started_at + one_sec
         self.work_request.result = WorkRequest.Results.SUCCESS
         self.work_request.save()
 
         with self.assertPrintsTable() as output:
-            stdout, stderr, _ = call_command("list_work_requests")
+            call_command("list_work_requests")
 
         self.assertEqual(output.col(1), ["neptune"])
         self.assertEqual(
