@@ -287,9 +287,7 @@ class VacuumStorageCommandTests(VacuumStorageTestMixin, TestCase):
 
         Also test that is not finding a file part of an artifact.
         """
-        artifact, _ = self.playground.create_artifact(
-            paths=["README"], create_files=True
-        )
+        self.playground.create_artifact(paths=["README"], create_files=True)
 
         orphan_file = self.create_temporary_file(
             directory=self.debusine_store_directory
@@ -2003,8 +2001,7 @@ class VacuumStorageCommandTests(VacuumStorageTestMixin, TestCase):
 
         self.assertEqual(
             Command._list_directory(
-                files_and_directories["root"],
-                filters=[lambda x: False],  # noqa: U100
+                files_and_directories["root"], filters=[lambda _: False]
             ),
             set(),
         )
@@ -2017,7 +2014,7 @@ class VacuumStorageCommandTests(VacuumStorageTestMixin, TestCase):
             Command._list_directory(
                 files_and_directories["root"],
                 files_only=True,
-                filters=[lambda x: True],  # noqa: U100,
+                filters=[lambda _: True],
             ),
             files_and_directories["files"],
         )
