@@ -161,8 +161,8 @@ class WorkerCommandTests(TabularOutputTests, TestCase):
             b"    - amd64\n"
             b"    - i386\n"
             b"  distributions:\n"
-            b"    - jessie\n"
-            b"    - stretch"
+            b"    - stretch\n"
+            b"    - buster"
         )
         call_command(
             "worker",
@@ -179,7 +179,7 @@ class WorkerCommandTests(TabularOutputTests, TestCase):
             {
                 "sbuild": {
                     "architectures": ["amd64", "i386"],
-                    "distributions": ["jessie", "stretch"],
+                    "distributions": ["stretch", "buster"],
                 }
             },
         )
@@ -224,20 +224,20 @@ class WorkerCommandTests(TabularOutputTests, TestCase):
         """Error message stderr if the YAML file is not found."""
         file_path = "/tmp/does_not_exist_file.yaml"
 
-        stdout, stderr, exit_code = call_command(
+        _, stderr, exit_code = call_command(
             "worker", "edit_metadata", "--set", file_path, self.worker.name
         )
 
         self.assertRegex(
             stderr,
-            fr"^Error: \[Errno 2\] No such file or directory: '{file_path}'\n",
+            rf"^Error: \[Errno 2\] No such file or directory: '{file_path}'\n",
         )
         self.assertEqual(exit_code, 3)
 
     def test_edit_metadata_cannot_open_file_is_directory(self) -> None:
         """Error message stderr if the YAML file cannot be opened."""
         temp_directory = self.create_temporary_directory()
-        stdout, stderr, exit_code = call_command(
+        _, stderr, exit_code = call_command(
             "worker",
             "edit_metadata",
             "--set",
@@ -247,7 +247,7 @@ class WorkerCommandTests(TabularOutputTests, TestCase):
 
         self.assertRegex(
             stderr,
-            fr"^Error: \[Errno 21\] Is a directory: '{temp_directory}'\n",
+            rf"^Error: \[Errno 21\] Is a directory: '{temp_directory}'\n",
         )
         self.assertEqual(exit_code, 3)
 
@@ -259,7 +259,7 @@ class WorkerCommandTests(TabularOutputTests, TestCase):
             "debusine.utils.input.YamlEditor.read_edited",
             side_effect=EditorInteractionError("cannot read"),
         ):
-            stdout, stderr, exit_code = call_command(
+            _, stderr, exit_code = call_command(
                 "worker",
                 "edit_metadata",
                 "--set",
@@ -275,7 +275,7 @@ class WorkerCommandTests(TabularOutputTests, TestCase):
         static_metadata_file = self.create_temporary_file(suffix=".yml")
         static_metadata_file.write_bytes(b"a\nb:")
 
-        stdout, stderr, exit_code = call_command(
+        _, stderr, exit_code = call_command(
             "worker",
             "edit_metadata",
             "--set",
@@ -293,7 +293,7 @@ class WorkerCommandTests(TabularOutputTests, TestCase):
         static_metadata_file = self.create_temporary_file(
             suffix=".yml", contents=b"bullseye"
         )
-        stdout, stderr, exit_code = call_command(
+        _, stderr, exit_code = call_command(
             "worker",
             "edit_metadata",
             "--set",
@@ -365,7 +365,7 @@ class WorkerCommandTests(TabularOutputTests, TestCase):
         assert self.worker.connected_at is not None
 
         with self.assertPrintsTable() as output:
-            stdout, stderr, _ = call_command("worker", "list")
+            call_command("worker", "list")
 
         self.assertEqual(output.col(0), [self.worker.name])
         self.assertEqual(output.col(2), [self.worker.registered_at.isoformat()])
@@ -380,7 +380,7 @@ class WorkerCommandTests(TabularOutputTests, TestCase):
         The worker is not connected.
         """
         with self.assertPrintsTable() as output:
-            stdout, stderr, _ = call_command("worker", "list")
+            call_command("worker", "list")
 
         self.assertEqual(output.col(0), [self.worker.name])
         self.assertEqual(output.col(2), [self.worker.registered_at.isoformat()])
