@@ -160,17 +160,13 @@ class Command(DebusineBaseCommand):
         editor: YamlEditor[dict[str, Any]] = YamlEditor({})
         try:
             shutil.copy2(path, editor.editor_file)
-        except OSError as e:
-            self.stderr.write("Error: " + str(e))
-            return False
-        try:
             editor.read_edited()
-        except InvalidData as e:
-            self.stderr.write("Error: " + str(e))
-            return False
-        except EditorInteractionError as e:
+        except (OSError, InvalidData, EditorInteractionError) as e:
             self.stderr.write("Error: " + str(e))
             return False
+        finally:
+            editor.cleanup()
+
         if editor.value:
             worker.static_metadata = editor.value
             worker.save()
