@@ -10,38 +10,45 @@
 """Middleware for maintaining debusine.db.context."""
 
 from collections.abc import Awaitable, Callable
-from typing import Any, TYPE_CHECKING
+from inspect import iscoroutinefunction
+from typing import TYPE_CHECKING
 
 import django.http
+from asgiref.typing import ASGIReceiveCallable, ASGISendCallable
+from django.utils.deprecation import MiddlewareMixin
 
 if TYPE_CHECKING:
-    from django.core.handlers.asgi import _ReceiveCallback, _SendCallback
-
-    _ReceiveCallback  # fake usage for vulture
-    _SendCallback  # fake usage for vulture
+    from channels.consumer import _ChannelScope
 
 
-class ContextMiddleware:
+class ContextMiddleware(MiddlewareMixin):
     """Run get_response in a private contextvar context."""
 
-    def __init__(
+    def process_request(
         self,
-        get_response: Callable[
-            [django.http.HttpRequest], django.http.HttpResponse
-        ],
+        request: django.http.HttpRequest,  # noqa: ARG002, U100
     ) -> None:
-        """Middleware API entry point."""
-        self.get_response = get_response
-
-    def __call__(
-        self, request: django.http.HttpRequest
-    ) -> django.http.HttpResponse:
-        """Middleware entry point."""
+        """Process request in middleware."""
         from debusine.db.context import context
 
         # Make application context request-local
         context.reset()
-        return self.get_response(request)
+
+    async def __acall__(
+        self, request: django.http.HttpRequest
+    ) -> django.http.HttpResponseBase:
+        """Asynchronous middleware entry point."""
+        # MiddlewareMixin provides __acall__, but its implementation calls
+        # process_request within sync_to_async.  In this case, we must call
+        # it in the async context: sync_to_async copies context variables
+        # that have been set in the async context into and out of its
+        # thread, but it doesn't copy out context variables that haven't
+        # been set at all in the async context.
+        self.process_request(request)
+        assert iscoroutinefunction(self.get_response)
+        response = await self.get_response(request)
+        assert isinstance(response, django.http.HttpResponseBase)
+        return response
 
 
 class ContextMiddlewareChannels:
@@ -50,7 +57,7 @@ class ContextMiddlewareChannels:
     def __init__(
         self,
         app: Callable[
-            [dict[str, Any], "_ReceiveCallback", "_SendCallback"],
+            ["_ChannelScope", ASGIReceiveCallable, ASGISendCallable],
             Awaitable[None],
         ],
     ) -> None:
@@ -59,9 +66,9 @@ class ContextMiddlewareChannels:
 
     async def __call__(
         self,
-        scope: dict[str, Any],
-        receive: "_ReceiveCallback",
-        send: "_SendCallback",
+        scope: "_ChannelScope",
+        receive: ASGIReceiveCallable,
+        send: ASGISendCallable,
     ) -> None:
         """Middleware entry point."""
         from debusine.db.context import context
