@@ -41,7 +41,7 @@ class ContextMiddlewareTests(TestCase):
         mock_scope = cast("Scope", 42)
         mock_scope_old = cast("Scope", 41)
 
-        def view(request: HttpRequest) -> HttpResponse:  # noqa: U100
+        def view(request: HttpRequest) -> HttpResponse:  # noqa: ARG001, U100
             # Application context is reset at the beginning of the view
             self.assertIsNone(context.scope)
 
@@ -84,9 +84,9 @@ class ContextMiddlewareChannelsTests(IsolatedAsyncioTestCase, TestCase):
         mock_scope_old = cast("Scope", 41)
 
         async def view(
-            scope: "_ChannelScope",  # noqa: U100
-            receive: ASGIReceiveCallable,  # noqa: U100
-            send: ASGISendCallable,  # noqa: U100
+            scope: "_ChannelScope",  # noqa: ARG001, U100
+            receive: ASGIReceiveCallable,  # noqa: ARG001, U100
+            send: ASGISendCallable,  # noqa: ARG001, U100
         ) -> None:
             # Application context is reset at the beginning of the view
             self.assertIsNone(context.scope)
