@@ -1,4 +1,4 @@
-# Copyright 2024 The Debusine Developers
+# Copyright © The Debusine Developers
 # See the AUTHORS file at the top-level directory of this distribution
 #
 # This file is part of Debusine. It is subject to the license terms
@@ -8,20 +8,20 @@
 # contained in the LICENSE file.
 
 """Middleware for updating Worker.last_seen_at."""
-from collections.abc import Awaitable, Callable
-from typing import Any, TYPE_CHECKING
 
+from collections.abc import Awaitable, Callable, Iterable
+from typing import TYPE_CHECKING
+
+from asgiref.typing import ASGIReceiveCallable, ASGISendCallable
 from channels.db import database_sync_to_async
 from django.utils import timezone
 
 from debusine.db.context import context
 from debusine.db.models import Token
+from debusine.server.consumers import ChannelScopeWithToken
 
 if TYPE_CHECKING:
-    from django.core.handlers.asgi import _ReceiveCallback, _SendCallback
-
-    _ReceiveCallback  # fake usage for vulture
-    _SendCallback  # fake usage for vulture
+    from channels.consumer import _ChannelScope
 
 
 class TokenLastSeenAtMiddlewareChannels:
@@ -34,7 +34,7 @@ class TokenLastSeenAtMiddlewareChannels:
     def __init__(
         self,
         app: Callable[
-            [dict[str, Any], "_ReceiveCallback", "_SendCallback"],
+            [ChannelScopeWithToken, ASGIReceiveCallable, ASGISendCallable],
             Awaitable[None],
         ],
     ) -> None:
@@ -42,7 +42,7 @@ class TokenLastSeenAtMiddlewareChannels:
         self.app = app
 
     @staticmethod
-    def get_token_header(headers: list[tuple[bytes, bytes]]) -> str | None:
+    def get_token_header(headers: Iterable[tuple[bytes, bytes]]) -> str | None:
         """Return the token key from the headers or None."""
         for header in headers:
             if header[0].lower() == b"token":
@@ -60,22 +60,22 @@ class TokenLastSeenAtMiddlewareChannels:
 
     async def __call__(
         self,
-        scope: dict[str, Any],
-        receive: "_ReceiveCallback",
-        send: "_SendCallback",
+        scope: "_ChannelScope",
+        receive: ASGIReceiveCallable,
+        send: ASGISendCallable,
     ) -> None:
         """Middleware entry point."""
         # When middleware is modifying the scope, it should make a copy of the
         # scope object before mutating it.
         # See https://asgi.readthedocs.io/en/latest/specs/main.html#middleware
-        scope = dict(scope)
+        scope_with_token = ChannelScopeWithToken(**scope, token=None)
 
-        token_key = self.get_token_header(scope["headers"])
+        token_key = self.get_token_header(scope_with_token["headers"])
 
         if token_key is None:
             # No token was in the request, nothing needs to be done
-            scope["token"] = None
-            return await self.app(scope, receive, send)
+            scope_with_token["token"] = None
+            return await self.app(scope_with_token, receive, send)
 
         token = await database_sync_to_async(Token.objects.get_token_or_none)(
             token_key
@@ -90,6 +90,6 @@ class TokenLastSeenAtMiddlewareChannels:
             if token.enabled and await self.is_worker_token(token):
                 context.set_worker_token(token)
 
-        scope["token"] = token
+        scope_with_token["token"] = token
 
-        return await self.app(scope, receive, send)
+        return await self.app(scope_with_token, receive, send)
