@@ -9,39 +9,29 @@
 
 """Mapping database models to REST Api support."""
 
+import datetime as dt
 from collections.abc import Callable
 from copy import copy
-from typing import (
-    Any,
-    NamedTuple,
-    Never,
-    NoReturn,
-    TYPE_CHECKING,
-    TypeAlias,
-    TypeVar,
-)
+from typing import Any, NamedTuple, Never, TYPE_CHECKING, TypeAlias
 
+import pydantic
 from django.conf import settings
 from django.db.models import QuerySet
 from django.http import HttpRequest
-
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
+from django.urls import reverse
 from rest_framework import serializers
 from rest_framework.exceptions import ErrorDetail, ValidationError
 
 from debusine.artifacts.models import (
     ArtifactCategory,
+    CollectionCategory,
     DebusineTaskConfiguration,
 )
 from debusine.assets import AssetCategory, asset_data_model
 from debusine.client.models import (
+    Link,
     LookupChildType,
     WorkspaceInheritanceChainElement,
-    model_to_json_serializable_dict,
 )
 from debusine.db.context import context
 from debusine.db.models import (
@@ -56,6 +46,7 @@ from debusine.db.models import (
     WorkflowTemplate,
     Workspace,
 )
+from debusine.db.models.collections import validate_collection_name
 from debusine.server.collections.lookup import LookupResult
 from debusine.server.exceptions import (
     DebusineAPIException,
@@ -66,11 +57,23 @@ from debusine.server.workflows.models import WorkRequestManualUnblockAction
 from debusine.tasks.models import EventReactions, OutputData, WorkerType
 
 if TYPE_CHECKING:
-    SerializerMixinBase: TypeAlias = serializers.Serializer[Any]
+    BaseSerializerBase: TypeAlias = serializers.BaseSerializer
+    SerializerMixinBase: TypeAlias = serializers.Serializer
     SlugRelatedFieldBase = serializers.SlugRelatedField
     FieldBase = serializers.Field
 else:
-    SerializerMixinBase = object
+    # BaseSerializer doesn't support generic types at run-time yet.
+    class _BaseSerializerBase:
+        def __class_getitem__(*args):
+            return serializers.BaseSerializer
+
+    BaseSerializerBase = _BaseSerializerBase
+
+    class _SerializerMixinBase:
+        def __class_getitem__(*args):
+            return serializers.Serializer
+
+    SerializerMixinBase = _SerializerMixinBase
 
     # SlugRelatedField doesn't support generic types at run-time yet.
     class _SlugRelatedFieldBase:
@@ -86,10 +89,8 @@ else:
 
     FieldBase = _FieldBase
 
-PydanticModel = TypeVar("PydanticModel", bound=pydantic.BaseModel)
 
-
-class DebusineSerializerMixin(SerializerMixinBase):
+class DebusineSerializerMixin[T](SerializerMixinBase[T]):
     """Adjust a serializer with debusine-specific behaviour."""
 
     validation_error_title: str
@@ -122,7 +123,7 @@ class WorkspaceInCurrentScopeField(SlugRelatedFieldBase[Workspace]):
 
     def get_queryset(self) -> QuerySet[Workspace]:
         """Limit to the current scope."""
-        return Workspace.objects.all().in_current_scope()
+        return Workspace.objects.in_current_scope()
 
     def _get_default_workspace(self) -> Workspace:
         """Get the default workspace."""
@@ -136,8 +137,30 @@ class WorkspaceInCurrentScopeField(SlugRelatedFieldBase[Workspace]):
             self.fail("required")
 
 
+class LinksSerializerMixin[T](SerializerMixinBase[T]):
+    """Add a links record to a serializer."""
+
+    def get_links(self, instance: T) -> dict[str, Link]:  # noqa: ARG002, U100
+        """Return links for this object."""
+        return {}
+
+    def to_representation(self, instance: T) -> dict[str, Any]:
+        """Add links to the serialized representation."""
+        links: dict[str, str | dict[str, str]] = {}
+        for name, link in self.get_links(instance).items():
+            if link.can_be_str():
+                links[name] = link.href
+            else:
+                links[name] = link.model_dump(exclude_unset=True)
+        res = super().to_representation(instance)
+        res["links"] = links
+        return res
+
+
 class WorkRequestSerializer(
-    DebusineSerializerMixin, serializers.ModelSerializer[WorkRequest]
+    LinksSerializerMixin[WorkRequest],
+    DebusineSerializerMixin[WorkRequest],
+    serializers.ModelSerializer[WorkRequest],
 ):
     """Serializer of a WorkRequest."""
 
@@ -164,14 +187,26 @@ class WorkRequestSerializer(
         self._only_fields = kwargs.pop('only_fields', None)
         super().__init__(*args, **kwargs)
 
+    def get_links(self, instance: WorkRequest) -> dict[str, Link]:
+        """Get links to add to the serialized record."""
+        res = super().get_links(instance)
+        res["self"] = Link(
+            href=reverse(
+                "api:work-request-detail",
+                kwargs={"work_request_id": instance.pk},
+            )
+        )
+        res["webui_self"] = Link(href=instance.get_absolute_url())
+        return res
+
     def artifacts_for_work_request(
         self, work_request: WorkRequest
     ) -> list[int]:
         """Return list of artifact ids created by this work request."""
         return list(
-            work_request.artifact_set.all()
-            .order_by("id")
-            .values_list("id", flat=True)
+            work_request.artifact_set.order_by("id").values_list(
+                "id", flat=True
+            )
         )
 
     def validate(self, data: Any) -> Any:
@@ -195,7 +230,7 @@ class WorkRequestSerializer(
     def validate_event_reactions(self, value: Any) -> Any:
         """Validate event reactions."""
         try:
-            EventReactions.parse_obj(value)
+            EventReactions.model_validate(value)
         except pydantic.ValidationError as e:
             raise serializers.ValidationError(f"Invalid event_reactions: {e}")
         return value
@@ -208,6 +243,7 @@ class WorkRequestSerializer(
             'task_name',
             'created_at',
             'created_by',
+            'completed_by',
             'aborted_by',
             'started_at',
             'completed_at',
@@ -231,14 +267,6 @@ class WorkRequestSerializer(
 class WorkRequestSerializerWithConfiguredTaskData(WorkRequestSerializer):
     """Specialization of WorkRequestSerializer to feed task data to workers."""
 
-    def update(self, instance: Any, validated_data: dict[str, Any]) -> NoReturn:
-        """Disable update."""
-        raise NotImplementedError('`update()` must be implemented.')
-
-    def create(self, validated_data: dict[str, Any]) -> NoReturn:
-        """Disable create."""
-        raise NotImplementedError('`create()` must be implemented.')
-
     def to_representation(self, instance: WorkRequest) -> dict[str, Any]:
         """
         Use configured_task_data instead of task_data.
@@ -268,7 +296,7 @@ class WorkRequestUpdateSerializer(WorkRequestSerializer):
 
 
 class WorkRequestUnblockSerializer(
-    DebusineSerializerMixin, serializers.Serializer[Never]
+    DebusineSerializerMixin[WorkRequest], serializers.Serializer[WorkRequest]
 ):
     """Serializer for the data used to edit a manual unblock."""
 
@@ -289,7 +317,20 @@ class WorkRequestUnblockSerializer(
         return data
 
 
-class WorkRequestExternalDebsignSerializer(WorkRequestSerializer):
+class WorkRequestConfirmSerializer(
+    DebusineSerializerMixin[WorkRequest], serializers.Serializer[WorkRequest]
+):
+    """Serializer for the data used to confirm a work request."""
+
+    validation_error_title = "Cannot deserialize work request confirmation"
+
+    confirm = serializers.BooleanField(required=False, default=True)
+    comment = serializers.CharField(required=False, max_length=65536)
+
+
+class WorkRequestExternalDebsignSerializer(
+    WorkRequestSerializerWithConfiguredTaskData
+):
     """
     Serializer for an `ExternalDebsign` work request.
 
@@ -310,8 +351,8 @@ class WorkRequestExternalDebsignSerializer(WorkRequestSerializer):
             data["dynamic_task_data"] = (
                 None
                 if dynamic_task_data is None
-                else model_to_json_serializable_dict(
-                    dynamic_task_data, exclude_unset=True
+                else dynamic_task_data.model_dump(
+                    mode="json", exclude_unset=True
                 )
             )
         except Exception as exc:
@@ -321,7 +362,7 @@ class WorkRequestExternalDebsignSerializer(WorkRequestSerializer):
 
 
 class WorkRequestExternalDebsignRequestSerializer(
-    DebusineSerializerMixin, serializers.Serializer[Never]
+    DebusineSerializerMixin[Never], serializers.Serializer[Never]
 ):
     """Serializer for the data used to complete an `ExternalDebsign` task."""
 
@@ -375,7 +416,7 @@ class WorkRequestCompletedSerializer(serializers.ModelSerializer[WorkRequest]):
     def validate_output_data(self, value: Any) -> Any:
         """Validate output_data."""
         try:
-            OutputData.parse_obj(value)
+            OutputData.model_validate(value)
         except pydantic.ValidationError as e:
             raise serializers.ValidationError(f"Invalid output_data: {e}")
         return value
@@ -413,7 +454,7 @@ class FileSerializerResponse(FileSerializer):
 
 
 class ArtifactSerializer(
-    DebusineSerializerMixin, serializers.Serializer[Artifact]
+    DebusineSerializerMixin[Artifact], serializers.Serializer[Artifact]
 ):
     """Serializer to deserialize the client request to create an artifact."""
 
@@ -430,7 +471,9 @@ class ArtifactSerializer(
     )
 
 
-class ArtifactSerializerResponse(serializers.ModelSerializer[Artifact]):
+class ArtifactSerializerResponse(
+    LinksSerializerMixin[Artifact], serializers.ModelSerializer[Artifact]
+):
     """Serializer for returning the information of an Artifact."""
 
     url = serializers.URLField(source="get_absolute_url", read_only=True)
@@ -468,6 +511,22 @@ class ArtifactSerializerResponse(serializers.ModelSerializer[Artifact]):
             "files",
         ]
 
+    def get_links(self, instance: Artifact) -> dict[str, Link]:
+        """Get links to add to the serialized record."""
+        res = super().get_links(instance)
+        res["self"] = Link(
+            href=reverse(
+                "api:artifact",
+                kwargs={"artifact_id": instance.pk},
+            )
+        )
+        res["webui_self"] = Link(href=instance.get_absolute_url())
+        res["download_tar_gz"] = Link(
+            href=instance.get_absolute_url_download() + "?archive=tar.gz",
+            type="application/tar+gzip",
+        )
+        return res
+
     def _files_to_upload(self, artifact: Artifact) -> list[str]:
         """Return file paths from artifact that have not been uploaded yet."""
         return list(
@@ -484,9 +543,7 @@ class ArtifactSerializerResponse(serializers.ModelSerializer[Artifact]):
         """
         files: dict[str, dict[str, Any]] = {}
 
-        for file_in_artifact in artifact.fileinartifact_set.all().order_by(
-            "path"
-        ):
+        for file_in_artifact in artifact.fileinartifact_set.order_by("path"):
             file = file_in_artifact.file
             data = {
                 "size": file.size,
@@ -504,7 +561,7 @@ class ArtifactSerializerResponse(serializers.ModelSerializer[Artifact]):
 
         return files
 
-    def _download_tar_gz_url(self, obj: Artifact) -> str:  # noqa: U100
+    def _download_tar_gz_url(self, obj: Artifact) -> str:  # noqa: ARG002, U100
         """Based on self._base_download_url return URL to download .tar.gz."""
         return self._base_download_url + "?archive=tar.gz"
 
@@ -528,7 +585,8 @@ class ArtifactSerializerResponse(serializers.ModelSerializer[Artifact]):
 
 
 class ArtifactRelationResponseSerializer(
-    DebusineSerializerMixin, serializers.ModelSerializer[ArtifactRelation]
+    DebusineSerializerMixin[ArtifactRelation],
+    serializers.ModelSerializer[ArtifactRelation],
 ):
     """Serializer for relations between artifacts."""
 
@@ -547,7 +605,9 @@ class ArtifactRelationResponseSerializer(
         validators: list[Callable[[ArtifactRelation], None]] = []
 
 
-class AssetSerializer(DebusineSerializerMixin, serializers.Serializer[Asset]):
+class AssetSerializer(
+    DebusineSerializerMixin[Asset], serializers.Serializer[Asset]
+):
     """Serializer to deserialize the client request to create an asset."""
 
     validation_error_title = "Cannot deserialize asset"
@@ -565,10 +625,7 @@ class AssetSerializer(DebusineSerializerMixin, serializers.Serializer[Asset]):
 
     def validate(self, data: dict[str, Any]) -> dict[str, Any]:
         """Validate category and data."""
-        try:
-            # Python 3.11 doesn't support X in StrEnum
-            AssetCategory(data["category"])
-        except ValueError:
+        if data["category"] not in AssetCategory:
             raise serializers.ValidationError(
                 {"category": f"{data['category']} is not a known category."}
             )
@@ -590,7 +647,7 @@ class AssetSerializer(DebusineSerializerMixin, serializers.Serializer[Asset]):
 
 
 class AssetPermissionCheckRequest(
-    DebusineSerializerMixin, serializers.Serializer[Never]
+    DebusineSerializerMixin[Never], serializers.Serializer[Never]
 ):
     """Serializer for a permission check on an asset."""
 
@@ -602,7 +659,7 @@ class AssetPermissionCheckRequest(
 
 
 class AssetPermissionCheckResponse(
-    DebusineSerializerMixin, serializers.Serializer[Never]
+    DebusineSerializerMixin[Never], serializers.Serializer[Never]
 ):
     """Serializer for a permission check result."""
 
@@ -683,7 +740,9 @@ class LookupResponseSerializer(serializers.Serializer[LookupResult]):
 
 
 class WorkflowTemplateSerializer(
-    DebusineSerializerMixin, serializers.ModelSerializer[WorkflowTemplate]
+    LinksSerializerMixin[WorkflowTemplate],
+    DebusineSerializerMixin[WorkflowTemplate],
+    serializers.ModelSerializer[WorkflowTemplate],
 ):
     """Serializer for workflow templates."""
 
@@ -691,23 +750,32 @@ class WorkflowTemplateSerializer(
 
     media_type = "application/json"
 
-    url = serializers.URLField(source="get_absolute_url", read_only=True)
-    scope = serializers.CharField(source="workspace.scope.name", read_only=True)
-    workspace = WorkspaceInCurrentScopeField(slug_field="name")
-
     class Meta:
         model = WorkflowTemplate
         fields = [
             "id",
-            "url",
             "name",
-            "scope",
-            "workspace",
             "task_name",
-            "task_data",
+            "static_parameters",
+            "runtime_parameters",
             "priority",
         ]
 
+    def get_links(self, instance: WorkflowTemplate) -> dict[str, Link]:
+        """Get links to add to the serialized record."""
+        res = super().get_links(instance)
+        res["self"] = Link(
+            href=reverse(
+                "api:workflow-template-detail",
+                kwargs={
+                    "workspace": instance.workspace.name,
+                    "pk": instance.pk,
+                },
+            )
+        )
+        res["webui_self"] = Link(href=instance.get_absolute_url())
+        return res
+
     def validate_task_name(self, value: str) -> str:
         """
         Ensure that task_name is valid.
@@ -724,7 +792,8 @@ class WorkflowTemplateSerializer(
 
 
 class CreateWorkflowRequestSerializer(
-    DebusineSerializerMixin, serializers.ModelSerializer[WorkRequest]
+    DebusineSerializerMixin[WorkRequest],
+    serializers.ModelSerializer[WorkRequest],
 ):
     """Serializer for requests to create workflows."""
 
@@ -744,14 +813,16 @@ class CreateWorkflowRequestSerializer(
         ]
 
 
-class PydanticSerializer(serializers.BaseSerializer[PydanticModel]):
+class PydanticSerializerMixin[PydanticModel: pydantic.BaseModel](
+    SerializerMixinBase[PydanticModel]
+):
     """Serialize pydantic models."""
 
     pydantic_model: type[PydanticModel]
 
     def to_representation(self, instance: PydanticModel) -> dict[str, Any]:
         """Delegate representation to pydantic."""
-        return instance.dict()
+        return instance.model_dump()
 
     def to_internal_value(self, data: Any) -> PydanticModel:
         """Delegate validation to pydantic."""
@@ -759,7 +830,8 @@ class PydanticSerializer(serializers.BaseSerializer[PydanticModel]):
 
 
 class DebusineTaskConfigurationSerializer(
-    DebusineSerializerMixin, PydanticSerializer[DebusineTaskConfiguration]
+    DebusineSerializerMixin[DebusineTaskConfiguration],
+    PydanticSerializerMixin[DebusineTaskConfiguration],
 ):
     """Serialize a DebusineTaskConfiguration item."""
 
@@ -767,7 +839,7 @@ class DebusineTaskConfigurationSerializer(
 
 
 class TaskConfigurationCollectionSerializer(
-    DebusineSerializerMixin, serializers.ModelSerializer[Collection]
+    DebusineSerializerMixin[Collection], serializers.ModelSerializer[Collection]
 ):
     """Serializer for a TaskConfiguration collection."""
 
@@ -789,7 +861,7 @@ class TaskConfigurationCollectionContents(NamedTuple):
 
 
 class TaskConfigurationCollectionContentsSerializer(
-    DebusineSerializerMixin, serializers.Serializer[Never]
+    DebusineSerializerMixin[TaskConfigurationCollectionContents],
 ):
     """Serializer for the contents of a TaskConfiguration collection."""
 
@@ -801,7 +873,8 @@ class TaskConfigurationCollectionContentsSerializer(
 
 
 class TaskConfigurationCollectionUpdateResultsSerializer(
-    DebusineSerializerMixin, serializers.Serializer[Never]
+    DebusineSerializerMixin[dict[str, int]],
+    serializers.Serializer[dict[str, int]],
 ):
     """Serializer for the result information of a task configuration update."""
 
@@ -822,12 +895,11 @@ class WorkspaceChainItemField(
 
     def to_representation(self, value: Workspace) -> dict[str, Any]:
         """Trivially serialize workspaces with IDs."""
-        res = WorkspaceInheritanceChainElement(
+        return WorkspaceInheritanceChainElement(
             id=value.id,
             scope=value.scope.name,
             workspace=value.name,
-        )
-        return model_to_json_serializable_dict(res)
+        ).model_dump(mode="json")
 
     def _workspace_from_id(
         self, el: WorkspaceInheritanceChainElement
@@ -898,21 +970,107 @@ class WorkspaceChainSerializer(serializers.Serializer[Never]):
     )
 
 
+class DurationInDays(FieldBase[dt.timedelta, int, int, dt.timedelta]):
+    """Represent a duration field reduced to a number of days."""
+
+    def to_representation(self, value: dt.timedelta) -> int:
+        """Represent a timedelta as a number of days."""
+        days = value.days
+        if value.seconds > 0 or value.microseconds > 0:
+            days += 1
+        return days
+
+    def to_internal_value(self, data: int) -> dt.timedelta:
+        """Parse a timedelta from a number of days."""
+        return dt.timedelta(days=int(data))
+
+
 class CollectionSerializer(
-    DebusineSerializerMixin, serializers.ModelSerializer[Collection]
+    LinksSerializerMixin[Collection],
+    DebusineSerializerMixin[Collection],
+    serializers.ModelSerializer[Collection],
 ):
     """Serializer of a Collection."""
 
     validation_error_title = "Cannot deserialize collection"
 
+    category = serializers.ChoiceField(
+        choices=list(CollectionCategory), required=False
+    )
     name = serializers.CharField(required=False)
+    full_history_retention_period = DurationInDays(
+        allow_null=True, required=False
+    )
+    metadata_only_retention_period = DurationInDays(
+        allow_null=True, required=False
+    )
+    stats = serializers.SerializerMethodField()
+
+    def get_links(self, instance: Collection) -> dict[str, Link]:
+        """Get links to add to the serialized record."""
+        res = super().get_links(instance)
+        res["self"] = Link(
+            href=reverse(
+                "api:collection-detail",
+                kwargs={
+                    "workspace": instance.workspace.name,
+                    "pk": instance.pk,
+                },
+            )
+        )
+        res["webui_self"] = Link(href=instance.get_absolute_url())
+        res["webui_category"] = Link(
+            href=reverse(
+                "workspaces:collections:category_list",
+                kwargs={
+                    "wname": instance.workspace.name,
+                    "ccat": instance.category,
+                },
+            ),
+            type="category",
+        )
+        return res
+
+    def get_stats(self, instance: Collection) -> list[dict[str, Any]] | None:
+        """Get statistics on the collections if requested."""
+        if not self.context.get("with_stats"):
+            return None
+        return [
+            {
+                "type": x["type"].name.lower(),
+                "category": x["category"],
+                "active": x["active"],
+                "count": x["count"],
+            }
+            for x in instance.get_item_stats()
+        ]
+
+    def validate_name(self, value: str) -> str:
+        """Ensure that name is valid."""
+        validate_collection_name(value)
+        return value
 
     class Meta:
         model = Collection
         fields = [
-            'id',
-            'name',
-            'full_history_retention_period',
-            'metadata_only_retention_period',
-            'data',
+            "id",
+            "category",
+            "name",
+            "full_history_retention_period",
+            "metadata_only_retention_period",
+            "data",
+            "stats",
         ]
+
+
+class EmitMetricSerializer(serializers.Serializer[Never]):
+    """Serializer for a metric to be emitted."""
+
+    metric_type = serializers.ChoiceField(
+        choices=("counter", "gauge", "summary", "histogram")
+    )
+    name = serializers.CharField()
+    labels = serializers.DictField(
+        child=serializers.CharField(), allow_empty=True
+    )
+    value = serializers.FloatField()
