@@ -10,7 +10,6 @@
 
 """Test of the backend for signon authentication using external providers."""
 
-
 import re
 from collections.abc import Collection
 from typing import Any
@@ -403,10 +402,7 @@ class SignonTests(SignonTestCase):
 
         self.assertEqual(
             log.output,
-            [
-                "INFO:debusine.server.signon:"
-                f"{user}: auto associated to {ident}"
-            ],
+            [f"INFO:debusine.server.signon:{user}: auto associated to {ident}"],
         )
 
     def test_bind_intention_succeeds_other_backend(self) -> None:
@@ -760,6 +756,15 @@ class SignonTests(SignonTestCase):
             self.request.signon.validate_claims(provider, identity), []
         )
 
+    def test_validate_empty_restrict(self) -> None:
+        ident = self.make_identity(
+            claims={
+                "name": "Test User",
+                "email": "test@example.org",
+            }
+        )
+        self.assertRestrictValidates(ident, [])
+
     def test_validate_email_verified(self) -> None:
         """email-verified validates as intended."""
         ident = self.make_identity(
@@ -787,62 +792,99 @@ class SignonTests(SignonTestCase):
                 "groups_direct": ["debian"],
             }
         )
-        self.assertRestrictValidates(ident, [])
         self.assertRestrictDoesNotValidate(
             ident, ["group:admin"], "not in group 'admin'"
         )
         self.assertRestrictValidates(ident, ["group:debian"])
+        self.assertRestrictValidates(ident, ["group:debian,admin"])
         self.assertRestrictDoesNotValidate(
-            ident, ["group:debian", "group:admin"], "not in group 'admin'"
-        )
-
-        ident.claims["groups_direct"] = []
-        self.assertRestrictValidates(ident, [])
-        self.assertRestrictDoesNotValidate(
-            ident, ["group:admin"], "not in group 'admin'"
+            ident,
+            ["group:foo,bar"],
+            "not in group 'foo' or 'bar'",
         )
         self.assertRestrictDoesNotValidate(
             ident,
-            ["group:debian", "group:admin"],
-            "not in group 'debian'",
-            "not in group 'admin'",
+            ["group:foo,bar,baz"],
+            "not in group 'foo', 'bar' or 'baz'",
         )
 
-        ident.claims["groups_direct"] = ["debian", "admin"]
-        self.assertRestrictValidates(ident, [])
-        self.assertRestrictValidates(ident, ["group:admin"])
-        self.assertRestrictValidates(ident, ["group:debian"])
-        self.assertRestrictValidates(ident, ["group:debian", "group:admin"])
-
-    def test_validate_combine(self) -> None:
-        """group:* and email-verified can be used together."""
+    def test_validate(self) -> None:
         ident = self.make_identity(
             claims={
                 "name": "Test User",
                 "email": "test@example.org",
-                "email_verified": False,
-                "groups_direct": ["debian"],
             }
         )
-        self.assertRestrictValidates(ident, [])
-        self.assertRestrictDoesNotValidate(
-            ident, ["email-verified"], "does not have a verified email"
-        )
-        self.assertRestrictValidates(ident, ["group:debian"])
-        self.assertRestrictDoesNotValidate(
-            ident,
-            ["email-verified", "group:debian"],
-            "does not have a verified email",
-        )
-
-        ident.claims["email_verified"] = True
-        self.assertRestrictValidates(ident, [])
-        self.assertRestrictValidates(ident, ["email-verified"])
-        self.assertRestrictValidates(ident, ["group:debian"])
-        self.assertRestrictValidates(ident, ["email-verified", "group:debian"])
-        self.assertRestrictDoesNotValidate(
-            ident, ["email-verified", "group:admin"], "not in group 'admin'"
-        )
+        for email_verified, groups, restrict, expected_issues in (
+            (False, [], ["group:debian"], ["not in group 'debian'"]),
+            (False, ["debian"], ["group:debian"], []),
+            (False, ["debian"], ["group:admin"], ["not in group 'admin'"]),
+            (
+                False,
+                ["debian"],
+                ["group:debian", "group:admin"],
+                ["not in group 'admin'"],
+            ),
+            (
+                False,
+                [],
+                ["group:debian", "group:admin"],
+                ["not in group 'debian'", "not in group 'admin'"],
+            ),
+            (False, ["debian", "admin"], ["group:debian"], []),
+            (False, ["debian", "admin"], ["group:admin"], []),
+            (False, ["debian", "admin"], ["group:debian", "group:admin"], []),
+            (
+                False,
+                ["debian"],
+                ["email-verified"],
+                ["does not have a verified email"],
+            ),
+            (
+                False,
+                ["debian"],
+                ["email-verified", "group:debian"],
+                ["does not have a verified email"],
+            ),
+            (True, ["debian"], ["email-verified"], []),
+            (True, ["debian"], ["group:debian"], []),
+            (True, ["debian"], ["email-verified", "group:debian"], []),
+            (
+                True,
+                ["debian"],
+                ["email-verified", "group:admin"],
+                ["not in group 'admin'"],
+            ),
+            (
+                True,
+                ["debian", "admin"],
+                ["email-verified", "group:debian,ubuntu", "group:admin"],
+                [],
+            ),
+            (
+                True,
+                ["ubuntu", "admin"],
+                ["email-verified", "group:debian,ubuntu", "group:admin"],
+                [],
+            ),
+            (
+                True,
+                ["debian", "ubuntu"],
+                ["email-verified", "group:debian,ubuntu", "group:admin"],
+                ["not in group 'admin'"],
+            ),
+        ):
+            with self.subTest(
+                email_verified=True, groups=groups, restrict=restrict
+            ):
+                ident.claims["email_verified"] = email_verified
+                ident.claims["groups_direct"] = groups
+                if not expected_issues:
+                    self.assertRestrictValidates(ident, restrict)
+                else:
+                    self.assertRestrictDoesNotValidate(
+                        ident, restrict, *expected_issues
+                    )
 
     def test_validate_invalid_expression(self) -> None:
         """An invalid restrict value raises ImproperlyConfigured."""
