@@ -13,11 +13,7 @@ import abc
 import logging
 from collections import defaultdict
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic  # type: ignore
-
+import pydantic
 from django.db.models import Count
 
 from debusine.artifacts.models import TaskTypes
@@ -31,11 +27,7 @@ log = logging.getLogger(__name__)
 class PydanticBase(pydantic.BaseModel, abc.ABC):
     """Stricter BaseModel."""
 
-    class Config:
-        """Set up stricter pydantic Config."""
-
-        validate_assignment = True
-        extra = "forbid"
+    model_config = pydantic.ConfigDict(validate_assignment=True, extra="forbid")
 
 
 class WorkerSummary(PydanticBase):
@@ -133,14 +125,16 @@ class WorkerStatus:
     ) -> dict[WorkerType, TaskQueueSummary]:
         """Re-count queued tasks by worker type."""
         result: dict[WorkerType, TaskQueueSummary] = {
-            worker_type: TaskQueueSummary() for worker_type in WorkerType
+            worker_type: TaskQueueSummary()
+            for worker_type in WorkerType
+            if worker_type != WorkerType.SCHEDULER
         }
         for task_type, worker_type in (
             (TaskTypes.WORKER, WorkerType.EXTERNAL),
             (TaskTypes.SERVER, WorkerType.CELERY),
             (TaskTypes.SIGNING, WorkerType.SIGNING),
         ):
-            for field_name in TaskQueueSummary.__fields__.keys():
+            for field_name in TaskQueueSummary.model_fields.keys():
                 setattr(
                     result[worker_type],
                     field_name,
@@ -229,10 +223,14 @@ class WorkerStatus:
     def _count_workers_by_type() -> dict[WorkerType, WorkerSummary]:
         """Return number of connected external workers by type."""
         result: dict[WorkerType, WorkerSummary] = {
-            worker_type: WorkerSummary() for worker_type in WorkerType
+            worker_type: WorkerSummary()
+            for worker_type in WorkerType
+            if worker_type != WorkerType.SCHEDULER
         }
 
-        for worker in Worker.objects.filter(token__enabled=True):
+        for worker in Worker.objects.filter(token__enabled=True).exclude(
+            worker_type=WorkerType.SCHEDULER
+        ):
             worker_type = WorkerType[worker.worker_type.upper()]
             result[worker_type].registered += 1
             if worker.connected():
@@ -269,9 +267,9 @@ class WorkerStatus:
         return dict(result)
 
     @staticmethod
-    def _count_external_workers_by_native_architecture() -> (
-        dict[str, WorkerSummary]
-    ):
+    def _count_external_workers_by_native_architecture() -> dict[
+        str, WorkerSummary
+    ]:
         """
         Return number of connected external workers by native architecture.
 
