@@ -12,7 +12,7 @@
 import shutil
 import tempfile
 from pathlib import Path
-from typing import Any
+from typing import Any, override
 
 from django.conf import settings
 
@@ -109,9 +109,8 @@ class CopyCollectionItems(
             )
         return new_artifact
 
-    @classmethod
     def copy_item(
-        cls,
+        self,
         source_item: LookupResult,
         target_collection: Collection,
         *,
@@ -174,6 +173,13 @@ class CopyCollectionItems(
         match source_item.result_type:
             case CollectionItem.Types.BARE:
                 assert source_item.collection_item is not None
+                self.append_to_log_file(
+                    "copy-collection-items.log",
+                    [
+                        f"Copying to {target_collection}: "
+                        f"{source_item.collection_item}"
+                    ],
+                )
                 target_collection.manager.add_bare_data(
                     category=BareDataCategory(
                         source_item.collection_item.category
@@ -188,7 +194,11 @@ class CopyCollectionItems(
                 )
             case CollectionItem.Types.ARTIFACT:
                 assert source_item.artifact is not None
-                new_artifact = cls.copy_artifact(
+                self.append_to_log_file(
+                    "copy-collection-items.log",
+                    [f"Copying to {target_collection}: {source_item.artifact}"],
+                )
+                new_artifact = self.copy_artifact(
                     source_item.artifact, target_workspace
                 )
                 target_collection.manager.add_artifact(
@@ -204,6 +214,7 @@ class CopyCollectionItems(
                     f"Unexpected lookup result type: {unreachable}"
                 )
 
+    @override
     def _execute(self) -> bool:
         """Execute the task."""
         assert self.work_request is not None
@@ -217,7 +228,7 @@ class CopyCollectionItems(
                 lookup=lookup,
                 workspace=self.work_request.workspace,
                 user=self.work_request.created_by,
-                workflow_root=self.work_request.get_workflow_root(),
+                workflow_root=self.work_request.workflow_root,
                 expect_type=LookupChildType.COLLECTION,
             ).collection
             for lookup in target_collection_lookups
@@ -228,23 +239,30 @@ class CopyCollectionItems(
                 copies.source_items,
                 self.workspace,
                 user=self.work_request.created_by,
-                workflow_root=self.work_request.get_workflow_root(),
+                workflow_root=self.work_request.workflow_root,
                 expect_type=LookupChildType.ANY,
             )
             for source_item in source_items:
-                self.copy_item(
-                    source_item,
-                    target_collections[copies.target_collection],
-                    unembargo=copies.unembargo,
-                    replace=copies.replace,
-                    name_template=copies.name_template,
-                    variables=copies.variables,
-                    user=self.work_request.created_by,
-                    workflow=self.work_request.parent,
-                )
+                try:
+                    self.copy_item(
+                        source_item,
+                        target_collections[copies.target_collection],
+                        unembargo=copies.unembargo,
+                        replace=copies.replace,
+                        name_template=copies.name_template,
+                        variables=copies.variables,
+                        user=self.work_request.created_by,
+                        workflow=self.work_request.parent,
+                    )
+                except Exception as e:
+                    self.append_to_log_file(
+                        "copy-collection-items.log", [f"Copy failed: {e}"]
+                    )
+                    raise
 
         return True
 
+    @override
     def get_label(self) -> str:
         """Return the task label."""
         target_collections = ", ".join(
