@@ -10,13 +10,9 @@
 """Models used by debusine server-side tasks."""
 
 import datetime as dt
-import re
-from typing import Any
+from typing import Annotated, Any, Self
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
+import pydantic
 
 from debusine.db.models.workspaces import workspace_name_regex
 from debusine.tasks.models import (
@@ -46,25 +42,22 @@ class APTMirrorData(BaseTaskData):
     architectures: list[str]
     signing_key: str | None = None
 
-    @pydantic.root_validator
-    @classmethod
-    def check_suite_components_consistency(
-        cls, values: dict[str, Any]
-    ) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def check_suite_components_consistency(self) -> Self:
         """Components are only allowed/required for non-flat repositories."""
-        if values["suite"].endswith("/"):
-            if values.get("components") is not None:
+        if self.suite.endswith("/"):
+            if self.components is not None:
                 raise ValueError(
                     'Flat repositories (where suite ends with "/") must not '
                     'have components'
                 )
         else:
-            if values.get("components") is None:
+            if self.components is None:
                 raise ValueError(
                     'Non-flat repositories (where suite does not end with '
                     '"/") must have components'
                 )
-        return values
+        return self
 
 
 class PackageUploadInput(BaseTaskData):
@@ -112,47 +105,21 @@ class CopyCollectionItemsCopies(BaseTaskData):
 class CopyCollectionItemsData(BaseTaskData):
     """In-memory task data for the CopyCollectionItems task."""
 
-    copies: list[CopyCollectionItemsCopies] = pydantic.Field(min_items=1)
+    copies: Annotated[
+        list[CopyCollectionItemsCopies], pydantic.Field(min_length=1)
+    ]
 
 
 class CreateChildWorkspaceData(BaseTaskData):
     """In-memory task data for CreateChildWorkspace."""
 
-    prefix: str
-    suffix: str
+    prefix: Annotated[str, pydantic.Field(pattern=workspace_name_regex)]
+    suffix: Annotated[str, pydantic.Field(pattern=workspace_name_regex)]
     public: bool = True
     owner_group: str | None = None
     workflow_template_names: list[str] = []
     expiration_delay: int | None = 60
 
-    @pydantic.validator("prefix")
-    @classmethod
-    def validate_prefix(cls, data: str) -> str:
-        """
-        Validate the prefix.
-
-        Valid characters are the same as workspace/group names.
-        """
-        # In pydantic 1.10 this could be done with constr, but mypy currently
-        # complains about their syntax
-        if not re.match(workspace_name_regex, data):
-            raise ValueError("prefix contains invalid characters")
-        return data
-
-    @pydantic.validator("suffix")
-    @classmethod
-    def validate_suffix(cls, data: str) -> str:
-        """
-        Validate the suffix.
-
-        Valid characters are the same as workspace/group names.
-        """
-        # In pydantic 1.10 this could be done with constr, but mypy currently
-        # complains about their syntax
-        if not re.match(workspace_name_regex, data):
-            raise ValueError("suffix contains invalid characters")
-        return data
-
 
 class GenerateSuiteIndexesData(BaseTaskData):
     """In-memory task data for GenerateSuiteIndexes."""
