@@ -9,30 +9,30 @@
 
 """Server-side no-operation task."""
 
+from typing import override
+
 from debusine.server.tasks import BaseServerTask
 from debusine.server.tasks.models import ServerNoopData
+from debusine.tasks import DefaultDynamicData
 from debusine.tasks.models import BaseDynamicTaskData
-from debusine.tasks.server import TaskDatabaseInterface
 
 
-class ServerNoop(BaseServerTask[ServerNoopData, BaseDynamicTaskData]):
+class ServerNoop(
+    BaseServerTask[ServerNoopData, BaseDynamicTaskData],
+    DefaultDynamicData[ServerNoopData],
+):
     """Task that runs on server-side Celery workers and returns a boolean."""
 
     TASK_VERSION = 1
 
+    @override
     def _execute(self) -> bool:
         """Act as specified by the client."""
         if self.data.exception:
             raise RuntimeError("Client requested an exception")
         return self.data.result
 
+    @override
     def get_label(self) -> str:
         """Return the task label."""
         return "noop"
-
-    def build_dynamic_data(
-        self,
-        task_database: TaskDatabaseInterface,  # noqa: U100
-    ) -> BaseDynamicTaskData:
-        """Resolve artifact lookups for this task."""
-        return BaseDynamicTaskData()
