@@ -14,16 +14,11 @@ import shutil
 import tempfile
 from ftplib import FTP
 from pathlib import Path
-from typing import cast
+from typing import override
 
 import tenacity
 from fabric import Connection
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic  # type: ignore
-
 from debusine.artifacts.models import ArtifactCategory
 from debusine.db.models import Artifact
 from debusine.server.tasks import BaseServerTask
@@ -46,6 +41,7 @@ class PackageUpload(
 
     TASK_VERSION = 1
 
+    @override
     def build_dynamic_data(
         self,
         task_database: TaskDatabaseInterface,
@@ -57,6 +53,7 @@ class PackageUpload(
             ).id,
         )
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """Return the list of input artifact IDs used by this task."""
         if not self.dynamic_data:
@@ -113,14 +110,7 @@ class PackageUpload(
                 f"{full_target.rstrip('/')}/"
                 f"DELAYED/{self.data.delayed_days}-day"
             )
-        # TODO: mypy should be able to recognize that this returns an
-        # instance of PackageUploadTarget, but for some reason it can't.
-        # Maybe the pydantic v2 API will fix this once we're able to switch
-        # to it?
-        return cast(
-            PackageUploadTarget,
-            pydantic.parse_obj_as(PackageUploadTarget, full_target),
-        )
+        return PackageUploadTarget(full_target)
 
     @tenacity.retry(
         stop=tenacity.stop_after_attempt(3),
@@ -139,9 +129,11 @@ class PackageUpload(
         try:
             with FTP(timeout=_TIMEOUT.total_seconds()) as ftp:
                 ftp.connect(host=target.host, port=int(target.port or 0))
-                ftp.login(user=target.user or "", passwd=target.password or "")
-                if target.path:
-                    ftp.cwd(target.path)
+                ftp.login(
+                    user=target.username or "", passwd=target.password or ""
+                )
+                assert target.path is not None
+                ftp.cwd(target.path)
                 for path in upload_paths:
                     self.append_to_log_file(
                         "package-upload.log", [f"Uploading {path.name}"]
@@ -171,7 +163,7 @@ class PackageUpload(
         try:
             with Connection(
                 host=target.host,
-                user=target.user,
+                user=target.username,
                 port=None if target.port is None else int(target.port),
                 connect_timeout=_TIMEOUT.total_seconds(),
             ) as connection:
@@ -188,6 +180,7 @@ class PackageUpload(
             )
             raise
 
+    @override
     def _execute(self) -> bool:
         """Execute the task."""
         with tempfile.TemporaryDirectory(
@@ -214,6 +207,7 @@ class PackageUpload(
             self.append_to_log_file("package-upload.log", ["Upload succeeded"])
             return True
 
+    @override
     def get_label(self) -> str:
         """Return the task label."""
         return f"upload to {self._make_target()}"
