@@ -44,7 +44,7 @@ class GenerateSuiteIndexesTests(TestCase):
 
     SAMPLE_TASK_DATA = {
         "suite_collection": f"bookworm@{CollectionCategory.SUITE}",
-        "generate_at": dt.datetime.now(dt.timezone.utc),
+        "generate_at": dt.datetime.now(dt.UTC),
     }
 
     def create_suite_collection(
@@ -64,7 +64,7 @@ class GenerateSuiteIndexesTests(TestCase):
     ) -> WorkRequest:
         """Create a :py:class:`GenerateSuiteIndexes` work request."""
         if generate_at is None:
-            generate_at = dt.datetime.now(dt.timezone.utc)
+            generate_at = dt.datetime.now(dt.UTC)
         work_request = self.playground.create_server_task(
             task_name="generatesuiteindexes",
             task_data=GenerateSuiteIndexesData(
@@ -108,7 +108,7 @@ class GenerateSuiteIndexesTests(TestCase):
             work_request.dynamic_task_data,
             GenerateSuiteIndexesDynamicData(
                 suite_collection_id=collection.pk
-            ).dict(exclude_unset=True),
+            ).model_dump(exclude_unset=True),
         )
 
     def test_get_input_artifacts_ids(self) -> None:
@@ -653,8 +653,7 @@ class GenerateSuiteIndexesTests(TestCase):
         suite_collection = f"bookworm@{CollectionCategory.SUITE}"
         trixie = self.create_suite_collection("trixie")
         dts = [
-            dt.datetime(2025, month, 1, tzinfo=dt.timezone.utc)
-            for month in (1, 2, 3, 4)
+            dt.datetime(2025, month, 1, tzinfo=dt.UTC) for month in (1, 2, 3, 4)
         ]
         to_remove = [
             (bookworm, "index:main/source/Sources.xz"),
@@ -689,7 +688,7 @@ class GenerateSuiteIndexesTests(TestCase):
 
         task1 = self.create_task(
             suite_collection=suite_collection,
-            generate_at=dt.datetime(2024, 12, 15, tzinfo=dt.timezone.utc),
+            generate_at=dt.datetime(2024, 12, 15, tzinfo=dt.UTC),
         )
         task1.supersede_older_items()
 
@@ -715,7 +714,7 @@ class GenerateSuiteIndexesTests(TestCase):
 
         task2 = self.create_task(
             suite_collection=suite_collection,
-            generate_at=dt.datetime(2025, 3, 15, tzinfo=dt.timezone.utc),
+            generate_at=dt.datetime(2025, 3, 15, tzinfo=dt.UTC),
         )
         task2.supersede_older_items()
 
@@ -746,7 +745,7 @@ class GenerateSuiteIndexesTests(TestCase):
 
         task3 = self.create_task(
             suite_collection=suite_collection,
-            generate_at=dt.datetime(2025, 4, 15, tzinfo=dt.timezone.utc),
+            generate_at=dt.datetime(2025, 4, 15, tzinfo=dt.UTC),
         )
         task3.supersede_older_items()
 
@@ -781,8 +780,7 @@ class GenerateSuiteIndexesTests(TestCase):
         suite_collection = f"bookworm@{CollectionCategory.SUITE}"
         trixie = self.create_suite_collection("trixie")
         dts = [
-            dt.datetime(2025, month, 1, tzinfo=dt.timezone.utc)
-            for month in (1, 2, 3, 4)
+            dt.datetime(2025, month, 1, tzinfo=dt.UTC) for month in (1, 2, 3, 4)
         ]
         to_remove = [
             (bookworm, "index:main/source/Sources.xz"),
@@ -817,18 +815,18 @@ class GenerateSuiteIndexesTests(TestCase):
 
         for generate_at, expected_item in (
             (
-                dt.datetime(2025, 2, 15, tzinfo=dt.timezone.utc),
+                dt.datetime(2025, 2, 15, tzinfo=dt.UTC),
                 bookworm.child_items.get(
                     name="index:main/source/Sources.xz", created_at=dts[2]
                 ),
             ),
             (
-                dt.datetime(2025, 3, 1, tzinfo=dt.timezone.utc),
+                dt.datetime(2025, 3, 1, tzinfo=dt.UTC),
                 bookworm.child_items.get(
                     name="index:main/source/Sources.xz", created_at=dts[3]
                 ),
             ),
-            (dt.datetime(2025, 4, 15, tzinfo=dt.timezone.utc), None),
+            (dt.datetime(2025, 4, 15, tzinfo=dt.UTC), None),
         ):
             with self.subTest(generate_at=generate_at.isoformat()):
                 task = self.create_task(
@@ -842,8 +840,7 @@ class GenerateSuiteIndexesTests(TestCase):
         self.playground.build_scenario(scenario, set_current=True)
         suite_collection = f"play_bookworm@{CollectionCategory.SUITE}"
         dts = [
-            dt.datetime(2025, month, 1, tzinfo=dt.timezone.utc)
-            for month in (1, 2, 3)
+            dt.datetime(2025, month, 1, tzinfo=dt.UTC) for month in (1, 2, 3)
         ]
         older_release = self.playground.create_repository_index("Release")
         older_release_item = scenario.suite.manager.add_artifact(
@@ -940,7 +937,7 @@ class GenerateSuiteIndexesTests(TestCase):
         """Test get_label."""
         self.create_suite_collection("bookworm")
         suite_collection = f"bookworm@{CollectionCategory.SUITE}"
-        generate_at = dt.datetime(2025, 1, 1, tzinfo=dt.timezone.utc)
+        generate_at = dt.datetime(2025, 1, 1, tzinfo=dt.UTC)
         task = self.create_task(
             suite_collection=suite_collection, generate_at=generate_at
         )
