@@ -1,4 +1,4 @@
-# Copyright 2024 The Debusine Developers
+# Copyright © The Debusine Developers
 # See the AUTHORS file at the top-level directory of this distribution
 #
 # This file is part of Debusine. It is subject to the license terms
@@ -11,11 +11,6 @@
 
 from unittest import TestCase
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
 from debusine.server.tasks.models import APTMirrorData
 
 
@@ -26,9 +21,7 @@ class APTMirrorDataTests(TestCase):
         """A flat repository must not have components."""
         APTMirrorData(
             collection="example",
-            url=pydantic.parse_obj_as(
-                pydantic.AnyUrl, "https://deb.example.org/"
-            ),
+            url="https://deb.example.org/",
             suite="./",
             architectures=["amd64"],
         )
@@ -39,9 +32,7 @@ class APTMirrorDataTests(TestCase):
         ):
             APTMirrorData(
                 collection="example",
-                url=pydantic.parse_obj_as(
-                    pydantic.AnyUrl, "https://deb.example.org/"
-                ),
+                url="https://deb.example.org/",
                 suite="./",
                 components=["main"],
                 architectures=["amd64"],
@@ -51,9 +42,7 @@ class APTMirrorDataTests(TestCase):
         """A non-flat repository must have components."""
         APTMirrorData(
             collection="debian/bookworm",
-            url=pydantic.parse_obj_as(
-                pydantic.AnyUrl, "https://deb.debian.org/debian"
-            ),
+            url="https://deb.debian.org/debian",
             suite="bookworm",
             components=["main"],
             architectures=["amd64"],
@@ -65,9 +54,7 @@ class APTMirrorDataTests(TestCase):
         ):
             APTMirrorData(
                 collection="debian/bookworm",
-                url=pydantic.parse_obj_as(
-                    pydantic.AnyUrl, "https://deb.debian.org/debian"
-                ),
+                url="https://deb.debian.org/debian",
                 suite="bookworm",
                 architectures=["amd64"],
             )
