@@ -10,17 +10,15 @@
 """Base support for wait tasks."""
 
 from abc import ABCMeta
-from typing import TypeVar
 
 from debusine.artifacts.models import TaskTypes
 from debusine.server.tasks.base import BaseServerTask
 from debusine.tasks.models import BaseDynamicTaskData, BaseTaskData
 
-TD = TypeVar("TD", bound=BaseTaskData)
-DTD = TypeVar("DTD", bound=BaseDynamicTaskData)
 
-
-class BaseWaitTask(BaseServerTask[TD, DTD], metaclass=ABCMeta):
+class BaseWaitTask[TD: BaseTaskData, DTD: BaseDynamicTaskData](
+    BaseServerTask[TD, DTD], metaclass=ABCMeta
+):
     """Base class for wait tasks."""
 
     TASK_TYPE = TaskTypes.WAIT
