@@ -24,16 +24,22 @@ class ExternalDebsign(
 
     TASK_VERSION = 1
 
-    def compute_dynamic_data(
+    def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> ExternalDebsignDynamicData:
         """Resolve artifact lookups for this task."""
         return ExternalDebsignDynamicData(
             unsigned_id=task_database.lookup_single_artifact(
                 self.data.unsigned
-            ).id
+            ).id,
         )
 
+    def get_input_artifacts_ids(self) -> list[int]:
+        """Return the list of input artifact IDs used by this task."""
+        if not self.dynamic_data:
+            return []
+        return [self.dynamic_data.unsigned_id]
+
     def _execute(self) -> bool:
         """Do nothing, successfully."""
         return True
