@@ -45,7 +45,7 @@ class DebusineAPIExceptionTests(unittest.TestCase):
         e = DebusineAPIException(
             title="Title",
             pydantic_validation_errors=[
-                {"loc": ("foo",), "msg": "bar", "type": "baz"}
+                {"loc": ("foo",), "msg": "bar", "type": "baz", "input": ""}
             ],
         )
         self.assertEqual(e.debusine_validation_errors, {"foo": ["bar"]})
