@@ -17,11 +17,6 @@ from asgiref.sync import sync_to_async
 from django.core import mail
 from django.core.mail import EmailMessage
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
 from debusine.db.models import NotificationChannel, Token, WorkRequest, Worker
 from debusine.server import notifications
 from debusine.tasks.models import (
@@ -181,9 +176,7 @@ class NotifyWorkRequestCompletedTests(TestCase):
         self.assert_send_notification(
             WorkRequest.Results.SUCCESS,
             event_name='on_success',
-            notification_data=NotificationDataEmail.parse_obj(
-                {"to": to, "cc": cc}
-            ),
+            notification_data=NotificationDataEmail(to=to, cc=cc),
             expected_to=to,
             expected_cc=cc,
             expected_subject=(
@@ -198,7 +191,7 @@ class NotifyWorkRequestCompletedTests(TestCase):
         self.assert_send_notification(
             WorkRequest.Results.SUCCESS,
             event_name='on_success',
-            notification_data=NotificationDataEmail.parse_obj({"cc": cc}),
+            notification_data=NotificationDataEmail(cc=cc),
             expected_cc=cc,
             expected_subject=(
                 "WorkRequest {work_request_id} completed in success"
@@ -214,14 +207,12 @@ class NotifyWorkRequestCompletedTests(TestCase):
         to = ["a@example.com"]
         self.assert_send_notification(
             WorkRequest.Results.FAILURE,
-            notification_data=NotificationDataEmail.parse_obj(
-                {
-                    "to": to,
-                    "subject": (
-                        "Bad news: $work_request_id completed "
-                        "in $work_request_result $invalid_variable"
-                    ),
-                }
+            notification_data=NotificationDataEmail(
+                to=to,
+                subject=(
+                    "Bad news: $work_request_id completed "
+                    "in $work_request_result $invalid_variable"
+                ),
             ),
             expected_to=to,
             expected_subject="Bad news: {work_request_id} completed in failure "
@@ -235,9 +226,7 @@ class NotifyWorkRequestCompletedTests(TestCase):
 
         self.assert_send_notification(
             WorkRequest.Results.ERROR,
-            notification_data=NotificationDataEmail.parse_obj(
-                {"to": to, "cc": cc}
-            ),
+            notification_data=NotificationDataEmail(to=to, cc=cc),
             expected_to=to,
             expected_cc=cc,
             expected_subject="WorkRequest {work_request_id} completed in error",
@@ -273,9 +262,7 @@ class NotifyWorkRequestCompletedTests(TestCase):
             on_failure=[
                 ActionSendNotification(
                     channel=channel_name,
-                    data=NotificationDataEmail(
-                        to=[pydantic.EmailStr("a@example.com")]
-                    ),
+                    data=NotificationDataEmail(to=["a@example.com"]),
                 )
             ]
         )
