@@ -29,6 +29,8 @@ from debusine.server.provisioning import (
     WorkerAllocator,
     create_new_workers,
     provision,
+    scrub,
+    scrub_workers,
     terminate_idle,
 )
 from debusine.server.worker_pools.models import WorkerPoolLimits
@@ -127,6 +129,22 @@ class TerminateIdleTests(TestCase):
             self.assertTrue(terminate_idle(minutes=10))
         term.assert_called_with(worker_pool, cloud)
 
+    def test_pool_disabled(self) -> None:
+        worker_pool = self.playground.create_worker_pool("test", enabled=False)
+        self._create_worker(idle_minutes=11, worker_pool=worker_pool)
+        with self.mock_terminate() as term:
+            self.assertFalse(terminate_idle(minutes=10))
+        term.assert_not_called()
+
+    def test_tombstone(self) -> None:
+        worker_pool = self.playground.create_worker_pool("test")
+        worker = self._create_worker(idle_minutes=11, worker_pool=worker_pool)
+        worker.instance_created_at = None
+        worker.save()
+        with self.mock_terminate() as term:
+            self.assertFalse(terminate_idle(minutes=10))
+        term.assert_not_called()
+
 
 class CreateNewWorkersTests(TestCase):
     """Test :py:func:`create_new_workers`."""
@@ -142,19 +160,39 @@ class WorkerAllocatorTests(TestCase):
     def test_static_workers_count_no_workers(self) -> None:
         """Static workers count with no workers is 0."""
         allocator = WorkerAllocator()
-        self.assertEqual(allocator.static_workers_count, 0)
+        self.assertEqual(allocator.static_workers, {})
 
     def test_static_workers_count(self) -> None:
         """Static workers count counts only connected static workers."""
         pool = self.playground.create_worker_pool()
-        connected_static_worker = self.playground.create_worker()
-        connected_static_worker.mark_connected()
-        self.playground.create_worker()
-        self.playground.create_worker()
-        self.playground.create_worker(worker_pool=pool)
-        self.playground.create_worker(worker_pool=pool)
+        for connected, in_pool, dyn_archs, static_archs in (
+            (True, False, ["amd64"], None),
+            (True, False, ["amd64"], ["i386"]),  # i386 overrides amd64
+            (True, False, None, ["amd64"]),
+            (True, False, ["ppc64el"], None),
+            (False, False, ["amd64"], None),
+            (True, True, ["amd64"], None),
+        ):
+            worker = self.playground.create_worker(
+                worker_pool=pool if in_pool else None,
+                extra_dynamic_metadata=(
+                    {"system:architectures": dyn_archs} if dyn_archs else None
+                ),
+            )
+            if static_archs:
+                worker.static_metadata = {"system:architectures": static_archs}
+                worker.save()
+            if connected:
+                worker.mark_connected()
         allocator = WorkerAllocator()
-        self.assertEqual(allocator.static_workers_count, 1)
+        self.assertEqual(
+            allocator.static_workers,
+            {
+                "amd64": 2,
+                "i386": 1,
+                "ppc64el": 1,
+            },
+        )
 
     def test_start_of_month(self) -> None:
         """Ensure WorkerAllocator computes start_of_month correctly."""
@@ -196,6 +234,10 @@ class WorkerAllocatorTests(TestCase):
             limits=WorkerPoolLimits(max_active_instances=5)
         )
         worker_allocator = WorkerAllocator()
+        # 1 worker tombstone
+        worker = self.playground.create_worker(worker_pool=pool)
+        worker.instance_created_at = None
+        worker.save()
         for value, expected in (
             (0, 0),
             (1, 1),
@@ -596,7 +638,9 @@ class ScopeWorkerAllocatorTests(TestCase):
         ]
         for worker, work_request in zip(workers, work_requests):
             work_request.assign_worker(worker)
-            work_request.mark_running()
+            self.playground.advance_work_request(
+                work_request, mark_running=True
+            )
 
         work_requests[0].started_at = TransactionNow() - dt.timedelta(minutes=1)
         work_requests[0].save()
@@ -652,7 +696,7 @@ class ScopeWorkerAllocatorTests(TestCase):
                 side_effect=limited_to,
             ),
         ):
-            for a, l, e in zip(asked, limited_to, expected):
+            for a, e in zip(asked, expected):
                 with mock.patch.object(
                     pool, "launch_workers"
                 ) as launch_workers:
@@ -674,62 +718,101 @@ class ScopeWorkerAllocatorTests(TestCase):
             workspace=other_workspace
         ).artifact
         assert other_environment is not None
-        self.playground.create_sbuild_work_request(
-            source=other_workspace_artifact,
-            architecture="amd64",
-            environment=other_environment,
-            workspace=other_workspace,
+        self.playground.advance_work_request(
+            self.playground.create_sbuild_work_request(
+                source=other_workspace_artifact,
+                architecture="amd64",
+                environment=other_environment,
+                workspace=other_workspace,
+            ),
+            mark_pending=True,
         )
 
         artifact = self.playground.create_source_artifact()
         environment = self.playground.create_debian_environment().artifact
         assert environment is not None
-        self.playground.create_sbuild_work_request(
-            source=artifact, architecture="amd64", environment=environment
-        )
-        self.playground.create_sbuild_work_request(
-            source=artifact, architecture="amd64", environment=environment
-        )
-        self.playground.create_sbuild_work_request(
-            source=artifact, architecture="arm64", environment=environment
-        )
+        for architecture in ("amd64", "amd64", "ppc64el"):
+            self.playground.advance_work_request(
+                self.playground.create_sbuild_work_request(
+                    source=artifact,
+                    architecture=architecture,
+                    environment=environment,
+                ),
+                mark_pending=True,
+            )
 
         worker_allocator = WorkerAllocator()
         allocator = ScopeWorkerAllocator(worker_allocator, self.scenario.scope)
-        # Only amd64 tasks for the selected scope are counted
-        self.assertEqual(allocator.pending_task_count, 2)
+        self.assertEqual(
+            allocator.pending_task_count(),
+            {
+                # Only amd64 tasks for the selected scope are counted
+                "amd64": 2,
+                "ppc64el": 1,
+            },
+        )
 
     def test_workers_required(self) -> None:
         worker_allocator = WorkerAllocator()
+        allocator = ScopeWorkerAllocator(worker_allocator, self.scenario.scope)
         # We currently assume a task takes 10 minutes to run, and all tasks
         # need to run within an hour
         for queue_size, workers_needed in (
+            (0, 0),  # Nothing to do
             (1, 1),  # One task can run within an hour, one worker is needed
-            (6, 1),  # For up to 6 tasks, one worker is ok
-            (7, 2),  # For the 7th task, we need another worker
+            (7, 1),  # For up to 6 tasks, one worker is ok
+            (8, 2),  # For the 7th task, we need another worker
             (12, 2),  # Two workers can do 12 tasks in an hour
         ):
             with self.subTest(queue_size=queue_size):
-                allocator = ScopeWorkerAllocator(
-                    worker_allocator, self.scenario.scope
-                )
-                # Calculations are based on the effort required to run all
-                # but the last pending task.
-                allocator.pending_task_count = queue_size + 1
-                self.assertEqual(
-                    allocator.workers_required,
-                    workers_needed,
-                )
+                with mock.patch.object(
+                    allocator,
+                    "pending_task_count",
+                    return_value={"amd64": queue_size},
+                ):
+                    # Calculations are based on the effort required to run all
+                    # but the last pending task.
+                    self.assertEqual(
+                        allocator.workers_required(),
+                        {"amd64": workers_needed},
+                    )
+
+    def test_workers_required_multi_archs(self) -> None:
+        worker_allocator = WorkerAllocator()
+        allocator = ScopeWorkerAllocator(worker_allocator, self.scenario.scope)
+        with mock.patch.object(
+            allocator,
+            "pending_task_count",
+            return_value={
+                "amd64": 10,
+                "arm64": 1,
+                "i386": 0,
+            },
+        ):
+            self.assertEqual(
+                allocator.workers_required(),
+                {
+                    "amd64": 2,
+                    "arm64": 1,
+                    "i386": 0,
+                },
+            )
 
     def test_workers_available(self) -> None:
         provider_account = self.playground.create_cloud_provider_account_asset()
 
         instance_wide_pool = self.playground.create_worker_pool(
-            "iw", instance_wide=True, provider_account=provider_account
+            "iw",
+            instance_wide=True,
+            provider_account=provider_account,
+            architectures=["amd64", "i386"],
         )
 
         scope_pool = self.playground.create_worker_pool(
-            "scope", instance_wide=False, provider_account=provider_account
+            "scope",
+            instance_wide=False,
+            provider_account=provider_account,
+            architectures=["amd64", "i386"],
         )
         ScopeWorkerPool.objects.create(
             worker_pool=scope_pool,
@@ -737,36 +820,62 @@ class ScopeWorkerAllocatorTests(TestCase):
         )
 
         other_pool = self.playground.create_worker_pool(
-            "other", instance_wide=False, provider_account=provider_account
+            "other",
+            instance_wide=False,
+            provider_account=provider_account,
+            architectures=["amd64", "i386"],
         )
 
-        # 3 static workers, of which 1 is connected
-        for connected in (True, False, False):
-            worker = self.playground.create_worker()
-            if connected:
-                worker.mark_connected()
-
-        # 2 workers in instance_wide pool
-        for _ in range(2):
-            self.playground.create_worker(worker_pool=instance_wide_pool)
-
-        # 4 workers in scope_pool
-        for _ in range(4):
-            self.playground.create_worker(worker_pool=scope_pool)
-
-        # 8 workers in other_pool
-        for _ in range(8):
-            self.playground.create_worker(worker_pool=other_pool)
+        for qty, connected, tombstone, pool, dyn_archs in (
+            # 3 static workers, of which 1 is connected
+            (1, True, False, None, ["amd64"]),
+            (2, False, False, None, ["amd64"]),
+            # 2 workers in instance_wide pool
+            (2, False, False, instance_wide_pool, None),
+            # 3 tombstones in instance_wide pool
+            (3, False, True, instance_wide_pool, None),
+            # 4 workers in scope_pool
+            (4, False, False, scope_pool, None),
+            # 8 workers in other_pool
+            (8, False, False, other_pool, None),
+        ):
+            for _ in range(qty):
+                worker = self.playground.create_worker(
+                    worker_pool=pool,
+                    extra_dynamic_metadata=(
+                        {"system:architectures": dyn_archs}
+                        if dyn_archs
+                        else None
+                    ),
+                )
+                if connected:
+                    worker.mark_connected()
+                if tombstone:
+                    worker.instance_created_at = None
+                    worker.save()
 
         worker_allocator = WorkerAllocator()
         allocator = ScopeWorkerAllocator(worker_allocator, self.scenario.scope)
-        self.assertEqual(allocator.workers_available, 7)
+        # 1 static (amd64-only), 2 instance_wide, 4 scope_pool
+        self.assertEqual(
+            allocator.workers_available(),
+            {
+                "amd64": 7,
+                "i386": 6,
+            },
+        )
 
     def test_allocation_pools(self) -> None:
         provider_account = self.playground.create_cloud_provider_account_asset()
 
-        instance_wide_pool = self.playground.create_worker_pool(
-            "iw", instance_wide=True, provider_account=provider_account
+        instance_wide_pool1 = self.playground.create_worker_pool(
+            "iw1", instance_wide=True, provider_account=provider_account
+        )
+        self.playground.create_worker_pool(
+            "iw2",
+            instance_wide=True,
+            provider_account=provider_account,
+            enabled=False,
         )
 
         scope_pool1 = self.playground.create_worker_pool(
@@ -787,6 +896,18 @@ class ScopeWorkerAllocatorTests(TestCase):
             priority=2,
         )
 
+        scope_pool3 = self.playground.create_worker_pool(
+            "scope3",
+            instance_wide=False,
+            provider_account=provider_account,
+            enabled=False,
+        )
+        ScopeWorkerPool.objects.create(
+            worker_pool=scope_pool3,
+            scope=self.scenario.scope,
+            priority=1,
+        )
+
         self.playground.create_worker_pool(
             "other", instance_wide=False, provider_account=provider_account
         )
@@ -795,7 +916,7 @@ class ScopeWorkerAllocatorTests(TestCase):
         allocator = ScopeWorkerAllocator(worker_allocator, self.scenario.scope)
         self.assertEqual(
             allocator.allocation_pools,
-            [scope_pool2, scope_pool1, instance_wide_pool],
+            [scope_pool2, scope_pool1, instance_wide_pool1],
         )
 
     def test_process_scope(self) -> None:
@@ -809,17 +930,39 @@ class ScopeWorkerAllocatorTests(TestCase):
             # 5 workers to allocate, first pool can only allocate 2
             (10, 5, 2, [5, 2], [3, 2]),
             # No new workers to allocate
-            (1, 2, 0, [], []),
+            (1, 2, 1, [], []),
         ):
             allocator = ScopeWorkerAllocator(
                 worker_allocator, self.scenario.scope
             )
-            allocator.workers_required = required
-            allocator.workers_available = available
-            allocator.allocation_pools = [WorkerPool() for _ in range(npools)]
-            with mock.patch.object(
-                allocator, "allocate_workers", side_effect=allocs_given
-            ) as allocate_workers:
+            allocator.allocation_pools = [
+                WorkerPool(architectures=["amd64"]) for _ in range(npools)
+            ]
+
+            def fake_allocate(
+                worker_pool: WorkerPool,  # noqa: ARG001, U100
+                amount: int,  # noqa: ARG001, U100
+            ) -> int:
+                nonlocal available
+                available += allocs_given[0]
+                return allocs_given.pop(0)
+
+            def fake_available() -> dict[str, int]:
+                return {"amd64": available}
+
+            with (
+                mock.patch.object(
+                    allocator, "allocate_workers", side_effect=fake_allocate
+                ) as allocate_workers,
+                mock.patch.object(
+                    allocator,
+                    "workers_required",
+                    return_value={"amd64": required},
+                ),
+                mock.patch.object(
+                    allocator, "workers_available", side_effect=fake_available
+                ),
+            ):
                 allocator.process_scope()
 
             if not allocs_asked:
@@ -831,3 +974,30 @@ class ScopeWorkerAllocatorTests(TestCase):
                     allocs_asked,
                 ):
                     self.assertEqual(call.args, (pool, asked))
+
+            # All expected allocations were made
+            self.assertEqual(allocs_given, [])
+
+
+class ScrubTests(TestCase):
+    """Test :py:func:`scrub`."""
+
+    def test_calls_scrub_workers(self) -> None:
+        with mock.patch(
+            "debusine.server.provisioning.scrub_workers",
+        ) as scrub_workers:
+            scrub()
+        scrub_workers.assert_called()
+
+
+class ScrubWorkersTests(TestCase):
+    """Test :py:func:`scrub`."""
+
+    def test_calls_pool_terminate_missing(self) -> None:
+        self.playground.create_worker_pool()
+        with mock.patch(
+            "debusine.server.worker_pools.dummy.DummyWorkerPool"
+            ".terminate_missing"
+        ) as terminate_missing:
+            scrub_workers()
+        terminate_missing.assert_called()
