@@ -21,11 +21,6 @@ from debusine.server.scopes import urlconf_scope
 class URLScopeTests(unittest.TestCase):
     """Tests scope handling in views."""
 
-    def setUp(self) -> None:
-        """Reset context at the beginning of tests."""
-        super().setUp()
-        context.reset()
-
     def assertReverses(self, scope: str) -> None:
         """Check that URLs are reversed for the right scope."""
         # Non-scoped URL
