@@ -21,10 +21,7 @@ from rest_framework.exceptions import ErrorDetail, ValidationError
 
 from debusine.artifacts.models import CollectionCategory, RuntimeStatistics
 from debusine.assets import AssetCategory, KeyPurpose, SigningKeyData
-from debusine.client.models import (
-    LookupChildType,
-    model_to_json_serializable_dict,
-)
+from debusine.client.models import LookupChildType
 from debusine.db.context import context
 from debusine.db.models import (
     Artifact,
@@ -84,12 +81,8 @@ class WorkRequestSerializerTests(TestCase):
         )
 
         cls.work_request = cls.playground.create_worker_task(
-            started_at=dt.datetime(
-                2022, 2, 20, 15, 19, 1, 158424, dt.timezone.utc
-            ),
-            completed_at=dt.datetime(
-                2022, 2, 20, 16, 2, 3, 558425, dt.timezone.utc
-            ),
+            started_at=dt.datetime(2022, 2, 20, 15, 19, 1, 158424, dt.UTC),
+            completed_at=dt.datetime(2022, 2, 20, 16, 2, 3, 558425, dt.UTC),
             worker=worker,
             task_name='sbuild',
             task_data=SbuildData(
@@ -328,12 +321,9 @@ class WorkRequestCompletedSerializerTests(TestCase):
         work_request_completed_serializer = WorkRequestCompletedSerializer(
             data={
                 "result": "success",
-                "output_data": model_to_json_serializable_dict(
-                    OutputData(
-                        runtime_statistics=RuntimeStatistics(duration=60)
-                    ),
-                    exclude_unset=True,
-                ),
+                "output_data": OutputData(
+                    runtime_statistics=RuntimeStatistics(duration=60)
+                ).model_dump(mode="json", exclude_unset=True),
             }
         )
         self.assertTrue(work_request_completed_serializer.is_valid())
@@ -633,7 +623,7 @@ class ArtifactSerializerResponseTransactionTests(TransactionTestCase):
             )
 
         with transaction.atomic():
-            artifact, files = self.playground.create_artifact(
+            artifact, _ = self.playground.create_artifact(
                 {"common-file": common_file_contents},
                 create_files=True,
                 skip_add_files_in_store=True,
@@ -725,7 +715,7 @@ class AssetSerializerTests(TestCase):
                     fingerprint="ABC123",
                     public_key=base64.b64encode(b"PUBLIC KEY").decode(),
                     purpose=KeyPurpose.OPENPGP_UPLOAD,
-                ).dict(),
+                ).model_dump(),
                 "work_request": work_request.id,
             },
         )
@@ -747,7 +737,7 @@ class AssetSerializerTests(TestCase):
                     fingerprint="ABC123",
                     public_key=base64.b64encode(b"PUBLIC KEY").decode(),
                     purpose=KeyPurpose.OPENPGP_UPLOAD,
-                ).dict(),
+                ).model_dump(),
             },
         )
         self.assertTrue(serializer.is_valid())
@@ -875,7 +865,7 @@ class WorkspaceChainItemFieldTests(TestCase):
         with self.assertRaisesRegex(
             ValidationError, r"Workspace with id \d+ does not exist"
         ):
-            field.to_internal_value({"id": hidden.pk}),
+            field.to_internal_value({"id": hidden.pk})
 
     def test_from_scope_workspace(self) -> None:
         field = WorkspaceChainItemField()
@@ -920,7 +910,7 @@ class WorkspaceChainItemFieldTests(TestCase):
             ValidationError,
             r"Workspace 'hidden' does not exist in scope 'debusine'",
         ):
-            field.to_internal_value({"workspace": "hidden"}),
+            field.to_internal_value({"workspace": "hidden"})
 
     def test_from_invalid(self) -> None:
         field = WorkspaceChainItemField()
@@ -985,6 +975,33 @@ class CollectionSerializerTests(TestCase):
             name="sid", category=CollectionCategory.SUITE
         )
 
+    def create(self, **data: Any) -> CollectionSerializer:
+        """Create a CollectionSerializer with data overrides."""
+        defaults = CollectionSerializer(self.sid).data
+        return CollectionSerializer(data=defaults | data)
+
+    def test_name_validation(self) -> None:
+        for value, expected in (
+            ("sid", True),
+            ("_", True),
+            ("sid/test", False),
+            ("_a", False),
+            ("9000", False),
+        ):
+            with self.subTest(name=value):
+                s = self.create(name=value)
+                self.assertIs(s.is_valid(), expected)
+
+    def test_category_validation(self) -> None:
+        for value, expected in (
+            ("debian:suite", True),
+            ("foobar", False),
+            ("9000", False),
+        ):
+            with self.subTest(category=value):
+                s = self.create(category=value)
+                self.assertIs(s.is_valid(), expected)
+
     def test_duration(self) -> None:
         for value, expected in (
             (None, None),
