@@ -9,9 +9,11 @@
 
 """Tests for tar related classes."""
 
+import errno
 import io
 import tarfile
 from pathlib import Path
+from unittest import mock
 
 from debusine.server.tar import TarArtifact
 from debusine.test.django import TestCase
@@ -26,7 +28,7 @@ class TarArtifactTests(TestCase):
         """Assert that TarArtifact return data in small chunks."""
         file_paths = ["README"]
 
-        artifact, files_contents = self.playground.create_artifact(
+        artifact, _ = self.playground.create_artifact(
             file_paths, create_files=True
         )
 
@@ -43,7 +45,7 @@ class TarArtifactTests(TestCase):
         """Test creating a tar for an artifact, only files from a subdir."""
         file_paths = ["README", "doc/README", "doc/README2", "src/main.c"]
 
-        artifact, files_contents = self.playground.create_artifact(
+        artifact, _ = self.playground.create_artifact(
             file_paths, create_files=True
         )
 
@@ -119,7 +121,7 @@ class TarArtifactTests(TestCase):
         """Creating a tar for an artifact excludes incomplete files."""
         file_paths = ["README", "README2", "doc/README3"]
 
-        artifact, files_contents = self.playground.create_artifact(
+        artifact, _ = self.playground.create_artifact(
             file_paths, create_files=True
         )
         artifact.fileinartifact_set.filter(path="README").update(complete=False)
@@ -141,7 +143,7 @@ class TarArtifactTests(TestCase):
         """Cannot read a file: exc logged, StopIteration raised."""
         file_paths = ["README"]
 
-        artifact, files_contents = self.playground.create_artifact(
+        artifact, _ = self.playground.create_artifact(
             file_paths, create_files=True
         )
 
@@ -162,3 +164,25 @@ class TarArtifactTests(TestCase):
             tar_artifact.__next__()
 
         self.assertTrue(tar_artifact._tar_file.closed)
+
+    def test_resource_cleanup_on_error(self) -> None:
+        file_paths = ["README"]
+        artifact, _ = self.playground.create_artifact(
+            file_paths, create_files=True
+        )
+
+        tar_artifact = TarArtifact(artifact)
+        self.assertFalse(tar_artifact._tar_closed)
+        self.assertFalse(tar_artifact._tar_file.closed)
+
+        # Simulate a read error to close the streaming prematurely
+        with mock.patch.object(
+            tar_artifact._tar_file,
+            "read",
+            side_effect=OSError(errno.EINTR, "expected error"),
+        ):
+            list(tar_artifact)
+
+        self.assertTrue(tar_artifact._closed)
+        self.assertTrue(tar_artifact._tar_closed)
+        self.assertTrue(tar_artifact._tar_file.closed)
