@@ -16,6 +16,7 @@ from debusine.server.views.artifacts import (
     ArtifactRelationsView,
     ArtifactView,
     UploadFileView,
+    WorkspaceArtifactView,
 )
 from debusine.server.views.assets import AssetPermissionCheckView, AssetView
 from debusine.server.views.base import SupersededAPIView, Whoami
@@ -25,7 +26,10 @@ from debusine.server.views.collections import (
 )
 from debusine.server.views.enroll import EnrollView
 from debusine.server.views.lookups import LookupMultipleView, LookupSingleView
-from debusine.server.views.open_metrics import OpenMetricsView
+from debusine.server.views.open_metrics import (
+    OpenMetricsEmitView,
+    OpenMetricsView,
+)
 from debusine.server.views.service_status import ServiceStatusView
 from debusine.server.views.work_requests import (
     WorkRequestAbortView,
@@ -105,6 +109,11 @@ urlpatterns_1_0: list[URLPattern | URLResolver] = [
         ArtifactView.as_view(),
         name="artifact-create",
     ),
+    path(
+        "artifact/<str:workspace>/<int:artifact_id>/",
+        WorkspaceArtifactView.as_view(),
+        name="workspace-artifact",
+    ),
     path(
         "artifact/<int:artifact_id>/",
         ArtifactView.as_view(),
@@ -121,10 +130,7 @@ urlpatterns_1_0: list[URLPattern | URLResolver] = [
         name="asset",
     ),
     path(
-        (
-            "asset/<str:asset_category>/<str:asset_slug>/"
-            "<str:permission_name>/"
-        ),
+        "asset/<str:asset_category>/<str:asset_slug>/<str:permission_name>/",
         AssetPermissionCheckView.as_view(),
         name="asset-permission-check",
     ),
@@ -171,6 +177,11 @@ urlpatterns_1_0: list[URLPattern | URLResolver] = [
         OpenMetricsView.as_view(),
         name="open-metrics",
     ),
+    path(
+        "open-metrics/emit/",
+        OpenMetricsEmitView.as_view(),
+        name="open-metrics-emit",
+    ),
     # Deprecated: use the workflow-template viewset instead
     path(
         "workflow-template/",
