@@ -8,19 +8,23 @@
 # contained in the LICENSE file.
 """Django REST Framework authentication infrastructure for Debusine."""
 
+from typing import Optional, TYPE_CHECKING, Union
+
 from django.contrib.auth.models import AnonymousUser
 from rest_framework.authentication import BaseAuthentication
-from rest_framework.request import Request
 
-from debusine.db.models import Token, User
+if TYPE_CHECKING:
+    from rest_framework.request import Request
+
+    from debusine.db.models import Token, User
 
 
 class DebusineTokenAuthentication(BaseAuthentication):
     """Restframework authentication for Debusine."""
 
     def authenticate(
-        self, request: Request
-    ) -> tuple[User | AnonymousUser | None, Token | None] | None:
+        self, request: "Request"
+    ) -> tuple[Union["User", AnonymousUser, None], Optional["Token"]] | None:
         """Authenticate the request and return a two-tuple of (user, token)."""
         token = getattr(request._request, "_debusine_token")
         if token is None:
