@@ -13,7 +13,6 @@ from rest_framework import status
 from rest_framework.request import Request
 from rest_framework.response import Response
 
-from debusine.client.models import model_to_json_serializable_dict
 from debusine.server.status import WorkerStatus
 from debusine.server.views.base import BaseAPIView
 
@@ -21,8 +20,8 @@ from debusine.server.views.base import BaseAPIView
 class ServiceStatusView(BaseAPIView):
     """View used to get the service status."""
 
-    def get(self, request: Request) -> Response:  # noqa: U100
+    def get(self, request: Request) -> Response:  # noqa: ARG002, U100
         """Return system health status."""
         health_status = WorkerStatus.get_status()
-        data = model_to_json_serializable_dict(health_status)
+        data = health_status.model_dump(mode="json")
         return Response(data, status=status.HTTP_200_OK)
