@@ -21,7 +21,6 @@ from django.utils import timezone
 from rest_framework import status
 
 from debusine.artifacts.models import RuntimeStatistics
-from debusine.client.models import model_to_json_serializable_dict
 from debusine.db.models import Token, WorkRequest, Worker
 from debusine.db.models.work_requests import MAX_AUTOMATIC_RETRIES
 from debusine.server.views.rest import IsWorkerAuthenticated
@@ -297,13 +296,13 @@ class GetNextWorkRequestViewTests(WorkRequestTestCase):
         """A partially-completed work request is aborted and retried."""
         # Create WorkRequest pending
         work_request_pending = self.create_work_request(
-            dt.datetime(2022, 1, 5, 10, 13, 20, 204242, dt.timezone.utc),
+            dt.datetime(2022, 1, 5, 10, 13, 20, 204242, dt.UTC),
             mark_pending=True,
         )
 
         # Create WorkRequest running with output
         work_request_running = self.create_work_request(
-            dt.datetime(2022, 1, 5, 11, 14, 22, 242178, dt.timezone.utc),
+            dt.datetime(2022, 1, 5, 11, 14, 22, 242178, dt.UTC),
             mark_running=True,
         )
         self.playground.create_build_log_artifact(
@@ -334,11 +333,11 @@ class GetNextWorkRequestViewTests(WorkRequestTestCase):
     def test_get_running_work_request_cannot_retry(self) -> None:
         """If a running work request cannot be retried, it is logged."""
         work_request_pending = self.create_work_request(
-            dt.datetime(2022, 1, 5, 10, 13, 20, 204242, dt.timezone.utc),
+            dt.datetime(2022, 1, 5, 10, 13, 20, 204242, dt.UTC),
             mark_pending=True,
         )
         work_request_running = self.create_work_request(
-            dt.datetime(2022, 1, 5, 11, 14, 22, 242178, dt.timezone.utc),
+            dt.datetime(2022, 1, 5, 11, 14, 22, 242178, dt.UTC),
             mark_running=True,
         )
         work_request_running.task_data = {"invalid": True}
@@ -372,7 +371,7 @@ class GetNextWorkRequestViewTests(WorkRequestTestCase):
     def test_get_work_request_change_status(self) -> None:
         """Get a WorkRequest change the status to running."""
         work_request = self.create_work_request(
-            dt.datetime(2022, 1, 5, 10, 13, 20, 204242, dt.timezone.utc),
+            dt.datetime(2022, 1, 5, 10, 13, 20, 204242, dt.UTC),
             mark_pending=True,
         )
 
@@ -393,7 +392,7 @@ class GetNextWorkRequestViewTests(WorkRequestTestCase):
     def test_get_work_request_configured_task_data(self) -> None:
         """Get a WorkRequest shows configured task data."""
         work_request = self.create_work_request(
-            dt.datetime(2022, 1, 5, 10, 13, 20, 204242, dt.timezone.utc),
+            dt.datetime(2022, 1, 5, 10, 13, 20, 204242, dt.UTC),
             mark_pending=True,
         )
         work_request.task_data = {"test": 1}
@@ -415,12 +414,12 @@ class GetNextWorkRequestViewTests(WorkRequestTestCase):
         """View return the older pending work request."""
         # Create WorkRequest pending
         work_request_pending_01 = self.create_work_request(
-            dt.datetime(2022, 1, 5, 10, 13, 20, 204242, dt.timezone.utc),
+            dt.datetime(2022, 1, 5, 10, 13, 20, 204242, dt.UTC),
             mark_pending=True,
         )
 
         work_request_pending_02 = self.create_work_request(
-            dt.datetime(2022, 1, 5, 10, 13, 22, 204242, dt.timezone.utc),
+            dt.datetime(2022, 1, 5, 10, 13, 22, 204242, dt.UTC),
             mark_pending=True,
         )
         # Request
@@ -439,7 +438,7 @@ class GetNextWorkRequestViewTests(WorkRequestTestCase):
         # Change created_at to force a change in the order that debusine
         # sends the WorkRequests to the client
         work_request_pending_01.created_at = dt.datetime(
-            2022, 1, 5, 10, 13, 24, 204242, dt.timezone.utc
+            2022, 1, 5, 10, 13, 24, 204242, dt.UTC
         )
 
         work_request_pending_01.save()
@@ -595,8 +594,8 @@ class UpdateWorkRequestAsCompletedTests(TestCase):
 
         data: dict[str, Any] = {"result": result}
         if output_data is not None:
-            data["output_data"] = model_to_json_serializable_dict(
-                output_data, exclude_unset=True
+            data["output_data"] = output_data.model_dump(
+                mode="json", exclude_unset=True
             )
         response = self.client.put(
             reverse(
