@@ -13,11 +13,7 @@ import itertools
 import logging
 from typing import Any
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
+import pydantic
 from django.http import Http404
 from django.http.response import HttpResponseBase
 from rest_framework import status
@@ -452,7 +448,10 @@ class IsWorkRequestCreator(BasePermission):
     """Allow access if the requester created the work request."""
 
     def has_object_permission(
-        self, request: Request, view: APIView, obj: Any  # noqa: U100
+        self,
+        request: Request,
+        view: APIView,  # noqa: ARG002, U100
+        obj: Any,
     ) -> bool:
         """Return True if the requester created the work request."""
         if isinstance(obj, WorkRequest) and request.auth.user != obj.created_by:
