@@ -183,7 +183,7 @@ class UpdateWorkRequestAsCompletedView(BaseAPIView):
             if work_request_completed_serializer.is_valid():
                 data = work_request_completed_serializer.validated_data
                 if "output_data" in data:
-                    output_data = OutputData.parse_obj(data["output_data"])
+                    output_data = OutputData.model_validate(data["output_data"])
                 else:
                     output_data = None
                 work_request.mark_completed(
