@@ -84,7 +84,15 @@ class WorkflowTemplateViewSet(
     def _check_permissions(
         self, serializer: BaseSerializer[WorkflowTemplate]
     ) -> None:
-        """Only users with appropriate permissions may set priorities."""
+        """Check permissions for various special cases."""
+        # Only users who can create workspaces in this scope may
+        # create/update workflow templates for create_child_workspace, since
+        # that amounts to delegating that authority.
+        task_name = serializer.validated_data.get("task_name")
+        if task_name == "create_child_workspace":
+            self.enforce(context.require_scope().can_create_workspace)
+
+        # Only users with appropriate permissions may set priorities.
         priority = serializer.validated_data.get("priority")
         if priority is not None and priority > 0:
             token = self.request.auth
@@ -257,6 +265,7 @@ class WorkflowView(BaseAPIView):
                 template=template,
                 data=serializer.validated_data.get("task_data", {}),
             )
+            workflow.mark_pending()
         except Exception as e:
             raise DebusineAPIException(
                 title="Cannot create workflow", detail=str(e)
