@@ -19,7 +19,6 @@ from rest_framework.response import Response
 from debusine.client.models import (
     WorkspaceInheritanceChain,
     WorkspaceInheritanceChainElement,
-    model_to_json_serializable_dict,
 )
 from debusine.db.context import context
 from debusine.db.models.workspaces import Workspace, WorkspaceChain
@@ -51,16 +50,19 @@ class WorkspaceInheritanceView(BaseAPIView):
             )
         return res
 
-    def get(self, request: Request, workspace: str) -> Response:  # noqa: U100
+    def get(
+        self,
+        request: Request,  # noqa: ARG002, U100
+        workspace: str,
+    ) -> Response:
         """Retrieve the contents of the collection."""
         self.set_current_workspace(workspace)
         chain = self._get_chain(context.require_workspace())
         return Response(
-            model_to_json_serializable_dict(chain),
-            status=status.HTTP_200_OK,
+            chain.model_dump(mode="json"), status=status.HTTP_200_OK
         )
 
-    def post(self, request: Request, workspace: str) -> Response:  # noqa: U100
+    def post(self, request: Request, workspace: str) -> Response:
         """Update the contents of the collection."""
         self.set_current_workspace(workspace)
         current = context.require_workspace()
@@ -101,6 +103,5 @@ class WorkspaceInheritanceView(BaseAPIView):
         # Return the new chain
         chain = self._get_chain(current)
         return Response(
-            model_to_json_serializable_dict(chain),
-            status=status.HTTP_200_OK,
+            chain.model_dump(mode="json"), status=status.HTTP_200_OK
         )
