@@ -128,7 +128,7 @@ class CloudInitConfig(BaseWorkerPoolDataModel):
     def as_str(self) -> str:
         """Render configuration file in YAML."""
         return "#cloud-config\n" + yaml.safe_dump(
-            self.dict(exclude_defaults=True)
+            self.model_dump(exclude_defaults=True)
         )
 
     def as_base64_str(self) -> str:
@@ -229,52 +229,49 @@ def worker_bootstrap_cloud_init(
         ],
     )
     backports_packages: list[str] = []
-    if debian_release == DebianRelease.BOOKWORM:
-        backports_packages += [
-            "src:autopkgtest",
-            "src:incus",
-            "src:python-django",
-            # Required by incus backport
-            "src:qemu",
-            # Required by QEMU backport
-            "src:seabios",
-        ]
-        config.apt = AptConfig(
-            preserve_sources_list=False,
-            sources_list=dedent(
-                """\
-                deb $MIRROR $RELEASE main contrib non-free-firmware
-                deb $MIRROR $RELEASE-backports main contrib non-free-firmware
-                deb $SECURITY $RELEASE-security main contrib non-free-firmware
-                """
-            ),
-        )
-
     if debusine_install_source == DebusineInstallSource.BACKPORTS:
         backports_packages.append("src:debusine")
 
     if backports_packages:
         if debian_release:
-            pin_release = f"n={debian_release}-backports"
+            pin_release = f"n={debian_release}"
         else:
-            pin_release = "a=stable-backports"
-        config.write_files.append(
+            pin_release = "a=stable"
+        config.write_files += [
             WriteFile(
-                path="/etc/apt/preferences.d/90-debusine",
+                path="/etc/apt/preferences.d/90-debusine-backports",
                 content=dedent(
                     f"""\
                     Package: {" ".join(backports_packages)}
-                    Pin: release {pin_release}
+                    Pin: release {pin_release}-backports
                     Pin-Priority: 900
+
+                    Package: {" ".join(backports_packages)}
+                    Pin: release {pin_release}
+                    Pin-Priority: -1
                     """
                 ),
-            )
-        )
+            ),
+        ]
     if debusine_install_source == DebusineInstallSource.DAILY_BUILDS:
-        config.write_files.append(
+        config.write_files += [
             WriteFile(
                 path="/etc/apt/sources.list.d/debusine.sources",
                 content=DAILY_BUILD_SOURCE,
             ),
-        )
+            WriteFile(
+                path="/etc/apt/preferences.d/90-debusine-ignore-debian",
+                content=dedent(
+                    """\
+                    Package: src:debusine
+                    Pin: release o=Debian Backports
+                    Pin-Priority: -1
+
+                    Package: src:debusine
+                    Pin: release o=Debian
+                    Pin-Priority: -1
+                    """
+                ),
+            ),
+        ]
     return config
