@@ -8,9 +8,10 @@
 # contained in the LICENSE file.
 
 """debdiff workflow."""
+
 from collections import defaultdict
 from collections.abc import Sequence
-from typing import NewType
+from typing import NewType, override
 
 from debian.debian_support import Version
 
@@ -65,8 +66,10 @@ class DebDiffWorkflow(
 
     TASK_NAME = "debdiff"
 
+    @override
     def build_dynamic_data(
-        self, task_database: TaskDatabaseInterface  # noqa: U100
+        self,
+        task_database: TaskDatabaseInterface,  # noqa: U100
     ) -> DebDiffWorkflowDynamicData:
         """
         Compute dynamic data for this workflow.
@@ -145,6 +148,7 @@ class DebDiffWorkflow(
             original_id=original_source_package_id,
         )
 
+    @override
     def get_input_artifacts(self) -> list[InputArtifact]:
         """Return input artifacts."""
         return [
@@ -177,6 +181,7 @@ class DebDiffWorkflow(
             ),
         ]
 
+    @override
     def populate(self) -> None:
         """Create work requests."""
         new_source_data = workflow_utils.source_package_data(self)
@@ -260,8 +265,10 @@ class DebDiffWorkflow(
                 else architecture
             )
             self._populate_binary_artifact_debdiff(
-                originals=LookupMultiple.parse_obj(sorted(original_relevants)),
-                news=LookupMultiple.parse_obj(sorted(new_relevants)),
+                originals=LookupMultiple.model_validate(
+                    sorted(original_relevants)
+                ),
+                news=LookupMultiple.model_validate(sorted(new_relevants)),
                 architecture=architecture,
                 build_architecture=build_arch,
                 environment=environment,
@@ -284,7 +291,7 @@ class DebDiffWorkflow(
         if source_package_version is not None:
             kwargs["data__srcpkg_version"] = source_package_version
 
-        lookup = LookupMultiple.parse_obj(kwargs)
+        lookup = LookupMultiple.model_validate(kwargs)
 
         return lookup_multiple(
             lookup,
@@ -445,9 +452,9 @@ class DebDiffWorkflow(
                                 relation.target
                             )
                         )
-                        packages_by_name_arch[pkg_name][
-                            arch
-                        ] = relation.target.id
+                        packages_by_name_arch[pkg_name][arch] = (
+                            relation.target.id
+                        )
 
                 # https://github.com/nedbat/coveragepy/issues/1860 (fixed in
                 # coverage 7.6.2)
