@@ -9,7 +9,7 @@
 
 """lintian workflow."""
 
-from typing import Any
+from typing import Any, override
 
 from debian.debian_support import Version
 from django.utils import timezone
@@ -110,6 +110,7 @@ class LintianWorkflow(
             )
         )
 
+    @override
     def populate(self) -> None:
         """Create work requests."""
         architectures = workflow_utils.get_lookup_architectures(
@@ -150,7 +151,7 @@ class LintianWorkflow(
         environment = f"{self.data.vendor}/match:codename={self.data.codename}"
 
         for arch in sorted(architectures):
-            output = self.data.output.copy()
+            output = self.data.output.model_copy()
             if arch != source_all_analysis_architecture:
                 output.source_analysis = False
                 output.binary_all_analysis = False
@@ -306,8 +307,10 @@ class LintianWorkflow(
             regression_analysis.add_dependency(wr)
             self.orchestrate_child(regression_analysis)
 
+    @override
     def build_dynamic_data(
-        self, task_database: TaskDatabaseInterface  # noqa: U100
+        self,
+        task_database: TaskDatabaseInterface,  # noqa: U100
     ) -> LintianWorkflowDynamicData:
         """
         Compute dynamic data for this workflow.
@@ -334,6 +337,7 @@ class LintianWorkflow(
             binary_artifacts_ids=artifact_ids(binary_artifacts_results),
         )
 
+    @override
     def get_input_artifacts(self) -> list[InputArtifact]:
         """Return source_artifact and the binary artifacts."""
         return [
