@@ -10,18 +10,21 @@
 """Make signed source workflow."""
 
 from functools import cached_property
+from typing import override
 
 from debusine.artifacts.models import ArtifactCategory
 from debusine.assets import KeyPurpose
 from debusine.client.models import LookupChildType
 from debusine.db.models import WorkRequest
 from debusine.server.collections.lookup import (
+    artifact_ids,
     lookup_multiple,
     reconstruct_lookup,
 )
 from debusine.server.workflows import Workflow, workflow_utils
 from debusine.server.workflows.models import (
     MakeSignedSourceWorkflowData,
+    MakeSignedSourceWorkflowDynamicData,
     SbuildWorkflowData,
     WorkRequestWorkflowData,
 )
@@ -30,9 +33,10 @@ from debusine.tasks.models import (
     ActionUpdateCollectionWithArtifacts,
     AssembleSignedSourceData,
     BackendType,
-    BaseDynamicTaskData,
     ExtractForSigningData,
     ExtractForSigningInput,
+    InputArtifact,
+    InputArtifactMultiple,
     LookupDict,
     LookupMultiple,
     LookupSingle,
@@ -42,21 +46,25 @@ from debusine.tasks.server import TaskDatabaseInterface
 
 
 class MakeSignedSourceWorkflow(
-    Workflow[MakeSignedSourceWorkflowData, BaseDynamicTaskData]
+    Workflow[MakeSignedSourceWorkflowData, MakeSignedSourceWorkflowDynamicData]
 ):
     """Make signed sources."""
 
     TASK_NAME = "make_signed_source"
 
+    @override
     def build_dynamic_data(
-        self, task_database: TaskDatabaseInterface  # noqa: U100
-    ) -> BaseDynamicTaskData:
+        self,
+        task_database: TaskDatabaseInterface,  # noqa: U100
+    ) -> MakeSignedSourceWorkflowDynamicData:
         """
         Compute dynamic data.
 
         :subject: source package names separated by spaces
         :parameter_summary: source package names separated by spaces followed
           by "for ``vendor``:``codename``"
+        :binary_artifacts_ids: ids of the binary_artifacts
+        :signing_template_artifacts_ids: ids of the signing_template_artifacts
         """
         binaries = lookup_multiple(
             self.data.binary_artifacts,
@@ -76,27 +84,63 @@ class MakeSignedSourceWorkflow(
                 ),
             )
         )
-        return BaseDynamicTaskData(
+
+        signing_templates = lookup_multiple(
+            self.data.signing_template_artifacts,
+            workflow_root=self.work_request.workflow_root,
+            workspace=self.workspace,
+            user=self.work_request.created_by,
+            expect_type=LookupChildType.ARTIFACT_OR_PROMISE,
+        )
+
+        return MakeSignedSourceWorkflowDynamicData(
             subject=source_package_names,
             parameter_summary=f"{source_package_names} for "
             f"{self.data.vendor}:{self.data.codename}",
+            binary_artifacts_ids=artifact_ids(binaries),
+            signing_template_artifacts_ids=artifact_ids(signing_templates),
         )
 
+    @override
+    def get_input_artifacts(self) -> list[InputArtifact]:
+        """Return input artifacts."""
+        return [
+            InputArtifactMultiple(
+                lookup=self.data.binary_artifacts,
+                label="binary_artifacts",
+                artifact_ids=(
+                    self.dynamic_data.binary_artifacts_ids
+                    if self.dynamic_data is not None
+                    else None
+                ),
+            ),
+            InputArtifactMultiple(
+                lookup=self.data.signing_template_artifacts,
+                label="signing_template_artifacts",
+                artifact_ids=(
+                    self.dynamic_data.signing_template_artifacts_ids
+                    if self.dynamic_data is not None
+                    else None
+                ),
+            ),
+        ]
+
     @cached_property
     def architectures(self) -> set[str]:
         """Architectures to run on."""
         return (
-            workflow_utils.get_architectures(
+            workflow_utils.get_lookup_architectures(
                 self, self.data.signing_template_artifacts
             )
             .intersection(
-                workflow_utils.get_architectures(
+                workflow_utils.get_lookup_architectures(
                     self, self.data.binary_artifacts
                 )
             )
             .intersection(self.data.architectures)
         )
 
+    @override
     def populate(self) -> None:
         """Create work requests and sub-workflows."""
         workflow_root = self.work_request.workflow_root
@@ -116,14 +160,14 @@ class MakeSignedSourceWorkflow(
                     result
                 ): reconstruct_lookup(result, workflow_root=workflow_root)
                 for result in signing_templates
-                if workflow_utils.lookup_result_architecture(result) == arch
+                if workflow_utils.lookup_result_architectures(result) == {arch}
             }
 
             binary_artifacts_lookups = (
                 workflow_utils.filter_artifact_lookup_by_arch(
                     self,
                     self.data.binary_artifacts,
-                    (arch, "all"),
+                    {arch, "all"},
                 )
             )
 
@@ -225,7 +269,7 @@ class MakeSignedSourceWorkflow(
                 artifact_filters={"category": ArtifactCategory.SIGNING_INPUT},
             ),
         )
-        lookup = LookupMultiple.parse_obj(
+        lookup = LookupMultiple.model_validate(
             {
                 "collection": "internal@collections",
                 "child_type": LookupChildType.ARTIFACT,
@@ -281,7 +325,7 @@ class MakeSignedSourceWorkflow(
                 artifact_filters={"category": ArtifactCategory.SIGNING_OUTPUT},
             ),
         )
-        lookup = LookupMultiple.parse_obj(
+        lookup = LookupMultiple.model_validate(
             {
                 "collection": "internal@collections",
                 "child_type": LookupChildType.ARTIFACT,
