@@ -8,6 +8,8 @@
 # contained in the LICENSE file.
 """Empty Workflow, used for testing."""
 
+from typing import override
+
 from debusine.server.workflows.base import Workflow
 from debusine.server.workflows.models import BaseWorkflowData
 from debusine.tasks import DefaultDynamicData
@@ -22,5 +24,6 @@ class NoopWorkflow(
 
     TASK_NAME = "noop"
 
+    @override
     def populate(self) -> None:
         """Do nothing."""
