@@ -12,7 +12,7 @@
 import datetime as dt
 from abc import ABCMeta
 from functools import cached_property
-from typing import TypeAlias, TypeVar
+from typing import TypeAlias, override
 
 from django.db.models import Max, Window
 from django.db.models.fields.json import KT
@@ -31,11 +31,11 @@ from debusine.tasks.models import (
     RegressionAnalysisStatus,
 )
 
-WD = TypeVar("WD", bound=RegressionTrackingWorkflowData)
-DTD = TypeVar("DTD", bound=BaseDynamicTaskData)
 
-
-class RegressionTrackingWorkflow(Workflow[WD, DTD], metaclass=ABCMeta):
+class RegressionTrackingWorkflow[
+    WD: RegressionTrackingWorkflowData,
+    DTD: BaseDynamicTaskData,
+](Workflow[WD, DTD], metaclass=ABCMeta):
     """Common code for a workflow that handles regression tracking."""
 
     @cached_property
@@ -77,6 +77,7 @@ class RegressionTrackingWorkflow(Workflow[WD, DTD], metaclass=ABCMeta):
             expect_type=LookupChildType.COLLECTION,
         ).collection
 
+    @override
     def validate_input(self) -> None:
         """Thorough validation of input data."""
         # Validate that we can look up self.data.qa_suite and
@@ -211,7 +212,7 @@ class RegressionTrackingWorkflow(Workflow[WD, DTD], metaclass=ABCMeta):
                 return RegressionAnalysisStatus.STABLE
             case WR(status=S.COMPLETED, result=reference_result), WR(
                 status=S.COMPLETED, result=new_result
-            ) if (reference_result == new_result):
+            ) if reference_result == new_result:
                 return RegressionAnalysisStatus.STABLE
             case _:
                 return RegressionAnalysisStatus.ERROR
