@@ -41,6 +41,7 @@ from debusine.server.workflows.base import orchestrate_workflow
 from debusine.server.workflows.models import (
     BaseWorkflowData,
     BlhcWorkflowData,
+    BlhcWorkflowDynamicData,
     SbuildWorkflowData,
     WorkRequestWorkflowData,
 )
@@ -56,6 +57,8 @@ from debusine.tasks.models import (
     ActionUpdateCollectionWithArtifacts,
     BaseDynamicTaskData,
     BlhcFlags,
+    InputArtifactMultiple,
+    InputArtifactSingle,
     LookupMultiple,
     LookupSingle,
     OutputData,
@@ -180,6 +183,7 @@ class BlhcWorkflowTests(
         *,
         package_build_logs: list[LookupSingle] | None = None,
         extra_task_data: dict[str, Any] | None = None,
+        include_source_artifact: bool = True,
     ) -> BlhcWorkflow:
         """
         Create and schedule a Blhc workflow.
@@ -187,23 +191,29 @@ class BlhcWorkflowTests(
         :param package_build_logs: build logs for the workflow. If None
           use all the expected promises by setUpTestData()
         :param extra_task_data: any extra task data to pass to the workflow
+        :param include_source_artifact: True to include self.source_artifact
         """
         if package_build_logs is None:
             package_build_logs = []
             for package_build_log in self.package_build_log_artifacts.values():
                 package_build_logs.append(package_build_log.id)
 
-        task_data: dict[str, Any] = {
-            "source_artifact": self.source_artifact.id,
-            "package_build_logs": package_build_logs,
-            "vendor": "debian",
-            "codename": "bookworm",
-        }
+        task_data = BlhcWorkflowData(
+            source_artifact=(
+                self.source_artifact.id if include_source_artifact else None
+            ),
+            package_build_logs=LookupMultiple.model_validate(
+                package_build_logs
+            ),
+            vendor="debian",
+            codename="bookworm",
+        )
+
         if extra_task_data is not None:
-            task_data.update(extra_task_data)
+            task_data = task_data.model_copy(update=extra_task_data)
 
         example_pipeline = self.orchestrate(
-            task_data=BlhcWorkflowData(**task_data),
+            task_data=task_data,
             source_artifact=self.source_artifact,
         )
         work_request = example_pipeline.children.get(
@@ -290,7 +300,7 @@ class BlhcWorkflowTests(
             task_name="blhc",
             task_data=BlhcWorkflowData(
                 prefix="reference-qa-result|",
-                package_build_logs=LookupMultiple.parse_obj([build_log.id]),
+                package_build_logs=LookupMultiple((build_log.id,)),
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
                 reference_qa_results=f"sid@{CollectionCategory.QA_RESULTS}",
                 update_qa_results=True,
@@ -324,7 +334,7 @@ class BlhcWorkflowTests(
             task_name="blhc",
             task_data=BlhcWorkflowData(
                 prefix="reference-qa-result|",
-                package_build_logs=LookupMultiple.parse_obj([build_log.id]),
+                package_build_logs=LookupMultiple((build_log.id,)),
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
                 reference_qa_results=f"sid@{CollectionCategory.QA_RESULTS}",
                 update_qa_results=True,
@@ -358,7 +368,7 @@ class BlhcWorkflowTests(
             task_name="blhc",
             task_data=BlhcWorkflowData(
                 prefix="reference-qa-result|",
-                package_build_logs=LookupMultiple.parse_obj([build_log.id]),
+                package_build_logs=LookupMultiple((build_log.id,)),
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
                 reference_qa_results=f"sid@{CollectionCategory.QA_RESULTS}",
                 update_qa_results=True,
@@ -391,7 +401,7 @@ class BlhcWorkflowTests(
             task_name="blhc",
             task_data=BlhcWorkflowData(
                 prefix="reference-qa-result|",
-                package_build_logs=LookupMultiple.parse_obj([build_log.id]),
+                package_build_logs=LookupMultiple((build_log.id,)),
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
                 reference_qa_results=f"sid@{CollectionCategory.QA_RESULTS}",
                 update_qa_results=True,
@@ -437,7 +447,7 @@ class BlhcWorkflowTests(
             task_name="blhc",
             task_data=BlhcWorkflowData(
                 prefix="reference-qa-result|",
-                package_build_logs=LookupMultiple.parse_obj(
+                package_build_logs=LookupMultiple.model_validate(
                     [f"test@{CollectionCategory.TEST}/name:test"]
                 ),
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
@@ -506,7 +516,7 @@ class BlhcWorkflowTests(
             task_name="blhc",
             task_data=BlhcWorkflowData(
                 source_artifact=upload_artifacts.upload.id,
-                package_build_logs=LookupMultiple.parse_obj([log.id]),
+                package_build_logs=LookupMultiple((log.id,)),
                 vendor="debian",
                 codename="sid",
             ),
@@ -534,7 +544,7 @@ class BlhcWorkflowTests(
             task_name="blhc",
             task_data=BlhcWorkflowData(
                 prefix="reference-qa-result|",
-                package_build_logs=LookupMultiple.parse_obj([build_log.id]),
+                package_build_logs=LookupMultiple((build_log.id,)),
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
                 reference_qa_results=f"sid@{CollectionCategory.QA_RESULTS}",
                 update_qa_results=True,
@@ -573,7 +583,7 @@ class BlhcWorkflowTests(
             task_name="blhc",
             task_data=BlhcWorkflowData(
                 prefix="reference-qa-result|",
-                package_build_logs=LookupMultiple.parse_obj([build_log.id]),
+                package_build_logs=LookupMultiple((build_log.id,)),
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
                 reference_qa_results=f"sid@{CollectionCategory.QA_RESULTS}",
                 update_qa_results=True,
@@ -644,8 +654,7 @@ class BlhcWorkflowTests(
         )
         self.assertEqual(
             lookup_single(
-                f"sid@{CollectionCategory.QA_RESULTS}/"
-                f"latest:blhc_hello_amd64",
+                f"sid@{CollectionCategory.QA_RESULTS}/latest:blhc_hello_amd64",
                 child.workspace,
                 user=child.created_by,
                 expect_type=LookupChildType.ARTIFACT,
@@ -670,7 +679,7 @@ class BlhcWorkflowTests(
             task_name="blhc",
             task_data=BlhcWorkflowData(
                 prefix="reference-qa-result|",
-                package_build_logs=LookupMultiple.parse_obj([build_log.id]),
+                package_build_logs=LookupMultiple((build_log.id,)),
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
                 reference_qa_results=f"sid@{CollectionCategory.QA_RESULTS}",
                 update_qa_results=True,
@@ -704,8 +713,7 @@ class BlhcWorkflowTests(
         )
         self.assertEqual(
             lookup_single(
-                f"sid@{CollectionCategory.QA_RESULTS}/"
-                f"latest:blhc_hello_amd64",
+                f"sid@{CollectionCategory.QA_RESULTS}/latest:blhc_hello_amd64",
                 child.workspace,
                 user=child.created_by,
                 expect_type=LookupChildType.ARTIFACT,
@@ -731,7 +739,7 @@ class BlhcWorkflowTests(
                 reference_qa_results=f"sid@{CollectionCategory.QA_RESULTS}",
                 update_qa_results=True,
                 source_artifact=reference_source_artifact.id,
-                package_build_logs=LookupMultiple.parse_obj(
+                package_build_logs=LookupMultiple.model_validate(
                     [
                         f"internal@collections/name:buildlog-{arch}"
                         for arch in architectures
@@ -753,7 +761,7 @@ class BlhcWorkflowTests(
                 reference_qa_results=f"sid@{CollectionCategory.QA_RESULTS}",
                 enable_regression_tracking=True,
                 source_artifact=self.source_artifact.id,
-                package_build_logs=LookupMultiple.parse_obj(
+                package_build_logs=LookupMultiple.model_validate(
                     [
                         f"internal@collections/name:buildlog-{arch}"
                         for arch in architectures
@@ -943,5 +951,79 @@ class BlhcWorkflowTests(
 
         self.assertEqual(
             workflow.compute_dynamic_data(TaskDatabase(workflow.work_request)),
-            BaseDynamicTaskData(subject="hello hello-traditional"),
+            BlhcWorkflowDynamicData(
+                subject="hello hello-traditional",
+                source_artifact_id=self.source_artifact.id,
+                package_build_logs_ids=[
+                    package_build_log_1.id,
+                    package_build_log_2.id,
+                ],
+            ),
+        )
+
+    @preserve_task_registry()
+    def test_get_input_artifacts(self) -> None:
+        package_build_log_1 = self.playground.create_build_log_artifact(
+            source="hello"
+        )
+        package_build_log_2 = self.playground.create_build_log_artifact(
+            source="hello-traditional"
+        )
+
+        workflow = self.create_blhc_workflow(
+            package_build_logs=[
+                f"{package_build_log_1.id}@artifacts",
+                f"{package_build_log_2.id}@artifacts",
+            ],
+        )
+
+        assert workflow.data.source_artifact is not None
+        self.assertEqual(
+            workflow.get_input_artifacts(),
+            [
+                InputArtifactSingle(
+                    lookup=workflow.data.source_artifact,
+                    label="source_artifact",
+                    artifact_id=self.source_artifact.id,
+                ),
+                InputArtifactMultiple(
+                    lookup=workflow.data.package_build_logs,
+                    label="package_build_logs",
+                    artifact_ids=[
+                        package_build_log_1.id,
+                        package_build_log_2.id,
+                    ],
+                ),
+            ],
+        )
+
+    @preserve_task_registry()
+    def test_get_input_artifacts_without_source_artifact(self) -> None:
+        package_build_log_1 = self.playground.create_build_log_artifact(
+            source="hello"
+        )
+        package_build_log_2 = self.playground.create_build_log_artifact(
+            source="hello-traditional"
+        )
+
+        workflow = self.create_blhc_workflow(
+            package_build_logs=[
+                f"{package_build_log_1.id}@artifacts",
+                f"{package_build_log_2.id}@artifacts",
+            ],
+            include_source_artifact=False,
+        )
+
+        self.assertEqual(
+            workflow.get_input_artifacts(),
+            [
+                InputArtifactMultiple(
+                    lookup=workflow.data.package_build_logs,
+                    label="package_build_logs",
+                    artifact_ids=[
+                        package_build_log_1.id,
+                        package_build_log_2.id,
+                    ],
+                ),
+            ],
         )
