@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Unit tests for the debdiff workflow."""
+
 from collections.abc import Iterable
 from typing import Any, ClassVar
 from unittest.mock import call, patch
@@ -464,11 +465,11 @@ class DebDiffWorkflowTests(WorkflowTestBase[DebDiffWorkflow]):
         self.assertIn(
             call(
                 amd64_work_request,
-                LookupMultiple.parse_obj(
-                    [
+                LookupMultiple(
+                    (
                         f"{bookworm_lookup}/name:hello_1.0.0_all",
                         f"{bookworm_lookup}/name:hello_1.0.0_amd64",
-                    ]
+                    )
                 ),
             ),
             requires_artifact.call_args_list,
@@ -476,11 +477,13 @@ class DebDiffWorkflowTests(WorkflowTestBase[DebDiffWorkflow]):
         self.assertIn(
             call(
                 amd64_work_request,
-                LookupMultiple.parse_obj(
-                    [
-                        self.new_binary_artifact_lookup("amd64"),
-                        self.new_binary_artifact_lookup("all"),
-                    ]
+                LookupMultiple.model_validate(
+                    sorted(
+                        [
+                            self.new_binary_artifact_lookup("amd64"),
+                            self.new_binary_artifact_lookup("all"),
+                        ]
+                    )
                 ),
             ),
             requires_artifact.call_args_list,
@@ -554,9 +557,7 @@ class DebDiffWorkflowTests(WorkflowTestBase[DebDiffWorkflow]):
 
         # Make workflow.data.binary_artifacts contain an artifact of an
         # unexpected category
-        workflow.data.binary_artifacts = LookupMultiple.parse_obj(
-            [source_artifact.id]
-        )
+        workflow.data.binary_artifacts = LookupMultiple((source_artifact.id,))
         with self.assertRaisesRegex(
             ValueError, "Unexpected category 'debian:source-package'"
         ):
