@@ -8,12 +8,8 @@
 # contained in the LICENSE file.
 
 """Unit tests for the debian pipeline workflow."""
-from typing import Any, ClassVar
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
+from typing import Any, ClassVar
 
 from debusine.artifacts.models import (
     ArtifactCategory,
@@ -237,9 +233,7 @@ class DebianPipelineWorkflowTests(WorkflowTestBase[DebianPipelineWorkflow]):
 
     def test_get_extra_repositories_explicit(self) -> None:
         external = ExtraExternalRepository(
-            url=pydantic.parse_obj_as(pydantic.AnyUrl, "http://example.com/"),
-            suite="sid",
-            components=["main"],
+            url="http://example.com/", suite="sid", components=["main"]
         )
         wr = self.playground.create_workflow(
             task_name="debian_pipeline",
@@ -306,9 +300,7 @@ class DebianPipelineWorkflowTests(WorkflowTestBase[DebianPipelineWorkflow]):
             variables={"path": "InRelease"},
         )
         external = ExtraExternalRepository(
-            url=pydantic.parse_obj_as(pydantic.AnyUrl, "http://example.com/"),
-            suite="sid",
-            components=["main"],
+            url="http://example.com/", suite="sid", components=["main"]
         )
         wr = self.playground.create_workflow(
             task_name="debian_pipeline",
