@@ -292,7 +292,7 @@ class LintianWorkflowTests(
             task_name="lintian",
             task_data=LintianWorkflowData(
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([]),
+                binary_artifacts=LookupMultiple(()),
                 vendor="debian",
                 codename="sid",
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
@@ -325,7 +325,7 @@ class LintianWorkflowTests(
             task_name="lintian",
             task_data=LintianWorkflowData(
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([]),
+                binary_artifacts=LookupMultiple(()),
                 vendor="debian",
                 codename="sid",
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
@@ -358,7 +358,7 @@ class LintianWorkflowTests(
             task_name="lintian",
             task_data=LintianWorkflowData(
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([]),
+                binary_artifacts=LookupMultiple(()),
                 vendor="debian",
                 codename="sid",
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
@@ -388,7 +388,7 @@ class LintianWorkflowTests(
             task_name="lintian",
             task_data=LintianWorkflowData(
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([]),
+                binary_artifacts=LookupMultiple(()),
                 vendor="debian",
                 codename="sid",
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
@@ -421,7 +421,7 @@ class LintianWorkflowTests(
             task_name="lintian",
             task_data=LintianWorkflowData(
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([]),
+                binary_artifacts=LookupMultiple(()),
                 vendor="debian",
                 codename="sid",
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
@@ -456,7 +456,7 @@ class LintianWorkflowTests(
             task_name="lintian",
             task_data=LintianWorkflowData(
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([]),
+                binary_artifacts=LookupMultiple(()),
                 vendor="debian",
                 codename="sid",
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
@@ -488,7 +488,7 @@ class LintianWorkflowTests(
             task_data=LintianWorkflowData(
                 architectures=architectures,
                 source_artifact=self.source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
+                binary_artifacts=LookupMultiple.model_validate(
                     [
                         f"internal@collections/name:build-{arch}"
                         for arch in architectures
@@ -571,7 +571,7 @@ class LintianWorkflowTests(
         root = self.orchestrate(
             task_data=LintianWorkflowData(
                 source_artifact=self.source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([]),
+                binary_artifacts=LookupMultiple(()),
                 vendor="debian",
                 codename="trixie",
             ),
@@ -616,7 +616,7 @@ class LintianWorkflowTests(
         root = self.orchestrate(
             task_data=LintianWorkflowData(
                 source_artifact=self.source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="trixie",
             ),
@@ -663,7 +663,7 @@ class LintianWorkflowTests(
         root = self.orchestrate(
             task_data=LintianWorkflowData(
                 source_artifact=self.source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="trixie",
                 arch_all_build_architecture="s390x",
@@ -712,8 +712,8 @@ class LintianWorkflowTests(
         root = self.orchestrate(
             task_data=LintianWorkflowData(
                 source_artifact=self.source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
-                    [binary_artifacts["all"].id, binary_artifacts["i386"].id]
+                binary_artifacts=LookupMultiple(
+                    (binary_artifacts["all"].id, binary_artifacts["i386"].id)
                 ),
                 vendor="debian",
                 codename="trixie",
@@ -772,8 +772,8 @@ class LintianWorkflowTests(
         root = self.orchestrate(
             task_data=LintianWorkflowData(
                 source_artifact=self.source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
-                    [binary_artifacts["i386"].id, binary_artifacts["s390x"].id]
+                binary_artifacts=LookupMultiple(
+                    (binary_artifacts["i386"].id, binary_artifacts["s390x"].id)
                 ),
                 vendor="debian",
                 codename="trixie",
@@ -824,8 +824,8 @@ class LintianWorkflowTests(
             task_data=LintianWorkflowData(
                 architectures=["i386"],
                 source_artifact=self.source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
-                    ["internal@collections/name:build-amd64"]
+                binary_artifacts=LookupMultiple(
+                    ("internal@collections/name:build-amd64",)
                 ),
                 vendor="debian",
                 codename="trixie",
@@ -859,12 +859,12 @@ class LintianWorkflowTests(
         root = self.orchestrate(
             task_data=LintianWorkflowData(
                 source_artifact=self.source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
-                    [
+                binary_artifacts=LookupMultiple(
+                    (
                         binary_artifacts["all"].id,
                         binary_artifacts["amd64"].id,
                         binary_artifacts["i386"].id,
-                    ]
+                    )
                 ),
                 vendor="debian",
                 codename="trixie",
@@ -917,7 +917,7 @@ class LintianWorkflowTests(
             task_data=LintianWorkflowData(
                 architectures=architectures,
                 source_artifact=upload_artifacts.upload.id,
-                binary_artifacts=LookupMultiple.parse_obj(
+                binary_artifacts=LookupMultiple.model_validate(
                     [
                         f"internal@collections/name:build-{arch}"
                         for arch in architectures
@@ -1011,9 +1011,7 @@ class LintianWorkflowTests(
             task_name="lintian",
             task_data=LintianWorkflowData(
                 source_artifact=artifacts.upload.id,
-                binary_artifacts=LookupMultiple.parse_obj(
-                    [artifacts.upload.id]
-                ),
+                binary_artifacts=LookupMultiple((artifacts.upload.id,)),
                 architectures=architectures,
                 vendor="debian",
                 codename="sid",
@@ -1066,7 +1064,7 @@ class LintianWorkflowTests(
                 prefix="reference-qa-result|",
                 architectures=architectures,
                 source_artifact=self.source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
+                binary_artifacts=LookupMultiple.model_validate(
                     [
                         f"internal@collections/name:build-{arch}"
                         for arch in architectures
@@ -1113,7 +1111,7 @@ class LintianWorkflowTests(
                 prefix="reference-qa-result|",
                 architectures=architectures,
                 source_artifact=self.source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
+                binary_artifacts=LookupMultiple.model_validate(
                     [
                         f"internal@collections/name:build-{arch}"
                         for arch in architectures
@@ -1291,7 +1289,7 @@ class LintianWorkflowTests(
             task_data=LintianWorkflowData(
                 prefix="reference-qa-result|",
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="trixie",
                 qa_suite=f"trixie@{CollectionCategory.SUITE}",
@@ -1345,7 +1343,7 @@ class LintianWorkflowTests(
             task_name="lintian",
             task_data=LintianWorkflowData(
                 source_artifact=self.source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary.id]),
+                binary_artifacts=LookupMultiple((binary.id,)),
                 vendor="debian",
                 codename="trixie",
             ),
@@ -1371,7 +1369,7 @@ class LintianWorkflowTests(
             task_name="lintian",
             task_data=LintianWorkflowData(
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="trixie",
             ),
@@ -1400,7 +1398,7 @@ class LintianWorkflowTests(
             task_name="lintian",
             task_data=LintianWorkflowData(
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="trixie",
             ),
@@ -1465,7 +1463,7 @@ class LintianWorkflowTests(
                 update_qa_results=True,
                 architectures=architectures,
                 source_artifact=reference_source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
+                binary_artifacts=LookupMultiple.model_validate(
                     [
                         f"internal@collections/name:build-{arch}"
                         for arch in ("all", *architectures)
@@ -1487,7 +1485,7 @@ class LintianWorkflowTests(
                 enable_regression_tracking=True,
                 architectures=architectures,
                 source_artifact=self.source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
+                binary_artifacts=LookupMultiple.model_validate(
                     [
                         f"internal@collections/name:build-{arch}"
                         for arch in ("all", *architectures)
