@@ -10,7 +10,7 @@
 """Unit tests for workflow models."""
 
 from abc import ABCMeta, abstractmethod
-from typing import Any, Generic, TypeVar
+from typing import Any
 
 from debusine.server.workflows.models import (
     AutopkgtestWorkflowData,
@@ -26,12 +26,7 @@ from debusine.server.workflows.models import (
     ReverseDependenciesAutopkgtestWorkflowData,
     SbuildWorkflowData,
 )
-from debusine.tasks.models import (
-    LookupMultiple,
-    LookupSingle,
-    SbuildInput,
-    empty_lookup_multiple,
-)
+from debusine.tasks.models import LookupMultiple, LookupSingle, SbuildInput
 from debusine.test.django import TestCase
 
 
@@ -48,7 +43,7 @@ class SbuildWorkflowDataTests(TestCase):
             retry_delays=delays,
         )
         self.assertEqual(
-            data.dict(exclude_unset=True),
+            data.model_dump(exclude_unset=True),
             {
                 "input": {"source_artifact": 42},
                 "target_distribution": "debian:bookworm",
@@ -60,9 +55,7 @@ class SbuildWorkflowDataTests(TestCase):
     def test_retry_delays_bad_format(self) -> None:
         """Items in `retry_delays` must be integers followed by m/h/d/w."""
         with self.assertRaisesRegex(
-            ValueError,
-            "Item in retry_delays must be an integer followed by "
-            "m, h, d, or w; got '2 weeks'",
+            ValueError, r"String should match pattern.*input_value='2 weeks'"
         ):
             SbuildWorkflowData(
                 input=SbuildInput(source_artifact=42),
@@ -72,11 +65,8 @@ class SbuildWorkflowDataTests(TestCase):
             )
 
 
-WD = TypeVar("WD", bound=RegressionTrackingWorkflowData)
-
-
-class RegressionTrackingWorkflowDataTests(
-    TestCase, Generic[WD], metaclass=ABCMeta
+class RegressionTrackingWorkflowDataTests[WD: RegressionTrackingWorkflowData](
+    TestCase, metaclass=ABCMeta
 ):
     """Common tests for models that handle regression tracking."""
 
@@ -149,7 +139,7 @@ class PiupartsWorkflowDataTests(
         """Make a `PiupartsWorkflowData`."""
         return PiupartsWorkflowData(
             source_artifact=1,
-            binary_artifacts=LookupMultiple.parse_obj([2]),
+            binary_artifacts=LookupMultiple((2,)),
             vendor="debian",
             codename="sid",
             **kwargs,
@@ -165,7 +155,7 @@ class AutopkgtestWorkflowDataTests(
         """Make an `AutopkgtestWorkflowData`."""
         return AutopkgtestWorkflowData(
             source_artifact=1,
-            binary_artifacts=LookupMultiple.parse_obj([2]),
+            binary_artifacts=LookupMultiple((2,)),
             vendor="debian",
             codename="sid",
             **kwargs,
@@ -187,7 +177,7 @@ class ReverseDependenciesAutopkgtestWorkflowDataTests(
         """Make a `ReverseDependenciesAutopkgtestWorkflowData`."""
         data: dict[str, Any] = {
             "source_artifact": 1,
-            "binary_artifacts": LookupMultiple.parse_obj([2]),
+            "binary_artifacts": LookupMultiple((2,)),
             "qa_suite": "sid@debian:suite",
             "vendor": "debian",
             "codename": "sid",
@@ -205,7 +195,7 @@ class LintianWorkflowDataTests(
         """Make a `LintianWorkflowData`."""
         return LintianWorkflowData(
             source_artifact=1,
-            binary_artifacts=LookupMultiple.parse_obj([2]),
+            binary_artifacts=LookupMultiple((2,)),
             vendor="debian",
             codename="sid",
             **kwargs,
@@ -223,7 +213,7 @@ class BlhcWorkflowDataTests(
         """Make a `BlhcWorkflowData`."""
         return BlhcWorkflowData(
             source_artifact=source_artifact,
-            package_build_logs=LookupMultiple.parse_obj([2]),
+            package_build_logs=LookupMultiple((2,)),
             vendor="debian",
             codename="sid",
             **kwargs,
@@ -258,11 +248,11 @@ class QAWorkflowDataTests(RegressionTrackingWorkflowDataTests[QAWorkflowData]):
 
     def make_data(self, **kwargs: Any) -> QAWorkflowData:
         """Make a `QAWorkflowData`."""
-        return QAWorkflowData.parse_obj(
+        return QAWorkflowData.model_validate(
             {
                 "source_artifact": 1,
-                "binary_artifacts": LookupMultiple.parse_obj([2]),
-                "package_build_logs": LookupMultiple.parse_obj([3]),
+                "binary_artifacts": LookupMultiple((2,)),
+                "package_build_logs": LookupMultiple((3,)),
                 "vendor": "debian",
                 "codename": "sid",
                 **kwargs,
@@ -413,11 +403,11 @@ class PackagePublishWorkflowDataTests(TestCase):
             source_artifact=1, target_suite="bookworm@debian:suite"
         )
         PackagePublishWorkflowData(
-            binary_artifacts=LookupMultiple.parse_obj([1]),
+            binary_artifacts=LookupMultiple((1,)),
             target_suite="bookworm@debian:suite",
         )
         PackagePublishWorkflowData(
-            binary_artifacts=LookupMultiple.parse_obj([1, 2]),
+            binary_artifacts=LookupMultiple((1, 2)),
             target_suite="bookworm@debian:suite",
         )
 
@@ -426,7 +416,7 @@ class PackagePublishWorkflowDataTests(TestCase):
             PackagePublishWorkflowData(target_suite="bookworm@debian:suite")
         with self.assertRaisesRegex(ValueError, error_msg):
             PackagePublishWorkflowData(
-                binary_artifacts=empty_lookup_multiple(),
+                binary_artifacts=LookupMultiple(()),
                 target_suite="bookworm@debian:suite",
             )
 
@@ -444,7 +434,7 @@ class ChildWorkspaceDataTests(TestCase):
             with (
                 self.subTest(name=name),
                 self.assertRaisesRegex(
-                    ValueError, "prefix contains invalid characters"
+                    ValueError, r"\bprefix\n.*String should match pattern"
                 ),
             ):
                 ChildWorkspaceData(prefix=name, suffix="suffix")
@@ -459,7 +449,7 @@ class ChildWorkspaceDataTests(TestCase):
             with (
                 self.subTest(name=name),
                 self.assertRaisesRegex(
-                    ValueError, "suffix contains invalid characters"
+                    ValueError, r"\bsuffix\n.*String should match pattern"
                 ),
             ):
                 ChildWorkspaceData(suffix=name)
