@@ -29,6 +29,7 @@ from debusine.server.workflows.base import orchestrate_workflow
 from debusine.server.workflows.models import (
     BaseWorkflowData,
     PackagePublishWorkflowData,
+    PackagePublishWorkflowDynamicData,
     SbuildWorkflowData,
     WorkRequestWorkflowData,
 )
@@ -38,6 +39,8 @@ from debusine.server.workflows.tests.helpers import (
 )
 from debusine.tasks.models import (
     BaseDynamicTaskData,
+    InputArtifactMultiple,
+    InputArtifactSingle,
     LookupMultiple,
     SbuildInput,
 )
@@ -102,7 +105,7 @@ class PackagePublishWorkflowTests(WorkflowTestBase[PackagePublishWorkflow]):
         )
 
     def create_package_publish_workflow(
-        self, task_data: dict[str, Any]
+        self, task_data: PackagePublishWorkflowData
     ) -> PackagePublishWorkflow:
         """Create a package_publish workflow."""
         wr = self.playground.create_workflow(
@@ -113,21 +116,20 @@ class PackagePublishWorkflowTests(WorkflowTestBase[PackagePublishWorkflow]):
     def test_create_orchestrator(self) -> None:
         """A PackagePublishWorkflow can be instantiated."""
         source_artifact = self.source_artifact.pk
-        binary_artifacts = [self.binary_artifact.pk]
-        target_suite = f"bookworm@{CollectionCategory.SUITE}"
+        binary_artifacts = (self.binary_artifact.pk,)
+        target_suite = self.create_suite_collection("bookworm").pk
 
         workflow = self.create_package_publish_workflow(
-            {
-                "source_artifact": source_artifact,
-                "binary_artifacts": binary_artifacts,
-                "target_suite": target_suite,
-            }
+            PackagePublishWorkflowData(
+                source_artifact=source_artifact,
+                binary_artifacts=LookupMultiple(binary_artifacts),
+                target_suite=target_suite,
+            )
         )
 
         self.assertEqual(workflow.data.source_artifact, source_artifact)
         self.assertEqual(
-            workflow.data.binary_artifacts,
-            LookupMultiple.parse_obj(binary_artifacts),
+            workflow.data.binary_artifacts, LookupMultiple(binary_artifacts)
         )
         self.assertEqual(workflow.data.target_suite, target_suite)
 
@@ -274,7 +276,7 @@ class PackagePublishWorkflowTests(WorkflowTestBase[PackagePublishWorkflow]):
         root = self.orchestrate(
             task_data=PackagePublishWorkflowData(
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
+                binary_artifacts=LookupMultiple.model_validate(
                     [
                         f"internal@collections/name:build-{arch}"
                         for arch in architectures
@@ -417,9 +419,7 @@ class PackagePublishWorkflowTests(WorkflowTestBase[PackagePublishWorkflow]):
         ) as log:
             root = self.orchestrate(
                 task_data=PackagePublishWorkflowData(
-                    binary_artifacts=LookupMultiple.parse_obj(
-                        [binary_artifact.id]
-                    ),
+                    binary_artifacts=LookupMultiple((binary_artifact.id,)),
                     target_suite=(
                         f"{target_suite.name}@{CollectionCategory.SUITE}"
                     ),
@@ -511,9 +511,7 @@ class PackagePublishWorkflowTests(WorkflowTestBase[PackagePublishWorkflow]):
             root = self.orchestrate(
                 task_data=PackagePublishWorkflowData(
                     source_artifact=source_artifact.id,
-                    binary_artifacts=LookupMultiple.parse_obj(
-                        [binary_artifact.id]
-                    ),
+                    binary_artifacts=LookupMultiple((binary_artifact.id,)),
                     target_suite=(
                         f"{target_suite.name}@{CollectionCategory.SUITE}"
                     ),
@@ -625,7 +623,7 @@ class PackagePublishWorkflowTests(WorkflowTestBase[PackagePublishWorkflow]):
 
         root = self.orchestrate(
             task_data=PackagePublishWorkflowData(
-                binary_artifacts=LookupMultiple.parse_obj(
+                binary_artifacts=LookupMultiple.model_validate(
                     binary_artifacts_lookup
                 ),
                 target_suite=(
@@ -734,7 +732,7 @@ class PackagePublishWorkflowTests(WorkflowTestBase[PackagePublishWorkflow]):
 
         root = self.orchestrate(
             task_data=PackagePublishWorkflowData(
-                binary_artifacts=LookupMultiple.parse_obj(
+                binary_artifacts=LookupMultiple.model_validate(
                     binary_artifacts_lookup
                 ),
                 target_suite=(
@@ -804,21 +802,94 @@ class PackagePublishWorkflowTests(WorkflowTestBase[PackagePublishWorkflow]):
         upload_artifact = (
             self.playground.create_upload_artifacts(src_name="hello")
         ).upload
+        target_suite = self.create_suite_collection("bookworm")
 
-        wr = self.playground.create_workflow(
-            task_name="package_publish",
+        workflow = self.create_package_publish_workflow(
             task_data=PackagePublishWorkflowData(
-                binary_artifacts=LookupMultiple.parse_obj([upload_artifact.id]),
-                target_suite=f"bookworm@{CollectionCategory.SUITE}",
-            ),
+                binary_artifacts=LookupMultiple((upload_artifact.id,)),
+                target_suite=(
+                    f"{target_suite.name}@{CollectionCategory.SUITE}"
+                ),
+                source_artifact=self.source_artifact.id,
+            )
         )
-        workflow = self.get_workflow(wr)
 
         self.assertEqual(
-            workflow.compute_dynamic_data(TaskDatabase(wr)),
-            BaseDynamicTaskData(
+            workflow.compute_dynamic_data(TaskDatabase(workflow.work_request)),
+            PackagePublishWorkflowDynamicData(
                 subject="hello",
                 parameter_summary="hello → "
                 f"bookworm@{CollectionCategory.SUITE}",
+                source_artifact_id=self.source_artifact.id,
+                target_suite_id=target_suite.id,
+                binary_artifacts_ids=[upload_artifact.id],
             ),
         )
+
+    def test_get_input_artifacts(self) -> None:
+        upload_artifact = (
+            self.playground.create_upload_artifacts(src_name="hello")
+        ).upload
+        target_suite = self.create_suite_collection("bookworm")
+
+        workflow = self.create_package_publish_workflow(
+            PackagePublishWorkflowData(
+                binary_artifacts=LookupMultiple((upload_artifact.id,)),
+                target_suite=(
+                    f"{target_suite.name}@{CollectionCategory.SUITE}"
+                ),
+                source_artifact=self.source_artifact.id,
+            ),
+        )
+
+        workflow.dynamic_data = workflow.build_dynamic_data(
+            TaskDatabase(workflow.work_request)
+        )
+
+        assert workflow.data.source_artifact is not None
+
+        self.assertEqual(
+            workflow.get_input_artifacts(),
+            [
+                InputArtifactSingle(
+                    lookup=workflow.data.source_artifact,
+                    label="source_artifact",
+                    artifact_id=self.source_artifact.id,
+                ),
+                InputArtifactMultiple(
+                    lookup=workflow.data.binary_artifacts,
+                    label="binary_artifacts",
+                    artifact_ids=[upload_artifact.id],
+                ),
+            ],
+        )
+
+    def test_get_input_artifacts_without_source_artifact(self) -> None:
+        upload_artifact = (
+            self.playground.create_upload_artifacts(src_name="hello")
+        ).upload
+        target_suite = self.create_suite_collection("bookworm")
+
+        workflow = self.create_package_publish_workflow(
+            task_data=PackagePublishWorkflowData(
+                binary_artifacts=LookupMultiple((upload_artifact.id,)),
+                target_suite=(
+                    f"{target_suite.name}@{CollectionCategory.SUITE}"
+                ),
+            ),
+        )
+
+        workflow.dynamic_data = workflow.build_dynamic_data(
+            TaskDatabase(workflow.work_request)
+        )
+
+        self.assertEqual(
+            workflow.get_input_artifacts(),
+            [
+                InputArtifactMultiple(
+                    lookup=workflow.data.binary_artifacts,
+                    label="binary_artifacts",
+                    artifact_ids=[upload_artifact.id],
+                ),
+            ],
+        )
