@@ -39,6 +39,7 @@ from debusine.server.workflows.base import orchestrate_workflow
 from debusine.server.workflows.models import (
     BaseWorkflowData,
     PiupartsWorkflowData,
+    PiupartsWorkflowDynamicData,
     SbuildWorkflowData,
     WorkRequestWorkflowData,
 )
@@ -55,6 +56,8 @@ from debusine.tasks.models import (
     ActionUpdateCollectionWithArtifacts,
     BackendType,
     BaseDynamicTaskData,
+    InputArtifactMultiple,
+    InputArtifactSingle,
     LookupMultiple,
     OutputData,
     RegressionAnalysisStatus,
@@ -290,7 +293,7 @@ class PiupartsWorkflowTests(
             task_data=PiupartsWorkflowData(
                 prefix="reference-qa-result|",
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="sid",
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
@@ -331,7 +334,7 @@ class PiupartsWorkflowTests(
             task_data=PiupartsWorkflowData(
                 prefix="reference-qa-result|",
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="sid",
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
@@ -372,7 +375,7 @@ class PiupartsWorkflowTests(
             task_data=PiupartsWorkflowData(
                 prefix="reference-qa-result|",
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="sid",
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
@@ -587,6 +590,47 @@ class PiupartsWorkflowTests(
         repo = child.task_data["extra_repositories"][0]
         self.assertEqual(repo["suite"], "experimental")
 
+    def test_populate_uploads(self) -> None:
+        """The workflow accepts debian:upload artifacts in all inputs."""
+        artifacts = self.playground.create_upload_artifacts(
+            binaries=[
+                ("hello", "amd64"),
+                ("hello", "i386"),
+                ("hello-doc", "all"),
+            ]
+        )
+        architectures = ["amd64", "i386"]
+
+        wr = self.playground.create_workflow(
+            task_name="piuparts",
+            task_data=PiupartsWorkflowData(
+                source_artifact=artifacts.upload.id,
+                binary_artifacts=LookupMultiple((artifacts.upload.id,)),
+                architectures=architectures,
+                vendor="debian",
+                codename="sid",
+            ),
+        )
+        self.get_workflow(wr).populate()
+        children = list(wr.children.order_by("id").all())
+        self.assertEqual(len(children), len(architectures))
+        for architecture, child in zip(architectures, children):
+            with self.subTest(architecture=architecture):
+                self.assertEqual(
+                    child.task_data["build_architecture"], architecture
+                )
+                self.assertEqual(
+                    child.task_data["input"],
+                    {
+                        "binary_artifacts": sorted(
+                            f"{artifact.id}@artifacts"
+                            for artifact in artifacts.binaries
+                            if artifact.data["deb_fields"]["Architecture"]
+                            in (architecture, "all")
+                        ),
+                    },
+                )
+
     def test_populate_has_current_reference_qa_result(self) -> None:
         """The workflow does nothing with a current reference QA result."""
         self.playground.create_collection("sid", CollectionCategory.SUITE)
@@ -617,7 +661,7 @@ class PiupartsWorkflowTests(
             task_data=PiupartsWorkflowData(
                 prefix="reference-qa-result|",
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="sid",
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
@@ -657,7 +701,7 @@ class PiupartsWorkflowTests(
             task_data=PiupartsWorkflowData(
                 prefix="reference-qa-result|",
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="sid",
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
@@ -769,7 +813,7 @@ class PiupartsWorkflowTests(
             task_data=PiupartsWorkflowData(
                 prefix="reference-qa-result|",
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="sid",
                 qa_suite=f"sid@{CollectionCategory.SUITE}",
@@ -852,7 +896,7 @@ class PiupartsWorkflowTests(
                 reference_qa_results=f"sid@{CollectionCategory.QA_RESULTS}",
                 update_qa_results=True,
                 source_artifact=reference_source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
+                binary_artifacts=LookupMultiple.model_validate(
                     [
                         artifact.id
                         for artifact in reference_binary_artifacts.values()
@@ -873,7 +917,7 @@ class PiupartsWorkflowTests(
                 reference_qa_results=f"sid@{CollectionCategory.QA_RESULTS}",
                 enable_regression_tracking=True,
                 source_artifact=new_source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
+                binary_artifacts=LookupMultiple.model_validate(
                     [
                         f"internal@collections/name:build-{arch}"
                         for arch in architectures
@@ -1073,7 +1117,7 @@ class PiupartsWorkflowTests(
             task_name="piuparts",
             task_data=PiupartsWorkflowData(
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="trixie",
             ),
@@ -1082,8 +1126,11 @@ class PiupartsWorkflowTests(
 
         self.assertEqual(
             workflow.compute_dynamic_data(TaskDatabase(wr)),
-            BaseDynamicTaskData(
-                subject="hello", parameter_summary="hello in debian:trixie"
+            PiupartsWorkflowDynamicData(
+                subject="hello",
+                parameter_summary="hello in debian:trixie",
+                source_artifact_id=source_artifact.id,
+                binary_artifacts_ids=[binary_artifact.id],
             ),
         )
 
@@ -1098,7 +1145,7 @@ class PiupartsWorkflowTests(
             task_name="piuparts",
             task_data=PiupartsWorkflowData(
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="trixie",
             ),
@@ -1107,8 +1154,11 @@ class PiupartsWorkflowTests(
 
         self.assertEqual(
             workflow.compute_dynamic_data(TaskDatabase(wr)),
-            BaseDynamicTaskData(
-                subject="hello", parameter_summary="hello in debian:trixie"
+            PiupartsWorkflowDynamicData(
+                subject="hello",
+                parameter_summary="hello in debian:trixie",
+                source_artifact_id=source_artifact.id,
+                binary_artifacts_ids=[binary_artifact.id],
             ),
         )
 
@@ -1129,8 +1179,8 @@ class PiupartsWorkflowTests(
             task_name="piuparts",
             task_data=PiupartsWorkflowData(
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
-                    [binary_artifact_1.id, binary_artifact_2.id]
+                binary_artifacts=LookupMultiple(
+                    (binary_artifact_1.id, binary_artifact_2.id)
                 ),
                 vendor="debian",
                 codename="trixie",
@@ -1140,9 +1190,14 @@ class PiupartsWorkflowTests(
 
         self.assertEqual(
             workflow.compute_dynamic_data(TaskDatabase(wr)),
-            BaseDynamicTaskData(
+            PiupartsWorkflowDynamicData(
                 subject="hello linux-base",
                 parameter_summary="hello linux-base in debian:trixie",
+                source_artifact_id=source_artifact.id,
+                binary_artifacts_ids=[
+                    binary_artifact_1.id,
+                    binary_artifact_2.id,
+                ],
             ),
         )
 
@@ -1160,8 +1215,8 @@ class PiupartsWorkflowTests(
                 task_name="piuparts",
                 task_data=PiupartsWorkflowData(
                     source_artifact=source_artifact.id,
-                    binary_artifacts=LookupMultiple.parse_obj(
-                        [f"{binary_artifact.id}@collections"]
+                    binary_artifacts=LookupMultiple(
+                        (f"{binary_artifact.id}@collections",)
                     ),
                     vendor="debian",
                     codename="trixie",
@@ -1232,12 +1287,12 @@ class PiupartsWorkflowTests(
                         task_name="piuparts",
                         task_data=PiupartsWorkflowData(
                             source_artifact=source_artifact.id,
-                            binary_artifacts=LookupMultiple.parse_obj(
-                                [
+                            binary_artifacts=LookupMultiple(
+                                (
                                     "internal@collections/name:build-amd64",
                                     "internal@collections/name:build-arm64",
                                     "internal@collections/name:build-i386",
-                                ]
+                                )
                             ),
                             vendor="debian",
                             codename="sid",
@@ -1257,8 +1312,29 @@ class PiupartsWorkflowTests(
             )
             self.assertEqual(
                 computed_data,
-                BaseDynamicTaskData(
+                PiupartsWorkflowDynamicData(
                     subject="hello linux-base",
                     parameter_summary="hello linux-base in debian:sid",
+                    source_artifact_id=source_artifact.id,
+                    binary_artifacts_ids=[],
                 ),
             )
+
+    def test_get_input_artifacts(self) -> None:
+        workflow = self.create_piuparts_workflow()
+
+        self.assertEqual(
+            workflow.get_input_artifacts(),
+            [
+                InputArtifactSingle(
+                    lookup=workflow.data.source_artifact,
+                    label="source_artifact",
+                    artifact_id=None,
+                ),
+                InputArtifactMultiple(
+                    lookup=workflow.data.binary_artifacts,
+                    label="binary_artifacts",
+                    artifact_ids=None,
+                ),
+            ],
+        )
