@@ -8,16 +8,12 @@
 # contained in the LICENSE file.
 
 """Unit tests for the qa workflow."""
+
 from collections.abc import Sequence
 from typing import Any, ClassVar
 
 from django.utils import timezone
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
 from debusine.artifacts.models import (
     ArtifactCategory,
     CollectionCategory,
@@ -229,11 +225,11 @@ class QAWorkflowTests(WorkflowTestBase[QAWorkflow]):
             task_name="qa",
             task_data=QAWorkflowData(
                 source_artifact=self.source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
-                    ["internal@collections/name:build-amd64"]
+                binary_artifacts=LookupMultiple(
+                    ("internal@collections/name:build-amd64",)
                 ),
-                package_build_logs=LookupMultiple.parse_obj(
-                    ["internal@collections/name:buildlog-amd64"]
+                package_build_logs=LookupMultiple(
+                    ("internal@collections/name:buildlog-amd64",)
                 ),
                 vendor="debian",
                 codename="sid",
@@ -268,11 +264,11 @@ class QAWorkflowTests(WorkflowTestBase[QAWorkflow]):
             task_name="qa",
             task_data=QAWorkflowData(
                 source_artifact=new_source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj(
-                    ["internal@collections/name:build-amd64"]
+                binary_artifacts=LookupMultiple(
+                    ("internal@collections/name:build-amd64",)
                 ),
-                package_build_logs=LookupMultiple.parse_obj(
-                    ["internal@collections/name:buildlog-amd64"]
+                package_build_logs=LookupMultiple(
+                    ("internal@collections/name:buildlog-amd64",)
                 ),
                 reference_source_artifact=reference_source_artifact.id,
                 vendor="debian",
@@ -311,11 +307,11 @@ class QAWorkflowTests(WorkflowTestBase[QAWorkflow]):
                 task_name="qa",
                 task_data=QAWorkflowData(
                     source_artifact=artifact.id,
-                    binary_artifacts=LookupMultiple.parse_obj(
-                        ["internal@collections/name:build-amd64"]
+                    binary_artifacts=LookupMultiple(
+                        ("internal@collections/name:build-amd64",)
                     ),
-                    package_build_logs=LookupMultiple.parse_obj(
-                        ["internal@collections/name:buildlog-amd64"]
+                    package_build_logs=LookupMultiple(
+                        ("internal@collections/name:buildlog-amd64",)
                     ),
                     vendor="debian",
                     codename="sid",
@@ -328,9 +324,7 @@ class QAWorkflowTests(WorkflowTestBase[QAWorkflow]):
             task_name="qa",
             task_data=QAWorkflowData(
                 source_artifact=upload_artifacts.upload.id,
-                binary_artifacts=LookupMultiple.parse_obj(
-                    [self.binary_artifact.id]
-                ),
+                binary_artifacts=LookupMultiple((self.binary_artifact.id,)),
                 enable_blhc=False,
                 vendor="debian",
                 codename="sid",
@@ -384,12 +378,12 @@ class QAWorkflowTests(WorkflowTestBase[QAWorkflow]):
             task_name="qa",
             task_data=QAWorkflowData(
                 source_artifact=upload_artifacts.upload.id,
-                binary_artifacts=LookupMultiple.parse_obj(
-                    ["internal@collections/name:build-amd64"]
+                binary_artifacts=LookupMultiple(
+                    ("internal@collections/name:build-amd64",)
                 ),
                 reference_source_artifact=reference_source_artifact.id,
-                package_build_logs=LookupMultiple.parse_obj(
-                    ["internal@collections/name:buildlog-amd64"]
+                package_build_logs=LookupMultiple(
+                    ("internal@collections/name:buildlog-amd64",)
                 ),
                 enable_blhc=False,
                 vendor="debian",
@@ -445,8 +439,8 @@ class QAWorkflowTests(WorkflowTestBase[QAWorkflow]):
             task_name="qa",
             task_data=QAWorkflowData(
                 source_artifact=upload_artifacts.upload.id,
-                binary_artifacts=LookupMultiple.parse_obj(
-                    ["internal@collections/name:build-amd64"]
+                binary_artifacts=LookupMultiple(
+                    ("internal@collections/name:build-amd64",)
                 ),
                 enable_blhc=False,
                 vendor="debian",
@@ -755,12 +749,8 @@ class QAWorkflowTests(WorkflowTestBase[QAWorkflow]):
             task_name="qa",
             task_data=QAWorkflowData(
                 source_artifact=f"{artifacts.upload.id}@artifacts",
-                binary_artifacts=LookupMultiple.parse_obj(
-                    [artifacts.upload.id]
-                ),
-                package_build_logs=LookupMultiple.parse_obj(
-                    [self.package_build_log.id]
-                ),
+                binary_artifacts=LookupMultiple((artifacts.upload.id,)),
+                package_build_logs=LookupMultiple((self.package_build_log.id,)),
                 architectures=architectures,
                 vendor="debian",
                 codename="sid",
@@ -1712,8 +1702,8 @@ class QAWorkflowTests(WorkflowTestBase[QAWorkflow]):
             architectures=["amd64"],
             extra_data={
                 "source_artifact": source_artifact.id,
-                "binary_artifacts": LookupMultiple.parse_obj(
-                    ["internal@collections/name:build-amd64"]
+                "binary_artifacts": LookupMultiple(
+                    ("internal@collections/name:build-amd64",)
                 ),
                 "architectures": ["amd64"],
                 "enable_autopkgtest": False,
@@ -1949,11 +1939,7 @@ class QAWorkflowTests(WorkflowTestBase[QAWorkflow]):
                 },
                 cmdline="unused",
                 source_package=DebianAutopkgtestSource(
-                    name="hello",
-                    version="1.0-1",
-                    url=pydantic.parse_obj_as(
-                        pydantic.AnyUrl, reference_source_url
-                    ),
+                    name="hello", version="1.0-1", url=reference_source_url
                 ),
                 architecture="amd64",
                 distribution="sid",
@@ -2034,9 +2020,7 @@ class QAWorkflowTests(WorkflowTestBase[QAWorkflow]):
                 },
                 cmdline="unused",
                 source_package=DebianAutopkgtestSource(
-                    name="hello",
-                    version="1.0-2",
-                    url=pydantic.parse_obj_as(pydantic.AnyUrl, new_source_url),
+                    name="hello", version="1.0-2", url=new_source_url
                 ),
                 architecture="amd64",
                 distribution="sid",
@@ -2119,9 +2103,7 @@ class QAWorkflowTests(WorkflowTestBase[QAWorkflow]):
                 },
                 cmdline="unused",
                 source_package=DebianAutopkgtestSource(
-                    name="hello",
-                    version="1.0-2",
-                    url=pydantic.parse_obj_as(pydantic.AnyUrl, new_source_url),
+                    name="hello", version="1.0-2", url=new_source_url
                 ),
                 architecture="amd64",
                 distribution="sid",
