@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Unit tests for the SbuildWorkflow class."""
+
 from typing import Any
 
 from debusine.artifacts.models import (
@@ -32,7 +33,10 @@ from debusine.server.workflows import (
     workflow_utils,
 )
 from debusine.server.workflows.base import orchestrate_workflow
-from debusine.server.workflows.models import SbuildWorkflowData
+from debusine.server.workflows.models import (
+    SbuildWorkflowData,
+    SbuildWorkflowDynamicData,
+)
 from debusine.server.workflows.tests.helpers import WorkflowTestBase
 from debusine.tasks import TaskConfigError
 from debusine.tasks.models import (
@@ -40,7 +44,7 @@ from debusine.tasks.models import (
     ActionUpdateCollectionWithArtifacts,
     ActionUpdateCollectionWithData,
     BackendType,
-    BaseDynamicTaskData,
+    InputArtifactSingle,
     SbuildInput,
 )
 from debusine.test.test_utils import create_system_tarball_data
@@ -153,11 +157,54 @@ class SbuildWorkflowTests(
 
         self.assertEqual(
             workflow.compute_dynamic_data(TaskDatabase(wr)),
-            BaseDynamicTaskData(
-                subject="hello", parameter_summary="hello_1.0-1"
+            SbuildWorkflowDynamicData(
+                subject="hello",
+                parameter_summary="hello_1.0-1",
+                source_artifact_id=source_artifact.id,
             ),
         )
 
+    def test_get_input_artifacts(self) -> None:
+        source_artifact = self.create_source_package(
+            "hello", "1.0", dsc_fields={"Architecture": "all"}
+        )
+        self.playground.create_debian_environment(codename="bookworm")
+        wr = self.playground.create_workflow(
+            task_name="sbuild",
+            task_data=SbuildWorkflowData(
+                input=SbuildInput(source_artifact=source_artifact.id),
+                target_distribution="debian:bookworm",
+                architectures=["all"],
+            ),
+        )
+        wf = self.get_workflow(wr)
+
+        self.assertIsNone(wf.dynamic_data)
+        self.assertEqual(
+            wf.get_input_artifacts(),
+            [
+                InputArtifactSingle(
+                    lookup=wf.data.input.source_artifact,
+                    label="input.source_artifact",
+                    artifact_id=None,
+                )
+            ],
+        )
+
+        wf.dynamic_data = wf.build_dynamic_data(TaskDatabase(wr))
+
+        self.assertIsNotNone(wf.dynamic_data)
+        self.assertEqual(
+            wf.get_input_artifacts(),
+            [
+                InputArtifactSingle(
+                    lookup=wf.data.input.source_artifact,
+                    label="input.source_artifact",
+                    artifact_id=source_artifact.id,
+                )
+            ],
+        )
+
     def test_validate_input(self) -> None:
         """Test that validate_input passes a valid case."""
         tarball_item = self.playground.create_debian_environment(
@@ -182,13 +229,18 @@ class SbuildWorkflowTests(
         self.assertEqual(wr.status, WorkRequest.Statuses.PENDING)
 
         o = self.get_workflow(wr)
-        self.assertEqual(workflow_utils.source_package(o), source)
+        self.assertEqual(
+            workflow_utils.source_package(
+                o, configuration_key="input.source_artifact"
+            ),
+            source,
+        )
         self.assertEqual(o.architectures, {"all"})
         self.assertEqual(o._get_environment("amd64"), tarball_item.artifact)
         o.validate_input()
 
         # environment_variant
-        tarball, _ = self.playground.create_artifact(
+        self.playground.create_artifact(
             category=ArtifactCategory.SYSTEM_TARBALL,
             data=create_system_tarball_data(
                 codename="bookworm", variant="buildd"
