@@ -9,13 +9,10 @@
 
 """Unit tests for the ``update_suite`` workflow."""
 
+import pydantic_core
 from django.db import connection
 
-from debusine.artifacts.models import (
-    ArtifactCategory,
-    CollectionCategory,
-    TaskTypes,
-)
+from debusine.artifacts.models import CollectionCategory, TaskTypes
 from debusine.db.models import (
     Collection,
     CollectionItem,
@@ -37,10 +34,9 @@ class UpdateSuiteWorkflowTests(TestCase):
     ) -> CollectionItem:
         """Create a minimal debian:repository-index item in the suite."""
         return CollectionItem.objects.create_from_artifact(
-            self.playground.create_artifact(
-                category=ArtifactCategory.REPOSITORY_INDEX,
-                work_request=work_request,
-            )[0],
+            self.playground.create_repository_index(
+                "Release", work_request=work_request
+            ),
             parent_collection=suite,
             name="index:Release",
             data={"path": "Release"},
@@ -92,7 +88,7 @@ class UpdateSuiteWorkflowTests(TestCase):
                     "generatesuiteindexes",
                     {
                         "suite_collection": f"sid@{CollectionCategory.SUITE}",
-                        "generate_at": now.isoformat(),
+                        "generate_at": pydantic_core.to_jsonable_python(now),
                     },
                     {
                         "display_name": "Generate indexes for sid",
@@ -187,9 +183,8 @@ class UpdateSuiteWorkflowTests(TestCase):
         )
         self.assertEqual(sign_clear.status, WorkRequest.Statuses.BLOCKED)
 
-        release_gpg, _ = self.playground.create_artifact(
-            category=ArtifactCategory.REPOSITORY_INDEX,
-            work_request=sign_detached,
+        release_gpg = self.playground.create_repository_index(
+            "Release.gpg", work_request=sign_detached
         )
         self.playground.advance_work_request(
             sign_detached, result=WorkRequest.Results.SUCCESS
@@ -206,8 +201,8 @@ class UpdateSuiteWorkflowTests(TestCase):
         sign_clear.refresh_from_db()
         self.assertEqual(sign_clear.status, WorkRequest.Statuses.PENDING)
 
-        inrelease, _ = self.playground.create_artifact(
-            category=ArtifactCategory.REPOSITORY_INDEX, work_request=sign_clear
+        inrelease = self.playground.create_repository_index(
+            "InRelease", work_request=sign_clear
         )
         self.playground.advance_work_request(
             sign_clear, result=WorkRequest.Results.SUCCESS
