@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Utility functions for workflows."""
+
 import functools
 from collections.abc import Collection as AbcCollection
 from collections.abc import Sequence
@@ -205,7 +206,7 @@ def filter_artifact_lookup_by_arch(
                 if pkg_architectures.issubset(architectures):
                     relevant.append(f"{binary_package.id}@artifacts")
 
-    return LookupMultiple.parse_obj(sorted(relevant))
+    return LookupMultiple.model_validate(sorted(relevant))
 
 
 def get_lookup_architectures(
@@ -444,7 +445,7 @@ def get_available_architectures(
     architectures = set()
 
     for result in lookup_multiple(
-        LookupMultiple.parse_obj(
+        LookupMultiple.model_validate(
             {"collection": vendor, "data__codename": codename}
         ),
         workflow.workspace,
