@@ -119,7 +119,7 @@ class KeyManager(models.Manager["Key"]):
             private_key=ProtectedKeyNaCl.encrypt(
                 settings.DEBUSINE_SIGNING_PRIVATE_KEYS[0].public_key,
                 private_key,
-            ).dict(),
+            ).model_dump(),
             public_key=public_key,
         )
         AuditLog.objects.create(
@@ -135,8 +135,6 @@ class KeyManager(models.Manager["Key"]):
 class Key(models.Model):
     """A key managed by the debusine signing service."""
 
-    objects = KeyManager()
-
     Purpose: TypeAlias = KeyPurpose
 
     purpose = models.CharField(max_length=32, choices=Purpose.choices)
@@ -146,6 +144,8 @@ class Key(models.Model):
     created_at = models.DateTimeField(auto_now_add=True)
     updated_at = models.DateTimeField(blank=True, null=True)
 
+    objects = KeyManager()
+
     class Meta(TypedModelMeta):
         app_label = "signing"
         constraints = [
@@ -158,7 +158,7 @@ class Key(models.Model):
     @property
     def stored_private_key(self) -> ProtectedKey:
         """Access private_key as a pydantic model."""
-        return ProtectedKey.parse_obj(self.private_key)
+        return ProtectedKey.model_validate(self.private_key)
 
 
 def sign(
