@@ -18,14 +18,11 @@ from pathlib import Path
 from tempfile import TemporaryDirectory
 from typing import Annotated, Literal, Self, TYPE_CHECKING
 
+import pydantic
 from django.conf import settings
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
 from debusine.signing.signing_utils import SensitiveTemporaryDirectory
+from debusine.utils import Base64BytesAsStr
 
 if TYPE_CHECKING:
     from nacl.public import PrivateKey, PublicKey
@@ -129,36 +126,18 @@ class ProtectedKeyNaCl(BaseProtectedKey):
     """Data for a private key encrypted in software using NaCl."""
 
     storage: Literal[ProtectedKeyStorage.NACL]
-    public_key: str
-    encrypted: str
+    public_key: Base64BytesAsStr
+    encrypted: Base64BytesAsStr
 
     @classmethod
-    def create(cls, *, public_key: str | bytes, encrypted: str | bytes) -> Self:
+    def create(cls, *, public_key: bytes, encrypted: bytes) -> Self:
         """Create a new :py:class:`ProtectedKeyNaCl`."""
         return cls(
             storage=ProtectedKeyStorage.NACL,
-            public_key=(
-                public_key
-                if isinstance(public_key, str)
-                else base64.b64encode(public_key).decode()
-            ),
-            encrypted=(
-                encrypted
-                if isinstance(encrypted, str)
-                else base64.b64encode(encrypted).decode()
-            ),
+            public_key=base64.b64encode(public_key).decode(),
+            encrypted=base64.b64encode(encrypted).decode(),
         )
 
-    @property
-    def public_key_bytes(self) -> bytes:
-        """Return the base64-decoded public key."""
-        return base64.b64decode(self.public_key.encode())
-
-    @property
-    def encrypted_bytes(self) -> bytes:
-        """Return the base64-decoded encrypted data."""
-        return base64.b64decode(self.encrypted.encode())
-
     @classmethod
     def encrypt(cls, public_key: "PublicKey", data: bytes) -> Self:
         """Encrypt data using a NaCl public key."""
@@ -183,11 +162,10 @@ class ProtectedKeyNaCl(BaseProtectedKey):
         from nacl.exceptions import CryptoError
         from nacl.public import SealedBox
 
-        public_key_bytes = self.public_key_bytes
         for private_key in private_keys:
-            if bytes(private_key.public_key) == public_key_bytes:
+            if bytes(private_key.public_key) == self.public_key:
                 try:
-                    return SealedBox(private_key).decrypt(self.encrypted_bytes)
+                    return SealedBox(private_key).decrypt(self.encrypted)
                 except CryptoError as e:
                     raise ProtectedKeyError(str(e)) from e
         raise ProtectedKeyError(
@@ -224,7 +202,7 @@ class ProtectedKeyPKCS11Static(BaseProtectedKey):
             storage=ProtectedKeyStorage.PKCS11_STATIC, pkcs11_uri=pkcs11_uri
         )
 
-    @pydantic.validator("pkcs11_uri")
+    @pydantic.field_validator("pkcs11_uri", mode="after")
     @classmethod
     def _pkcs11_uri_is_pkcs11(cls, value: str) -> str:
         """Ensure that the PKCS#11 URI uses the "pkcs11" scheme."""
@@ -245,13 +223,15 @@ class ProtectedKeyPKCS11Static(BaseProtectedKey):
             )
 
 
-class ProtectedKey(pydantic.BaseModel):
-    """A protected private key."""
-
-    __root__: Annotated[
-        ProtectedKeyNaCl | ProtectedKeyPKCS11Static,
-        pydantic.Field(discriminator="storage"),
+class ProtectedKey(
+    pydantic.RootModel[
+        Annotated[
+            ProtectedKeyNaCl | ProtectedKeyPKCS11Static,
+            pydantic.Field(discriminator="storage"),
+        ]
     ]
+):
+    """A protected private key."""
 
     @contextmanager
     def available(self, public_key: bytes) -> Generator[BaseAvailableKey]:
@@ -262,7 +242,7 @@ class ProtectedKey(pydantic.BaseModel):
         protection used, but they should at least ensure that private keys
         do not end up on a persistent file system.
         """
-        with self.__root__.available(public_key) as available:
+        with self.root.available(public_key) as available:
             yield available
 
 
