@@ -13,4 +13,4 @@ except (ModuleNotFoundError, PermissionError):
     )
 
 # Use paths from the package
-from debusine.signing.settings.pkg_paths import *  # noqa: F401, F403, I202
+from debusine.signing.settings.pkg_paths import *  # noqa: F401, F403
