@@ -10,7 +10,7 @@
 """Base support for tasks that run on signing workers."""
 
 from abc import ABCMeta
-from typing import TypeVar
+from typing import override
 
 from django.db import close_old_connections, transaction
 
@@ -18,15 +18,15 @@ from debusine.artifacts.models import TaskTypes
 from debusine.tasks import BaseExternalTask
 from debusine.tasks.models import BaseDynamicTaskData, BaseTaskData
 
-TD = TypeVar("TD", bound=BaseTaskData)
-DTD = TypeVar("DTD", bound=BaseDynamicTaskData)
 
-
-class BaseSigningTask(BaseExternalTask[TD, DTD], metaclass=ABCMeta):
+class BaseSigningTask[TD: BaseTaskData, DTD: BaseDynamicTaskData](
+    BaseExternalTask[TD, DTD], metaclass=ABCMeta
+):
     """Base class for tasks that run on signing workers."""
 
     TASK_TYPE = TaskTypes.SIGNING
 
+    @override
     def execute(self) -> bool:
         """
         Execute task in a transaction.
