@@ -19,7 +19,7 @@ files.
 import os
 import shutil
 from pathlib import Path
-from typing import Any
+from typing import Any, override
 
 from debusine import utils
 from debusine.artifacts import Upload
@@ -42,6 +42,7 @@ class Debsign(BaseSigningTask[DebsignData, DebsignDynamicData]):
 
     TASK_VERSION = 1
 
+    @override
     def __init__(
         self,
         task_data: dict[str, Any],
@@ -55,6 +56,7 @@ class Debsign(BaseSigningTask[DebsignData, DebsignDynamicData]):
         self._signed_changes_path: Path | None = None
         self._permission_check: AssetPermissionCheckResponse | None = None
 
+    @override
     @classmethod
     def analyze_worker(cls) -> dict[str, Any]:
         """Report metadata for this task on this worker."""
@@ -66,6 +68,7 @@ class Debsign(BaseSigningTask[DebsignData, DebsignDynamicData]):
 
         return metadata
 
+    @override
     def can_run_on(self, worker_metadata: dict[str, Any]) -> bool:
         """Check if the specified worker can run the task."""
         if not super().can_run_on(worker_metadata):
@@ -77,6 +80,7 @@ class Debsign(BaseSigningTask[DebsignData, DebsignDynamicData]):
 
         return True
 
+    @override
     def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> DebsignDynamicData:
@@ -87,6 +91,7 @@ class Debsign(BaseSigningTask[DebsignData, DebsignDynamicData]):
             ).id,
         )
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """Return the list of input artifact IDs used by this task."""
         if not self.dynamic_data:
@@ -95,6 +100,7 @@ class Debsign(BaseSigningTask[DebsignData, DebsignDynamicData]):
             self.dynamic_data.unsigned_id,
         ]
 
+    @override
     def fetch_input(self, destination: Path) -> bool:
         """Fetch artifacts and database objects needed by the task."""
         assert self.debusine is not None
@@ -138,7 +144,7 @@ class Debsign(BaseSigningTask[DebsignData, DebsignDynamicData]):
 
         try:
             self._key = Key.objects.get(
-                purpose=KeyPurpose.OPENPGP, fingerprint=self.data.key
+                purpose=KeyPurpose.OPENPGP_UPLOAD, fingerprint=self.data.key
             )
         except Key.DoesNotExist:
             self.append_to_log_file(
@@ -149,13 +155,16 @@ class Debsign(BaseSigningTask[DebsignData, DebsignDynamicData]):
 
         return True
 
+    @override
     def configure_for_execution(
-        self, download_directory: Path  # noqa: U100
+        self,
+        download_directory: Path,  # noqa: U100
     ) -> bool:
         """Configure task variables."""
         # Nothing to do here; fetch_input does it all.
         return True
 
+    @override
     def prepare_to_run(
         self, download_directory: Path, execute_directory: Path
     ) -> None:
@@ -168,6 +177,7 @@ class Debsign(BaseSigningTask[DebsignData, DebsignDynamicData]):
             copy_function=os.link,
         )
 
+    @override
     def run(self, execute_directory: Path) -> bool:
         """Sign all the requested files."""
         assert self.work_request_id is not None
@@ -204,8 +214,9 @@ class Debsign(BaseSigningTask[DebsignData, DebsignDynamicData]):
 
         return True
 
+    @override
     def upload_artifacts(
-        self, execute_directory: Path, *, execution_success: bool  # noqa: U100
+        self, execute_directory: Path, *, execution_success: bool
     ) -> None:
         """Upload artifacts for the task."""
         assert self.dynamic_data is not None
@@ -228,6 +239,7 @@ class Debsign(BaseSigningTask[DebsignData, DebsignDynamicData]):
             RelationType.RELATES_TO,
         )
 
+    @override
     def get_label(self) -> str:
         """Return the task label."""
         return "sign upload"
