@@ -9,10 +9,9 @@
 
 """Models used by debusine signing tasks."""
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
+from typing import Annotated
+
+import pydantic
 
 from debusine.assets import KeyPurpose
 from debusine.signing.models import SigningMode
@@ -44,7 +43,7 @@ class SignData(BaseTaskData):
     unsigned: LookupMultiple
     key: str
 
-    @pydantic.validator("purpose")
+    @pydantic.field_validator("purpose", mode="after")
     @classmethod
     def validate_purpose(cls, purpose: KeyPurpose) -> KeyPurpose:
         """Don't allow OpenPGP repository signing keys."""
@@ -82,9 +81,9 @@ class SignRepositoryIndexData(BaseTaskData):
     suite_collection: LookupSingle
     unsigned: LookupSingle
     mode: SigningMode
-    signed_name: str
+    signed_name: Annotated[str, pydantic.Field(pattern=r"^[^/]+$")]
 
-    @pydantic.validator("mode")
+    @pydantic.field_validator("mode", mode="after")
     @classmethod
     def validate_mode(cls, mode: SigningMode) -> SigningMode:
         """Only allow detached or clear signatures."""
@@ -94,19 +93,6 @@ class SignRepositoryIndexData(BaseTaskData):
             )
         return mode
 
-    # With pydantic >= 2.0.2, use `signed_name: str =
-    # pydantic.Field(pattern=...)` instead.
-    @pydantic.validator("signed_name")
-    @classmethod
-    def validate_signed_name(cls, signed_name: str) -> str:
-        """Require the signed name to be a single path segment."""
-        if "/" in signed_name:
-            raise ValueError(
-                f"Signed name must be a single path segment; got "
-                f"{signed_name!r}"
-            )
-        return signed_name
-
 
 class SignRepositoryIndexDynamicData(BaseDynamicTaskData):
     """Dynamic data for the SignRepositoryIndex task."""
