@@ -11,7 +11,7 @@
 
 import shutil
 from pathlib import Path
-from typing import Any
+from typing import Any, override
 
 from debusine.artifacts import RepositoryIndex
 from debusine.artifacts.models import ArtifactCategory, CollectionCategory
@@ -34,6 +34,7 @@ class SignRepositoryIndex(
 
     TASK_VERSION = 1
 
+    @override
     def __init__(
         self,
         task_data: dict[str, Any],
@@ -47,6 +48,7 @@ class SignRepositoryIndex(
         self._permission_check: AssetPermissionCheckResponse | None = None
         self._signed_path: Path | None = None
 
+    @override
     def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> SignRepositoryIndexDynamicData:
@@ -83,12 +85,14 @@ class SignRepositoryIndex(
             signing_keys=signing_keys or [], unsigned_id=unsigned.id
         )
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """Return the list of input artifact IDs used by this task."""
         if not self.dynamic_data:
             return []
         return [self.dynamic_data.unsigned_id]
 
+    @override
     def fetch_input(self, destination: Path) -> bool:
         """Fetch artifacts and database objects needed by the task."""
         assert self.debusine is not None
@@ -164,19 +168,23 @@ class SignRepositoryIndex(
 
         return True
 
+    @override
     def configure_for_execution(
-        self, download_directory: Path  # noqa: U100
+        self,
+        download_directory: Path,  # noqa: U100
     ) -> bool:
         """Configure task variables."""
         # Nothing to do here; fetch_input does it all.
         return True
 
+    @override
     def prepare_to_run(
         self, download_directory: Path, execute_directory: Path
     ) -> None:
         """Copy downloaded files into the execution directory."""
         shutil.copytree(download_directory, execute_directory / "input")
 
+    @override
     def run(self, execute_directory: Path) -> bool:
         """Sign the requested file."""
         assert self.work_request_id is not None
@@ -207,8 +215,9 @@ class SignRepositoryIndex(
 
         return True
 
+    @override
     def upload_artifacts(
-        self, execute_directory: Path, *, execution_success: bool  # noqa: U100
+        self, execute_directory: Path, *, execution_success: bool
     ) -> None:
         """Upload artifacts for the task."""
         assert self.dynamic_data is not None
@@ -248,6 +257,7 @@ class SignRepositoryIndex(
             RelationType.RELATES_TO,
         )
 
+    @override
     def get_label(self) -> str:
         """Return the task label."""
         return f"sign {self.data.signed_name} for {self.data.suite_collection}"
