@@ -8,16 +8,14 @@
 # contained in the LICENSE file.
 
 """Task to use autopkgtest in debusine."""
+
 import logging
 import re
 import shlex
 from pathlib import Path
-from typing import Any, cast
+from typing import Any, cast, override
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
+import pydantic
 
 from debusine import utils
 from debusine.artifacts.local_artifact import AutopkgtestArtifact
@@ -64,6 +62,7 @@ class Autopkgtest(
     ARTIFACT_DIR = "artifact-dir"
     SUMMARY_FILE = "artifact-dir/summary"
 
+    @override
     def __init__(
         self,
         task_data: dict[str, Any],
@@ -74,12 +73,13 @@ class Autopkgtest(
 
         self._source_package_name: str | None = None
         self._source_package_version: str | None = None
-        self._source_package_url: str | None = None
+        self._source_package_url: pydantic.AnyUrl | None = None
         self._source_package_path: str | None = None
 
         self._parsed: ParsedSummaryFile | None = None
         self._autopkgtest_targets: list[Path] = []
 
+    @override
     @classmethod
     def analyze_worker(cls) -> dict[str, Any]:
         """Report metadata for this task on this worker."""
@@ -90,6 +90,7 @@ class Autopkgtest(
 
         return metadata
 
+    @override
     def can_run_on(self, worker_metadata: dict[str, Any]) -> bool:
         """Check if the specified worker can run the task."""
         if not super().can_run_on(worker_metadata):
@@ -102,6 +103,7 @@ class Autopkgtest(
             and worker_metadata.get(available_key, False)
         )
 
+    @override
     def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> AutopkgtestDynamicData:
@@ -187,6 +189,7 @@ class Autopkgtest(
             configuration_context=environment.data.codename,
         )
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """Return the list of input artifact IDs used by this task."""
         if not self.dynamic_data:
@@ -198,8 +201,9 @@ class Autopkgtest(
             *self.dynamic_data.input_context_artifacts_ids,
         ]
 
+    @override
     def check_directory_for_consistency_errors(
-        self, build_directory: Path  # noqa: U100
+        self, build_directory: Path
     ) -> list[str]:
         """Autopkgtest ARTIFACT_DIR/summary file does not exist."""
         summary_path = build_directory / self.SUMMARY_FILE
@@ -275,6 +279,7 @@ class Autopkgtest(
             )
         return cast(str, self.executor.system_image.data["codename"])
 
+    @override
     def fetch_input(self, destination: Path) -> bool:
         """Download the required artifacts."""
         assert self.dynamic_data
@@ -303,6 +308,7 @@ class Autopkgtest(
 
         return True
 
+    @override
     def _cmdline(self) -> list[str]:
         """
         Return autopkgtest command line (idempotent).
@@ -344,7 +350,9 @@ class Autopkgtest(
         cmd.append(f"--needs-internet={self.data.needs_internet}")
 
         if self.data.timeout is not None:
-            for key, timeout in self.data.timeout.dict(by_alias=True).items():
+            for key, timeout in self.data.timeout.model_dump(
+                by_alias=True
+            ).items():
                 if timeout is not None:
                     cmd.append(f"--timeout-{key}={timeout}")
 
@@ -368,24 +376,17 @@ class Autopkgtest(
     def _cmdline_extra_repository(self) -> list[str]:
         """Generate command line arguments for extra_repositories."""
         args: list[str] = []
-        if self.supports_deb822_sources(self._environment_codename()):
-            # autopkgtest has native deb822 support coming soon: #1089736
-            for path in self.extra_repository_sources:
-                args.append(
-                    f"--copy={path}:/etc/apt/sources.list.d/{path.name}"
-                )
-        else:
-            for source in self.iter_oneline_sources():
-                args.append(f"--add-apt-source={source}")
+        # autopkgtest has native deb822 support coming soon: #1089736
+        for path in self.extra_repository_sources:
+            args.append(f"--copy={path}:/etc/apt/sources.list.d/{path.name}")
 
         # apt < 2.3.10 has no support for keys embedded in Signed-By
         for path in self.extra_repository_keys:
             args.append(f"--copy={path}:/etc/apt/keyrings/{path.name}")
         return args
 
-    def configure_for_execution(
-        self, download_directory: Path  # noqa: U100
-    ) -> bool:
+    @override
+    def configure_for_execution(self, download_directory: Path) -> bool:
         """Gather information used later on (_cmdline(), upload_artifacts())."""
         # Not yet strictly guaranteed, because the source artifact might be
         # of the wrong type; see
@@ -414,8 +415,9 @@ class Autopkgtest(
 
         return True
 
+    @override
     def task_succeeded(
-        self, returncode: int | None, execute_directory: Path  # noqa: U100
+        self, returncode: int | None, execute_directory: Path
     ) -> bool:
         """
         Parse the summary file and return success.
@@ -451,8 +453,12 @@ class Autopkgtest(
         # 8 no tests in this package, or all non-superficial tests were skipped
         return returncode in {0, 2, 8}
 
+    @override
     def upload_artifacts(
-        self, execute_directory: Path, *, execution_success: bool  # noqa: U100
+        self,
+        execute_directory: Path,
+        *,
+        execution_success: bool,  # noqa: U100
     ) -> None:
         """Upload AutopkgtestArtifact with the files, data and relationships."""
         if not self.debusine:
@@ -480,9 +486,7 @@ class Autopkgtest(
                 source_package=DebianAutopkgtestSource(
                     name=self._source_package_name,
                     version=self._source_package_version,
-                    url=pydantic.parse_obj_as(
-                        pydantic.AnyUrl, self._source_package_url
-                    ),
+                    url=self._source_package_url,
                 ),
                 # TODO: Should this be the architecture of the binary
                 # packages instead?  If we're testing `Architecture: all`
