@@ -8,10 +8,12 @@
 # contained in the LICENSE file.
 
 """Task to use debdiff in debusine."""
+
+from dataclasses import dataclass
 from itertools import chain
 from pathlib import Path
 from tempfile import mkdtemp
-from typing import Any
+from typing import Any, override
 
 from debusine import utils
 from debusine.artifacts import DebDiffArtifact
@@ -21,7 +23,9 @@ from debusine.artifacts.models import (
     DebianBinaryPackage,
     DebianSourcePackage,
     DebianUpload,
+    get_binary_package_version,
     get_source_package_name,
+    get_source_package_version,
 )
 from debusine.client.models import RelationType
 from debusine.tasks import BaseTaskWithExecutor, RunCommandTask, TaskConfigError
@@ -29,6 +33,29 @@ from debusine.tasks.models import DebDiffData, DebDiffDynamicData
 from debusine.tasks.server import TaskDatabaseInterface
 
 
+@dataclass(frozen=True, kw_only=True)
+class ArtifactSummaryBase:
+    """Summary of the artifacts."""
+
+    package: str | None
+    original_version: str | None
+    new_version: str | None
+
+
+@dataclass(frozen=True, kw_only=True)
+class SourceArtifactsSummary(ArtifactSummaryBase):
+    """Summary of the source artifacts."""
+
+    ids: list[int]
+
+
+@dataclass(frozen=True, kw_only=True)
+class BinaryArtifactsSummary(ArtifactSummaryBase):
+    """Summary of the binary artifacts."""
+
+    ids: list[list[int]]
+
+
 class DebDiff(
     RunCommandTask[DebDiffData, DebDiffDynamicData],
     BaseTaskWithExecutor[DebDiffData, DebDiffDynamicData],
@@ -39,6 +66,7 @@ class DebDiff(
 
     CAPTURE_OUTPUT_FILENAME = "debdiff.txt"
 
+    @override
     def __init__(
         self,
         task_data: dict[str, Any],
@@ -71,6 +99,142 @@ class DebDiff(
                 f"(got {original_count} and {new_count})"
             )
 
+    def _summarize_source_artifacts(
+        self, task_database: TaskDatabaseInterface
+    ) -> SourceArtifactsSummary | None:
+        if not self.data.input.source_artifacts:
+            return None
+
+        source_artifacts = [
+            task_database.lookup_single_artifact(artifact)
+            for artifact in self.data.input.source_artifacts
+        ]
+
+        package = None
+        artifacts_ids = []
+
+        for source_artifact in source_artifacts:
+            # TODO: improve configuration_key including the index?
+            self.ensure_artifact_categories(
+                configuration_key="input.source_artifacts",
+                category=source_artifact.category,
+                expected=(ArtifactCategory.SOURCE_PACKAGE,),
+            )
+
+            if package is None:
+                assert isinstance(source_artifact.data, DebianSourcePackage)
+                package = get_source_package_name(source_artifact.data)
+
+            artifacts_ids.append(source_artifact.id)
+
+        assert isinstance(source_artifacts[0].data, DebianSourcePackage)
+        assert isinstance(source_artifacts[1].data, DebianSourcePackage)
+
+        original_version = get_source_package_version(source_artifacts[0].data)
+        new_version = get_source_package_version(source_artifacts[1].data)
+
+        return SourceArtifactsSummary(
+            package=package,
+            original_version=original_version,
+            new_version=new_version,
+            ids=artifacts_ids,
+        )
+
+    def _summarize_binary_artifacts(
+        self, task_database: TaskDatabaseInterface
+    ) -> BinaryArtifactsSummary | None:
+        if not self.data.input.binary_artifacts:
+            return None
+
+        binary_artifacts_original = task_database.lookup_multiple_artifacts(
+            self.data.input.binary_artifacts[0]
+        )
+        binary_artifacts_new = task_database.lookup_multiple_artifacts(
+            self.data.input.binary_artifacts[1]
+        )
+
+        self._validate_binary_original_new_count(
+            len(binary_artifacts_original), len(binary_artifacts_new)
+        )
+
+        ids = []
+        source_package_names = set()
+        binary_artifact_category = None
+
+        for multiple_artifacts in [
+            binary_artifacts_original,
+            binary_artifacts_new,
+        ]:
+            ids.append(multiple_artifacts.get_ids())
+
+            for artifact in multiple_artifacts:
+                # TODO: improve configuration_key including the index?
+                self.ensure_artifact_categories(
+                    configuration_key="input.binary_artifacts",
+                    category=artifact.category,
+                    expected=(
+                        ArtifactCategory.UPLOAD,
+                        ArtifactCategory.BINARY_PACKAGE,
+                    ),
+                )
+
+                assert isinstance(
+                    artifact.data,
+                    (DebianUpload, DebianBinaryPackage),
+                )
+                if binary_artifact_category is None:
+                    binary_artifact_category = artifact.category
+
+                if binary_artifact_category != artifact.category:
+                    raise TaskConfigError(
+                        f'All binary artifacts must have the same '
+                        f'category. Found "{binary_artifact_category}" '
+                        f'and "{artifact.category}"'
+                    )
+
+                source_package_names.add(get_source_package_name(artifact.data))
+
+            if (
+                binary_artifact_category != ArtifactCategory.BINARY_PACKAGE
+                and len(multiple_artifacts) > 1
+            ):
+                raise TaskConfigError(
+                    "If binary_artifacts source and new contain more than "
+                    "one artifact all must be of category "
+                    "debian:binary-package. Found: "
+                    f"{binary_artifact_category}"
+                )
+
+        package = None
+        original_version = None
+        new_version = None
+
+        if len(source_package_names) == 1:
+            (package,) = tuple(source_package_names)
+            assert isinstance(
+                binary_artifacts_original[0].data,
+                (DebianUpload, DebianBinaryPackage),
+            )
+            original_version = get_binary_package_version(
+                binary_artifacts_original[0].data
+            )
+
+            assert isinstance(
+                binary_artifacts_new[0].data,
+                (DebianUpload, DebianBinaryPackage),
+            )
+            new_version = get_binary_package_version(
+                binary_artifacts_new[0].data
+            )
+
+        return BinaryArtifactsSummary(
+            package=package,
+            original_version=original_version,
+            new_version=new_version,
+            ids=ids,
+        )
+
+    @override
     def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> DebDiffDynamicData:
@@ -80,103 +244,34 @@ class DebDiff(
         :subject: ``source:NAME_OF_PACKAGE`` if ``input.source_artifacts``
           is set, otherwise ``binary:NAME_OF_PACKAGE`` if all binary artifacts
           in ``input.binary_artifacts`` originate from the same source package
+        :parameter_summary: subject: original_version → new_version (arch)
         """
+        source_summary = self._summarize_source_artifacts(task_database)
+        binary_summary = self._summarize_binary_artifacts(task_database)
+
+        relevant_summary = source_summary if source_summary else binary_summary
+        assert relevant_summary is not None
+
+        original_version = relevant_summary.original_version
+        new_version = relevant_summary.new_version
+
         subject = None
-        source_artifacts_ids = []
+        parameter_summary = None
 
-        if self.data.input.source_artifacts:
-            source_artifacts = [
-                task_database.lookup_single_artifact(artifact)
-                for artifact in self.data.input.source_artifacts
-            ]
+        if (package := relevant_summary.package) is not None:
+            if source_summary is not None:
+                subject = f"source:{package}"
+            else:
+                subject = f"binary:{package}"
 
-            if any(artifact is None for artifact in source_artifacts):
-                raise TaskConfigError(
-                    f"Could not look up one of source_artifacts. "
-                    f"Source artifacts lookup result: {source_artifacts}"
-                )
+            parameter_summary = f"{package}: {original_version} → {new_version}"
 
-            for source_artifact in source_artifacts:
-                # TODO: improve configuration_key including the index?
-                self.ensure_artifact_categories(
-                    configuration_key="input.source_artifacts",
-                    category=source_artifact.category,
-                    expected=(ArtifactCategory.SOURCE_PACKAGE,),
-                )
-
-                if subject is None:
-                    assert isinstance(source_artifact.data, DebianSourcePackage)
-
-                    package_name = get_source_package_name(source_artifact.data)
-                    subject = f"source:{package_name}"
-
-                source_artifacts_ids.append(source_artifact.id)
-
-        binary_artifacts_ids = []
-
-        if self.data.input.binary_artifacts:
-            binary_artifacts_original = task_database.lookup_multiple_artifacts(
-                self.data.input.binary_artifacts[0]
-            )
-            binary_artifacts_new = task_database.lookup_multiple_artifacts(
-                self.data.input.binary_artifacts[1]
-            )
-
-            self._validate_binary_original_new_count(
-                len(binary_artifacts_original), len(binary_artifacts_new)
-            )
-
-            source_package_names = set()
-
-            binary_artifact_category = None
-            for multiple_artifacts in [
-                binary_artifacts_original,
-                binary_artifacts_new,
-            ]:
-                binary_artifacts_ids.append(multiple_artifacts.get_ids())
-
-                for artifact in multiple_artifacts:
-                    # TODO: improve configuration_key including the index?
-                    self.ensure_artifact_categories(
-                        configuration_key="input.binary_artifacts",
-                        category=artifact.category,
-                        expected=(
-                            ArtifactCategory.UPLOAD,
-                            ArtifactCategory.BINARY_PACKAGE,
-                        ),
-                    )
-
-                    assert isinstance(
-                        artifact.data,
-                        (DebianUpload, DebianBinaryPackage),
-                    )
-                    if binary_artifact_category is None:
-                        binary_artifact_category = artifact.category
-
-                    if binary_artifact_category != artifact.category:
-                        raise TaskConfigError(
-                            f'All binary artifacts must have the same '
-                            f'category. Found "{binary_artifact_category}" '
-                            f'and "{artifact.category}"'
-                        )
-
-                    source_package_names.add(
-                        get_source_package_name(artifact.data)
-                    )
-
-                if (
-                    binary_artifact_category != ArtifactCategory.BINARY_PACKAGE
-                    and len(multiple_artifacts) > 1
-                ):
-                    raise TaskConfigError(
-                        "If binary_artifacts source and new contain more than "
-                        "one artifact all must be of category "
-                        "debian:binary-package. Found: "
-                        f"{binary_artifact_category}"
-                    )
-
-            if subject is None and len(source_package_names) == 1:
-                subject = f"binary:{source_package_names.pop()}"
+            if source_summary is not None:
+                parameter_summary += " (source)"
+            else:
+                # TODO: It would probably be better to get the architecture
+                # of the input binary artifacts and use that.
+                parameter_summary += f" ({self.build_architecture()})"
 
         return DebDiffDynamicData(
             environment_id=self.get_environment(
@@ -184,11 +279,17 @@ class DebDiff(
                 self.data.environment,
                 default_category=CollectionCategory.ENVIRONMENTS,
             ).id,
-            input_source_artifacts_ids=source_artifacts_ids or None,
-            input_binary_artifacts_ids=binary_artifacts_ids or None,
+            input_source_artifacts_ids=(
+                source_summary.ids if source_summary else None
+            ),
+            input_binary_artifacts_ids=(
+                binary_summary.ids if binary_summary else None
+            ),
             subject=subject,
+            parameter_summary=parameter_summary,
         )
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """Return the list of input artifact IDs used by this task."""
         if self.dynamic_data is None:
@@ -199,6 +300,7 @@ class DebDiff(
 
         return list(chain(input_ids, *binary_ids))
 
+    @override
     def _cmdline(self) -> list[str]:
         """
         Build the debdiff command line.
@@ -236,6 +338,7 @@ class DebDiff(
 
         return artifact_directory
 
+    @override
     def fetch_input(self, destination: Path) -> bool:
         """Download the required artifacts."""
         assert self.dynamic_data
@@ -271,7 +374,6 @@ class DebDiff(
 
     @staticmethod
     def _find_file(path: Path) -> Path:
-
         file = utils.find_file_suffixes(path, [".changes"])
 
         if file is None:
@@ -283,8 +385,10 @@ class DebDiff(
 
         return file
 
+    @override
     def configure_for_execution(
-        self, download_directory: Path  # noqa: U100
+        self,
+        download_directory: Path,  # noqa: U100
     ) -> bool:
         """
         Set self._(original|new)_targets to the relevant files.
@@ -328,8 +432,12 @@ class DebDiff(
 
         return True
 
+    @override
     def upload_artifacts(
-        self, exec_directory: Path, *, execution_success: bool  # noqa: U100
+        self,
+        exec_directory: Path,
+        *,
+        execution_success: bool,  # noqa: U100
     ) -> None:
         """Upload the DebDiffArtifact with the files and relationships."""
         assert self.dynamic_data
@@ -363,8 +471,11 @@ class DebDiff(
                     uploaded.id, binary_artifact_id, RelationType.RELATES_TO
                 )
 
+    @override
     def task_succeeded(
-        self, returncode: int | None, execute_directory: Path  # noqa: U100
+        self,
+        returncode: int | None,
+        execute_directory: Path,  # noqa: U100
     ) -> bool:
         """
         Evaluate task output and return success.
@@ -375,9 +486,3 @@ class DebDiff(
         :return: True for success, False failure.
         """
         return returncode in [0, 1]
-
-    def get_label(self) -> str:
-        """Return the task label."""
-        # TODO: copy the source package information in dynamic task data and
-        # use them here if available
-        return "debdiff"
