@@ -13,7 +13,7 @@ import re
 from collections import defaultdict
 from collections.abc import Sequence
 from pathlib import Path
-from typing import Any
+from typing import Any, override
 
 from debian.deb822 import Changes
 
@@ -44,6 +44,7 @@ class MergeUploads(BaseExternalTask[MergeUploadsData, MergeUploadsDynamicData]):
 
     TASK_VERSION = 1
 
+    @override
     def __init__(
         self,
         task_data: dict[str, Any],
@@ -54,6 +55,7 @@ class MergeUploads(BaseExternalTask[MergeUploadsData, MergeUploadsDynamicData]):
         self._changes_paths: list[Path] = []
         self._upload_artifact: Upload | None = None
 
+    @override
     def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> MergeUploadsDynamicData:
@@ -108,6 +110,7 @@ class MergeUploads(BaseExternalTask[MergeUploadsData, MergeUploadsDynamicData]):
             return []
         return self.dynamic_data.input_uploads_ids
 
+    @override
     def fetch_input(self, destination: Path) -> bool:
         """Populate work directory with user-specified binary artifact(s)."""
         if not self.debusine:
@@ -134,6 +137,7 @@ class MergeUploads(BaseExternalTask[MergeUploadsData, MergeUploadsDynamicData]):
 
         return True
 
+    @override
     def configure_for_execution(self, download_directory: Path) -> bool:
         r"""
         Find the .changes files to merge.
@@ -306,15 +310,20 @@ class MergeUploads(BaseExternalTask[MergeUploadsData, MergeUploadsDynamicData]):
         """Make an Upload artifact from a merged .changes file."""
         return Upload.create(changes_file=merged_changes_path)
 
-    def run(self, execute_directory: Path) -> bool:  # noqa: U100
+    @override
+    def run(self, execute_directory: Path) -> bool:
         """Do the main work of the task."""
         all_changes = [self._read_changes(path) for path in self._changes_paths]
         merged_changes_path = self.merge_changes(execute_directory, all_changes)
         self._upload_artifact = self.make_upload_artifact(merged_changes_path)
         return True
 
+    @override
     def upload_artifacts(
-        self, execute_directory: Path, *, execution_success: bool  # noqa: U100
+        self,
+        execute_directory: Path,
+        *,
+        execution_success: bool,  # noqa: U100
     ) -> None:
         """Create DebianUpload artifact and relationships."""
         if not self.debusine:
