@@ -13,17 +13,15 @@ import datetime as dt
 import re
 from abc import ABC
 from collections.abc import Iterator
+from dataclasses import dataclass
 from enum import StrEnum
+from functools import partial
 from itertools import groupby
 from pathlib import Path
-from typing import Annotated, Any, ClassVar, Literal, TypeAlias, Union
+from typing import Annotated, Any, ClassVar, Literal, Self, TypeAlias, Union
 
 import debian.deb822 as deb822
-
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
+import pydantic
 
 from debusine.artifacts.models import (
     BareDataCategory,
@@ -37,6 +35,7 @@ from debusine.utils import DjangoChoicesEnum
 class WorkerType(DjangoChoicesEnum):
     """The type of a Worker."""
 
+    SCHEDULER = "scheduler"
     EXTERNAL = "external"
     CELERY = "celery"
     SIGNING = "signing"
@@ -75,16 +74,22 @@ class LintianFailOnSeverity(StrEnum):
 class BaseTaskDataModel(pydantic.BaseModel):
     """Stricter pydantic defaults for task data models."""
 
-    class Config:
-        """Set up stricter pydantic Config."""
+    model_config = pydantic.ConfigDict(validate_assignment=True, extra="forbid")
 
-        validate_assignment = True
-        extra = "forbid"
-
-    def dict(self, **kwargs: Any) -> dict[str, Any]:
+    # Replace with serialize_by_alias=True in model_config once we can
+    # assume pydantic >= 2.11.
+    def model_dump(self, **kwargs: Any) -> dict[str, Any]:
         """Use aliases by default when serializing."""
         kwargs.setdefault("by_alias", True)
-        return super().dict(**kwargs)
+        return super().model_dump(**kwargs)
+
+
+# https://github.com/pydantic/pydantic-core/issues/296
+def require_unique(v: list[Any]) -> list[Any]:
+    """Field validator to require that list items are unique."""
+    if sorted(v) != sorted(set(v)):
+        raise ValueError(f"{v} contains duplicate items")
+    return v
 
 
 # Lookups resulting in exactly one collection item.
@@ -139,21 +144,17 @@ class CollectionItemMatcher(BaseTaskDataModel):
 class BaseExtraRepository(BaseTaskDataModel, ABC):
     """Generic extra repositories for Debian tasks."""
 
-    components: list[str] | None = None
+    components: (
+        list[Annotated[str, pydantic.Field(pattern=r"^(\w|-)+$")]] | None
+    ) = None
 
-    @pydantic.validator("components")
+    @pydantic.field_validator("components", mode="after")
     @classmethod
-    def components_regex(cls, components: list[str] | None) -> list[str] | None:
-        """Ensure that ``components`` matches a regex."""
-        if not components:
-            return None
-        # Replace with an Annotated[str] in pydantic 2
-        for component in components:
-            if not re.match(r"^(\w|-)+$", component):
-                raise ValueError(
-                    f"Invalid component {component}, must match (\\w|-)+"
-                )
-        return components
+    def convert_empty_components_to_none(
+        cls, value: list[str] | None
+    ) -> list[str] | None:
+        """Rewrite an empty components list to None."""
+        return value if value else None
 
 
 class ExtraDebusineRepository(BaseExtraRepository):
@@ -165,53 +166,28 @@ class ExtraDebusineRepository(BaseExtraRepository):
 class ExtraExternalRepository(BaseExtraRepository):
     """An extra external repository for Debian tasks."""
 
-    url: pydantic.AnyUrl
-    suite: str
+    url: Annotated[pydantic.AnyUrl, pydantic.UrlConstraints(host_required=True)]
+    suite: Annotated[str, pydantic.Field(pattern=r"^(\w|[./ -])+$")]
     signing_key: str | None = None
 
-    @pydantic.validator("suite")
-    @classmethod
-    def suite_regex(cls, suite: str) -> str:
-        """Ensure that suite matches a regex."""
-        # Replace with an Annotated[str] in pydantic 2
-        if not re.match(r"^(\w|[./ -])+$", suite):
-            raise ValueError(f"Invalid suite {suite}, must match (\\w|[./ -])+")
-        return suite
-
-    @pydantic.root_validator
-    @classmethod
-    def flat_repository(cls, values: dict[str, Any]) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def flat_repository(self) -> Self:
         """Check if suite is a flat repository."""
-        suite = values.get("suite")
-        components = values.get("components")
-        if suite and suite.endswith("/"):
-            if components is not None:
+        if self.suite.endswith("/"):
+            if self.components is not None:
                 raise ValueError(
                     "Components cannot be specified for a flat "
                     "repository (where the suite ends with /)"
                 )
-        elif not components:
+        elif not self.components:
             raise ValueError("Components must be specified")
-        return values
-
-    def as_oneline_source(self, signed_by_filename: str | None = None) -> str:
-        """Render a one-line sources.list entry."""
-        parts = ["deb"]
-        if self.signing_key:
-            if not signed_by_filename:
-                raise ValueError("No signed_by_filename specified")
-            parts.append(f"[signed-by={signed_by_filename}]")
-        parts.append(self.url)
-        parts.append(self.suite)
-        if self.components:
-            parts += self.components
-        return ' '.join(parts)
+        return self
 
     def as_deb822_source(self, signed_by_filename: str | None = None) -> str:
         """Render a Deb822 sources.list.d entry."""
         source = deb822.Deb822()
         source["Types"] = "deb"
-        source["URIs"] = self.url
+        source["URIs"] = str(self.url)
         source["Suites"] = self.suite
         if self.components:
             source["Components"] = " ".join(self.components)
@@ -232,8 +208,9 @@ ExtraRepository: TypeAlias = ExtraDebusineRepository | ExtraExternalRepository
 class LookupDict(BaseTaskDataModel):
     """Dictionary lookups for collection items."""
 
-    class Config(BaseTaskDataModel.Config):
-        frozen = True
+    model_config = BaseTaskDataModel.model_config | pydantic.ConfigDict(
+        frozen=True
+    )
 
     collection: LookupSingle
     child_type: LookupChildType = LookupChildType.ARTIFACT
@@ -250,9 +227,9 @@ class LookupDict(BaseTaskDataModel):
         tuple[str, Union[LookupSingle, "LookupMultiple"]], ...
     ] = ()
 
-    @pydantic.root_validator(pre=True, allow_reuse=True)
+    @pydantic.model_validator(mode="before")
     @classmethod
-    def normalize_matchers(cls, values: dict[str, Any]) -> dict[str, Any]:
+    def normalize_matchers(cls, data: Any) -> dict[str, Any]:  # noqa: C901
         """
         Transform the lookup syntax into a form more convenient for pydantic.
 
@@ -277,15 +254,19 @@ class LookupDict(BaseTaskDataModel):
                 case _:
                     return ()
 
+        if not isinstance(data, dict):
+            raise ValueError(f"Expected dict, got {type(data)!r}")
+        data = data.copy()
+
         data_matchers: dict[str, CollectionItemMatcher] = dict(
-            values.get("data_matchers", ())
+            data.get("data_matchers", ())
         )
         lookup_filters: dict[str, LookupSingle | LookupMultiple] = dict(
-            values.get("lookup_filters", ())
+            data.get("lookup_filters", ())
         )
 
         for key, group in groupby(
-            sorted(values, key=matcher_prefix), matcher_prefix
+            sorted(data, key=matcher_prefix), matcher_prefix
         ):
             if not key:
                 # Only keys with `name`, `data`, or `lookup` as their first
@@ -300,7 +281,7 @@ class LookupDict(BaseTaskDataModel):
             matcher_name = matcher_names[0]
 
             data_key: str | None = None
-            match (words := split_words(matcher_name)):
+            match words := split_words(matcher_name):
                 case ["name"]:
                     kind = "exact"
                 case ["name", kind] if kind != "exact":
@@ -310,12 +291,17 @@ class LookupDict(BaseTaskDataModel):
                 case ["data", data_key, kind] if kind != "exact":
                     pass
                 case ["lookup", lookup_key]:
-                    lookup_filters[lookup_key] = pydantic.parse_obj_as(
-                        LookupSingle | LookupMultiple,  # type: ignore[arg-type]
-                        values[matcher_name],
-                    )
+                    match data[matcher_name]:
+                        case int() | str():
+                            lookup_filters[lookup_key] = data[matcher_name]
+                        case _:
+                            lookup_filters[lookup_key] = (
+                                LookupMultiple.model_validate(
+                                    data[matcher_name]
+                                )
+                            )
                     for k in matcher_names:
-                        del values[k]
+                        del data[k]
                     continue
                 case _:
                     # We filter out keys with first segments other than
@@ -324,23 +310,23 @@ class LookupDict(BaseTaskDataModel):
                     raise ValueError(f"Unrecognized matcher: {matcher_name}")
 
             matcher = CollectionItemMatcher(
-                kind=CollectionItemMatcherKind(kind), value=values[matcher_name]
+                kind=CollectionItemMatcherKind(kind), value=data[matcher_name]
             )
             if words[0] == "name":
-                values["name_matcher"] = matcher
+                data["name_matcher"] = matcher
             else:
                 assert words[0] == "data"
                 assert data_key is not None
                 data_matchers[data_key] = matcher
             for k in matcher_names:
-                del values[k]
+                del data[k]
 
         if data_matchers:
-            values["data_matchers"] = tuple(sorted(data_matchers.items()))
+            data["data_matchers"] = tuple(sorted(data_matchers.items()))
         if lookup_filters:
-            values["lookup_filters"] = tuple(sorted(lookup_filters.items()))
+            data["lookup_filters"] = tuple(sorted(lookup_filters.items()))
 
-        return values
+        return data
 
     def export(self) -> dict[str, Any]:
         """
@@ -374,24 +360,19 @@ class LookupDict(BaseTaskDataModel):
         return value
 
 
-class LookupMultiple(BaseTaskDataModel):
+class LookupMultiple(pydantic.RootModel[tuple[LookupSingle | LookupDict, ...]]):
     """Lookups resulting in multiple collection items."""
 
-    class Config(BaseTaskDataModel.Config):
-        frozen = True
+    model_config = pydantic.ConfigDict(validate_assignment=True, frozen=True)
 
-    # LookupMultiple parses a list instead of an object/dict; we turn this
-    # into a tuple so that lookups are hashable
-    __root__: tuple[LookupSingle | LookupDict, ...]
-
-    @pydantic.validator("__root__", pre=True, allow_reuse=True)
+    @pydantic.model_validator(mode="before")
     @classmethod
-    def normalize(cls, values: Any) -> tuple[Any, ...]:
-        """Normalize into a list of multiple matchers."""
-        if isinstance(values, dict):
-            return (values,)
-        elif isinstance(values, (tuple, list)):
-            return tuple(values)
+    def normalize(cls, data: Any) -> tuple[Any, ...]:
+        """Normalize into a tuple of multiple matchers."""
+        if isinstance(data, dict):
+            return (data,)
+        elif isinstance(data, (tuple, list)):
+            return tuple(data)
         else:
             raise ValueError(
                 "Lookup of multiple collection items must be a dictionary or "
@@ -402,11 +383,11 @@ class LookupMultiple(BaseTaskDataModel):
         self,
     ) -> Iterator[LookupSingle | LookupDict]:
         """Iterate over individual lookups."""
-        return iter(self.__root__)
+        return iter(self.root)
 
     def __bool__(self) -> bool:
         """Return True if and only if this lookup is non-empty."""
-        return bool(self.__root__)
+        return bool(self.root)
 
     def export(self) -> dict[str, Any] | list[int | str | dict[str, Any]]:
         """
@@ -414,8 +395,8 @@ class LookupMultiple(BaseTaskDataModel):
 
         This reverses the transformations applied by :py:meth:`normalize`.
         """
-        if len(self.__root__) == 1 and isinstance(self.__root__[0], LookupDict):
-            return self.__root__[0].export()
+        if len(self.root) == 1 and isinstance(self.root[0], LookupDict):
+            return self.root[0].export()
         else:
             return [
                 lookup.export() if isinstance(lookup, LookupDict) else lookup
@@ -424,14 +405,14 @@ class LookupMultiple(BaseTaskDataModel):
 
 
 # Resolve circular reference to LookupMultiple.
-LookupDict.update_forward_refs()
+LookupDict.model_rebuild()
 
 
 class NotificationDataEmail(BaseTaskDataModel):
     """Channel data for email notifications."""
 
     from_: pydantic.EmailStr | None = pydantic.Field(default=None, alias="from")
-    to: list[pydantic.EmailStr] | None
+    to: list[pydantic.EmailStr] | None = None
     cc: list[pydantic.EmailStr] = pydantic.Field(default_factory=list)
     subject: str | None = None
 
@@ -499,24 +480,15 @@ class ActionUpdateCollectionWithData(BaseTaskDataModel):
 class ActionRetryWithDelays(BaseTaskDataModel):
     """Action for retrying a work request with delays."""
 
-    _delay_re = re.compile(r"^([0-9]+)([mhdw])$")
+    _delay_re: ClassVar[re.Pattern[str]] = re.compile(r"^([0-9]+)([mhdw])$")
 
     action: Literal[ActionTypes.RETRY_WITH_DELAYS] = (
         ActionTypes.RETRY_WITH_DELAYS
     )
-    delays: list[str] = pydantic.Field(min_items=1)
-
-    @pydantic.validator("delays")
-    @classmethod
-    def validate_delays(cls, values: list[str]) -> list[str]:
-        """Check items in `delays` field."""
-        for v in values:
-            if cls._delay_re.match(v) is None:
-                raise ValueError(
-                    f"Item in delays must be an integer followed by "
-                    f"m, h, d, or w; got {v!r}"
-                )
-        return values
+    delays: Annotated[
+        list[Annotated[str, pydantic.Field(pattern=_delay_re)]],
+        (pydantic.Field(min_length=1)),
+    ]
 
 
 class ActionRecordInTaskHistory(BaseTaskDataModel):
@@ -551,8 +523,8 @@ class EventReactions(BaseTaskDataModel):
     on_success: list[EventReaction] = []
     on_failure: list[EventReaction] = []
 
-    def dict(self, **kwargs: Any) -> dict[str, Any]:
-        """Wrap pydantic's dict to ensure discriminators are serializers."""
+    def model_dump(self, **kwargs: Any) -> dict[str, Any]:
+        """Wrap pydantic to ensure discriminators are serializers."""
         # TODO: from python 3.5, docstrings are inherited from the parent
         # class, which would be the right thing here. However, flake8 doesn't
         # like it.
@@ -567,9 +539,9 @@ class EventReactions(BaseTaskDataModel):
             "on_failure",
         ):
             for item in getattr(self, name):
-                item.__fields_set__.add("action")
+                item.model_fields_set.add("action")
 
-        return super().dict(**kwargs)
+        return super().model_dump(**kwargs)
 
     def add_reaction(
         self,
@@ -592,7 +564,7 @@ class EventReactions(BaseTaskDataModel):
             current.append(action)
             # Let pydantic know we modified the field.
             # See: https://github.com/pydantic/pydantic/issues/9866
-            self.__fields_set__.add(name)
+            self.model_fields_set.add(name)
 
 
 class BaseTaskData(BaseTaskDataModel):
@@ -694,12 +666,16 @@ class RegressionAnalysis(BaseTaskDataModel):
     """The result of a regression analysis."""
 
     original_source_version: str | None = None
-    original_url: str | None = None
+    original_artifact_id: int | None = None
     new_source_version: str | None = None
-    new_url: str | None = None
+    new_artifact_id: int | None = None
     status: RegressionAnalysisStatus
     details: dict[str, Any] | list[Any] | None = None
 
+    # Obsolete, but may be present in old rows.
+    original_url: str | None = None
+    new_url: str | None = None
+
 
 class Confirmation(BaseTaskDataModel):
     """A record that a work request was confirmed or denied by a user."""
@@ -725,30 +701,25 @@ class OutputData(BaseTaskDataModel):
         field is set on both models, the values in ``other`` take
         precedence.
         """
-        merged = self.copy()
-        for name in other.__fields_set__:
+        merged = self.model_copy()
+        for name in other.model_fields_set:
             setattr(merged, name, getattr(other, name))
         return merged
 
 
-class NoopData(BaseTaskData):
+class NoopData(BaseTaskDataWithExecutor):
     """In memory task data for the Noop task."""
 
     result: bool = True
 
 
-def empty_lookup_multiple() -> LookupMultiple:
-    """Return an empty :py:class:`LookupMultiple`."""
-    return LookupMultiple.parse_obj(())
-
-
 class AutopkgtestInput(BaseTaskDataModel):
     """Input for an autopkgtest task."""
 
     source_artifact: LookupSingle
     binary_artifacts: LookupMultiple
     context_artifacts: LookupMultiple = pydantic.Field(
-        default_factory=empty_lookup_multiple
+        default_factory=partial(LookupMultiple, ())
     )
 
 
@@ -763,12 +734,16 @@ class AutopkgtestFailOn(BaseTaskDataModel):
 class AutopkgtestTimeout(BaseTaskDataModel):
     """Timeout specifications for an autopkgtest task."""
 
-    global_: int | None = pydantic.Field(alias="global", ge=0)
-    factor: int | None = pydantic.Field(ge=0)
-    short: int | None = pydantic.Field(ge=0)
-    install: int | None = pydantic.Field(ge=0)
-    test: int | None = pydantic.Field(ge=0)
-    copy_: int | None = pydantic.Field(alias="copy", ge=0)
+    global_: Annotated[int | None, pydantic.Field(ge=0)] = pydantic.Field(
+        default=None, alias="global"
+    )
+    factor: Annotated[int | None, pydantic.Field(ge=0)] = None
+    short: Annotated[int | None, pydantic.Field(ge=0)] = None
+    install: Annotated[int | None, pydantic.Field(ge=0)] = None
+    test: Annotated[int | None, pydantic.Field(ge=0)] = None
+    copy_: Annotated[int | None, pydantic.Field(ge=0)] = pydantic.Field(
+        default=None, alias="copy"
+    )
 
 
 class AutopkgtestData(
@@ -782,7 +757,7 @@ class AutopkgtestData(
     build_architecture: str
     include_tests: list[str] = pydantic.Field(default_factory=list)
     exclude_tests: list[str] = pydantic.Field(default_factory=list)
-    debug_level: int = pydantic.Field(default=0, ge=0, le=3)
+    debug_level: Annotated[int, pydantic.Field(ge=0, le=3)] = 0
     use_packages_from_base_repository: bool = False
     extra_environment: dict[str, str] = pydantic.Field(default_factory=dict)
     needs_internet: AutopkgtestNeedsInternet = AutopkgtestNeedsInternet.RUN
@@ -816,22 +791,17 @@ class LintianInput(BaseTaskDataModel):
 
     source_artifact: LookupSingle | None = None
     binary_artifacts: LookupMultiple = pydantic.Field(
-        default_factory=empty_lookup_multiple
+        default_factory=partial(LookupMultiple, ())
     )
 
-    @pydantic.root_validator(allow_reuse=True)
-    @classmethod
-    def check_one_of_source_or_binary(
-        cls, values: dict[str, Any]
-    ) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def check_one_of_source_or_binary(self) -> Self:
         """Ensure a source or binary artifact is present."""
-        if values.get("source_artifact") is None and not values.get(
-            "binary_artifacts"
-        ):
+        if self.source_artifact is None and not self.binary_artifacts:
             raise ValueError(
                 'One of source_artifact or binary_artifacts must be set'
             )
-        return values
+        return self
 
 
 class LintianOutput(BaseTaskDataModel):
@@ -914,27 +884,22 @@ class BlhcDynamicData(BaseDynamicTaskDataWithExecutor):
 class DebDiffInput(BaseTaskDataModel):
     """Input for a debdiff task."""
 
-    source_artifacts: list[LookupSingle] | None = pydantic.Field(
-        default=None, min_items=2, max_items=2
-    )
-    binary_artifacts: list[LookupMultiple] | None = pydantic.Field(
-        default=None, min_items=2, max_items=2
-    )
+    source_artifacts: Annotated[
+        list[LookupSingle] | None, pydantic.Field(min_length=2, max_length=2)
+    ] = None
+    binary_artifacts: Annotated[
+        list[LookupMultiple] | None, pydantic.Field(min_length=2, max_length=2)
+    ] = None
 
-    @pydantic.root_validator(allow_reuse=True)
-    @classmethod
-    def check_one_of_source_or_binary(
-        cls, values: dict[str, Any]
-    ) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def check_one_of_source_or_binary(self) -> Self:
         """Ensure only source or binary artifacts are present."""
-        if (values.get("source_artifacts") is None) == (
-            values.get("binary_artifacts") is None
-        ):
+        if (self.source_artifacts is None) == (self.binary_artifacts is None):
             raise ValueError(
-                'Exactly one of source_artifacts'
-                'or binary_artifacts must be set'
+                "Exactly one of source_artifacts"
+                " or binary_artifacts must be set"
             )
-        return values
+        return self
 
 
 class DebDiffFlags(StrEnum):
@@ -970,12 +935,32 @@ class DebDiffDynamicData(BaseDynamicTaskDataWithExecutor):
     # required here.
     environment_id: int
 
-    input_source_artifacts_ids: list[int] | None = pydantic.Field(
-        default=None, min_items=2, max_items=2
-    )
-    # TODO: Once we depend on pydantic 2.9.2-1 add a check:
-    # pydantic.Field(default=None, min_items=2, max_items=2)
-    input_binary_artifacts_ids: list[list[int]] | None = None
+    input_source_artifacts_ids: Annotated[
+        list[int] | None, pydantic.Field(min_length=2, max_length=2)
+    ] = None
+    input_binary_artifacts_ids: Annotated[
+        list[list[int]] | None, pydantic.Field(min_length=2, max_length=2)
+    ] = None
+
+    @pydantic.model_validator(mode="after")
+    def validate_source_or_binary_exclusive(self) -> Self:
+        """
+        Validate mutually exclusive input artifacts.
+
+        Ensure input_source_artifacts_ids and input_binary_artifacts_ids
+        are not both set.
+        """
+        # It currently allows to have "input_source_artifacts_ids" == None and
+        # "input_binary_artifacts_ids" == None to allow backwards compatibility
+        # with older data
+        if (self.input_source_artifacts_ids is not None) and (
+            self.input_binary_artifacts_ids is not None
+        ):
+            raise ValueError(
+                "Only one of 'input_source_artifacts_ids' or "
+                "'input_binary_artifacts_ids' may be set (not both)."
+            )
+        return self
 
 
 class MmDebstrapVariant(StrEnum):
@@ -1030,15 +1015,13 @@ class SystemBootstrapRepositoryCheckSignatureWith(StrEnum):
 class SystemBootstrapRepositoryKeyring(BaseTaskDataModel):
     """Description of a repository keyring."""
 
-    url: pydantic.AnyUrl | pydantic.FileUrl
+    url: pydantic.AnyUrl
     sha256sum: str = ""
     install: bool = False
 
-    @pydantic.validator("url")
+    @pydantic.field_validator("url", mode="after")
     @classmethod
-    def validate_url(
-        cls, url: pydantic.AnyUrl | pydantic.FileUrl
-    ) -> pydantic.AnyUrl | pydantic.FileUrl:
+    def validate_url(cls, url: pydantic.AnyUrl) -> pydantic.AnyUrl:
         """
         Reject file:// URLs outside /usr/(local/)share/keyrings/.
 
@@ -1068,43 +1051,44 @@ class SystemBootstrapRepository(BaseTaskDataModel):
 
     mirror: str
     suite: str
-    types: list[SystemBootstrapRepositoryType] = pydantic.Field(
-        default_factory=lambda: [SystemBootstrapRepositoryType.DEB],
-        min_items=1,
-        unique_items=True,
-    )
-    components: list[str] | None = pydantic.Field(
-        default=None, unique_items=True
+    types: Annotated[
+        list[SystemBootstrapRepositoryType],
+        pydantic.Field(min_length=1),
+        pydantic.AfterValidator(require_unique),
+    ] = pydantic.Field(
+        default_factory=lambda: [SystemBootstrapRepositoryType.DEB]
     )
+    components: (
+        Annotated[list[str], pydantic.AfterValidator(require_unique)] | None
+    ) = None
     check_signature_with: SystemBootstrapRepositoryCheckSignatureWith = (
         SystemBootstrapRepositoryCheckSignatureWith.SYSTEM
     )
     keyring_package: str | None = None
     keyring: SystemBootstrapRepositoryKeyring | None = None
 
-    @pydantic.root_validator(allow_reuse=True)
-    @classmethod
-    def _check_external_keyring(cls, values: Any) -> Any:
+    @pydantic.model_validator(mode="after")
+    def _check_external_keyring(self) -> Self:
         """Require keyring if check_signature_with is external."""
         if (
-            values.get("check_signature_with")
+            self.check_signature_with
             == SystemBootstrapRepositoryCheckSignatureWith.EXTERNAL
         ):
-            if values.get("keyring") is None:
+            if self.keyring is None:
                 raise ValueError(
                     "repository requires 'keyring': "
                     "'check_signature_with' is set to 'external'"
                 )
-        return values
+        return self
 
 
 class SystemBootstrapData(BaseTaskData):
     """Base for in-memory class data for SystemBootstrap tasks."""
 
     bootstrap_options: SystemBootstrapOptions
-    bootstrap_repositories: list[SystemBootstrapRepository] = pydantic.Field(
-        min_items=1
-    )
+    bootstrap_repositories: Annotated[
+        list[SystemBootstrapRepository], pydantic.Field(min_length=1)
+    ]
     customization_script: str | None = None
 
 
@@ -1149,7 +1133,7 @@ class DiskImage(BaseTaskDataModel):
     filename: str = "image"
     kernel_package: str | None = None
     bootloader: str | None = None
-    partitions: list[Partition] = pydantic.Field(min_items=1)
+    partitions: Annotated[list[Partition], pydantic.Field(min_length=1)]
 
 
 class SystemImageBuildData(SystemBootstrapData):
@@ -1196,7 +1180,7 @@ class SbuildInput(BaseTaskDataModel):
 
     source_artifact: LookupSingle
     extra_binary_artifacts: LookupMultiple = pydantic.Field(
-        default_factory=empty_lookup_multiple
+        default_factory=partial(LookupMultiple, ())
     )
 
 
@@ -1238,7 +1222,7 @@ class SbuildData(BaseTaskDataWithExecutor, BaseTaskDataWithExtraRepositories):
     # here.
     build_architecture: str
     build_components: list[SbuildBuildComponent] = pydantic.Field(
-        default_factory=lambda: [SbuildBuildComponent.ANY],
+        default_factory=lambda: [SbuildBuildComponent.ANY]
     )
     binnmu: SbuildBinNMU | None = None
     build_profiles: list[str] | None = None
@@ -1249,18 +1233,15 @@ class SbuildData(BaseTaskDataWithExecutor, BaseTaskDataWithExtraRepositories):
     aspcud_criteria: str | None = None
     resolve_alternatives: bool = False
 
-    @pydantic.root_validator
-    @classmethod
-    def check_binnmu_against_components(
-        cls, values: dict[str, Any]
-    ) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def check_binnmu_against_components(self) -> Self:
         """Binnmus are incompatible with architecture-independent builds."""
-        if values.get("binnmu") is not None:
-            if SbuildBuildComponent.ALL in values.get("build_components", []):
+        if self.binnmu is not None:
+            if SbuildBuildComponent.ALL in self.build_components:
                 raise ValueError(
                     "Cannot build architecture-independent packages in a binNMU"
                 )
-        return values
+        return self
 
 
 class SbuildDynamicData(
@@ -1282,7 +1263,7 @@ class ImageCacheUsageLogEntry(BaseTaskDataModel):
     backend: BackendType | None = None
     timestamp: dt.datetime
 
-    @pydantic.validator("timestamp")
+    @pydantic.field_validator("timestamp", mode="after")
     @classmethod
     def timestamp_is_aware(cls, timestamp: dt.datetime) -> dt.datetime:
         """Ensure that the timestamp is TZ-aware."""
@@ -1299,7 +1280,7 @@ class ImageCacheUsageLog(BaseTaskDataModel):
     backends: set[BackendType] = pydantic.Field(default_factory=set)
     usage: list[ImageCacheUsageLogEntry] = pydantic.Field(default_factory=list)
 
-    @pydantic.validator("version")
+    @pydantic.field_validator("version", mode="after")
     @classmethod
     def version_is_known(cls, version: int) -> int:
         """Ensure that the version is known."""
@@ -1324,7 +1305,7 @@ class ExtractForSigningData(BaseTaskDataWithExecutor):
 
     input: ExtractForSigningInput
 
-    @pydantic.validator("backend")
+    @pydantic.field_validator("backend", mode="after")
     @classmethod
     def backend_is_auto(cls, backend: str) -> str:
         """Ensure that the backend is "auto"."""
@@ -1357,7 +1338,7 @@ class AssembleSignedSourceData(BaseTaskDataWithExecutor):
     template: LookupSingle
     signed: LookupMultiple
 
-    @pydantic.validator("backend")
+    @pydantic.field_validator("backend", mode="after")
     @classmethod
     def backend_is_auto(cls, backend: str) -> str:
         """Ensure that the backend is "auto"."""
@@ -1394,8 +1375,8 @@ class MakeSourcePackageUploadData(BaseTaskDataWithExecutor):
     environment: LookupSingle
 
     input: MakeSourcePackageUploadInput
-    since_version: str | None
-    target_distribution: str | None
+    since_version: str | None = None
+    target_distribution: str | None = None
 
 
 class MakeSourcePackageUploadDynamicData(BaseDynamicTaskDataWithExecutor):
@@ -1434,7 +1415,40 @@ class MergeUploadsDynamicData(BaseDynamicTaskData):
     input_uploads_ids: list[int]
 
 
-class DebianPipelineWorkflowDynamicData(BaseDynamicTaskData):
-    """Dynamic data for the DebianPipeline workflow."""
+@dataclass(frozen=True)
+class InputArtifactSingle:
+    """Represent a declared single input artifact for a task."""
 
-    input_source_artifact_id: int | None = None
+    #: Lookup used to obtain the artifact. Usually from the task data but
+    #: could be generated by the task logic.
+    lookup: LookupSingle
+
+    #: the task data label.
+    label: str
+
+    #: artifact_id if it's already known
+    artifact_id: int | None = None
+
+    def resolved_ids(self) -> list[int]:
+        """Return [artifact_id] or []."""
+        return [] if self.artifact_id is None else [self.artifact_id]
+
+
+@dataclass(frozen=True)
+class InputArtifactMultiple:
+    """Represent declared multiple input artifacts for a task."""
+
+    lookup: LookupMultiple
+
+    #: the task data label.
+    label: str
+
+    #: artifact_ids if it's already known
+    artifact_ids: list[int] | None = None
+
+    def resolved_ids(self) -> list[int]:
+        """Return artifact_ids or []."""
+        return self.artifact_ids or []
+
+
+InputArtifact: TypeAlias = InputArtifactSingle | InputArtifactMultiple
