@@ -10,6 +10,7 @@
 """no operation task. Waits and returns. Used in the integration tests."""
 
 from pathlib import Path
+from typing import override
 
 from debusine.tasks import BaseExternalTask, DefaultDynamicData
 from debusine.tasks.models import BaseDynamicTaskData, NoopData
@@ -27,10 +28,7 @@ class Noop(
 
     TASK_VERSION = 1
 
+    @override
     def run(self, execute_directory: Path) -> bool:  # noqa: U100
         """Return self.data.result (was sent by the client)."""
         return self.data.result
-
-    def get_label(self) -> str:
-        """Return the task label."""
-        return "noop"
