@@ -17,13 +17,9 @@ https://freexian-team.pages.debian.net/debusine/reference/tasks/ontology-generic
 import email.utils
 import os
 from pathlib import Path
-from typing import Any, cast
-
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic  # type: ignore
+from typing import Any, cast, override
 
+import pydantic
 import yaml
 
 import debusine.utils
@@ -68,6 +64,7 @@ class Sbuild(
 
     TASK_VERSION = 1
 
+    @override
     def __init__(
         self,
         task_data: dict[str, Any],
@@ -82,6 +79,7 @@ class Sbuild(
         self._dsc_file: Path | None = None
         self._extra_packages: list[Path] = []
 
+    @override
     def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> SbuildDynamicData:
@@ -169,6 +167,7 @@ class Sbuild(
             case _:
                 return self.data.build_architecture
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """
         Return the list of input artifact IDs used by this task.
@@ -185,6 +184,7 @@ class Sbuild(
         result.extend(self.dynamic_data.input_extra_binary_artifacts_ids)
         return result
 
+    @override
     @classmethod
     def analyze_worker(cls) -> dict[str, Any]:
         """Report metadata for this task on this worker."""
@@ -195,6 +195,7 @@ class Sbuild(
 
         return metadata
 
+    @override
     def can_run_on(self, worker_metadata: dict[str, Any]) -> bool:
         """Check the specified worker can run the requested task."""
         if not super().can_run_on(worker_metadata):
@@ -213,6 +214,7 @@ class Sbuild(
 
         return True
 
+    @override
     def fetch_input(self, destination: Path) -> bool:
         """Download the source artifact."""
         if not self.debusine:
@@ -282,6 +284,7 @@ class Sbuild(
 
         return cast(str, self.executor.system_image.data["codename"])
 
+    @override
     def _cmdline(self) -> list[str]:
         """
         Build the sbuild command line.
@@ -364,17 +367,13 @@ class Sbuild(
         """Generate the command line arguments for extra_repositories."""
         args: list[str] = []
 
-        if self.supports_deb822_sources(self._environment_codename()):
-            # sbuild has no native deb822 support, yet: #1089735
-            for path in self.extra_repository_sources:
-                args.append(
-                    f"--pre-build-commands=cat {path} | "
-                    f"%SBUILD_CHROOT_EXEC sh -c 'cat > "
-                    f"/etc/apt/sources.list.d/{path.name}'"
-                )
-        else:
-            for source in self.iter_oneline_sources():
-                args.append(f"--extra-repository={source}")
+        # sbuild has no native deb822 support, yet: #1089735
+        for path in self.extra_repository_sources:
+            args.append(
+                f"--pre-build-commands=cat {path} | "
+                f"%SBUILD_CHROOT_EXEC sh -c 'cat > "
+                f"/etc/apt/sources.list.d/{path.name}'"
+            )
 
         # apt < 2.3.10 has no support for keys embedded in Signed-By
         for path in self.extra_repository_keys:
@@ -417,6 +416,7 @@ class Sbuild(
             if profile in ("nocheck", "nodoc")
         ]
 
+    @override
     def _cmd_env(self) -> dict[str, str] | None:
         """Set DEB_BUILD_OPTIONS for build profiles."""
         if build_options := self._build_options():
@@ -427,10 +427,9 @@ class Sbuild(
             return env
         return None
 
+    @override
     def task_succeeded(
-        self,
-        returncode: int | None,  # noqa: U100
-        execute_directory: Path,  # noqa: U100
+        self, returncode: int | None, execute_directory: Path
     ) -> bool:
         """
         Check whether the task succeeded.
@@ -485,7 +484,7 @@ class Sbuild(
             # https://gitlab.com/irill/dose3/-/issues/18
             parsed_dict = yaml.load(output, yaml.CBaseLoader)
             try:
-                return DoseDistCheck.parse_obj(parsed_dict)
+                return DoseDistCheck.model_validate(parsed_dict)
             except pydantic.ValidationError:
                 return None
 
@@ -670,8 +669,10 @@ class Sbuild(
                 RelationType.RELATES_TO,
             )
 
+    @override
     def configure_for_execution(
-        self, download_directory: Path  # noqa: U100
+        self,
+        download_directory: Path,  # noqa: U100
     ) -> bool:
         """
         Configure Task: set variables needed for the build() step.
@@ -687,6 +688,7 @@ class Sbuild(
 
         return True
 
+    @override
     def upload_artifacts(
         self, directory: Path, *, execution_success: bool
     ) -> None:
