@@ -126,7 +126,7 @@ class AssembleSignedSourceTests(
             },
             multiple_lookups={
                 # signed
-                (LookupMultiple.parse_obj([12]), None): [
+                (LookupMultiple((12,)), None): [
                     ArtifactInfo(
                         id=12,
                         category=ArtifactCategory.SIGNING_OUTPUT,
@@ -363,7 +363,7 @@ class AssembleSignedSourceTests(
         }
 
         def relation_list(artifact_id: int) -> RelationsResponse:
-            return RelationsResponse.parse_obj(
+            return RelationsResponse.model_validate(
                 [
                     {
                         "id": 1,
@@ -376,7 +376,8 @@ class AssembleSignedSourceTests(
             )
 
         def artifact_get(
-            artifact_id: int, workspace: str  # noqa: U100
+            artifact_id: int,
+            workspace: str,  # noqa: ARG001, U100
         ) -> ArtifactResponse:
             return create_artifact_response(
                 id=6, category=artifact_categories[artifact_id]
@@ -807,9 +808,7 @@ class AssembleSignedSourceTests(
         local_execute_directory = self.create_temporary_directory()
         local_source_path = local_execute_directory / "source"
         self._create_source_template(local_source_path)
-        now = dt.datetime.now(dt.timezone.utc).strftime(
-            "%a, %d %b %Y %H:%M:%S %z"
-        )
+        now = dt.datetime.now(dt.UTC).strftime("%a, %d %b %Y %H:%M:%S %z")
         (local_source_path / "debian/changelog").write_text(
             dedent(
                 f"""\
@@ -838,9 +837,7 @@ class AssembleSignedSourceTests(
         remote_source_path = self.task._remote_execute_directory / "source"
         local_source_path = local_execute_directory / "source"
         self._create_source_template(local_source_path)
-        now = dt.datetime.now(dt.timezone.utc).strftime(
-            "%a, %d %b %Y %H:%M:%S %z"
-        )
+        now = dt.datetime.now(dt.UTC).strftime("%a, %d %b %Y %H:%M:%S %z")
         (local_source_path / "debian/changelog").write_text(
             dedent(
                 f"""\
@@ -1017,9 +1014,7 @@ class AssembleSignedSourceTests(
         template_deb_path = directory / "hello-signed_1.0+1_amd64.deb"
         code_signing_path = PurePath("usr/share/code-signing/hello-signed")
         source_template_path = code_signing_path / "source-template"
-        now = dt.datetime.now(dt.timezone.utc).strftime(
-            "%a, %d %b %Y %H:%M:%S %z"
-        )
+        now = dt.datetime.now(dt.UTC).strftime("%a, %d %b %Y %H:%M:%S %z")
         ArtifactPlayground.write_deb_file(
             template_deb_path,
             source_name="hello-signed",
@@ -1039,8 +1034,7 @@ class AssembleSignedSourceTests(
                 (
                     source_template_path / "debian/source/format"
                 ): b"3.0 (native)\n",
-                source_template_path
-                / "debian/changelog": dedent(
+                source_template_path / "debian/changelog": dedent(
                     f"""\
                     hello-signed (1.0+1) unstable; urgency=low
 
@@ -1049,8 +1043,7 @@ class AssembleSignedSourceTests(
                      -- Example Maintainer <example@example.org>  {now}
                     """
                 ).encode(),
-                source_template_path
-                / "debian/control": dedent(
+                source_template_path / "debian/control": dedent(
                     """\
                     Source: hello-signed
                     Section: admin
@@ -1109,7 +1102,7 @@ class AssembleSignedSourceTests(
             artifact_id: int,
             destination: Path,
             tarball: bool = False,
-            workspace: str | None = None,  # noqa: U100
+            workspace: str | None = None,  # noqa: ARG001, U100
         ) -> ArtifactResponse:
             assert not tarball
             for file_name in artifacts[artifact_id].files:
@@ -1119,7 +1112,7 @@ class AssembleSignedSourceTests(
             return artifacts[artifact_id]
 
         def relation_list(artifact_id: int) -> RelationsResponse:
-            return RelationsResponse.parse_obj(
+            return RelationsResponse.model_validate(
                 [
                     {
                         "id": 1,
@@ -1132,7 +1125,8 @@ class AssembleSignedSourceTests(
             )
 
         def artifact_get(
-            artifact_id: int, workspace: str  # noqa: U100
+            artifact_id: int,
+            workspace: str,  # noqa: ARG001, U100
         ) -> ArtifactResponse:
             return create_artifact_response(
                 id=6, category=artifact_categories[artifact_id]
@@ -1162,7 +1156,7 @@ class AssembleSignedSourceTests(
 
         def run(
             args: list[str],
-            run_as_root: bool = False,  # noqa: U100
+            run_as_root: bool = False,  # noqa: ARG001, U100
             **kwargs: Any,
         ) -> subprocess.CompletedProcess[AnyStr]:
             if args[0] == "apt-get":
