@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Unit tests for the Autopkgtest class."""
+
 import copy
 import datetime as dt
 import shlex
@@ -16,10 +17,7 @@ from pathlib import Path
 from typing import Any, cast
 from unittest.mock import MagicMock, call, create_autospec, patch
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
+import pydantic
 
 from debusine.artifacts.local_artifact import AutopkgtestArtifact
 from debusine.artifacts.models import (
@@ -27,14 +25,12 @@ from debusine.artifacts.models import (
     CollectionCategory,
     DebianAutopkgtest,
     DebianAutopkgtestResult,
-)
-from debusine.artifacts.models import DebianAutopkgtestResultStatus as rs
-from debusine.artifacts.models import (
     DebianAutopkgtestSource,
     DebianBinaryPackage,
     DebianSourcePackage,
     DebianUpload,
 )
+from debusine.artifacts.models import DebianAutopkgtestResultStatus as rs
 from debusine.client.debusine import Debusine
 from debusine.client.models import FileResponse, FilesResponseType
 from debusine.tasks import Autopkgtest, TaskConfigError
@@ -119,7 +115,7 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
             },
             multiple_lookups={
                 # input.binary_artifacts
-                (LookupMultiple.parse_obj([10, 11]), None): [
+                (LookupMultiple((10, 11)), None): [
                     ArtifactInfo(
                         id=10,
                         category=ArtifactCategory.BINARY_PACKAGE,
@@ -607,8 +603,8 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
 
     def test_compute_dynamic_data_context(self) -> None:
         """Dynamic data includes input context artifact IDs if relevant."""
-        binary_artifacts_lookup = LookupMultiple.parse_obj([10, 11])
-        self.task.data.input.context_artifacts = LookupMultiple.parse_obj(
+        binary_artifacts_lookup = LookupMultiple((10, 11))
+        self.task.data.input.context_artifacts = LookupMultiple.model_validate(
             {"collection": "bookworm@debian:suite"}
         )
         self.task_db.multiple_lookups[(binary_artifacts_lookup, None)] = [
@@ -658,7 +654,7 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
 
         source_artifact's category is unexpected.
         """
-        self.task.data.input.context_artifacts = LookupMultiple.parse_obj(
+        self.task.data.input.context_artifacts = LookupMultiple.model_validate(
             {"collection": "bookworm@debian:suite"}
         )
         self.task_db.single_lookups[(5, None)] = ArtifactInfo(
@@ -761,34 +757,6 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
 
         self.assertIn("-dd", cmdline)
 
-    def test_cmdline_extra_repositories_jessie(self) -> None:
-        """Ensure the --add-apt-source= parameter is passed to autopkgtest."""
-        self.configure_task(
-            override={
-                "extra_repositories": [
-                    {
-                        "url": "http://example.com/",
-                        "suite": "unstable",
-                        "components": ["main"],
-                    },
-                    {
-                        "url": "http://example.net/",
-                        "suite": "flat/",
-                    },
-                ],
-            }
-        )
-        self.set_dynamic_data()
-        self.mock_executor()
-        assert self.task.executor
-        self.task.executor.system_image.data["codename"] = "jessie"
-        cmdline = self.task._cmdline()
-
-        self.assertIn(
-            "--add-apt-source=deb http://example.com/ unstable main", cmdline
-        )
-        self.assertIn("--add-apt-source=deb http://example.net/ flat/", cmdline)
-
     def test_cmdline_extra_repositories_trixie(self) -> None:
         """Ensure the --copy= parameter is passed to autopkgtest."""
         self.set_dynamic_data()
@@ -1051,9 +1019,7 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
             category="Test",
             created_at=dt.datetime.now(),
             data={},
-            download_tar_gz_url=pydantic.parse_obj_as(
-                pydantic.AnyUrl, "https://example.com/not-used"
-            ),
+            download_tar_gz_url="https://example.com/not-used",
             files=FilesResponseType({}),
             files_to_upload=[],
         )
@@ -1066,16 +1032,10 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
                 size=4000,
                 checksums={},
                 type="file",
-                url=pydantic.parse_obj_as(
-                    pydantic.AnyUrl,
-                    "http://example.com/artifact/1/hello.orig.tar.gz",
-                ),
+                url="http://example.com/artifact/1/hello.orig.tar.gz",
             ),
             "hello.dsc": FileResponse(
-                size=258,
-                checksums={},
-                type="file",
-                url=pydantic.parse_obj_as(pydantic.AnyUrl, source_package_url),
+                size=258, checksums={}, type="file", url=source_package_url
             ),
         }
 
@@ -1087,9 +1047,7 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
             category="Test",
             created_at=dt.datetime.now(),
             data={},
-            download_tar_gz_url=pydantic.parse_obj_as(
-                pydantic.AnyUrl, "https://example.com/not-used"
-            ),
+            download_tar_gz_url="https://example.com/not-used",
             files=FilesResponseType(files),
             files_to_upload=[],
         )
@@ -1119,7 +1077,7 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
 
         debusine_mock.download_artifact.assert_has_calls(calls)
 
-        self.assertEqual(self.task._source_package_url, source_package_url)
+        self.assertEqual(str(self.task._source_package_url), source_package_url)
         self.assertEqual(self.task._source_package_path, "hello.dsc")
 
     def test_fetch_input_context_artifacts(self) -> None:
@@ -1131,7 +1089,7 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
         destination = self.create_temporary_directory()
 
         data_input = self.task.data.input
-        data_input.context_artifacts = LookupMultiple.parse_obj([50, 51])
+        data_input.context_artifacts = LookupMultiple((50, 51))
         assert self.task.dynamic_data
         self.task.dynamic_data.input_context_artifacts_ids = [50, 51]
 
@@ -1296,7 +1254,9 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
         self.task._source_package_path = "test"
         self.task._source_package_name = "hello"
         self.task._source_package_version = "2.0.5b"
-        self.task._source_package_url = "https://some-url.com/test"
+        self.task._source_package_url = pydantic.AnyUrl(
+            "https://some-url.com/test"
+        )
 
         self.task.upload_artifacts(exec_dir, execution_success=True)
 
@@ -1310,9 +1270,7 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
                 source_package=DebianAutopkgtestSource(
                     name="hello",
                     version="2.0.5b",
-                    url=pydantic.parse_obj_as(
-                        pydantic.AnyUrl, "https://some-url.com/test"
-                    ),
+                    url="https://some-url.com/test",
                 ),
                 architecture=self.task.data.build_architecture,
                 distribution="debian:bookworm",
