@@ -8,7 +8,9 @@
 # contained in the LICENSE file.
 
 """Unit tests for the makesourcepackageupload task support on the worker."""
+
 from pathlib import Path
+from typing import Any
 from unittest import mock
 from unittest.mock import call
 
@@ -54,9 +56,16 @@ class MakeSourcePackageUploadTests(
             self.task._debug_log_files_directory.cleanup()
         super().tearDown()
 
-    def test_compute_dynamic_data(self) -> None:
-        """Dynamic data receives relevant artifact IDs."""
-        task_db = FakeTaskDatabase(
+    def configure_task(
+        self,
+        task_data: dict[str, Any] | None = None,
+        override: dict[str, Any] | None = None,
+        remove: list[str] | None = None,
+    ) -> None:
+        """Perform further setup."""
+        super().configure_task(task_data, override, remove)
+
+        self.task_db = FakeTaskDatabase(
             single_lookups={
                 # environment
                 (
@@ -79,37 +88,25 @@ class MakeSourcePackageUploadTests(
             }
         )
 
+    def test_compute_dynamic_data(self) -> None:
+        """Dynamic data receives relevant artifact IDs."""
         self.assertEqual(
-            self.task.compute_dynamic_data(task_db),
+            self.task.compute_dynamic_data(self.task_db),
             MakeSourcePackageUploadDynamicData(
                 environment_id=1,
                 input_source_artifact_id=421,
                 subject="hello",
+                parameter_summary="hello_1.0",
             ),
         )
 
     def test_compute_dynamic_data_raise_task_config_error_source(self) -> None:
-        task_db = FakeTaskDatabase(
-            single_lookups={
-                # environment
-                (
-                    "debian/match:codename=bookworm:format=tarball:"
-                    "backend=unshare:variant=",
-                    CollectionCategory.ENVIRONMENTS,
-                ): ArtifactInfo(
-                    id=1,
-                    category=ArtifactCategory.SYSTEM_TARBALL,
-                    data=create_system_tarball_data(),
-                ),
-                # input.source_artifact
-                (421, None): ArtifactInfo(
-                    id=421,
-                    category=ArtifactCategory.BINARY_PACKAGE,
-                    data=DebianSourcePackage(
-                        name="hello", version="1.0", type="dpkg", dsc_fields={}
-                    ),
-                ),
-            }
+        self.task_db.single_lookups[(421, None)] = ArtifactInfo(
+            id=421,
+            category=ArtifactCategory.BINARY_PACKAGE,
+            data=DebianSourcePackage(
+                name="hello", version="1.0", type="dpkg", dsc_fields={}
+            ),
         )
 
         with self.assertRaisesRegex(
@@ -118,7 +115,7 @@ class MakeSourcePackageUploadTests(
             r"'debian:binary-package'. Valid categories: "
             r"\['debian:source-package'\]",
         ):
-            self.task.compute_dynamic_data(task_db)
+            self.task.compute_dynamic_data(self.task_db)
 
     def test_get_input_artifacts_ids(self) -> None:
         """Test get_input_artifacts_ids."""
@@ -367,7 +364,3 @@ class MakeSourcePackageUploadTests(
         # Assert that the artifacts were uploaded and relations created
         debusine_mock.upload_artifact.assert_has_calls(upload_artifact_calls)
         debusine_mock.relation_create.assert_has_calls(relation_create_calls)
-
-    def test_get_label(self) -> None:
-        """Test get_label."""
-        self.assertEqual(self.task.get_label(), "prepare source package upload")
