@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Unit tests for the piuparts task support on the worker."""
+
 import datetime as dt
 import shlex
 import tarfile
@@ -21,11 +22,6 @@ from unittest.mock import MagicMock, call
 
 from debian.debian_support import Version
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
 from debusine.artifacts import PiupartsArtifact
 from debusine.artifacts.models import (
     ArtifactCategory,
@@ -40,7 +36,6 @@ from debusine.client.models import (
     FileResponse,
     FilesResponseType,
     RelationType,
-    StrMaxLength255,
 )
 from debusine.tasks import Piuparts, TaskConfigError
 from debusine.tasks.models import (
@@ -121,7 +116,7 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
             },
             multiple_lookups={
                 # input.binary_artifacts
-                (LookupMultiple.parse_obj([421]), None): [
+                (LookupMultiple((421,)), None): [
                     ArtifactInfo(
                         id=421,
                         category=ArtifactCategory.UPLOAD,
@@ -236,7 +231,7 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
         }
         self.task_db.multiple_lookups = {
             # input.binary_artifacts
-            (LookupMultiple.parse_obj([421, 422]), None): [
+            (LookupMultiple((421, 422)), None): [
                 ArtifactInfo(
                     id=421,
                     category=ArtifactCategory.UPLOAD,
@@ -284,7 +279,7 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
             "^base_tgz: unexpected artifact category: 'debian:source-package'. "
             r"Valid categories: \['debian:system-tarball'\]$",
         ):
-            self.task.compute_dynamic_data(self.task_db),
+            self.task.compute_dynamic_data(self.task_db)
 
     def test_compute_dynamic_raise_config_task_error_wrong_binary_artifact(
         self,
@@ -294,7 +289,7 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
 
         binary_artifact artifact category is unexpected.
         """
-        self.task_db.multiple_lookups[(LookupMultiple.parse_obj([421]), None)][
+        self.task_db.multiple_lookups[(LookupMultiple((421,)), None)][
             0
         ].category = ArtifactCategory.SYSTEM_TARBALL
 
@@ -378,7 +373,9 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
         def _create_basetgz_file(
             artifact_id: int,
             destination: Path,
-            default_category: CollectionCategory | None = None,  # noqa: U100
+            default_category: (  # noqa: ARG001, U100
+                CollectionCategory | None
+            ) = None,
         ) -> ArtifactResponse:
             symlinks: list[tuple[Path, Path]] = []
             empty_files: list[Path] = []
@@ -397,9 +394,7 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
                 empty_files=empty_files,
             )
 
-            fake_url = pydantic.parse_obj_as(
-                pydantic.AnyUrl, "https://not-used"
-            )
+            fake_url = "https://not-used"
 
             data = DebianSystemTarball(
                 filename=filename,
@@ -416,9 +411,7 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
 
             file_model = FileResponse(
                 size=100,
-                checksums={
-                    "sha256": pydantic.parse_obj_as(StrMaxLength255, "not-used")
-                },
+                checksums={"sha256": "not-used"},
                 type="file",
                 url=fake_url,
             )
@@ -430,10 +423,9 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
                 workspace="System",
                 category=ArtifactCategory.SYSTEM_TARBALL,
                 created_at=dt.datetime.now(),
-                data=data.dict(),
-                download_tar_gz_url=pydantic.parse_obj_as(
-                    pydantic.AnyUrl,
-                    f"http://localhost/artifact/{artifact_id}?archive=tar.gz",
+                data=data.model_dump(),
+                download_tar_gz_url=(
+                    f"http://localhost/artifact/{artifact_id}?archive=tar.gz"
                 ),
                 files_to_upload=[],
                 files=files,
@@ -463,8 +455,7 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
         ).read_text()
         self.assertEqual(
             log_file_contents,
-            f"There must be at least one *.deb file. "
-            f"Current files: {files}\n",
+            f"There must be at least one *.deb file. Current files: {files}\n",
         )
 
     def test_configure_for_execution_prepare_executor_base_tgz(self) -> None:
@@ -475,6 +466,7 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
         self.patch_prepare_executor_instance()
 
         with (
+            mock.patch.object(self.task, "_base_tar_data", autospec=True),
             mock.patch.object(
                 self.task, "_prepare_base_tgz", autospec=True
             ) as prepare_base_tgz_mocked,
@@ -721,49 +713,35 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
                 ],
             )
 
-    def prepare_scripts(self, codename: str) -> str:
-        """Build and read the post_chroot_unpack_debusine script."""
+    def prepare_script(self, codename: str, script_name: str) -> str:
+        """Build scripts and return the contents of script_name."""
         directory = self.create_temporary_directory()
         with mock.patch.object(self.task, "_base_tar_data", autospec=True):
             assert self.task._base_tar_data
             self.task._base_tar_data.codename = codename
             self.task._prepare_scripts(directory)
-        script = directory / "post_chroot_unpack_debusine"
+        script = directory / script_name
         self.assertTrue(script.exists())
         return script.read_text()
 
-    def test_prepare_scripts_jessie(self) -> None:
-        """_prepare_scripts with oneline apt sources."""
-        self.configure_task(
-            override={
-                "extra_repositories": [
-                    {
-                        "url": "http://example.net",
-                        "suite": "bookworm",
-                        "components": ["main"],
-                        "signing_key": "KEY A",
-                    },
-                ]
-            }
-        )
+    def test_prepare_scripts_bad_permissions(self) -> None:
+        """_prepare_scripts overrides pre_remove_50_find_bad_permissions."""
         self.set_dynamic_data()
-        script = self.prepare_scripts("jessie")
-        self.assertIn("mkdir -p /etc/apt/keyrings\n", script)
-        key = shlex.quote("KEY A\n")
-        self.assertIn(
-            f"printf %s {key} > /etc/apt/keyrings/extra_apt_key_0.asc\n",
-            script,
+        script = self.prepare_script(
+            "trixie", "pre_remove_50_find_bad_permissions"
         )
-        source = shlex.quote(
-            "deb [signed-by=/etc/apt/keyrings/extra_apt_key_0.asc] "
-            "http://example.net bookworm main\n"
-        )
-        self.assertIn(
-            (
-                f"printf %s {source} > "
-                f"/etc/apt/sources.list.d/extra_repository_0.list\n"
-            ),
-            script,
+        self.assertIn("Skipping", script)
+
+    def test_prepare_scripts_install_useradd(self) -> None:
+        """_prepare_scripts adds a script to install useradd."""
+        self.set_dynamic_data()
+        script = self.prepare_script("trixie", "post_setup_00_passwd")
+        self.assertIn("apt-get -y install passwd", script)
+
+    def prepare_extra_repo_script(self, codename: str) -> str:
+        """Build and read the post_chroot_unpack_debusine_extra_repos script."""
+        return self.prepare_script(
+            codename, "post_chroot_unpack_debusine_extra_repos"
         )
 
     def test_prepare_scripts_buster(self) -> None:
@@ -781,7 +759,7 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
             }
         )
         self.set_dynamic_data()
-        script = self.prepare_scripts("buster")
+        script = self.prepare_extra_repo_script("buster")
         self.assertIn("mkdir -p /etc/apt/keyrings\n", script)
         key = shlex.quote("KEY A\n")
         self.assertIn(
@@ -792,7 +770,7 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
             textwrap.dedent(
                 """\
                 Types: deb
-                URIs: http://example.net
+                URIs: http://example.net/
                 Suites: bookworm
                 Components: main
                 Signed-By: /etc/apt/keyrings/extra_apt_key_0.asc
@@ -822,13 +800,13 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
             }
         )
         self.set_dynamic_data()
-        script = self.prepare_scripts("bookworm")
+        script = self.prepare_extra_repo_script("bookworm")
         self.assertNotIn("/etc/apt/keyrings", script)
         source = shlex.quote(
             textwrap.dedent(
                 """\
                 Types: deb
-                URIs: http://example.net
+                URIs: http://example.net/
                 Suites: bookworm
                 Components: main
                 Signed-By:
@@ -873,7 +851,7 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
             )
         )
         self.set_dynamic_data()
-        script = self.prepare_scripts("trixie")
+        script = self.prepare_extra_repo_script("trixie")
         self.assertNotIn("/etc/apt/keyrings", script)
         source = shlex.quote(
             textwrap.dedent(
@@ -898,15 +876,16 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
             script,
         )
 
-    def test_execution_consistency_no_errors(self) -> None:
+    def test_check_directory_for_consistency_errors_none(self) -> None:
         """There are no consistency errors."""
         build_directory = self.create_temporary_directory()
         (build_directory / self.task.CAPTURE_OUTPUT_FILENAME).touch()
         self.assertEqual(
-            self.task.execution_consistency_errors(build_directory), []
+            self.task.check_directory_for_consistency_errors(build_directory),
+            [],
         )
 
-    def test_execution_consistency_errors(self) -> None:
+    def test_check_directory_for_consistency_errors(self) -> None:
         """There is one consistency error: no piuparts.txt."""
         build_directory = self.create_temporary_directory()
 
@@ -914,7 +893,8 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
             f"{self.task.CAPTURE_OUTPUT_FILENAME} not in {build_directory}"
         )
         self.assertEqual(
-            self.task.execution_consistency_errors(build_directory), [expected]
+            self.task.check_directory_for_consistency_errors(build_directory),
+            [expected],
         )
 
     def test_upload_artifacts(self) -> None:
@@ -1023,6 +1003,7 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
                 "--allow-database",
                 "--warn-on-leftovers-after-purge",
                 f"--basetgz={self.task._base_tar}",
+                "--scriptsdir=/etc/piuparts/scripts",
                 f"--scriptsdir={self.task._scripts_dir}",
                 str(file1),
                 str(file2),
