@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Unit tests for the sbuild task support on the worker client."""
+
 import itertools
 import textwrap
 import types
@@ -394,7 +395,8 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
         debusine_mock = self.mock_debusine()
 
         def artifact_get(
-            artifact_id: int, workspace: str  # noqa: U100
+            artifact_id: int,
+            workspace: str,  # noqa: ARG001, U100
         ) -> ArtifactResponse:
             """Fake for debusine client artifact_get."""
             if artifact_id == source_artifact.id:
@@ -540,42 +542,11 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
         """Ensure --dist parameter is computed from data."""
         self.configure_task()
         self.set_dynamic_data()
-        self.patch_executor(codename="jessie")
+        self.patch_executor(codename="stretch")
 
         cmdline = self.task._cmdline()
 
-        self.assertIn("--dist=jessie", cmdline)
-
-    def test_cmdline_extra_repositories_jessie(self) -> None:
-        """Ensure the --extra-repository= parameter is passed to sbuild."""
-        self.configure_task(
-            override={
-                "extra_repositories": [
-                    {
-                        "url": "http://example.com/",
-                        "suite": "unstable",
-                        "components": ["main"],
-                    },
-                    {
-                        "url": "http://example.net/",
-                        "suite": "flat/",
-                    },
-                ],
-            }
-        )
-        self.set_dynamic_data()
-        self.patch_executor(codename="jessie")
-        env = self.task._cmd_env()
-        self.assertIsNone(env)
-
-        cmdline = self.task._cmdline()
-
-        self.assertIn(
-            "--extra-repository=deb http://example.com/ unstable main", cmdline
-        )
-        self.assertIn(
-            "--extra-repository=deb http://example.net/ flat/", cmdline
-        )
+        self.assertIn("--dist=stretch", cmdline)
 
     def test_cmdline_extra_repositories_deb822_keyring(self) -> None:
         """Ensure the --pre-build-commands= parameter is passed to sbuild."""
@@ -720,7 +691,7 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
             }
         )
         self.set_dynamic_data()
-        self.patch_executor(codename="jessie")
+        self.patch_executor(codename="stretch")
         cmdline = self.task._cmdline()
         self.assertIn("--make-binNMU=Rebuild for 64bit time_t", cmdline)
         self.assertIn("--append-to-version=+b1", cmdline)
@@ -740,7 +711,7 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
             }
         )
         self.set_dynamic_data()
-        self.patch_executor(codename="jessie")
+        self.patch_executor(codename="stretch")
         cmdline = self.task._cmdline()
         self.assertIn("--make-binNMU=Rebuild for 64bit time_t", cmdline)
         self.assertIn("--append-to-version=+b1", cmdline)
@@ -754,7 +725,7 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
         """Check that missing build_profiles key is handled."""
         self.configure_task()
         self.set_dynamic_data()
-        self.patch_executor(codename="jessie")
+        self.patch_executor(codename="stretch")
         cmdline = self.task._cmdline()
         for argument in cmdline:
             self.assertFalse(argument.startswith("--profiles="))
@@ -763,7 +734,7 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
         """Check that empty build_profiles don't appear on the command line."""
         self.configure_task(override={"build_profiles": []})
         self.set_dynamic_data()
-        self.patch_executor(codename="jessie")
+        self.patch_executor(codename="stretch")
         cmdline = self.task._cmdline()
         for argument in cmdline:
             self.assertFalse(argument.startswith("--profiles="))
@@ -772,7 +743,7 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
         """Check that build_profiles make it onto the command line."""
         self.configure_task(override={"build_profiles": ["nodoc", "nocheck"]})
         self.set_dynamic_data()
-        self.patch_executor(codename="jessie")
+        self.patch_executor(codename="stretch")
         cmdline = self.task._cmdline()
         self.assertIn("--profiles=nodoc,nocheck", cmdline)
 
@@ -780,7 +751,7 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
         """Check that environment isn't modified, without build_profiles."""
         self.configure_task(override={"build_profiles": ["cross"]})
         self.set_dynamic_data()
-        self.patch_executor(codename="jessie")
+        self.patch_executor(codename="stretch")
         env = self.task._cmd_env()
         self.assertIsNone(env)
 
@@ -790,7 +761,7 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
             override={"build_profiles": ["nodoc", "nocheck", "cross"]}
         )
         self.set_dynamic_data()
-        self.patch_executor(codename="jessie")
+        self.patch_executor(codename="stretch")
         env = self.task._cmd_env()
         self.assertIsInstance(env, dict)
         assert env
@@ -831,7 +802,7 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
         """The default build_dep_resolver doesn't generate arguments."""
         self.configure_task()
         self.set_dynamic_data()
-        self.patch_executor(codename="jessie")
+        self.patch_executor(codename="stretch")
         cmdline = self.task._cmdline()
         for argument in cmdline:
             self.assertFalse(argument.startswith("--build-dep-resolver="))
@@ -840,7 +811,7 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
         """The aspcud build_dep_resolver generates arguments."""
         self.configure_task(override={"build_dep_resolver": "aspcud"})
         self.set_dynamic_data()
-        self.patch_executor(codename="jessie")
+        self.patch_executor(codename="stretch")
         cmdline = self.task._cmdline()
         self.assertIn("--build-dep-resolver=aspcud", cmdline)
 
@@ -848,7 +819,7 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
         """The default aspcud_criteria doesn't generate arguments."""
         self.configure_task()
         self.set_dynamic_data()
-        self.patch_executor(codename="jessie")
+        self.patch_executor(codename="stretch")
         cmdline = self.task._cmdline()
         for argument in cmdline:
             self.assertFalse(argument.startswith("--aspcud-criteria="))
@@ -863,7 +834,7 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
             }
         )
         self.set_dynamic_data()
-        self.patch_executor(codename="jessie")
+        self.patch_executor(codename="stretch")
         cmdline = self.task._cmdline()
         self.assertIn(
             "--aspcud-criteria=-count(changed,APT-Release:=/a=experimental/)",
@@ -873,7 +844,7 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
     def test_cmdline_resolve_alternatives(self) -> None:
         self.configure_task(override={"resolve_alternatives": True})
         self.set_dynamic_data()
-        self.patch_executor(codename="jessie")
+        self.patch_executor(codename="stretch")
         cmdline = self.task._cmdline()
         self.assertIn("--resolve-alternatives", cmdline)
 
@@ -1288,7 +1259,7 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
         self.patch_sbuild_debusine()
         self.patch_fetch_input(return_value=True)
 
-        temporary_directory, *_ = self.patch_temporary_directory(3)
+        self.patch_temporary_directory(3)
 
         patcher_configure = mock.patch.object(
             self.task, "configure_for_execution"
@@ -1466,9 +1437,7 @@ class SbuildTests(ExternalTaskHelperMixin[Sbuild], TestCase):
                     work_request=self.task.work_request_id,
                 ),
                 call(
-                    Upload.create(
-                        changes_file=changes_file, exclude_files=set()
-                    ),
+                    Upload.create(changes_file=changes_file),
                     workspace=self.task.workspace_name,
                     work_request=self.task.work_request_id,
                 ),
@@ -1547,7 +1516,7 @@ broken-packages: 4
                         source=dsc["Source"],
                         version=dsc["Version"],
                         architecture=self.task._host_architecture,
-                        bd_uninstallable=DoseDistCheck.parse_obj(
+                        bd_uninstallable=DoseDistCheck.model_validate(
                             {
                                 "output-version": "1.2",
                                 "native-architecture": "amd64",
@@ -1633,7 +1602,7 @@ broken-packages: 1
         )
         self.assertEqual(
             self.task._extract_dose3_explanation(log_file),
-            DoseDistCheck.parse_obj(
+            DoseDistCheck.model_validate(
                 {
                     'output-version': '1.2',
                     'native-architecture': 'amd64',
@@ -1726,7 +1695,7 @@ broken-packages: 1
 
         self.assertEqual(
             self.task._extract_dose3_explanation(log_file),
-            DoseDistCheck.parse_obj(
+            DoseDistCheck.model_validate(
                 {
                     'output-version': '1.2',
                     'native-architecture': 'amd64',
@@ -1808,7 +1777,7 @@ broken-packages: 4
         )
         self.assertEqual(
             self.task._extract_dose3_explanation(log_file),
-            DoseDistCheck.parse_obj(
+            DoseDistCheck.model_validate(
                 {
                     'output-version': '1.2',
                     'report': [
@@ -1917,7 +1886,7 @@ broken-packages: 4
                 work_request=self.task.work_request_id,
             ),
             call(
-                Upload.create(changes_file=changes_file, exclude_files=set()),
+                Upload.create(changes_file=changes_file),
                 workspace=self.task.workspace_name,
                 work_request=self.task.work_request_id,
             ),
@@ -1980,7 +1949,9 @@ broken-packages: 4
         """The build directory is checked for consistency errors."""
 
         def populate_sbuild_directory(
-            cmd: list[str], working_directory: Path, **kwargs: Any  # noqa: U100
+            cmd: list[str],  # noqa: ARG001, U100
+            working_directory: Path,
+            **kwargs: Any,
         ) -> int:
             (dsc := working_directory / "hello.dsc").touch()
             self.write_changes_file(working_directory / "hello.changes", [dsc])
@@ -2495,24 +2466,22 @@ broken-packages: 4
                 BinaryPackage(
                     category=BinaryPackage._category,
                     files={package_file.name: package_file},
-                    data=DebianBinaryPackage.parse_obj(
-                        {
-                            "srcpkg_name": dsc_data["Source"],
-                            "srcpkg_version": dsc_data["Version"],
-                            "deb_fields": {
-                                "Package": "package",
-                                "Version": "1.0",
-                                "Architecture": "amd64",
-                                "Maintainer": "Example Maintainer"
-                                " <example@example.org>",
-                                "Description": "Example description",
-                                "Source": (
-                                    f"{dsc_data['Source']} "
-                                    f"({dsc_data['Version']})"
-                                ),
-                            },
-                            "deb_control_files": ["control"],
-                        }
+                    data=DebianBinaryPackage(
+                        srcpkg_name=dsc_data["Source"],
+                        srcpkg_version=dsc_data["Version"],
+                        deb_fields={
+                            "Package": "package",
+                            "Version": "1.0",
+                            "Architecture": "amd64",
+                            "Maintainer": (
+                                "Example Maintainer <example@example.org>"
+                            ),
+                            "Description": "Example description",
+                            "Source": (
+                                f"{dsc_data['Source']} ({dsc_data['Version']})"
+                            ),
+                        },
+                        deb_control_files=["control"],
                     ),
                 ),
             ],
