@@ -104,15 +104,15 @@ class TestCase(unittest.TestCase):
             self.get_precious_globals(),
         )
 
-    def create_temp_config_directory(self, config: dict[str, Any]) -> str:
+    def create_temp_config_directory(self, config: dict[str, Any]) -> Path:
         """
         Create a temp directory with a config.ini file inside.
 
         The method also register the automatic removal of said directory.
         """
-        temp_directory = tempfile.mkdtemp()
-        config_file_name = os.path.join(temp_directory, 'config.ini')
-        with open(config_file_name, 'w') as config_file:
+        temp_directory = Path(tempfile.mkdtemp())
+        config_file_name = temp_directory / 'config.ini'
+        with config_file_name.open('w') as config_file:
             config_writer = ConfigParser()
 
             for section, values in config.items():
@@ -247,7 +247,7 @@ class TestCase(unittest.TestCase):
     @contextlib.contextmanager
     def assertLogsContains(
         self, message: str, expected_count: int = 1, **assert_logs_kwargs: Any
-    ) -> "Generator[_LoggingWatcher, None, None]":
+    ) -> "Generator[_LoggingWatcher]":
         """
         Raise failureException if message is not in the logs.
 
@@ -694,7 +694,7 @@ class TestCase(unittest.TestCase):
                 " a YYYY-MM-DD HH:MM datetime"
             )
         actual = dt.datetime.strptime(m.group(), "%Y-%m-%d %H:%M").replace(
-            tzinfo=dt.timezone.utc
+            tzinfo=dt.UTC
         )
         expected = d.replace(second=0, microsecond=0)
         self.assertEqual(actual, expected)
