@@ -20,18 +20,15 @@ import itertools
 import json
 import traceback
 import unittest
-from collections.abc import Callable
+from collections.abc import Callable, Generator, Sequence
 from collections.abc import Collection as AbcCollection
-from collections.abc import Generator, Sequence
 from operator import itemgetter
 from pathlib import Path
 from typing import (
     Any,
     ClassVar,
-    Generic,
     Protocol,
     TYPE_CHECKING,
-    TypeVar,
     Union,
     cast,
     runtime_checkable,
@@ -46,9 +43,18 @@ import requests
 from asgiref.sync import async_to_sync
 from channels.layers import get_channel_layer
 from django.conf import settings
-from django.db import OperationalError, connection, connections, transaction
+from django.core.signals import request_finished
+from django.db import (
+    OperationalError,
+    close_old_connections,
+    connection,
+    connections,
+    transaction,
+)
 from django.db.models import Model, QuerySet
+from django.http import HttpRequest
 from django.http.response import HttpResponseBase
+from django.template import engines
 from django.test.client import JSON_CONTENT_TYPE_RE
 from rest_framework import status
 
@@ -66,7 +72,6 @@ from debusine.db.models.permissions import (
     Allow,
     PermissionCheckPredicate,
     PermissionUser,
-    Roles,
     get_resource_scope,
     get_resource_workspace,
     resolve_roles_list,
@@ -77,7 +82,7 @@ from debusine.tasks.models import BaseTaskDataModel
 from debusine.test.playground import Playground
 
 # Relative import needed to break an import loop
-from .base import TestCase as BaseTestCase  # noqa: ABS101
+from .base import TestCase as BaseTestCase  # noqa: ABS101, TID252
 
 if TYPE_CHECKING:
     from django.test.client import _MonkeyPatchedWSGIResponse
@@ -86,16 +91,13 @@ if TYPE_CHECKING:
 else:
     TestMixinBase = object
 
-M = TypeVar("M", bound=Model)
-R = TypeVar("R", bound=Roles)
-
 #: Type alias for response objects returned by the Django test client
 type TestResponseType = "_MonkeyPatchedWSGIResponse"
 #: Type alias for any response type
 type AnyResponseType = Union[HttpResponseBase, "_MonkeyPatchedWSGIResponse"]
 
 
-class PermissionOverride(abc.ABC, Generic[M]):
+class PermissionOverride[M: Model](abc.ABC):
     """Base class for configurable permission overrides for tests."""
 
     @abc.abstractmethod
@@ -109,35 +111,39 @@ class PermissionOverride(abc.ABC, Generic[M]):
         """Filter a QuerySet with the predicate."""
 
 
-class AllowAll(PermissionOverride[M]):
+class AllowAll[M: Model](PermissionOverride[M]):
     """Permission override allowing all."""
 
-    def check(self, obj: M, user: PermissionUser) -> bool:  # noqa: U100
+    def check(self, obj: M, user: PermissionUser) -> bool:  # noqa: ARG002, U100
         """Test the predicate on an object."""
         return True
 
     def filter(
-        self, queryset: QuerySet[M, M], user: PermissionUser  # noqa: U100
+        self,
+        queryset: QuerySet[M, M],
+        user: PermissionUser,  # noqa: ARG002, U100
     ) -> QuerySet[M, M]:
         """Filter a QuerySet with the predicate."""
         return queryset
 
 
-class DenyAll(PermissionOverride[M]):
+class DenyAll[M: Model](PermissionOverride[M]):
     """Permission override denying all."""
 
-    def check(self, obj: M, user: PermissionUser) -> bool:  # noqa: U100
+    def check(self, obj: M, user: PermissionUser) -> bool:  # noqa: ARG002, U100
         """Test the predicate on an object."""
         return False
 
     def filter(
-        self, queryset: QuerySet[M, M], user: PermissionUser  # noqa: U100
+        self,
+        queryset: QuerySet[M, M],
+        user: PermissionUser,  # noqa: ARG002, U100
     ) -> QuerySet[M, M]:
         """Filter a QuerySet with the predicate."""
         return queryset.none()
 
 
-class ListFilter(PermissionOverride[M]):
+class ListFilter[M: Model](PermissionOverride[M]):
     """Permission override that includes or excludes specific items."""
 
     def __init__(
@@ -148,7 +154,7 @@ class ListFilter(PermissionOverride[M]):
         self._include = include
         self._exclude = exclude
 
-    def check(self, obj: M, user: PermissionUser) -> bool:  # noqa: U100
+    def check(self, obj: M, user: PermissionUser) -> bool:  # noqa: ARG002, U100
         """Test the predicate on an object."""
         if self._include is not None:
             return obj in self._include
@@ -157,7 +163,9 @@ class ListFilter(PermissionOverride[M]):
         return True
 
     def filter(
-        self, queryset: QuerySet[M, M], user: PermissionUser  # noqa: U100
+        self,
+        queryset: QuerySet[M, M],
+        user: PermissionUser,  # noqa: ARG002, U100
     ) -> QuerySet[M, M]:
         """Filter a QuerySet with the predicate."""
         res = queryset
@@ -180,7 +188,7 @@ def set_context_for_resource(resource: Model, user: PermissionUser) -> None:
 
 
 @contextlib.contextmanager
-def override_permission(
+def override_permission[M: Model](
     model_cls: type[M],
     pred: str,
     override_cls: type[PermissionOverride[M]],
@@ -639,7 +647,7 @@ class BaseDjangoTestCase(django.test.SimpleTestCase, BaseTestCase):
             self.assertNotIn(resource, list(filtered))
 
     @context.local()
-    def _test_check_predicate(
+    def _test_check_predicate[M: Model](
         self,
         user: PermissionUser,
         obj: M,
@@ -692,8 +700,29 @@ class BaseDjangoTestCase(django.test.SimpleTestCase, BaseTestCase):
 
         return errors
 
+    def _check_predicate_filter_output(
+        self,
+        prefix: str,
+        filtered: list[str],
+        expected: list[str],
+        errors: list[str],
+    ) -> None:
+        if filtered == expected:
+            return
+        error = prefix
+        if filtered:
+            error += ", ".join(filtered)
+        else:
+            error += "nothing"
+        error += " instead of "
+        if expected:
+            error += ", ".join(expected)
+        else:
+            error += "nothing"
+        errors.append(error)
+
     @context.local()
-    def assertPermission(  # noqa: C901
+    def assertPermission[M: Model](
         self,
         name: str,
         users: PermissionUser | AbcCollection[PermissionUser],
@@ -741,24 +770,27 @@ class BaseDjangoTestCase(django.test.SimpleTestCase, BaseTestCase):
             # Pick the model class from the first element of allow or
             # denied
             model_cls = next(itertools.chain(allowed, denied)).__class__
-            manager = getattr(model_cls, "objects")
+            queryset = getattr(model_cls, "objects")
+            filter_predicate = getattr(queryset, name)
 
-            filtered = sorted(
-                str(obj) for obj in getattr(manager, name)(user=user)
-            )
+            # Check that there are no allowed resources that weren't in the
+            # allowed list
+            filtered = sorted(str(obj) for obj in filter_predicate(user=user))
             expected = sorted(str(obj) for obj in allowed)
-            if filtered != expected:
-                error = f"{name} for {user} selects "
-                if filtered:
-                    error += ", ".join(filtered)
-                else:
-                    error += "nothing"
-                error += " instead of "
-                if expected:
-                    error += ", ".join(expected)
-                else:
-                    error += "nothing"
-                errors.append(error)
+            self._check_predicate_filter_output(
+                f"{name} for {user} selects ", filtered, expected, errors
+            )
+
+            # Check that there are no allowed resources that weren't in the
+            # allowed list
+            filtered = sorted(
+                str(obj)
+                for obj in queryset.exclude(pk__in=filter_predicate(user=user))
+            )
+            expected = sorted(str(obj) for obj in denied)
+            self._check_predicate_filter_output(
+                f"{name} for {user} denies ", filtered, expected, errors
+            )
 
         if errors:
             with io.StringIO() as buf:
@@ -816,6 +848,31 @@ class BaseDjangoTestCase(django.test.SimpleTestCase, BaseTestCase):
             ),
         )
 
+    def close_streaming_response(self, response: HttpResponseBase) -> None:
+        """Close a streaming response without reading the rest of its data."""
+        # See https://code.djangoproject.com/ticket/35618
+        #
+        # django.test.client.ClientHandler does this when closing a response in
+        # the non-streaming case, but I cannot find a standard way to close a
+        # streaming response without invalidating the database connection held
+        # by the tests, which will cause further tests to fail.
+        #
+        # This is a copy of what django.test.client.ClientHandler does in the
+        # non-streaming case
+        request_finished.disconnect(close_old_connections)
+        response.close()  # will fire request_finished
+        request_finished.connect(close_old_connections)
+
+    def render_string(
+        self,
+        template_code: str,
+        request: HttpRequest,
+        **context: Any,
+    ) -> str:
+        """Render a template from a string."""
+        template = engines["django"].from_string(template_code)
+        return template.render(context, request=request)
+
 
 class PlaygroundTestCase(BaseDjangoTestCase):
     """
