@@ -632,7 +632,9 @@ class TestCaseTests(TestCase):
             "* can_display is True for playground on debusine/System"
             " with scope and workspace set in context\n"
             "* can_display for playground selects debusine/System"
-            " instead of debusine/private\n",
+            " instead of debusine/private\n"
+            "* can_display for playground denies debusine/private"
+            " instead of debusine/System\n",
         )
 
         with self.assertRaises(self.failureException) as exc:
@@ -669,9 +671,53 @@ class TestCaseTests(TestCase):
             "* can_display is False for playground on debusine/System"
             " with scope set in context\n"
             "* can_display for playground selects nothing"
-            " instead of debusine/System\n",
+            " instead of debusine/System\n"
+            "* can_display for playground denies debusine/System"
+            " instead of nothing\n",
         )
 
+    def test_assertPermission_denied(self) -> None:
+        """Test assertPermission failure reporting."""
+        workspace = self.playground.get_default_workspace()
+        workspace.public = False
+        workspace.save()
+        workspace1 = self.playground.create_workspace(
+            name="other", public=False
+        )
+
+        with self.assertRaises(self.failureException) as exc:
+            self.assertPermission(
+                "can_display",
+                users=[self.playground.get_default_user()],
+                denied=[workspace],
+            )
+        self.assertEqual(
+            exc.exception.args[0],
+            "Predicate permission mismatch:\n"
+            f"* can_display for playground denies {workspace}, {workspace1}"
+            f" instead of {workspace}\n",
+        )
+
+    def test_check_predicate_filter_output(self) -> None:
+        for prefix, filtered, expected, message in (
+            ("has ", [], [], None),
+            ("has ", ["a"], ["a"], None),
+            ("has ", ["a"], [], "has a instead of nothing"),
+            ("has ", [], ["a"], "has nothing instead of a"),
+            ("has ", ["a", "b"], ["1", "2"], "has a, b instead of 1, 2"),
+        ):
+            with self.subTest(
+                prefix=prefix, filtered=filtered, expected=expected
+            ):
+                errors: list[str] = []
+                self._check_predicate_filter_output(
+                    prefix, filtered, expected, errors
+                )
+                if message is None:
+                    self.assertEqual(errors, [])
+                else:
+                    self.assertEqual(errors, [message])
+
     def test_build_permission_when_role_testlist(self) -> None:
         """Test the _build_permission_when_role_testlist method."""
         scope = self.playground.get_or_create_scope("scope")
@@ -1013,7 +1059,9 @@ class AssertRolePredicateTests(TestCase):
     def test_queryset_filter_undecorated(self) -> None:
         class TestQuerySet(QuerySet[Workspace]):
             def with_role(
-                self, user: PermissionUser, role: Workspace.Roles  # noqa: U100
+                self,
+                user: PermissionUser,
+                role: Workspace.Roles,  # noqa: U100
             ) -> Self:
                 raise NotImplementedError()
 
@@ -1032,7 +1080,9 @@ class AssertRolePredicateTests(TestCase):
     def test_queryset_filter_wrong_result(self) -> None:
         class TestQuerySet(QuerySet[Workspace]):
             def with_role(
-                self, user: PermissionUser, role: Workspace.Roles  # noqa: U100
+                self,
+                user: PermissionUser,
+                role: Workspace.Roles,  # noqa: U100
             ) -> Self:
                 raise NotImplementedError()
 
@@ -1050,7 +1100,9 @@ class AssertRolePredicateTests(TestCase):
     def test_queryset_filter_wrong_role(self) -> None:
         class TestQuerySet(QuerySet[Workspace]):
             def with_role(
-                self, user: PermissionUser, role: Workspace.Roles  # noqa: U100
+                self,
+                user: PermissionUser,
+                role: Workspace.Roles,  # noqa: U100
             ) -> Self:
                 raise NotImplementedError()
 
