@@ -41,7 +41,7 @@ class SnapshotConverterTests(TestCase):
             {
                 "scope": "test-scope",
                 "workspace": "test-workspace",
-                "snapshot": dt.datetime(2025, 5, 1, tzinfo=dt.timezone.utc),
+                "snapshot": dt.datetime(2025, 5, 1, tzinfo=dt.UTC),
             },
         )
         self.assertEqual(reverse("archive", kwargs=match.kwargs), url)
