@@ -13,21 +13,21 @@ import datetime as dt
 import re
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
-from typing import Any
+from typing import Any, override
 
 from django.conf import settings
+from django.core.handlers.exception import response_for_exception
 from django.db.models import QuerySet
 from django.db.models.fields.json import KT
-from django.http import Http404, HttpRequest, HttpResponseBase
+from django.http import Http404, HttpRequest, HttpResponse, HttpResponseBase
 from django.shortcuts import get_object_or_404
 from django.utils.cache import patch_cache_control, patch_vary_headers
-from rest_framework import status
-from rest_framework.renderers import TemplateHTMLRenderer
-from rest_framework.request import Request
-from rest_framework.response import Response
+from django.views.generic import TemplateView
+from pgpy import PGPKey
 
 from debian import deb822
 from debusine.artifacts.models import ArtifactCategory, CollectionCategory
+from debusine.assets.asset_utils import ExportablePGPKeyring
 from debusine.db.context import context
 from debusine.db.models import Asset, Collection, CollectionItem, FileInArtifact
 from debusine.db.models.assets import get_public_keys
@@ -35,11 +35,8 @@ from debusine.server.collections.debian_suite import (
     DebianSuiteManager,
     make_source_prefix,
 )
-from debusine.server.exceptions import DebusineAPIException
-from debusine.server.views.base import BaseAPIView
 from debusine.web.archives.converters import SnapshotConverter
-from debusine.web.archives.negotiation import IgnoreClientContentNegotiation
-from debusine.web.archives.renderers import SigningKeysRenderer
+from debusine.web.views.base import BaseUIView
 from debusine.web.views.files import FileDownloadMixin, FileUI
 
 
@@ -109,9 +106,24 @@ class RenderableSuite:
         return source.dump()
 
 
-class ArchiveView(BaseAPIView, ABC):
+class SigningKeysResponse(HttpResponse):
+    """A renderer for OpenPGP signing keys."""
+
+    def __init__(self, keys: list[bytes]) -> None:
+        """Construct an HTTP response from a list of keys."""
+        content = str(
+            ExportablePGPKeyring(*(PGPKey.from_blob(key)[0] for key in keys))
+        )
+        super().__init__(
+            content=content.encode("utf-8"),
+            content_type="application/pgp-keys; charset=utf-8",
+        )
+
+
+class ArchiveView(BaseUIView, ABC):
     """A view of something in an archive."""
 
+    base_template = "web/_base_archives.html"
     archive: Collection
 
     @property
@@ -155,13 +167,9 @@ class ArchiveView(BaseAPIView, ABC):
                 workspace=workspace, category=CollectionCategory.ARCHIVE
             )
         except Collection.DoesNotExist:
-            raise DebusineAPIException(
-                title="Archive not found",
-                detail=(
-                    f"No {CollectionCategory.ARCHIVE} collection found in "
-                    f"{workspace}"
-                ),
-                status_code=status.HTTP_404_NOT_FOUND,
+            raise Http404(
+                f"No {CollectionCategory.ARCHIVE} collection found in "
+                f"{workspace}"
             )
         self.enforce(self.archive.can_display)
 
@@ -169,22 +177,23 @@ class ArchiveView(BaseAPIView, ABC):
         self, request: HttpRequest, *args: Any, **kwargs: Any
     ) -> HttpResponseBase:
         """Dispatch the request, setting appropriate response headers."""
-        response = super().dispatch(request, *args, **kwargs)
+        try:
+            response = super().dispatch(request, *args, **kwargs)
+        except Exception as exc:
+            response = response_for_exception(request, exc)
         patch_cache_control(response, **self.cache_control)
         patch_vary_headers(response, ("Authorization",))
         return response
 
 
-class ArchiveRootView(ArchiveView):
+class ArchiveRootView(ArchiveView, TemplateView):
     """The root of an archive."""
 
-    renderer_classes = [TemplateHTMLRenderer]
     template_name = "web/archive-root.html"
 
-    def get(
-        self, request: Request, *args: Any, **kwargs: Any  # noqa: U100
-    ) -> Response:
-        """Describe an archive."""
+    @override
+    def get_context_data(self, *args: Any, **kwargs: Any) -> dict[str, Any]:
+        ctx = super().get_context_data(**kwargs)
         self.set_archive()
         suites: list[RenderableSuite] = []
         for suite in self.get_suites().order_by("name"):
@@ -195,54 +204,41 @@ class ArchiveRootView(ArchiveView):
                     collection=suite,
                 )
             )
-        return Response(
-            {
-                "base_template": "web/_base_unscoped.html",
-                "suites": suites,
-                "scope": self.kwargs["scope"],
-            }
-        )
+        ctx["suites"] = suites
+        return ctx
 
 
-class SuiteRootView(ArchiveView):
+class SuiteRootView(ArchiveView, TemplateView):
     """The root of a suite."""
 
-    renderer_classes = [TemplateHTMLRenderer]
     template_name = "web/suite-root.html"
 
-    def get(
-        self, request: Request, *args: Any, **kwargs: Any  # noqa: U100
-    ) -> Response:
-        """Describe a suite."""
+    @override
+    def get_context_data(self, *args: Any, **kwargs: Any) -> dict[str, Any]:
+        ctx = super().get_context_data(**kwargs)
         self.set_archive()
         try:
             suite = self.get_suites().get()
         except Collection.DoesNotExist:
-            raise DebusineAPIException(
-                title="Suite not found", status_code=status.HTTP_404_NOT_FOUND
-            )
+            raise Http404("Suite not found")
         assert suite is not None
-        return Response(
-            {
-                "base_template": "web/_base_unscoped.html",
-                "suite": RenderableSuite(
-                    request_scheme=self.request.scheme or "http",
-                    snapshot=self.kwargs.get("snapshot"),
-                    collection=suite,
-                ),
-                "scope": self.kwargs["scope"],
-            }
+        ctx["suite"] = RenderableSuite(
+            request_scheme=self.request.scheme or "http",
+            snapshot=self.kwargs.get("snapshot"),
+            collection=suite,
         )
+        return ctx
 
 
 class SigningKeysView(ArchiveView):
     """Signing keys for an archive or a suite."""
 
-    renderer_classes = [SigningKeysRenderer]
-
     def get(
-        self, request: Request, *args: Any, **kwargs: Any  # noqa: U100
-    ) -> Response:
+        self,
+        request: HttpRequest,  # noqa: ARG002, U100
+        *args: Any,
+        **kwargs: Any,
+    ) -> HttpResponse:
         """Show signing keys for an archive or a suite."""
         self.set_archive()
         signing_keys: set[Asset] = set()
@@ -250,14 +246,12 @@ class SigningKeysView(ArchiveView):
             signing_keys.update(
                 DebianSuiteManager(suite).get_signing_keys() or []
             )
-        return Response({"signing_keys": list(get_public_keys(signing_keys))})
+        return SigningKeysResponse(list(get_public_keys(signing_keys)))
 
 
 class ArchiveFileView(ArchiveView, FileDownloadMixin, ABC):
     """A file in an archive."""
 
-    content_negotiation_class = IgnoreClientContentNegotiation
-
     @abstractmethod
     def get_collection_items(self) -> QuerySet[CollectionItem]:
         """
@@ -283,16 +277,14 @@ class ArchiveFileView(ArchiveView, FileDownloadMixin, ABC):
         )
 
     def get(
-        self, request: Request, *args: Any, **kwargs: Any  # noqa: U100
+        self,
+        request: HttpRequest,  # noqa: ARG002, U100
+        *args: Any,
+        **kwargs: Any,
     ) -> HttpResponseBase:
         """Download a file."""
         self.set_archive()
-        try:
-            file_in_artifact = get_object_or_404(self.get_queryset())
-        except Http404 as exc:
-            raise DebusineAPIException(
-                title=str(exc), status_code=status.HTTP_404_NOT_FOUND
-            )
+        file_in_artifact = get_object_or_404(self.get_queryset())
         ui_info = FileUI.from_file_in_artifact(file_in_artifact)
         return self.stream_file(file_in_artifact, ui_info)
 
@@ -410,10 +402,7 @@ class PoolFileView(SuiteFileView):
         if self.kwargs["sourceprefix"] != make_source_prefix(
             self.kwargs["source"]
         ):
-            raise DebusineAPIException(
-                title="No FileInArtifact matches the given query.",
-                status_code=status.HTTP_404_NOT_FOUND,
-            )
+            raise Http404("No FileInArtifact matches the given query.")
 
         qs = (
             super()
