@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """debusine template context processors."""
+
 from typing import Any, TYPE_CHECKING
 
 from django.conf import settings
@@ -17,7 +18,7 @@ if TYPE_CHECKING:  # pragma: no cover
 
 
 def server_info(
-    request: "django.http.HttpRequest",  # noqa: U100
+    request: "django.http.HttpRequest",  # noqa: ARG001, U100
 ) -> dict[str, Any]:
     """Add general server information to the request context."""
     return {
@@ -26,7 +27,7 @@ def server_info(
 
 
 def application_context(
-    request: "django.http.HttpRequest",  # noqa: U100
+    request: "django.http.HttpRequest",  # noqa: ARG001, U100
 ) -> dict[str, Any]:
     """Add general server information to the request context."""
     from debusine.db.context import context
