@@ -33,7 +33,7 @@ class LoginTests(ViewTestMixin, TestCase):
 
         # Has "next" form hidden field
         input_next = tree.xpath(
-            ".//form//input[@name='next' and @type='hidden']"
+            ".//form[@id='login-form']//input[@name='next' and @type='hidden']"
         )
 
         self.assertEqual(len(input_next), 1)
@@ -54,10 +54,10 @@ class LoginTests(ViewTestMixin, TestCase):
 
     def test_view_login_without_next(self) -> None:
         """
-        _base.html do not include ?next=login path.
+        Base templates do not include ?next=login path.
 
-        URL for login add is_login_view, _base.html use the variable
-        to not add ?next={next_path}
+        URL for login add is_login_view, base templates use the variable to not
+        add ?next={next_path}
         """
         response = self.client.get(reverse("login"))
 
@@ -70,10 +70,10 @@ class LogoutTests(ViewTestMixin, TestCase):
 
     def test_view_login_without_next(self) -> None:
         """
-        _base.html do not include ?next=logout path.
+        Base templates do not include ?next=logout path.
 
-        URL for logout add is_logout_view, _base.html use the variable
-        to not add ?next={next_path}
+        URL for logout add is_logout_view, base templates use the variable to
+        not add ?next={next_path}
         """
         response = self.client.post(reverse("logout"))
 
@@ -81,7 +81,7 @@ class LogoutTests(ViewTestMixin, TestCase):
         self.assertNotContains(response, f"?next={next_path}")
 
     def test_view_login_with_next(self) -> None:
-        """_base.html do include ?next=workspaces_list path."""
+        """Base templates do include ?next=workspaces_list path."""
         next_path = reverse("scopes:detail")
         response = self.client.get(next_path)
         self.assertContains(response, f"?next={next_path}")
