@@ -8,12 +8,15 @@
 # contained in the LICENSE file.
 
 """Tests for the forms."""
+
 import datetime as dt
 import textwrap
 from pathlib import Path
 from typing import Any, ClassVar, override
 from unittest import mock
 
+import pydantic
+import yaml
 from django import forms
 from django.contrib.auth import get_user_model
 from django.core.files.uploadedfile import SimpleUploadedFile
@@ -21,13 +24,6 @@ from django.forms.fields import InvalidJSONInput
 from django.test import RequestFactory
 from django.utils.datastructures import MultiValueDict
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic  # type: ignore
-
-import yaml
-
 from debusine.artifacts import PackageBuildLog
 from debusine.artifacts.models import (
     ArtifactCategory,
@@ -479,7 +475,7 @@ class WorkRequestFormTests(TestCase):
         self.assertFalse(form.is_valid())
         self.assertRegex(
             str(form.errors["task_data"][0]),
-            r'environment\s+field required \(type=value_error\.missing\)',
+            r"environment\s+Field required.*type=missing",
         )
 
     def test_clean_data_yaml_return_dictionary(self) -> None:
@@ -745,12 +741,12 @@ class ArtifactFormTests(TestCase):
         with self.assertRaises(pydantic.ValidationError) as raised:
             PackageBuildLog(
                 category=category,
-                data=DebianPackageBuildLog.parse_obj(data),
+                data=DebianPackageBuildLog.model_validate(data),
                 files={file_name: Path("not-used.txt")},
             )
 
         self.assertEqual(
-            form.errors, {"files": [str(raised.exception.args[0][0].exc)]}
+            form.errors, {"files": [str(raised.exception.errors()[0]["msg"])]}
         )
 
     def test_data_invalid(self) -> None:
@@ -789,12 +785,12 @@ class ArtifactFormTests(TestCase):
         with self.assertRaises(pydantic.ValidationError) as raised:
             PackageBuildLog(
                 category=category,
-                data=DebianPackageBuildLog.parse_obj(data),
+                data=DebianPackageBuildLog.model_validate(data),
                 files={file_name: Path("not-used.txt")},
             )
 
         self.assertEqual(
-            form.errors, {"files": [str(raised.exception.args[0][0].exc)]}
+            form.errors, {"files": [str(raised.exception.errors()[0]["msg"])]}
         )
 
 
