@@ -21,6 +21,11 @@ urlpatterns = [
         views.CollectionListView.as_view(),
         name="list",
     ),
+    path(
+        "create/",
+        views.CollectionCreateView.as_view(),
+        name="create",
+    ),
     path(
         "<str:ccat>/",
         views.CollectionCategoryListView.as_view(),
@@ -31,13 +36,23 @@ urlpatterns = [
         views.CollectionDetailView.as_view(),
         name="detail",
     ),
+    path(
+        "<str:ccat>/<str:cname>/update/",
+        views.CollectionUpdateView.as_view(),
+        name="update",
+    ),
     path(
         "<str:ccat>/<str:cname>/search/",
         views.CollectionSearchView.as_view(),
         name="search",
     ),
     path(
-        "<str:ccat>/<str:cname>/item/<str:iid>/<str:iname>/",
+        "<str:ccat>/<str:cname>/delete/",
+        views.CollectionDeleteView.as_view(),
+        name="delete",
+    ),
+    path(
+        "<str:ccat>/<str:cname>/item/<str:iid>/<path:iname>/",
         views.CollectionItemDetailView.as_view(),
         name="item_detail",
     ),
