@@ -277,7 +277,9 @@ class FileDetailViewRaw(FileView):
         return self.object.ui(self.request).place_raw
 
     def get(
-        self, request: HttpRequest, **kwargs: Any  # noqa: U100
+        self,
+        request: HttpRequest,  # noqa: ARG002, U100
+        **kwargs: Any,
     ) -> HttpResponseBase:
         """Download file with disposition inline."""
         self.object = self.get_object()
