@@ -12,7 +12,6 @@
 import abc
 import logging
 from collections.abc import Callable
-from importlib.metadata import PackageNotFoundError, version
 from typing import Any, NoReturn, TYPE_CHECKING
 
 from django.core.exceptions import PermissionDenied
@@ -38,6 +37,8 @@ from debusine.db.models.permissions import (
     PermissionUser,
     format_permission_check_error,
 )
+from debusine.utils import debusine_version
+from debusine.web.views.places import IndexPlace, Place
 
 if TYPE_CHECKING:
     CreateViewBase = CreateView
@@ -109,7 +110,7 @@ class Widget(abc.ABC):
 class BaseUIView(ContextMixin, View):
     """Base class for Debusine web views."""
 
-    base_template = "web/_base.html"
+    base_template = "web/_base_scoped.html"
     title = ""
 
     # If a member is defined for these methods
@@ -142,9 +143,9 @@ class BaseUIView(ContextMixin, View):
         checks.
         """
 
-    def get_title(self) -> str:
-        """Get the title for the page."""
-        return self.title
+    def get_place(self) -> Place:
+        """Get a Place object for this page."""
+        return IndexPlace(title=self.title, url=self.request.get_full_path())
 
     def get_base_template(self) -> str:
         """Return the name of the base template to use with this view."""
@@ -160,8 +161,9 @@ class BaseUIView(ContextMixin, View):
         * title: string to use as default page title and header
         """
         ctx = super().get_context_data(**kwargs)
+        ctx["theme"] = self.request.COOKIES.get("theme", None)
         ctx["base_template"] = self.get_base_template()
-        ctx["title"] = self.get_title()
+        ctx["place"] = self.get_place()
         ctx["scopes"] = Scope.objects.can_display(context.user).order_by("name")
         if context.workspace:
             ctx["other_workspaces"] = list(
@@ -179,10 +181,7 @@ class BaseUIView(ContextMixin, View):
                     context.user
                 ).order_by("name")
             )
-        try:
-            ctx["debusine_version"] = version("debusine")
-        except PackageNotFoundError:
-            pass
+        ctx["debusine_version"] = debusine_version()
         return ctx
 
     def _raise_workspace_not_found(
