@@ -11,7 +11,7 @@
 
 from collections.abc import Iterator
 from functools import cached_property
-from typing import Any, Generic, TYPE_CHECKING, TypeVar
+from typing import Any, TYPE_CHECKING
 
 from django.db.models import Model
 from django.template.context import Context
@@ -33,9 +33,6 @@ if TYPE_CHECKING:
     from debusine.web.views.table.table import Table
 
 
-M = TypeVar("M", bound=Model)
-
-
 class Column(Attribute):
     """A table column definition."""
 
@@ -89,7 +86,7 @@ class DateTimeColumn(Column):
     ordering_class: type[Ordering] = DateTimeOrdering
 
 
-class BoundColumn(Widget, Generic[M]):
+class BoundColumn[M: Model](Widget):
     """An instantiated table column."""
 
     def __init__(self, column: Column, table: "Table[Any]") -> None:
@@ -136,7 +133,7 @@ class BoundColumn(Widget, Generic[M]):
             return template.render(context)
 
 
-class Columns(Generic[M]):
+class Columns[M: Model]:
     """All columns for a table."""
 
     def __init__(self, table: "Table[M]"):
@@ -150,8 +147,12 @@ class Columns(Generic[M]):
         self.columns[name] = bc
         return bc
 
+    def __len__(self) -> int:
+        """Return the number of columns."""
+        return len(self.columns)
+
     def __getitem__(self, name: str) -> BoundColumn[M]:
-        """Get a filter by name."""
+        """Get a column by name."""
         return self.columns[name]
 
     def __iter__(self) -> Iterator[BoundColumn[M]]:
