@@ -10,7 +10,7 @@
 """Pagination support widgets."""
 
 from functools import cached_property
-from typing import Generic, TYPE_CHECKING, TypeVar
+from typing import Any, TYPE_CHECKING
 
 from django.core import paginator as django_paginator
 from django.core.exceptions import ImproperlyConfigured
@@ -46,10 +46,7 @@ else:
     PageBase = _PageBase
 
 
-M = TypeVar("M", bound=Model)
-
-
-class TableHead(Widget, Generic[M]):
+class TableHead[M: Model](Widget):
     """Render a standard table header."""
 
     template_name = "web/_table_header.html"
@@ -66,7 +63,7 @@ class TableHead(Widget, Generic[M]):
             return template.render(context)
 
 
-class TableFoot(Widget, Generic[M]):
+class TableFoot[M: Model](Widget):
     """Render a standard table footer."""
 
     template_name = "web/_table_footer.html"
@@ -85,7 +82,7 @@ class TableFoot(Widget, Generic[M]):
             return template.render(context)
 
 
-class Paginator(Widget, PaginatorBase[M], Generic[M]):
+class Paginator[M: Model](Widget, PaginatorBase[M]):
     """Pagination handling via widgets."""
 
     def __init__(
@@ -153,6 +150,10 @@ class Paginator(Widget, PaginatorBase[M], Generic[M]):
         """Return a standard <tfoot> widget."""
         return TableFoot(self)
 
+    def get_context_data(self) -> dict[str, Any]:
+        """Return additional context data to use when rendering."""
+        return {"paginator": self, "table": self.table}
+
     def render(self, context: Context) -> str:
         """Render as a widget if template_name is set."""
         if self.table.template_name is None:
@@ -164,5 +165,5 @@ class Paginator(Widget, PaginatorBase[M], Generic[M]):
         template = context.template.engine.get_template(
             self.table.template_name
         )
-        with context.update({"paginator": self, "table": self.table}):
+        with context.update(self.get_context_data()):
             return template.render(context)
