@@ -11,6 +11,7 @@
 
 from typing import Any, cast
 from unittest import mock
+from urllib.parse import urlencode
 
 from django.core.exceptions import ImproperlyConfigured
 from django.db.models import F
@@ -359,6 +360,7 @@ class TableOrderingsTests(TestCase):
         if order is not None:
             data[f"{prefix}order"] = order
         table.request = RequestFactory().get("/", data=data)
+        table.make_link = lambda **kwargs: urlencode(kwargs)
         return TableOrderings(table)
 
     def test_init(self) -> None:
@@ -490,8 +492,8 @@ class TableOrderingsTests(TestCase):
         orderings = self._orderings(
             default_order="username", order="username.desc"
         )
-        uasc, udesc = orderings.add("username", Ordering("username"))
-        easc, edesc = orderings.add("email", Ordering("username"))
+        orderings.add("username", Ordering("username"))
+        orderings.add("email", Ordering("username"))
         orderings.finalize()
         entries = orderings.what_menu_entries
 
@@ -507,7 +509,7 @@ class TableOrderingsTests(TestCase):
         orderings = self._orderings(
             default_order="username", order="email.desc"
         )
-        uasc, udesc = orderings.add("username", Ordering("username"))
+        orderings.add("username", Ordering("username"))
         easc, edesc = orderings.add("email", Ordering("username"))
         orderings.finalize()
         entries = orderings.how_menu_entries
