@@ -15,7 +15,7 @@ from urllib.parse import urlencode
 from django.core.exceptions import ImproperlyConfigured
 from django.test import RequestFactory
 
-from debusine.db.models import User
+from debusine.db.models import User, Workspace
 from debusine.test.django import TestCase
 from debusine.web.views.table import Column, FilterText, Ordering, Table
 from debusine.web.views.tests.utils import ViewTestMixin
@@ -35,6 +35,7 @@ class TableTestCase(ViewTestMixin, TestCase, abc.ABC):
         table_class: type[Table[User]] | None = None,
         qstring: dict[str, str] | None = None,
         preview: bool = False,
+        fragment: str | None = None,
     ) -> Table[User]:
         """Instantiate a table."""
         url = "/"
@@ -50,6 +51,7 @@ class TableTestCase(ViewTestMixin, TestCase, abc.ABC):
             prefix=prefix,
             default_order=default_order,
             preview=preview,
+            fragment=fragment,
         )
 
 
@@ -266,3 +268,40 @@ class TableTests(TableTestCase):
 
         table = self._table(table_class=_Table, preview=True)
         self.assertEqual(list(table.filters.options.keys()), [])
+
+    def test_make_link(self) -> None:
+        table = self._table()
+        for kwargs, expected in (
+            ({}, ""),
+            ({"test": 1}, "test=1"),
+        ):
+            with self.subTest(kwargs=kwargs):
+                self.assertEqual(table.make_link(**kwargs), expected)
+
+    def test_make_link_fragment(self) -> None:
+        table = self._table(fragment="foo")
+        for kwargs, expected in (
+            ({}, "#foo"),
+            ({"test": 1}, "test=1#foo"),
+        ):
+            with self.subTest(kwargs=kwargs):
+                self.assertEqual(table.make_link(**kwargs), expected)
+
+    def test_related_fields(self) -> None:
+        class _Table(Table[Workspace]):
+            workspace = Column("Workspace", ordering="name")
+            default_order = "workspace"
+            related_fields = ("scope",)
+
+        for i in range(3):
+            self.playground.create_workspace(name=f"test-{i}")
+        table = _Table(
+            request=RequestFactory().get("/"),
+            object_list=Workspace.objects.all(),
+        )
+        expected_workspaces = list(Workspace.objects.order_by("name"))
+        with self.assertNumQueries(1):
+            rows = table.rows
+            self.assertQuerySetEqual(rows, expected_workspaces)
+        with self.assertNumQueries(0):
+            [row.scope.id for row in rows]
