@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Unit tests for QA work request plugin."""
+
 from typing import ClassVar
 
 from debusine.db.models import WorkRequest
@@ -51,7 +52,8 @@ class QAViewWorkRequestPluginTests(TestCase):
         self.assertFalse(plugin.is_enabled())
 
     def test_is_enabled_requires_regression_analysis(self) -> None:
-        assert (od := self.scenario.workflow_qa.output_data) is not None
+        od = self.scenario.workflow_qa.output_data
+        assert od is not None
         od.regression_analysis = None
         self.scenario.workflow_qa.output_data = od
         self.scenario.workflow_qa.save()
@@ -59,8 +61,10 @@ class QAViewWorkRequestPluginTests(TestCase):
         self.assertFalse(plugin.is_enabled())
 
     def test_is_enabled_requires_regression_analysis_summary(self) -> None:
-        assert (od := self.scenario.workflow_qa.output_data) is not None
-        assert (ra := od.regression_analysis) is not None
+        od = self.scenario.workflow_qa.output_data
+        assert od is not None
+        ra = od.regression_analysis
+        assert ra is not None
         del ra[""]
         self.scenario.workflow_qa.output_data = od
         self.scenario.workflow_qa.save()
@@ -68,8 +72,10 @@ class QAViewWorkRequestPluginTests(TestCase):
         self.assertFalse(plugin.is_enabled())
 
     def test_get_context_data_only_summary(self) -> None:
-        assert (od := self.scenario.workflow_qa.output_data) is not None
-        assert (ra := od.regression_analysis) is not None
+        od = self.scenario.workflow_qa.output_data
+        assert od is not None
+        ra = od.regression_analysis
+        assert ra is not None
         ctx = self.get_tab().get_context_data()
         self.assertEqual(ctx["summary"], ra[""])
         self.assertEqual(ctx["orig"], self.scenario.reference_source)
@@ -79,8 +85,10 @@ class QAViewWorkRequestPluginTests(TestCase):
 
     def test_get_context_data_rows(self) -> None:
         self.scenario.simulate_autopkgtest()
-        assert (od := self.scenario.workflow_qa.output_data) is not None
-        assert (ra := od.regression_analysis) is not None
+        od = self.scenario.workflow_qa.output_data
+        assert od is not None
+        ra = od.regression_analysis
+        assert ra is not None
         ctx = self.get_tab().get_context_data()
         self.assertEqual(ctx["summary"], ra[""])
         self.assertEqual(ctx["orig"], self.scenario.reference_source)
@@ -106,8 +114,10 @@ class QAViewWorkRequestPluginTests(TestCase):
 
     def test_get_context_data_rows_hide_boring_revdep(self) -> None:
         self.scenario.simulate_rev_dep_autopkgtest()
-        assert (od := self.scenario.workflow_qa.output_data) is not None
-        assert (ra := od.regression_analysis) is not None
+        od = self.scenario.workflow_qa.output_data
+        assert od is not None
+        ra = od.regression_analysis
+        assert ra is not None
         ctx = self.get_tab().get_context_data()
         self.assertEqual(ctx["summary"], ra[""])
         self.assertEqual(ctx["orig"], self.scenario.reference_source)
@@ -128,8 +138,10 @@ class QAViewWorkRequestPluginTests(TestCase):
 
     def test_get_context_data_missing_artifacts(self) -> None:
         self.scenario.simulate_autopkgtest()
-        assert (od := self.scenario.workflow_qa.output_data) is not None
-        assert (ra := od.regression_analysis) is not None
+        od = self.scenario.workflow_qa.output_data
+        assert od is not None
+        ra = od.regression_analysis
+        assert ra is not None
         ra[""].original_artifact_id = None
         ra[""].new_artifact_id = None
         self.scenario.workflow_qa.output_data = od
@@ -148,8 +160,10 @@ class QAViewWorkRequestPluginTests(TestCase):
 
     def test_render(self) -> None:
         self.scenario.simulate_autopkgtest()
-        assert (od := self.scenario.workflow_qa.output_data) is not None
-        assert (ra := od.regression_analysis) is not None
+        od = self.scenario.workflow_qa.output_data
+        assert od is not None
+        ra = od.regression_analysis
+        assert ra is not None
         response = self.client.get(self.scenario.workflow_qa.get_absolute_url())
         tree = self.assertResponseHTML(response, dump_on_error=True)
         tab = self.assertHasElement(tree, "//div[@id='nav-qa']")
