@@ -9,16 +9,27 @@
 
 """Test tables."""
 
-from typing import Any, ClassVar
+from typing import Any, ClassVar, override
 
+import lxml
 from django.test import RequestFactory
 
 from debusine.artifacts.models import TaskTypes
-from debusine.db.models import WorkRequest, Worker, WorkerPool, WorkflowTemplate
+from debusine.db.context import context
+from debusine.db.models import (
+    Group,
+    WorkRequest,
+    Worker,
+    WorkerPool,
+    WorkflowTemplate,
+)
+from debusine.db.models.auth import GroupMembership
 from debusine.db.playground import scenarios
 from debusine.test.django import TestCase
 from debusine.web.views.tables import (
     FilterFailedWorkRequests,
+    GroupMembershipAdminTable,
+    GroupMembershipTable,
     WorkRequestTable,
     WorkerPoolTable,
     WorkerTable,
@@ -26,6 +37,102 @@ from debusine.web.views.tables import (
 )
 
 
+class GroupMembershipTableTests(TestCase):
+    """Tests for :py:class:`GroupMembershipTable`."""
+
+    scenario = scenarios.DefaultContext(set_current=True)
+
+    @override
+    def setUp(self) -> None:
+        super().setUp()
+        self.request = RequestFactory().get("/")
+
+    def assertUserTableRow(
+        self, table: GroupMembershipTable
+    ) -> lxml.objectify.ObjectifiedElement:
+        tree = self.assertHTMLValid(
+            self.render_string(
+                "{% load debusine %}{% widget test %}",
+                test=table.get_paginator(per_page=10),
+                request=self.request,
+                user=context.user,
+            )
+        )
+        row = self.assertHasElement(tree, "*/table/tbody/tr")
+
+        self.assertTextContentEqual(
+            row.td[0], f"{self.scenario.user.username} (you)"
+        )
+
+        self.assertTextContentEqual(
+            row.td[1], self.scenario.user.get_full_name()
+        )
+
+        return row
+
+    def test_group_without_workspace(self) -> None:
+        group = self.playground.create_group("Admins", [self.scenario.user])
+        table = GroupMembershipTable(
+            self.request, GroupMembership.objects.filter(group=group)
+        )
+        row = self.assertUserTableRow(table)
+        role = row.td[2]
+        self.assertFalse(role.xpath("a"))
+        self.assertTextContentEqual(role, Group.Roles.MEMBER)
+        self.assertEqual(len(row.td), 3)
+
+    def test_admin_group_without_workspace(self) -> None:
+        group = self.playground.create_group("Admins", [self.scenario.user])
+        gm = group.set_user_role(self.scenario.user, Group.Roles.ADMIN)
+        table = GroupMembershipAdminTable(
+            self.request, GroupMembership.objects.filter(group=group)
+        )
+        row = self.assertUserTableRow(table)
+
+        role = row.td[2]
+        a = self.assertHasElement(role, "a")
+        self.assertEqual(a.get("href"), gm.get_absolute_url_update())
+        self.assertTextContentEqual(a, Group.Roles.ADMIN)
+
+        actions = row.td[3]
+        a = self.assertHasElement(actions, "a")
+        self.assertEqual(a.get("href"), gm.get_absolute_url_remove())
+        self.assertTextContentEqual(a, "Remove")
+
+    def test_group_with_workspace(self) -> None:
+        group = self.playground.create_group(
+            "Admins", [self.scenario.user], workspace=self.scenario.workspace
+        )
+        table = GroupMembershipTable(
+            self.request, GroupMembership.objects.filter(group=group)
+        )
+        row = self.assertUserTableRow(table)
+        role = row.td[2]
+        self.assertFalse(role.xpath("a"))
+        self.assertTextContentEqual(role, Group.Roles.MEMBER)
+        self.assertEqual(len(row.td), 3)
+
+    def test_admin_group_with_workspace(self) -> None:
+        group = self.playground.create_group(
+            "Admins", [self.scenario.user], workspace=self.scenario.workspace
+        )
+        gm = group.set_user_role(self.scenario.user, Group.Roles.ADMIN)
+        table = GroupMembershipAdminTable(
+            self.request, GroupMembership.objects.filter(group=group)
+        )
+        row = self.assertUserTableRow(table)
+
+        role = row.td[2]
+        a = self.assertHasElement(role, "a")
+        self.assertEqual(a.get("href"), gm.get_absolute_url_update())
+        self.assertTextContentEqual(a, Group.Roles.ADMIN)
+
+        actions = row.td[3]
+        a = self.assertHasElement(actions, "a")
+        self.assertEqual(a.get("href"), gm.get_absolute_url_remove())
+        self.assertTextContentEqual(a, "Remove")
+
+
 class WorkerTableTests(TestCase):
     """Tests for :py:class:`WorkerTable`."""
 
