@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Tests for the views."""
+
 from typing import Any
 from unittest import mock
 
@@ -70,7 +71,7 @@ class HomepageViewTests(ViewTestMixin, TestCase):
         self.assertTextContentEqual(h1, "Welcome to Debusine!")
 
         title = self.assertHasElement(tree, "//title")
-        self.assertTextContentEqual(title, "Debusine - Welcome to Debusine!")
+        self.assertTextContentEqual(title, "Main page")
 
         self.assertNavCommonElements(tree)
         self.assertNavNoUser(tree)
@@ -203,8 +204,7 @@ class HomepageViewTests(ViewTestMixin, TestCase):
         for i in range(5):
             workflow = self.playground.create_workflow(template)
             workflow.mark_running()
-        # with self.assertNumQueries(14): # if there are no workflows to display
-        with self.assertNumQueries(22):
+        with self.assertNumQueries(14):
             response = self.client.get(reverse("homepage:homepage"))
         self.assertEqual(
             len(response.context["workflows_current"].page_obj.object_list),
@@ -222,12 +222,12 @@ class HomepageViewTests(ViewTestMixin, TestCase):
             template.write_text(
                 "{% extends 'web/homepage.html' %}"
                 "{% block pagetitle %}"
-                "<h1>Welcome to a custom Debusine</h1>"
+                "<h1 class='jumbo'>Welcome to a custom Debusine</h1>"
                 "{% endblock %}"
             )
             response = self.client.get(reverse("homepage:homepage"))
             tree = self.assertResponseHTML(response)
-            h1 = self.assertHasElement(tree, "//h1")
+            h1 = self.assertHasElement(tree, "//h1[@class='jumbo']")
             self.assertTextContentEqual(h1, "Welcome to a custom Debusine")
 
     def test_only_root_workflows_shown(self) -> None:
