@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Tests for the work request views."""
+
 import copy
 import datetime as dt
 import json
@@ -772,7 +773,7 @@ class WorkRequestDetailViewTests(ViewTestMixin, TestCase):
         # that this doesn't make a query for each child work request.
         # Django >= 5.2 makes an extra two queries to put a savepoint around
         # constraint checks.
-        with self.assertNumQueries(34 if django.VERSION >= (5, 2) else 32):
+        with self.assertNumQueries(32 if django.VERSION >= (5, 2) else 30):
             response = self.client.get(child.get_absolute_url())
         self.assertResponseHTML(response)
 
@@ -1269,12 +1270,12 @@ class WorkRequestDetailViewTests(ViewTestMixin, TestCase):
         response = self.client.get(wr.get_absolute_url())
         tree = self.assertResponseHTML(response)
         el = self.assertHasElement(tree, "//div[@id='validation-error']")
-        self.assertTextContentEqual(
-            el,
-            "{'task_data': ['invalid Worker task data: 1 validation error"
-            " for NoopData\\ninvalid\\n  extra fields not permitted"
-            " (type=value_error.extra)']}",
-            dump_on_error=True,
+        message = self.get_node_text_normalized(el)
+        self.assertRegex(
+            message,
+            r"{'task_data': \['invalid Worker task data: 1 validation error"
+            r" for NoopData\\ninvalid\\n Extra inputs are not permitted"
+            r" \[type=extra_forbidden.*']}",
         )
 
 
@@ -1680,21 +1681,21 @@ class WorkRequestCreateViewTests(ViewTestMixin, TestCase):
 
     def test_create_work_request_invalid_task_data(self) -> None:
         """Test form invalid due to some_method raising a ValidationError."""
-        source_artifact, _ = self.playground.create_artifact()
+        source_artifact = self.playground.create_source_artifact()
 
         self.client.force_login(self.scenario.user)
         workspace = self.scenario.workspace
         name = "sbuild"
 
         task_data_yaml = textwrap.dedent(
-            """
+            f"""
             build_architecture: amd64
             build_components:
             - any
             - all
             environment: does-not-exist/match:codename=trixie:variant=sbuild
             input:
-                source_artifact: 536
+                source_artifact: {source_artifact.id}
             """
         )
 
