@@ -11,7 +11,7 @@
 
 from collections.abc import Generator
 from contextlib import contextmanager
-from typing import Any, Generic, Self, TypeVar, cast
+from typing import Any, Self, cast
 
 from django.db.models import Model
 from django.http import HttpRequest
@@ -19,8 +19,6 @@ from django.http import HttpRequest
 from debusine.db.context import context
 from debusine.utils import extract_generic_type_arguments
 
-M = TypeVar("M", bound=Model)
-
 REQUEST_CACHE_NAME = "_debusine_ui_helpers"
 
 #: Registry of helper classes indexed by model class
@@ -32,7 +30,7 @@ def model_name(m: type[Model] | Model) -> str:
     return m._meta.label_lower
 
 
-class UI(Generic[M]):
+class UI[M: Model]:
     """
     Per-model UI helpers.
 
