@@ -46,7 +46,7 @@ class UIShortcut(Widget):
     #: Target URL for the action
     url: str
 
-    def render(self, context: BaseContext) -> str:  # noqa: U100
+    def render(self, context: BaseContext) -> str:  # noqa: ARG002, U100
         """Render the shortcut as an <a> button."""
         return format_html(
             "<a class='btn btn-outline-secondary'"
