@@ -28,7 +28,7 @@ class WorkersListView(BaseUIView, TableMixin[Worker], ListViewBase[Worker]):
     """List workers."""
 
     model = Worker
-    base_template = "web/_base_unscoped.html"
+    base_template = "web/_base_debusine.html"
     template_name = "web/worker-list.html"
     title = "List of workers"
     table_class = WorkerTable
@@ -53,7 +53,7 @@ class WorkerDetailView(BaseUIView, DetailViewBase[Worker]):
     """Show details about a worker."""
 
     model = Worker
-    base_template = "web/_base_unscoped.html"
+    base_template = "web/_base_debusine.html"
     template_name = "web/worker-detail.html"
     context_object_name = "worker"
 
