@@ -15,6 +15,7 @@ import logging
 import sys
 from collections.abc import Sequence
 
+from debusine.utils import debusine_version
 from debusine.worker import Worker
 from debusine.worker.config import ConfigHandler
 
@@ -29,6 +30,11 @@ def main(argv: Sequence[str]) -> None:
         f'the files config.ini and token in the '
         f'directories {config_paths})',
     )
+    parser.add_argument(
+        "--version",
+        action="version",
+        version=f"%(prog)s {debusine_version() or 'uninstalled-version'}",
+    )
     parser.add_argument(
         '--log-file',
         type=str,
