@@ -41,27 +41,24 @@ Objects documentation
 ---------------------
 
 """
+
 import asyncio
 import functools
 import logging
 import secrets
 import signal
 import socket
-import time
+import time as tm
 from concurrent.futures import Future, ThreadPoolExecutor
 from pathlib import Path
+from textwrap import dedent
 from threading import Lock
 from typing import Any, Literal, NoReturn, assert_never
 
 import aiohttp
-from aiohttp.web_exceptions import HTTPCreated, HTTPNoContent, HTTPOk
-
-try:
-    from pydantic.v1 import ValidationError
-except ImportError:
-    from pydantic import ValidationError  # type: ignore
-
 import tenacity
+from aiohttp.web_exceptions import HTTPCreated, HTTPNoContent, HTTPOk
+from pydantic import ValidationError
 
 from debusine.artifacts.models import RuntimeStatistics, TaskTypes
 from debusine.client.debusine import Debusine
@@ -79,7 +76,7 @@ from debusine.worker.config import ConfigHandler
 from debusine.worker.debusine_async_http_client import DebusineAsyncHttpClient
 from debusine.worker.system_information import (
     cpu_time,
-    host_architecture,
+    native_architecture,
     system_metadata,
 )
 
@@ -170,6 +167,9 @@ class Worker:
         # Set to True if the retry_attempt_number should be reset
         self._reset_retry_attempt_number: bool = False
 
+        # Set to True to stop the main loop from looping
+        self._shutting_down: bool = False
+
     def _create_client(self, scope: str | None = None) -> Debusine:
         return Debusine(
             self._config.api_url,
@@ -240,6 +240,7 @@ class Worker:
 
     async def close(self) -> None:
         """Close the AioHTTP session."""
+        self._shutting_down = True
         if self._aiohttp_client_session is not None:
             await self._aiohttp_client_session.close()
 
@@ -350,8 +351,9 @@ class Worker:
                     async for msg in ws:  # pragma: no branch
                         await self._process_message(msg, client)
 
-                    # The server disconnected the worker
-                    self._raise_try_again()
+                    if not self._shutting_down:
+                        # The server disconnected the worker
+                        self._raise_try_again()
 
             except TokenDisabledError as exc:
                 # The server disconnected the worker because the token is
@@ -437,11 +439,13 @@ class Worker:
          and it logs the reason.
         """
 
-        def connected(msg_content: dict[Any, Any]) -> None:  # noqa: U100
+        def connected(
+            msg_content: dict[Any, Any],  # noqa: ARG001, U100
+        ) -> None:
             logging.info("Connected to %s", self._config.api_url)
 
         async def work_request_available(
-            msg_content: dict[Any, Any],  # noqa: U100
+            msg_content: dict[Any, Any],  # noqa: ARG001, U100
         ) -> None:
             await self._request_and_execute_work_request()
 
@@ -471,7 +475,7 @@ class Worker:
             )
             if work_request.status == HTTPOk.status_code:
                 try:
-                    work_request_obj = WorkRequestResponse.parse_raw(
+                    work_request_obj = WorkRequestResponse.model_validate_json(
                         await work_request.text()
                     )
                 except ValidationError as exc:
@@ -490,7 +494,8 @@ class Worker:
         return await inner()
 
     async def _send_dynamic_metadata(
-        self, msg_content: dict[Any, Any]  # noqa: U100
+        self,
+        msg_content: dict[Any, Any],  # noqa: ARG002, U100
     ) -> None:
         dynamic_metadata_path = '/1.0/worker/dynamic-metadata/'
 
@@ -581,7 +586,7 @@ class Worker:
         self._task_statistics_poller = asyncio.create_task(
             self._poll_statistics()
         )
-        self._task_start_time = time.monotonic()
+        self._task_start_time = tm.monotonic()
         self._task_start_cpu_time = cpu_time()
 
     async def _execute_work_request_and_submit_result(
@@ -670,7 +675,7 @@ class Worker:
         self._task_running.configure_server_access(client)
         self._task_running.work_request_id = work_request.id
         self._task_running.workspace_name = work_request.workspace
-        self._task_running.worker_host_architecture = host_architecture()
+        self._task_running.worker_native_architecture = native_architecture()
         self._initialize_statistics()
 
         self._task_name = self._task_running.name
@@ -738,7 +743,7 @@ class Worker:
             self._task_statistics_poller.cancel()
 
             self._task_statistics.duration = int(
-                time.monotonic() - self._task_start_time
+                tm.monotonic() - self._task_start_time
             )
             self._task_statistics.cpu_time = int(
                 cpu_time() - self._task_start_cpu_time
@@ -791,9 +796,29 @@ class Worker:
         if not hook_dir.exists() or not any(hook_dir.iterdir()):
             logging.debug("No hooks in %r, skipping execution", str(hook_dir))
             return
-        p = await asyncio.create_subprocess_exec("run-parts", str(hook_dir))
-        if await p.wait() != 0:
-            logging.warning("Hooks failed to execute in %r", str(hook_dir))
+
+        p = await asyncio.create_subprocess_exec(
+            "run-parts",
+            str(hook_dir),
+            stdout=asyncio.subprocess.PIPE,
+            stderr=asyncio.subprocess.PIPE,
+        )
+        stdout, stderr = await p.communicate()
+        if p.returncode != 0:
+            logging.warning(
+                dedent(
+                    """\
+                    Hooks failed to execute in %r .
+                    stdout:
+                    %s
+                    stderr:
+                    %s
+                    """
+                ).rstrip("\n"),
+                str(hook_dir),
+                stdout.decode("utf-8", errors="replace"),
+                stderr.decode("utf-8", errors="replace"),
+            )
 
     @staticmethod
     def log_forced_exit(signum: signal.Signals) -> None:
